import * as cdk from "../../core";
import * as constructs from "constructs";
import * as cfn_parse from "../../core/lib/helpers-internal";
/**
 * Creates an analysis in Amazon QuickSight.
 *
 * @cloudformationResource AWS::QuickSight::Analysis
 * @stability external
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html
 */
export declare class CfnAnalysis extends cdk.CfnResource implements cdk.IInspectable, cdk.ITaggable {
    /**
     * The CloudFormation resource type name for this resource class.
     */
    static readonly CFN_RESOURCE_TYPE_NAME: string;
    /**
     * Build a CfnAnalysis from CloudFormation properties
     *
     * A factory method that creates a new instance of this class from an object
     * containing the CloudFormation properties of this resource.
     * Used in the @aws-cdk/cloudformation-include module.
     *
     * @internal
     */
    static _fromCloudFormation(scope: constructs.Construct, id: string, resourceAttributes: any, options: cfn_parse.FromCloudFormationOptions): CfnAnalysis;
    /**
     * The Amazon Resource Name (ARN) of the analysis.
     *
     * @cloudformationAttribute Arn
     */
    readonly attrArn: string;
    /**
     * The time that the analysis was created.
     *
     * @cloudformationAttribute CreatedTime
     */
    readonly attrCreatedTime: string;
    /**
     * The ARNs of the datasets of the analysis.
     *
     * @cloudformationAttribute DataSetArns
     */
    readonly attrDataSetArns: Array<string>;
    /**
     * @cloudformationAttribute Errors
     */
    readonly attrErrors: cdk.IResolvable;
    /**
     * The time that the analysis was last updated.
     *
     * @cloudformationAttribute LastUpdatedTime
     */
    readonly attrLastUpdatedTime: string;
    /**
     * @cloudformationAttribute Sheets
     */
    readonly attrSheets: cdk.IResolvable;
    /**
     * The ID for the analysis that you're creating.
     */
    analysisId: string;
    /**
     * The ID of the AWS account where you are creating an analysis.
     */
    awsAccountId: string;
    definition?: CfnAnalysis.AnalysisDefinitionProperty | cdk.IResolvable;
    /**
     * Errors associated with the analysis.
     */
    errors?: Array<CfnAnalysis.AnalysisErrorProperty | cdk.IResolvable> | cdk.IResolvable;
    /**
     * A descriptive name for the analysis that you're creating.
     */
    name: string;
    /**
     * The parameter names and override values that you want to use.
     */
    parameters?: cdk.IResolvable | CfnAnalysis.ParametersProperty;
    /**
     * A structure that describes the principals and the resource-level permissions on an analysis.
     */
    permissions?: Array<cdk.IResolvable | CfnAnalysis.ResourcePermissionProperty> | cdk.IResolvable;
    /**
     * A list of the associated sheets with the unique identifier and name of each sheet.
     */
    sheets?: Array<cdk.IResolvable | CfnAnalysis.SheetProperty> | cdk.IResolvable;
    /**
     * A source entity to use for the analysis that you're creating.
     */
    sourceEntity?: CfnAnalysis.AnalysisSourceEntityProperty | cdk.IResolvable;
    /**
     * Status associated with the analysis.
     */
    status?: string;
    /**
     * Tag Manager which manages the tags for this resource
     */
    readonly tags: cdk.TagManager;
    /**
     * Contains a map of the key-value pairs for the resource tag or tags assigned to the analysis.
     */
    tagsRaw?: Array<cdk.CfnTag>;
    /**
     * The ARN for the theme to apply to the analysis that you're creating.
     */
    themeArn?: string;
    /**
     * The option to relax the validation that is required to create and update analyses, dashboards, and templates with definition objects.
     */
    validationStrategy?: cdk.IResolvable | CfnAnalysis.ValidationStrategyProperty;
    /**
     * @param scope Scope in which this resource is defined
     * @param id Construct identifier for this resource (unique in its scope)
     * @param props Resource properties
     */
    constructor(scope: constructs.Construct, id: string, props: CfnAnalysisProps);
    protected get cfnProperties(): Record<string, any>;
    /**
     * Examines the CloudFormation resource and discloses attributes
     *
     * @param inspector tree inspector to collect and process attributes
     */
    inspect(inspector: cdk.TreeInspector): void;
    protected renderProperties(props: Record<string, any>): Record<string, any>;
}
export declare namespace CfnAnalysis {
    /**
     * A list of Amazon QuickSight parameters and the list's override values.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameters.html
     */
    interface ParametersProperty {
        /**
         * The parameters that have a data type of date-time.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameters.html#cfn-quicksight-analysis-parameters-datetimeparameters
         */
        readonly dateTimeParameters?: Array<CfnAnalysis.DateTimeParameterProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The parameters that have a data type of decimal.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameters.html#cfn-quicksight-analysis-parameters-decimalparameters
         */
        readonly decimalParameters?: Array<CfnAnalysis.DecimalParameterProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The parameters that have a data type of integer.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameters.html#cfn-quicksight-analysis-parameters-integerparameters
         */
        readonly integerParameters?: Array<CfnAnalysis.IntegerParameterProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The parameters that have a data type of string.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameters.html#cfn-quicksight-analysis-parameters-stringparameters
         */
        readonly stringParameters?: Array<cdk.IResolvable | CfnAnalysis.StringParameterProperty> | cdk.IResolvable;
    }
    /**
     * A string parameter.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringparameter.html
     */
    interface StringParameterProperty {
        /**
         * A display name for a string parameter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringparameter.html#cfn-quicksight-analysis-stringparameter-name
         */
        readonly name: string;
        /**
         * The values of a string parameter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringparameter.html#cfn-quicksight-analysis-stringparameter-values
         */
        readonly values: Array<string>;
    }
    /**
     * A decimal parameter.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimalparameter.html
     */
    interface DecimalParameterProperty {
        /**
         * A display name for the decimal parameter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimalparameter.html#cfn-quicksight-analysis-decimalparameter-name
         */
        readonly name: string;
        /**
         * The values for the decimal parameter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimalparameter.html#cfn-quicksight-analysis-decimalparameter-values
         */
        readonly values: Array<number> | cdk.IResolvable;
    }
    /**
     * An integer parameter.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integerparameter.html
     */
    interface IntegerParameterProperty {
        /**
         * The name of the integer parameter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integerparameter.html#cfn-quicksight-analysis-integerparameter-name
         */
        readonly name: string;
        /**
         * The values for the integer parameter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integerparameter.html#cfn-quicksight-analysis-integerparameter-values
         */
        readonly values: Array<number> | cdk.IResolvable;
    }
    /**
     * A date-time parameter.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimeparameter.html
     */
    interface DateTimeParameterProperty {
        /**
         * A display name for the date-time parameter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimeparameter.html#cfn-quicksight-analysis-datetimeparameter-name
         */
        readonly name: string;
        /**
         * The values for the date-time parameter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimeparameter.html#cfn-quicksight-analysis-datetimeparameter-values
         */
        readonly values: Array<string>;
    }
    /**
     * The source entity of an analysis.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysissourceentity.html
     */
    interface AnalysisSourceEntityProperty {
        /**
         * The source template for the source entity of the analysis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysissourceentity.html#cfn-quicksight-analysis-analysissourceentity-sourcetemplate
         */
        readonly sourceTemplate?: CfnAnalysis.AnalysisSourceTemplateProperty | cdk.IResolvable;
    }
    /**
     * The source template of an analysis.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysissourcetemplate.html
     */
    interface AnalysisSourceTemplateProperty {
        /**
         * The Amazon Resource Name (ARN) of the source template of an analysis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysissourcetemplate.html#cfn-quicksight-analysis-analysissourcetemplate-arn
         */
        readonly arn: string;
        /**
         * The dataset references of the source template of an analysis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysissourcetemplate.html#cfn-quicksight-analysis-analysissourcetemplate-datasetreferences
         */
        readonly dataSetReferences: Array<CfnAnalysis.DataSetReferenceProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * Dataset reference.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datasetreference.html
     */
    interface DataSetReferenceProperty {
        /**
         * Dataset Amazon Resource Name (ARN).
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datasetreference.html#cfn-quicksight-analysis-datasetreference-datasetarn
         */
        readonly dataSetArn: string;
        /**
         * Dataset placeholder.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datasetreference.html#cfn-quicksight-analysis-datasetreference-datasetplaceholder
         */
        readonly dataSetPlaceholder: string;
    }
    /**
     * The definition of an analysis.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysisdefinition.html
     */
    interface AnalysisDefinitionProperty {
        /**
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysisdefinition.html#cfn-quicksight-analysis-analysisdefinition-analysisdefaults
         */
        readonly analysisDefaults?: CfnAnalysis.AnalysisDefaultsProperty | cdk.IResolvable;
        /**
         * An array of calculated field definitions for the analysis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysisdefinition.html#cfn-quicksight-analysis-analysisdefinition-calculatedfields
         */
        readonly calculatedFields?: Array<CfnAnalysis.CalculatedFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * An array of analysis-level column configurations.
         *
         * Column configurations can be used to set default formatting for a column to be used throughout an analysis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysisdefinition.html#cfn-quicksight-analysis-analysisdefinition-columnconfigurations
         */
        readonly columnConfigurations?: Array<CfnAnalysis.ColumnConfigurationProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * An array of dataset identifier declarations.
         *
         * This mapping allows the usage of dataset identifiers instead of dataset ARNs throughout analysis sub-structures.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysisdefinition.html#cfn-quicksight-analysis-analysisdefinition-datasetidentifierdeclarations
         */
        readonly dataSetIdentifierDeclarations: Array<CfnAnalysis.DataSetIdentifierDeclarationProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * Filter definitions for an analysis.
         *
         * For more information, see [Filtering Data in Amazon QuickSight](https://docs.aws.amazon.com/quicksight/latest/user/adding-a-filter.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysisdefinition.html#cfn-quicksight-analysis-analysisdefinition-filtergroups
         */
        readonly filterGroups?: Array<CfnAnalysis.FilterGroupProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * An array of option definitions for an analysis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysisdefinition.html#cfn-quicksight-analysis-analysisdefinition-options
         */
        readonly options?: CfnAnalysis.AssetOptionsProperty | cdk.IResolvable;
        /**
         * An array of parameter declarations for an analysis.
         *
         * Parameters are named variables that can transfer a value for use by an action or an object.
         *
         * For more information, see [Parameters in Amazon QuickSight](https://docs.aws.amazon.com/quicksight/latest/user/parameters-in-quicksight.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysisdefinition.html#cfn-quicksight-analysis-analysisdefinition-parameterdeclarations
         */
        readonly parameterDeclarations?: Array<cdk.IResolvable | CfnAnalysis.ParameterDeclarationProperty> | cdk.IResolvable;
        /**
         * An array of sheet definitions for an analysis.
         *
         * Each `SheetDefinition` provides detailed information about a sheet within this analysis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysisdefinition.html#cfn-quicksight-analysis-analysisdefinition-sheets
         */
        readonly sheets?: Array<cdk.IResolvable | CfnAnalysis.SheetDefinitionProperty> | cdk.IResolvable;
    }
    /**
     * A grouping of individual filters. Filter groups are applied to the same group of visuals.
     *
     * For more information, see [Adding filter conditions (group filters) with AND and OR operators](https://docs.aws.amazon.com/quicksight/latest/user/add-a-compound-filter.html) in the *Amazon QuickSight User Guide* .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtergroup.html
     */
    interface FilterGroupProperty {
        /**
         * The filter new feature which can apply filter group to all data sets. Choose one of the following options:.
         *
         * - `ALL_DATASETS`
         * - `SINGLE_DATASET`
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtergroup.html#cfn-quicksight-analysis-filtergroup-crossdataset
         */
        readonly crossDataset: string;
        /**
         * The value that uniquely identifies a `FilterGroup` within a dashboard, template, or analysis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtergroup.html#cfn-quicksight-analysis-filtergroup-filtergroupid
         */
        readonly filterGroupId: string;
        /**
         * The list of filters that are present in a `FilterGroup` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtergroup.html#cfn-quicksight-analysis-filtergroup-filters
         */
        readonly filters: Array<CfnAnalysis.FilterProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The configuration that specifies what scope to apply to a `FilterGroup` .
         *
         * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtergroup.html#cfn-quicksight-analysis-filtergroup-scopeconfiguration
         */
        readonly scopeConfiguration: CfnAnalysis.FilterScopeConfigurationProperty | cdk.IResolvable;
        /**
         * The status of the `FilterGroup` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtergroup.html#cfn-quicksight-analysis-filtergroup-status
         */
        readonly status?: string;
    }
    /**
     * With a `Filter` , you can remove portions of data from a particular visual or view.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filter.html
     */
    interface FilterProperty {
        /**
         * A `CategoryFilter` filters text values.
         *
         * For more information, see [Adding text filters](https://docs.aws.amazon.com/quicksight/latest/user/add-a-text-filter-data-prep.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filter.html#cfn-quicksight-analysis-filter-categoryfilter
         */
        readonly categoryFilter?: CfnAnalysis.CategoryFilterProperty | cdk.IResolvable;
        /**
         * A `NumericEqualityFilter` filters numeric values that equal or do not equal a given numeric value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filter.html#cfn-quicksight-analysis-filter-numericequalityfilter
         */
        readonly numericEqualityFilter?: cdk.IResolvable | CfnAnalysis.NumericEqualityFilterProperty;
        /**
         * A `NumericRangeFilter` filters numeric values that are either inside or outside a given numeric range.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filter.html#cfn-quicksight-analysis-filter-numericrangefilter
         */
        readonly numericRangeFilter?: cdk.IResolvable | CfnAnalysis.NumericRangeFilterProperty;
        /**
         * A `RelativeDatesFilter` filters date values that are relative to a given date.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filter.html#cfn-quicksight-analysis-filter-relativedatesfilter
         */
        readonly relativeDatesFilter?: cdk.IResolvable | CfnAnalysis.RelativeDatesFilterProperty;
        /**
         * A `TimeEqualityFilter` filters date-time values that equal or do not equal a given date/time value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filter.html#cfn-quicksight-analysis-filter-timeequalityfilter
         */
        readonly timeEqualityFilter?: cdk.IResolvable | CfnAnalysis.TimeEqualityFilterProperty;
        /**
         * A `TimeRangeFilter` filters date-time values that are either inside or outside a given date/time range.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filter.html#cfn-quicksight-analysis-filter-timerangefilter
         */
        readonly timeRangeFilter?: cdk.IResolvable | CfnAnalysis.TimeRangeFilterProperty;
        /**
         * A `TopBottomFilter` filters data to the top or bottom values for a given column.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filter.html#cfn-quicksight-analysis-filter-topbottomfilter
         */
        readonly topBottomFilter?: cdk.IResolvable | CfnAnalysis.TopBottomFilterProperty;
    }
    /**
     * A `NumericEqualityFilter` filters values that are equal to the specified value.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericequalityfilter.html
     */
    interface NumericEqualityFilterProperty {
        /**
         * The aggregation function of the filter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericequalityfilter.html#cfn-quicksight-analysis-numericequalityfilter-aggregationfunction
         */
        readonly aggregationFunction?: CfnAnalysis.AggregationFunctionProperty | cdk.IResolvable;
        /**
         * The column that the filter is applied to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericequalityfilter.html#cfn-quicksight-analysis-numericequalityfilter-column
         */
        readonly column: CfnAnalysis.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericequalityfilter.html#cfn-quicksight-analysis-numericequalityfilter-filterid
         */
        readonly filterId: string;
        /**
         * The match operator that is used to determine if a filter should be applied.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericequalityfilter.html#cfn-quicksight-analysis-numericequalityfilter-matchoperator
         */
        readonly matchOperator: string;
        /**
         * This option determines how null values should be treated when filtering data.
         *
         * - `ALL_VALUES` : Include null values in filtered results.
         * - `NULLS_ONLY` : Only include null values in filtered results.
         * - `NON_NULLS_ONLY` : Exclude null values from filtered results.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericequalityfilter.html#cfn-quicksight-analysis-numericequalityfilter-nulloption
         */
        readonly nullOption: string;
        /**
         * The parameter whose value should be used for the filter value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericequalityfilter.html#cfn-quicksight-analysis-numericequalityfilter-parametername
         */
        readonly parameterName?: string;
        /**
         * Select all of the values. Null is not the assigned value of select all.
         *
         * - `FILTER_ALL_VALUES`
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericequalityfilter.html#cfn-quicksight-analysis-numericequalityfilter-selectalloptions
         */
        readonly selectAllOptions?: string;
        /**
         * The input value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericequalityfilter.html#cfn-quicksight-analysis-numericequalityfilter-value
         */
        readonly value?: number;
    }
    /**
     * An aggregation function aggregates values from a dimension or measure.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-aggregationfunction.html
     */
    interface AggregationFunctionProperty {
        /**
         * Aggregation for attributes.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-aggregationfunction.html#cfn-quicksight-analysis-aggregationfunction-attributeaggregationfunction
         */
        readonly attributeAggregationFunction?: CfnAnalysis.AttributeAggregationFunctionProperty | cdk.IResolvable;
        /**
         * Aggregation for categorical values.
         *
         * - `COUNT` : Aggregate by the total number of values, including duplicates.
         * - `DISTINCT_COUNT` : Aggregate by the total number of distinct values.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-aggregationfunction.html#cfn-quicksight-analysis-aggregationfunction-categoricalaggregationfunction
         */
        readonly categoricalAggregationFunction?: string;
        /**
         * Aggregation for date values.
         *
         * - `COUNT` : Aggregate by the total number of values, including duplicates.
         * - `DISTINCT_COUNT` : Aggregate by the total number of distinct values.
         * - `MIN` : Select the smallest date value.
         * - `MAX` : Select the largest date value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-aggregationfunction.html#cfn-quicksight-analysis-aggregationfunction-dateaggregationfunction
         */
        readonly dateAggregationFunction?: string;
        /**
         * Aggregation for numerical values.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-aggregationfunction.html#cfn-quicksight-analysis-aggregationfunction-numericalaggregationfunction
         */
        readonly numericalAggregationFunction?: cdk.IResolvable | CfnAnalysis.NumericalAggregationFunctionProperty;
    }
    /**
     * Aggregation for attributes.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-attributeaggregationfunction.html
     */
    interface AttributeAggregationFunctionProperty {
        /**
         * The built-in aggregation functions for attributes.
         *
         * - `UNIQUE_VALUE` : Returns the unique value for a field, aggregated by the dimension fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-attributeaggregationfunction.html#cfn-quicksight-analysis-attributeaggregationfunction-simpleattributeaggregation
         */
        readonly simpleAttributeAggregation?: string;
        /**
         * Used by the `UNIQUE_VALUE` aggregation function.
         *
         * If there are multiple values for the field used by the aggregation, the value for this property will be returned instead. Defaults to '*'.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-attributeaggregationfunction.html#cfn-quicksight-analysis-attributeaggregationfunction-valueformultiplevalues
         */
        readonly valueForMultipleValues?: string;
    }
    /**
     * Aggregation for numerical values.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericalaggregationfunction.html
     */
    interface NumericalAggregationFunctionProperty {
        /**
         * An aggregation based on the percentile of values in a dimension or measure.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericalaggregationfunction.html#cfn-quicksight-analysis-numericalaggregationfunction-percentileaggregation
         */
        readonly percentileAggregation?: cdk.IResolvable | CfnAnalysis.PercentileAggregationProperty;
        /**
         * Built-in aggregation functions for numerical values.
         *
         * - `SUM` : The sum of a dimension or measure.
         * - `AVERAGE` : The average of a dimension or measure.
         * - `MIN` : The minimum value of a dimension or measure.
         * - `MAX` : The maximum value of a dimension or measure.
         * - `COUNT` : The count of a dimension or measure.
         * - `DISTINCT_COUNT` : The count of distinct values in a dimension or measure.
         * - `VAR` : The variance of a dimension or measure.
         * - `VARP` : The partitioned variance of a dimension or measure.
         * - `STDEV` : The standard deviation of a dimension or measure.
         * - `STDEVP` : The partitioned standard deviation of a dimension or measure.
         * - `MEDIAN` : The median value of a dimension or measure.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericalaggregationfunction.html#cfn-quicksight-analysis-numericalaggregationfunction-simplenumericalaggregation
         */
        readonly simpleNumericalAggregation?: string;
    }
    /**
     * An aggregation based on the percentile of values in a dimension or measure.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-percentileaggregation.html
     */
    interface PercentileAggregationProperty {
        /**
         * The percentile value.
         *
         * This value can be any numeric constant 0–100. A percentile value of 50 computes the median value of the measure.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-percentileaggregation.html#cfn-quicksight-analysis-percentileaggregation-percentilevalue
         */
        readonly percentileValue?: number;
    }
    /**
     * A column of a data set.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnidentifier.html
     */
    interface ColumnIdentifierProperty {
        /**
         * The name of the column.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnidentifier.html#cfn-quicksight-analysis-columnidentifier-columnname
         */
        readonly columnName: string;
        /**
         * The data set that the column belongs to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnidentifier.html#cfn-quicksight-analysis-columnidentifier-datasetidentifier
         */
        readonly dataSetIdentifier: string;
    }
    /**
     * A `NumericRangeFilter` filters values that are within the value range.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericrangefilter.html
     */
    interface NumericRangeFilterProperty {
        /**
         * The aggregation function of the filter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericrangefilter.html#cfn-quicksight-analysis-numericrangefilter-aggregationfunction
         */
        readonly aggregationFunction?: CfnAnalysis.AggregationFunctionProperty | cdk.IResolvable;
        /**
         * The column that the filter is applied to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericrangefilter.html#cfn-quicksight-analysis-numericrangefilter-column
         */
        readonly column: CfnAnalysis.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericrangefilter.html#cfn-quicksight-analysis-numericrangefilter-filterid
         */
        readonly filterId: string;
        /**
         * Determines whether the maximum value in the filter value range should be included in the filtered results.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericrangefilter.html#cfn-quicksight-analysis-numericrangefilter-includemaximum
         */
        readonly includeMaximum?: boolean | cdk.IResolvable;
        /**
         * Determines whether the minimum value in the filter value range should be included in the filtered results.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericrangefilter.html#cfn-quicksight-analysis-numericrangefilter-includeminimum
         */
        readonly includeMinimum?: boolean | cdk.IResolvable;
        /**
         * This option determines how null values should be treated when filtering data.
         *
         * - `ALL_VALUES` : Include null values in filtered results.
         * - `NULLS_ONLY` : Only include null values in filtered results.
         * - `NON_NULLS_ONLY` : Exclude null values from filtered results.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericrangefilter.html#cfn-quicksight-analysis-numericrangefilter-nulloption
         */
        readonly nullOption: string;
        /**
         * The maximum value for the filter value range.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericrangefilter.html#cfn-quicksight-analysis-numericrangefilter-rangemaximum
         */
        readonly rangeMaximum?: cdk.IResolvable | CfnAnalysis.NumericRangeFilterValueProperty;
        /**
         * The minimum value for the filter value range.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericrangefilter.html#cfn-quicksight-analysis-numericrangefilter-rangeminimum
         */
        readonly rangeMinimum?: cdk.IResolvable | CfnAnalysis.NumericRangeFilterValueProperty;
        /**
         * Select all of the values. Null is not the assigned value of select all.
         *
         * - `FILTER_ALL_VALUES`
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericrangefilter.html#cfn-quicksight-analysis-numericrangefilter-selectalloptions
         */
        readonly selectAllOptions?: string;
    }
    /**
     * The value input pf the numeric range filter.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericrangefiltervalue.html
     */
    interface NumericRangeFilterValueProperty {
        /**
         * The parameter that is used in the numeric range.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericrangefiltervalue.html#cfn-quicksight-analysis-numericrangefiltervalue-parameter
         */
        readonly parameter?: string;
        /**
         * The static value of the numeric range filter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericrangefiltervalue.html#cfn-quicksight-analysis-numericrangefiltervalue-staticvalue
         */
        readonly staticValue?: number;
    }
    /**
     * A `TimeRangeFilter` filters values that are between two specified values.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangefilter.html
     */
    interface TimeRangeFilterProperty {
        /**
         * The column that the filter is applied to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangefilter.html#cfn-quicksight-analysis-timerangefilter-column
         */
        readonly column: CfnAnalysis.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * The exclude period of the time range filter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangefilter.html#cfn-quicksight-analysis-timerangefilter-excludeperiodconfiguration
         */
        readonly excludePeriodConfiguration?: CfnAnalysis.ExcludePeriodConfigurationProperty | cdk.IResolvable;
        /**
         * An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangefilter.html#cfn-quicksight-analysis-timerangefilter-filterid
         */
        readonly filterId: string;
        /**
         * Determines whether the maximum value in the filter value range should be included in the filtered results.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangefilter.html#cfn-quicksight-analysis-timerangefilter-includemaximum
         */
        readonly includeMaximum?: boolean | cdk.IResolvable;
        /**
         * Determines whether the minimum value in the filter value range should be included in the filtered results.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangefilter.html#cfn-quicksight-analysis-timerangefilter-includeminimum
         */
        readonly includeMinimum?: boolean | cdk.IResolvable;
        /**
         * This option determines how null values should be treated when filtering data.
         *
         * - `ALL_VALUES` : Include null values in filtered results.
         * - `NULLS_ONLY` : Only include null values in filtered results.
         * - `NON_NULLS_ONLY` : Exclude null values from filtered results.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangefilter.html#cfn-quicksight-analysis-timerangefilter-nulloption
         */
        readonly nullOption: string;
        /**
         * The maximum value for the filter value range.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangefilter.html#cfn-quicksight-analysis-timerangefilter-rangemaximumvalue
         */
        readonly rangeMaximumValue?: cdk.IResolvable | CfnAnalysis.TimeRangeFilterValueProperty;
        /**
         * The minimum value for the filter value range.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangefilter.html#cfn-quicksight-analysis-timerangefilter-rangeminimumvalue
         */
        readonly rangeMinimumValue?: cdk.IResolvable | CfnAnalysis.TimeRangeFilterValueProperty;
        /**
         * The level of time precision that is used to aggregate `DateTime` values.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangefilter.html#cfn-quicksight-analysis-timerangefilter-timegranularity
         */
        readonly timeGranularity?: string;
    }
    /**
     * The value of a time range filter.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangefiltervalue.html
     */
    interface TimeRangeFilterValueProperty {
        /**
         * The parameter type input value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangefiltervalue.html#cfn-quicksight-analysis-timerangefiltervalue-parameter
         */
        readonly parameter?: string;
        /**
         * The rolling date input value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangefiltervalue.html#cfn-quicksight-analysis-timerangefiltervalue-rollingdate
         */
        readonly rollingDate?: cdk.IResolvable | CfnAnalysis.RollingDateConfigurationProperty;
        /**
         * The static input value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangefiltervalue.html#cfn-quicksight-analysis-timerangefiltervalue-staticvalue
         */
        readonly staticValue?: string;
    }
    /**
     * The rolling date configuration of a date time filter.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-rollingdateconfiguration.html
     */
    interface RollingDateConfigurationProperty {
        /**
         * The data set that is used in the rolling date configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-rollingdateconfiguration.html#cfn-quicksight-analysis-rollingdateconfiguration-datasetidentifier
         */
        readonly dataSetIdentifier?: string;
        /**
         * The expression of the rolling date configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-rollingdateconfiguration.html#cfn-quicksight-analysis-rollingdateconfiguration-expression
         */
        readonly expression: string;
    }
    /**
     * The exclude period of `TimeRangeFilter` or `RelativeDatesFilter` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-excludeperiodconfiguration.html
     */
    interface ExcludePeriodConfigurationProperty {
        /**
         * The amount or number of the exclude period.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-excludeperiodconfiguration.html#cfn-quicksight-analysis-excludeperiodconfiguration-amount
         */
        readonly amount: number;
        /**
         * The granularity or unit (day, month, year) of the exclude period.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-excludeperiodconfiguration.html#cfn-quicksight-analysis-excludeperiodconfiguration-granularity
         */
        readonly granularity: string;
        /**
         * The status of the exclude period. Choose from the following options:.
         *
         * - `ENABLED`
         * - `DISABLED`
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-excludeperiodconfiguration.html#cfn-quicksight-analysis-excludeperiodconfiguration-status
         */
        readonly status?: string;
    }
    /**
     * A `RelativeDatesFilter` filters relative dates values.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-relativedatesfilter.html
     */
    interface RelativeDatesFilterProperty {
        /**
         * The date configuration of the filter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-relativedatesfilter.html#cfn-quicksight-analysis-relativedatesfilter-anchordateconfiguration
         */
        readonly anchorDateConfiguration: CfnAnalysis.AnchorDateConfigurationProperty | cdk.IResolvable;
        /**
         * The column that the filter is applied to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-relativedatesfilter.html#cfn-quicksight-analysis-relativedatesfilter-column
         */
        readonly column: CfnAnalysis.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * The configuration for the exclude period of the filter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-relativedatesfilter.html#cfn-quicksight-analysis-relativedatesfilter-excludeperiodconfiguration
         */
        readonly excludePeriodConfiguration?: CfnAnalysis.ExcludePeriodConfigurationProperty | cdk.IResolvable;
        /**
         * An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-relativedatesfilter.html#cfn-quicksight-analysis-relativedatesfilter-filterid
         */
        readonly filterId: string;
        /**
         * The minimum granularity (period granularity) of the relative dates filter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-relativedatesfilter.html#cfn-quicksight-analysis-relativedatesfilter-minimumgranularity
         */
        readonly minimumGranularity?: string;
        /**
         * This option determines how null values should be treated when filtering data.
         *
         * - `ALL_VALUES` : Include null values in filtered results.
         * - `NULLS_ONLY` : Only include null values in filtered results.
         * - `NON_NULLS_ONLY` : Exclude null values from filtered results.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-relativedatesfilter.html#cfn-quicksight-analysis-relativedatesfilter-nulloption
         */
        readonly nullOption: string;
        /**
         * The parameter whose value should be used for the filter value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-relativedatesfilter.html#cfn-quicksight-analysis-relativedatesfilter-parametername
         */
        readonly parameterName?: string;
        /**
         * The range date type of the filter. Choose one of the options below:.
         *
         * - `PREVIOUS`
         * - `THIS`
         * - `LAST`
         * - `NOW`
         * - `NEXT`
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-relativedatesfilter.html#cfn-quicksight-analysis-relativedatesfilter-relativedatetype
         */
        readonly relativeDateType: string;
        /**
         * The date value of the filter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-relativedatesfilter.html#cfn-quicksight-analysis-relativedatesfilter-relativedatevalue
         */
        readonly relativeDateValue?: number;
        /**
         * The level of time precision that is used to aggregate `DateTime` values.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-relativedatesfilter.html#cfn-quicksight-analysis-relativedatesfilter-timegranularity
         */
        readonly timeGranularity: string;
    }
    /**
     * The date configuration of the filter.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-anchordateconfiguration.html
     */
    interface AnchorDateConfigurationProperty {
        /**
         * The options for the date configuration. Choose one of the options below:.
         *
         * - `NOW`
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-anchordateconfiguration.html#cfn-quicksight-analysis-anchordateconfiguration-anchoroption
         */
        readonly anchorOption?: string;
        /**
         * The name of the parameter that is used for the anchor date configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-anchordateconfiguration.html#cfn-quicksight-analysis-anchordateconfiguration-parametername
         */
        readonly parameterName?: string;
    }
    /**
     * A `TopBottomFilter` filters values that are at the top or the bottom.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottomfilter.html
     */
    interface TopBottomFilterProperty {
        /**
         * The aggregation and sort configuration of the top bottom filter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottomfilter.html#cfn-quicksight-analysis-topbottomfilter-aggregationsortconfigurations
         */
        readonly aggregationSortConfigurations: Array<CfnAnalysis.AggregationSortConfigurationProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The column that the filter is applied to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottomfilter.html#cfn-quicksight-analysis-topbottomfilter-column
         */
        readonly column: CfnAnalysis.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottomfilter.html#cfn-quicksight-analysis-topbottomfilter-filterid
         */
        readonly filterId: string;
        /**
         * The number of items to include in the top bottom filter results.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottomfilter.html#cfn-quicksight-analysis-topbottomfilter-limit
         */
        readonly limit?: number;
        /**
         * The parameter whose value should be used for the filter value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottomfilter.html#cfn-quicksight-analysis-topbottomfilter-parametername
         */
        readonly parameterName?: string;
        /**
         * The level of time precision that is used to aggregate `DateTime` values.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottomfilter.html#cfn-quicksight-analysis-topbottomfilter-timegranularity
         */
        readonly timeGranularity?: string;
    }
    /**
     * The configuration options to sort aggregated values.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-aggregationsortconfiguration.html
     */
    interface AggregationSortConfigurationProperty {
        /**
         * The function that aggregates the values in `Column` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-aggregationsortconfiguration.html#cfn-quicksight-analysis-aggregationsortconfiguration-aggregationfunction
         */
        readonly aggregationFunction?: CfnAnalysis.AggregationFunctionProperty | cdk.IResolvable;
        /**
         * The column that determines the sort order of aggregated values.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-aggregationsortconfiguration.html#cfn-quicksight-analysis-aggregationsortconfiguration-column
         */
        readonly column: CfnAnalysis.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * The sort direction of values.
         *
         * - `ASC` : Sort in ascending order.
         * - `DESC` : Sort in descending order.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-aggregationsortconfiguration.html#cfn-quicksight-analysis-aggregationsortconfiguration-sortdirection
         */
        readonly sortDirection: string;
    }
    /**
     * A `TimeEqualityFilter` filters values that are equal to a given value.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timeequalityfilter.html
     */
    interface TimeEqualityFilterProperty {
        /**
         * The column that the filter is applied to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timeequalityfilter.html#cfn-quicksight-analysis-timeequalityfilter-column
         */
        readonly column: CfnAnalysis.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timeequalityfilter.html#cfn-quicksight-analysis-timeequalityfilter-filterid
         */
        readonly filterId: string;
        /**
         * The parameter whose value should be used for the filter value.
         *
         * This field is mutually exclusive to `Value` and `RollingDate` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timeequalityfilter.html#cfn-quicksight-analysis-timeequalityfilter-parametername
         */
        readonly parameterName?: string;
        /**
         * The rolling date input for the `TimeEquality` filter.
         *
         * This field is mutually exclusive to `Value` and `ParameterName` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timeequalityfilter.html#cfn-quicksight-analysis-timeequalityfilter-rollingdate
         */
        readonly rollingDate?: cdk.IResolvable | CfnAnalysis.RollingDateConfigurationProperty;
        /**
         * The level of time precision that is used to aggregate `DateTime` values.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timeequalityfilter.html#cfn-quicksight-analysis-timeequalityfilter-timegranularity
         */
        readonly timeGranularity?: string;
        /**
         * The value of a `TimeEquality` filter.
         *
         * This field is mutually exclusive to `RollingDate` and `ParameterName` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timeequalityfilter.html#cfn-quicksight-analysis-timeequalityfilter-value
         */
        readonly value?: string;
    }
    /**
     * A `CategoryFilter` filters text values.
     *
     * For more information, see [Adding text filters](https://docs.aws.amazon.com/quicksight/latest/user/add-a-text-filter-data-prep.html) in the *Amazon QuickSight User Guide* .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoryfilter.html
     */
    interface CategoryFilterProperty {
        /**
         * The column that the filter is applied to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoryfilter.html#cfn-quicksight-analysis-categoryfilter-column
         */
        readonly column: CfnAnalysis.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * The configuration for a `CategoryFilter` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoryfilter.html#cfn-quicksight-analysis-categoryfilter-configuration
         */
        readonly configuration: CfnAnalysis.CategoryFilterConfigurationProperty | cdk.IResolvable;
        /**
         * An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoryfilter.html#cfn-quicksight-analysis-categoryfilter-filterid
         */
        readonly filterId: string;
    }
    /**
     * The configuration for a `CategoryFilter` .
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoryfilterconfiguration.html
     */
    interface CategoryFilterConfigurationProperty {
        /**
         * A custom filter that filters based on a single value.
         *
         * This filter can be partially matched.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoryfilterconfiguration.html#cfn-quicksight-analysis-categoryfilterconfiguration-customfilterconfiguration
         */
        readonly customFilterConfiguration?: CfnAnalysis.CustomFilterConfigurationProperty | cdk.IResolvable;
        /**
         * A list of custom filter values.
         *
         * In the Amazon QuickSight console, this filter type is called a custom filter list.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoryfilterconfiguration.html#cfn-quicksight-analysis-categoryfilterconfiguration-customfilterlistconfiguration
         */
        readonly customFilterListConfiguration?: CfnAnalysis.CustomFilterListConfigurationProperty | cdk.IResolvable;
        /**
         * A list of filter configurations.
         *
         * In the Amazon QuickSight console, this filter type is called a filter list.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoryfilterconfiguration.html#cfn-quicksight-analysis-categoryfilterconfiguration-filterlistconfiguration
         */
        readonly filterListConfiguration?: CfnAnalysis.FilterListConfigurationProperty | cdk.IResolvable;
    }
    /**
     * A list of custom filter values.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customfilterlistconfiguration.html
     */
    interface CustomFilterListConfigurationProperty {
        /**
         * The list of category values for the filter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customfilterlistconfiguration.html#cfn-quicksight-analysis-customfilterlistconfiguration-categoryvalues
         */
        readonly categoryValues?: Array<string>;
        /**
         * The match operator that is used to determine if a filter should be applied.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customfilterlistconfiguration.html#cfn-quicksight-analysis-customfilterlistconfiguration-matchoperator
         */
        readonly matchOperator: string;
        /**
         * This option determines how null values should be treated when filtering data.
         *
         * - `ALL_VALUES` : Include null values in filtered results.
         * - `NULLS_ONLY` : Only include null values in filtered results.
         * - `NON_NULLS_ONLY` : Exclude null values from filtered results.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customfilterlistconfiguration.html#cfn-quicksight-analysis-customfilterlistconfiguration-nulloption
         */
        readonly nullOption: string;
        /**
         * Select all of the values. Null is not the assigned value of select all.
         *
         * - `FILTER_ALL_VALUES`
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customfilterlistconfiguration.html#cfn-quicksight-analysis-customfilterlistconfiguration-selectalloptions
         */
        readonly selectAllOptions?: string;
    }
    /**
     * A custom filter that filters based on a single value.
     *
     * This filter can be partially matched.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customfilterconfiguration.html
     */
    interface CustomFilterConfigurationProperty {
        /**
         * The category value for the filter.
         *
         * This field is mutually exclusive to `ParameterName` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customfilterconfiguration.html#cfn-quicksight-analysis-customfilterconfiguration-categoryvalue
         */
        readonly categoryValue?: string;
        /**
         * The match operator that is used to determine if a filter should be applied.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customfilterconfiguration.html#cfn-quicksight-analysis-customfilterconfiguration-matchoperator
         */
        readonly matchOperator: string;
        /**
         * This option determines how null values should be treated when filtering data.
         *
         * - `ALL_VALUES` : Include null values in filtered results.
         * - `NULLS_ONLY` : Only include null values in filtered results.
         * - `NON_NULLS_ONLY` : Exclude null values from filtered results.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customfilterconfiguration.html#cfn-quicksight-analysis-customfilterconfiguration-nulloption
         */
        readonly nullOption: string;
        /**
         * The parameter whose value should be used for the filter value.
         *
         * This field is mutually exclusive to `CategoryValue` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customfilterconfiguration.html#cfn-quicksight-analysis-customfilterconfiguration-parametername
         */
        readonly parameterName?: string;
        /**
         * Select all of the values. Null is not the assigned value of select all.
         *
         * - `FILTER_ALL_VALUES`
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customfilterconfiguration.html#cfn-quicksight-analysis-customfilterconfiguration-selectalloptions
         */
        readonly selectAllOptions?: string;
    }
    /**
     * A list of filter configurations.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterlistconfiguration.html
     */
    interface FilterListConfigurationProperty {
        /**
         * The list of category values for the filter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterlistconfiguration.html#cfn-quicksight-analysis-filterlistconfiguration-categoryvalues
         */
        readonly categoryValues?: Array<string>;
        /**
         * The match operator that is used to determine if a filter should be applied.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterlistconfiguration.html#cfn-quicksight-analysis-filterlistconfiguration-matchoperator
         */
        readonly matchOperator: string;
        /**
         * This option determines how null values should be treated when filtering data.
         *
         * - `ALL_VALUES` : Include null values in filtered results.
         * - `NULLS_ONLY` : Only include null values in filtered results.
         * - `NON_NULLS_ONLY` : Exclude null values from filtered results.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterlistconfiguration.html#cfn-quicksight-analysis-filterlistconfiguration-nulloption
         */
        readonly nullOption?: string;
        /**
         * Select all of the values. Null is not the assigned value of select all.
         *
         * - `FILTER_ALL_VALUES`
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterlistconfiguration.html#cfn-quicksight-analysis-filterlistconfiguration-selectalloptions
         */
        readonly selectAllOptions?: string;
    }
    /**
     * The scope configuration for a `FilterGroup` .
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterscopeconfiguration.html
     */
    interface FilterScopeConfigurationProperty {
        /**
         * The configuration for applying a filter to all sheets.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterscopeconfiguration.html#cfn-quicksight-analysis-filterscopeconfiguration-allsheets
         */
        readonly allSheets?: any | cdk.IResolvable;
        /**
         * The configuration for applying a filter to specific sheets.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterscopeconfiguration.html#cfn-quicksight-analysis-filterscopeconfiguration-selectedsheets
         */
        readonly selectedSheets?: cdk.IResolvable | CfnAnalysis.SelectedSheetsFilterScopeConfigurationProperty;
    }
    /**
     * The configuration for applying a filter to specific sheets or visuals.
     *
     * You can apply this filter to multiple visuals that are on one sheet or to all visuals on a sheet.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-selectedsheetsfilterscopeconfiguration.html
     */
    interface SelectedSheetsFilterScopeConfigurationProperty {
        /**
         * The sheet ID and visual IDs of the sheet and visuals that the filter is applied to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-selectedsheetsfilterscopeconfiguration.html#cfn-quicksight-analysis-selectedsheetsfilterscopeconfiguration-sheetvisualscopingconfigurations
         */
        readonly sheetVisualScopingConfigurations?: Array<cdk.IResolvable | CfnAnalysis.SheetVisualScopingConfigurationProperty> | cdk.IResolvable;
    }
    /**
     * The filter that is applied to the options.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetvisualscopingconfiguration.html
     */
    interface SheetVisualScopingConfigurationProperty {
        /**
         * The scope of the applied entities. Choose one of the following options:.
         *
         * - `ALL_VISUALS`
         * - `SELECTED_VISUALS`
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetvisualscopingconfiguration.html#cfn-quicksight-analysis-sheetvisualscopingconfiguration-scope
         */
        readonly scope: string;
        /**
         * The selected sheet that the filter is applied to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetvisualscopingconfiguration.html#cfn-quicksight-analysis-sheetvisualscopingconfiguration-sheetid
         */
        readonly sheetId: string;
        /**
         * The selected visuals that the filter is applied to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetvisualscopingconfiguration.html#cfn-quicksight-analysis-sheetvisualscopingconfiguration-visualids
         */
        readonly visualIds?: Array<string>;
    }
    /**
     * The calculated field of an analysis.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-calculatedfield.html
     */
    interface CalculatedFieldProperty {
        /**
         * The data set that is used in this calculated field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-calculatedfield.html#cfn-quicksight-analysis-calculatedfield-datasetidentifier
         */
        readonly dataSetIdentifier: string;
        /**
         * The expression of the calculated field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-calculatedfield.html#cfn-quicksight-analysis-calculatedfield-expression
         */
        readonly expression: string;
        /**
         * The name of the calculated field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-calculatedfield.html#cfn-quicksight-analysis-calculatedfield-name
         */
        readonly name: string;
    }
    /**
     * A data set.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datasetidentifierdeclaration.html
     */
    interface DataSetIdentifierDeclarationProperty {
        /**
         * The Amazon Resource Name (ARN) of the data set.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datasetidentifierdeclaration.html#cfn-quicksight-analysis-datasetidentifierdeclaration-datasetarn
         */
        readonly dataSetArn: string;
        /**
         * The identifier of the data set, typically the data set's name.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datasetidentifierdeclaration.html#cfn-quicksight-analysis-datasetidentifierdeclaration-identifier
         */
        readonly identifier: string;
    }
    /**
     * The general configuration of a column.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnconfiguration.html
     */
    interface ColumnConfigurationProperty {
        /**
         * The color configurations of the column.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnconfiguration.html#cfn-quicksight-analysis-columnconfiguration-colorsconfiguration
         */
        readonly colorsConfiguration?: CfnAnalysis.ColorsConfigurationProperty | cdk.IResolvable;
        /**
         * The column.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnconfiguration.html#cfn-quicksight-analysis-columnconfiguration-column
         */
        readonly column: CfnAnalysis.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * The format configuration of a column.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnconfiguration.html#cfn-quicksight-analysis-columnconfiguration-formatconfiguration
         */
        readonly formatConfiguration?: CfnAnalysis.FormatConfigurationProperty | cdk.IResolvable;
        /**
         * The role of the column.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnconfiguration.html#cfn-quicksight-analysis-columnconfiguration-role
         */
        readonly role?: string;
    }
    /**
     * The formatting configuration for all types of field.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-formatconfiguration.html
     */
    interface FormatConfigurationProperty {
        /**
         * Formatting configuration for `DateTime` fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-formatconfiguration.html#cfn-quicksight-analysis-formatconfiguration-datetimeformatconfiguration
         */
        readonly dateTimeFormatConfiguration?: CfnAnalysis.DateTimeFormatConfigurationProperty | cdk.IResolvable;
        /**
         * Formatting configuration for number fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-formatconfiguration.html#cfn-quicksight-analysis-formatconfiguration-numberformatconfiguration
         */
        readonly numberFormatConfiguration?: cdk.IResolvable | CfnAnalysis.NumberFormatConfigurationProperty;
        /**
         * Formatting configuration for string fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-formatconfiguration.html#cfn-quicksight-analysis-formatconfiguration-stringformatconfiguration
         */
        readonly stringFormatConfiguration?: cdk.IResolvable | CfnAnalysis.StringFormatConfigurationProperty;
    }
    /**
     * Formatting configuration for number fields.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numberformatconfiguration.html
     */
    interface NumberFormatConfigurationProperty {
        /**
         * The options that determine the numeric format configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numberformatconfiguration.html#cfn-quicksight-analysis-numberformatconfiguration-formatconfiguration
         */
        readonly formatConfiguration?: cdk.IResolvable | CfnAnalysis.NumericFormatConfigurationProperty;
    }
    /**
     * The options that determine the numeric format configuration.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericformatconfiguration.html
     */
    interface NumericFormatConfigurationProperty {
        /**
         * The options that determine the currency display format configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericformatconfiguration.html#cfn-quicksight-analysis-numericformatconfiguration-currencydisplayformatconfiguration
         */
        readonly currencyDisplayFormatConfiguration?: CfnAnalysis.CurrencyDisplayFormatConfigurationProperty | cdk.IResolvable;
        /**
         * The options that determine the number display format configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericformatconfiguration.html#cfn-quicksight-analysis-numericformatconfiguration-numberdisplayformatconfiguration
         */
        readonly numberDisplayFormatConfiguration?: cdk.IResolvable | CfnAnalysis.NumberDisplayFormatConfigurationProperty;
        /**
         * The options that determine the percentage display format configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericformatconfiguration.html#cfn-quicksight-analysis-numericformatconfiguration-percentagedisplayformatconfiguration
         */
        readonly percentageDisplayFormatConfiguration?: cdk.IResolvable | CfnAnalysis.PercentageDisplayFormatConfigurationProperty;
    }
    /**
     * The options that determine the number display format configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numberdisplayformatconfiguration.html
     */
    interface NumberDisplayFormatConfigurationProperty {
        /**
         * The option that determines the decimal places configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numberdisplayformatconfiguration.html#cfn-quicksight-analysis-numberdisplayformatconfiguration-decimalplacesconfiguration
         */
        readonly decimalPlacesConfiguration?: CfnAnalysis.DecimalPlacesConfigurationProperty | cdk.IResolvable;
        /**
         * The options that determine the negative value configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numberdisplayformatconfiguration.html#cfn-quicksight-analysis-numberdisplayformatconfiguration-negativevalueconfiguration
         */
        readonly negativeValueConfiguration?: cdk.IResolvable | CfnAnalysis.NegativeValueConfigurationProperty;
        /**
         * The options that determine the null value format configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numberdisplayformatconfiguration.html#cfn-quicksight-analysis-numberdisplayformatconfiguration-nullvalueformatconfiguration
         */
        readonly nullValueFormatConfiguration?: cdk.IResolvable | CfnAnalysis.NullValueFormatConfigurationProperty;
        /**
         * Determines the number scale value of the number format.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numberdisplayformatconfiguration.html#cfn-quicksight-analysis-numberdisplayformatconfiguration-numberscale
         */
        readonly numberScale?: string;
        /**
         * Determines the prefix value of the number format.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numberdisplayformatconfiguration.html#cfn-quicksight-analysis-numberdisplayformatconfiguration-prefix
         */
        readonly prefix?: string;
        /**
         * The options that determine the numeric separator configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numberdisplayformatconfiguration.html#cfn-quicksight-analysis-numberdisplayformatconfiguration-separatorconfiguration
         */
        readonly separatorConfiguration?: cdk.IResolvable | CfnAnalysis.NumericSeparatorConfigurationProperty;
        /**
         * Determines the suffix value of the number format.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numberdisplayformatconfiguration.html#cfn-quicksight-analysis-numberdisplayformatconfiguration-suffix
         */
        readonly suffix?: string;
    }
    /**
     * The options that determine the negative value configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-negativevalueconfiguration.html
     */
    interface NegativeValueConfigurationProperty {
        /**
         * Determines the display mode of the negative value configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-negativevalueconfiguration.html#cfn-quicksight-analysis-negativevalueconfiguration-displaymode
         */
        readonly displayMode: string;
    }
    /**
     * The option that determines the decimal places configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimalplacesconfiguration.html
     */
    interface DecimalPlacesConfigurationProperty {
        /**
         * The values of the decimal places.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimalplacesconfiguration.html#cfn-quicksight-analysis-decimalplacesconfiguration-decimalplaces
         */
        readonly decimalPlaces: number;
    }
    /**
     * The options that determine the null value format configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-nullvalueformatconfiguration.html
     */
    interface NullValueFormatConfigurationProperty {
        /**
         * Determines the null string of null values.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-nullvalueformatconfiguration.html#cfn-quicksight-analysis-nullvalueformatconfiguration-nullstring
         */
        readonly nullString: string;
    }
    /**
     * The options that determine the numeric separator configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericseparatorconfiguration.html
     */
    interface NumericSeparatorConfigurationProperty {
        /**
         * Determines the decimal separator.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericseparatorconfiguration.html#cfn-quicksight-analysis-numericseparatorconfiguration-decimalseparator
         */
        readonly decimalSeparator?: string;
        /**
         * The options that determine the thousands separator configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericseparatorconfiguration.html#cfn-quicksight-analysis-numericseparatorconfiguration-thousandsseparator
         */
        readonly thousandsSeparator?: cdk.IResolvable | CfnAnalysis.ThousandSeparatorOptionsProperty;
    }
    /**
     * The options that determine the thousands separator configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-thousandseparatoroptions.html
     */
    interface ThousandSeparatorOptionsProperty {
        /**
         * Determines the thousands separator symbol.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-thousandseparatoroptions.html#cfn-quicksight-analysis-thousandseparatoroptions-symbol
         */
        readonly symbol?: string;
        /**
         * Determines the visibility of the thousands separator.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-thousandseparatoroptions.html#cfn-quicksight-analysis-thousandseparatoroptions-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The options that determine the currency display format configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-currencydisplayformatconfiguration.html
     */
    interface CurrencyDisplayFormatConfigurationProperty {
        /**
         * The option that determines the decimal places configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-currencydisplayformatconfiguration.html#cfn-quicksight-analysis-currencydisplayformatconfiguration-decimalplacesconfiguration
         */
        readonly decimalPlacesConfiguration?: CfnAnalysis.DecimalPlacesConfigurationProperty | cdk.IResolvable;
        /**
         * The options that determine the negative value configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-currencydisplayformatconfiguration.html#cfn-quicksight-analysis-currencydisplayformatconfiguration-negativevalueconfiguration
         */
        readonly negativeValueConfiguration?: cdk.IResolvable | CfnAnalysis.NegativeValueConfigurationProperty;
        /**
         * The options that determine the null value format configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-currencydisplayformatconfiguration.html#cfn-quicksight-analysis-currencydisplayformatconfiguration-nullvalueformatconfiguration
         */
        readonly nullValueFormatConfiguration?: cdk.IResolvable | CfnAnalysis.NullValueFormatConfigurationProperty;
        /**
         * Determines the number scale value for the currency format.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-currencydisplayformatconfiguration.html#cfn-quicksight-analysis-currencydisplayformatconfiguration-numberscale
         */
        readonly numberScale?: string;
        /**
         * Determines the prefix value of the currency format.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-currencydisplayformatconfiguration.html#cfn-quicksight-analysis-currencydisplayformatconfiguration-prefix
         */
        readonly prefix?: string;
        /**
         * The options that determine the numeric separator configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-currencydisplayformatconfiguration.html#cfn-quicksight-analysis-currencydisplayformatconfiguration-separatorconfiguration
         */
        readonly separatorConfiguration?: cdk.IResolvable | CfnAnalysis.NumericSeparatorConfigurationProperty;
        /**
         * Determines the suffix value of the currency format.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-currencydisplayformatconfiguration.html#cfn-quicksight-analysis-currencydisplayformatconfiguration-suffix
         */
        readonly suffix?: string;
        /**
         * Determines the symbol for the currency format.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-currencydisplayformatconfiguration.html#cfn-quicksight-analysis-currencydisplayformatconfiguration-symbol
         */
        readonly symbol?: string;
    }
    /**
     * The options that determine the percentage display format configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-percentagedisplayformatconfiguration.html
     */
    interface PercentageDisplayFormatConfigurationProperty {
        /**
         * The option that determines the decimal places configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-percentagedisplayformatconfiguration.html#cfn-quicksight-analysis-percentagedisplayformatconfiguration-decimalplacesconfiguration
         */
        readonly decimalPlacesConfiguration?: CfnAnalysis.DecimalPlacesConfigurationProperty | cdk.IResolvable;
        /**
         * The options that determine the negative value configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-percentagedisplayformatconfiguration.html#cfn-quicksight-analysis-percentagedisplayformatconfiguration-negativevalueconfiguration
         */
        readonly negativeValueConfiguration?: cdk.IResolvable | CfnAnalysis.NegativeValueConfigurationProperty;
        /**
         * The options that determine the null value format configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-percentagedisplayformatconfiguration.html#cfn-quicksight-analysis-percentagedisplayformatconfiguration-nullvalueformatconfiguration
         */
        readonly nullValueFormatConfiguration?: cdk.IResolvable | CfnAnalysis.NullValueFormatConfigurationProperty;
        /**
         * Determines the prefix value of the percentage format.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-percentagedisplayformatconfiguration.html#cfn-quicksight-analysis-percentagedisplayformatconfiguration-prefix
         */
        readonly prefix?: string;
        /**
         * The options that determine the numeric separator configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-percentagedisplayformatconfiguration.html#cfn-quicksight-analysis-percentagedisplayformatconfiguration-separatorconfiguration
         */
        readonly separatorConfiguration?: cdk.IResolvable | CfnAnalysis.NumericSeparatorConfigurationProperty;
        /**
         * Determines the suffix value of the percentage format.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-percentagedisplayformatconfiguration.html#cfn-quicksight-analysis-percentagedisplayformatconfiguration-suffix
         */
        readonly suffix?: string;
    }
    /**
     * Formatting configuration for `DateTime` fields.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimeformatconfiguration.html
     */
    interface DateTimeFormatConfigurationProperty {
        /**
         * Determines the `DateTime` format.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimeformatconfiguration.html#cfn-quicksight-analysis-datetimeformatconfiguration-datetimeformat
         */
        readonly dateTimeFormat?: string;
        /**
         * The options that determine the null value format configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimeformatconfiguration.html#cfn-quicksight-analysis-datetimeformatconfiguration-nullvalueformatconfiguration
         */
        readonly nullValueFormatConfiguration?: cdk.IResolvable | CfnAnalysis.NullValueFormatConfigurationProperty;
        /**
         * The formatting configuration for numeric `DateTime` fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimeformatconfiguration.html#cfn-quicksight-analysis-datetimeformatconfiguration-numericformatconfiguration
         */
        readonly numericFormatConfiguration?: cdk.IResolvable | CfnAnalysis.NumericFormatConfigurationProperty;
    }
    /**
     * Formatting configuration for string fields.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringformatconfiguration.html
     */
    interface StringFormatConfigurationProperty {
        /**
         * The options that determine the null value format configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringformatconfiguration.html#cfn-quicksight-analysis-stringformatconfiguration-nullvalueformatconfiguration
         */
        readonly nullValueFormatConfiguration?: cdk.IResolvable | CfnAnalysis.NullValueFormatConfigurationProperty;
        /**
         * The formatting configuration for numeric strings.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringformatconfiguration.html#cfn-quicksight-analysis-stringformatconfiguration-numericformatconfiguration
         */
        readonly numericFormatConfiguration?: cdk.IResolvable | CfnAnalysis.NumericFormatConfigurationProperty;
    }
    /**
     * The color configurations for a column.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-colorsconfiguration.html
     */
    interface ColorsConfigurationProperty {
        /**
         * A list of up to 50 custom colors.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-colorsconfiguration.html#cfn-quicksight-analysis-colorsconfiguration-customcolors
         */
        readonly customColors?: Array<CfnAnalysis.CustomColorProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * Determines the color that's applied to a particular data value in a column.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcolor.html
     */
    interface CustomColorProperty {
        /**
         * The color that is applied to the data value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcolor.html#cfn-quicksight-analysis-customcolor-color
         */
        readonly color: string;
        /**
         * The data value that the color is applied to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcolor.html#cfn-quicksight-analysis-customcolor-fieldvalue
         */
        readonly fieldValue?: string;
        /**
         * The value of a special data value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcolor.html#cfn-quicksight-analysis-customcolor-specialvalue
         */
        readonly specialValue?: string;
    }
    /**
     * The configuration for default analysis settings.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysisdefaults.html
     */
    interface AnalysisDefaultsProperty {
        /**
         * The configuration for default new sheet settings.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysisdefaults.html#cfn-quicksight-analysis-analysisdefaults-defaultnewsheetconfiguration
         */
        readonly defaultNewSheetConfiguration: CfnAnalysis.DefaultNewSheetConfigurationProperty | cdk.IResolvable;
    }
    /**
     * The configuration for default new sheet settings.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultnewsheetconfiguration.html
     */
    interface DefaultNewSheetConfigurationProperty {
        /**
         * The options that determine the default settings for interactive layout configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultnewsheetconfiguration.html#cfn-quicksight-analysis-defaultnewsheetconfiguration-interactivelayoutconfiguration
         */
        readonly interactiveLayoutConfiguration?: CfnAnalysis.DefaultInteractiveLayoutConfigurationProperty | cdk.IResolvable;
        /**
         * The options that determine the default settings for a paginated layout configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultnewsheetconfiguration.html#cfn-quicksight-analysis-defaultnewsheetconfiguration-paginatedlayoutconfiguration
         */
        readonly paginatedLayoutConfiguration?: CfnAnalysis.DefaultPaginatedLayoutConfigurationProperty | cdk.IResolvable;
        /**
         * The option that determines the sheet content type.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultnewsheetconfiguration.html#cfn-quicksight-analysis-defaultnewsheetconfiguration-sheetcontenttype
         */
        readonly sheetContentType?: string;
    }
    /**
     * The options that determine the default settings for interactive layout configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultinteractivelayoutconfiguration.html
     */
    interface DefaultInteractiveLayoutConfigurationProperty {
        /**
         * The options that determine the default settings of a free-form layout configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultinteractivelayoutconfiguration.html#cfn-quicksight-analysis-defaultinteractivelayoutconfiguration-freeform
         */
        readonly freeForm?: CfnAnalysis.DefaultFreeFormLayoutConfigurationProperty | cdk.IResolvable;
        /**
         * The options that determine the default settings for a grid layout configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultinteractivelayoutconfiguration.html#cfn-quicksight-analysis-defaultinteractivelayoutconfiguration-grid
         */
        readonly grid?: CfnAnalysis.DefaultGridLayoutConfigurationProperty | cdk.IResolvable;
    }
    /**
     * The options that determine the default settings of a free-form layout configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultfreeformlayoutconfiguration.html
     */
    interface DefaultFreeFormLayoutConfigurationProperty {
        /**
         * Determines the screen canvas size options for a free-form layout.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultfreeformlayoutconfiguration.html#cfn-quicksight-analysis-defaultfreeformlayoutconfiguration-canvassizeoptions
         */
        readonly canvasSizeOptions: CfnAnalysis.FreeFormLayoutCanvasSizeOptionsProperty | cdk.IResolvable;
    }
    /**
     * Configuration options for the canvas of a free-form layout.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutcanvassizeoptions.html
     */
    interface FreeFormLayoutCanvasSizeOptionsProperty {
        /**
         * The options that determine the sizing of the canvas used in a free-form layout.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutcanvassizeoptions.html#cfn-quicksight-analysis-freeformlayoutcanvassizeoptions-screencanvassizeoptions
         */
        readonly screenCanvasSizeOptions?: CfnAnalysis.FreeFormLayoutScreenCanvasSizeOptionsProperty | cdk.IResolvable;
    }
    /**
     * The options that determine the sizing of the canvas used in a free-form layout.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutscreencanvassizeoptions.html
     */
    interface FreeFormLayoutScreenCanvasSizeOptionsProperty {
        /**
         * The width that the view port will be optimized for when the layout renders.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutscreencanvassizeoptions.html#cfn-quicksight-analysis-freeformlayoutscreencanvassizeoptions-optimizedviewportwidth
         */
        readonly optimizedViewPortWidth: string;
    }
    /**
     * The options that determine the default settings for a grid layout configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultgridlayoutconfiguration.html
     */
    interface DefaultGridLayoutConfigurationProperty {
        /**
         * Determines the screen canvas size options for a grid layout.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultgridlayoutconfiguration.html#cfn-quicksight-analysis-defaultgridlayoutconfiguration-canvassizeoptions
         */
        readonly canvasSizeOptions: CfnAnalysis.GridLayoutCanvasSizeOptionsProperty | cdk.IResolvable;
    }
    /**
     * Configuration options for the canvas of a grid layout.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutcanvassizeoptions.html
     */
    interface GridLayoutCanvasSizeOptionsProperty {
        /**
         * The options that determine the sizing of the canvas used in a grid layout.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutcanvassizeoptions.html#cfn-quicksight-analysis-gridlayoutcanvassizeoptions-screencanvassizeoptions
         */
        readonly screenCanvasSizeOptions?: CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty | cdk.IResolvable;
    }
    /**
     * The options that determine the sizing of the canvas used in a grid layout.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutscreencanvassizeoptions.html
     */
    interface GridLayoutScreenCanvasSizeOptionsProperty {
        /**
         * The width that the view port will be optimized for when the layout renders.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutscreencanvassizeoptions.html#cfn-quicksight-analysis-gridlayoutscreencanvassizeoptions-optimizedviewportwidth
         */
        readonly optimizedViewPortWidth?: string;
        /**
         * This value determines the layout behavior when the viewport is resized.
         *
         * - `FIXED` : A fixed width will be used when optimizing the layout. In the Amazon QuickSight console, this option is called `Classic` .
         * - `RESPONSIVE` : The width of the canvas will be responsive and optimized to the view port. In the Amazon QuickSight console, this option is called `Tiled` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutscreencanvassizeoptions.html#cfn-quicksight-analysis-gridlayoutscreencanvassizeoptions-resizeoption
         */
        readonly resizeOption: string;
    }
    /**
     * The options that determine the default settings for a paginated layout configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultpaginatedlayoutconfiguration.html
     */
    interface DefaultPaginatedLayoutConfigurationProperty {
        /**
         * The options that determine the default settings for a section-based layout configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultpaginatedlayoutconfiguration.html#cfn-quicksight-analysis-defaultpaginatedlayoutconfiguration-sectionbased
         */
        readonly sectionBased?: CfnAnalysis.DefaultSectionBasedLayoutConfigurationProperty | cdk.IResolvable;
    }
    /**
     * The options that determine the default settings for a section-based layout configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultsectionbasedlayoutconfiguration.html
     */
    interface DefaultSectionBasedLayoutConfigurationProperty {
        /**
         * Determines the screen canvas size options for a section-based layout.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultsectionbasedlayoutconfiguration.html#cfn-quicksight-analysis-defaultsectionbasedlayoutconfiguration-canvassizeoptions
         */
        readonly canvasSizeOptions: cdk.IResolvable | CfnAnalysis.SectionBasedLayoutCanvasSizeOptionsProperty;
    }
    /**
     * The options for the canvas of a section-based layout.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionbasedlayoutcanvassizeoptions.html
     */
    interface SectionBasedLayoutCanvasSizeOptionsProperty {
        /**
         * The options for a paper canvas of a section-based layout.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionbasedlayoutcanvassizeoptions.html#cfn-quicksight-analysis-sectionbasedlayoutcanvassizeoptions-papercanvassizeoptions
         */
        readonly paperCanvasSizeOptions?: cdk.IResolvable | CfnAnalysis.SectionBasedLayoutPaperCanvasSizeOptionsProperty;
    }
    /**
     * The options for a paper canvas of a section-based layout.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionbasedlayoutpapercanvassizeoptions.html
     */
    interface SectionBasedLayoutPaperCanvasSizeOptionsProperty {
        /**
         * Defines the spacing between the canvas content and the top, bottom, left, and right edges.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionbasedlayoutpapercanvassizeoptions.html#cfn-quicksight-analysis-sectionbasedlayoutpapercanvassizeoptions-papermargin
         */
        readonly paperMargin?: cdk.IResolvable | CfnAnalysis.SpacingProperty;
        /**
         * The paper orientation that is used to define canvas dimensions. Choose one of the following options:.
         *
         * - PORTRAIT
         * - LANDSCAPE
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionbasedlayoutpapercanvassizeoptions.html#cfn-quicksight-analysis-sectionbasedlayoutpapercanvassizeoptions-paperorientation
         */
        readonly paperOrientation?: string;
        /**
         * The paper size that is used to define canvas dimensions.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionbasedlayoutpapercanvassizeoptions.html#cfn-quicksight-analysis-sectionbasedlayoutpapercanvassizeoptions-papersize
         */
        readonly paperSize?: string;
    }
    /**
     * The configuration of spacing (often a margin or padding).
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-spacing.html
     */
    interface SpacingProperty {
        /**
         * Define the bottom spacing.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-spacing.html#cfn-quicksight-analysis-spacing-bottom
         */
        readonly bottom?: string;
        /**
         * Define the left spacing.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-spacing.html#cfn-quicksight-analysis-spacing-left
         */
        readonly left?: string;
        /**
         * Define the right spacing.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-spacing.html#cfn-quicksight-analysis-spacing-right
         */
        readonly right?: string;
        /**
         * Define the top spacing.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-spacing.html#cfn-quicksight-analysis-spacing-top
         */
        readonly top?: string;
    }
    /**
     * A sheet is an object that contains a set of visuals that are viewed together on one page in a paginated report.
     *
     * Every analysis and dashboard must contain at least one sheet.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetdefinition.html
     */
    interface SheetDefinitionProperty {
        /**
         * The layout content type of the sheet. Choose one of the following options:.
         *
         * - `PAGINATED` : Creates a sheet for a paginated report.
         * - `INTERACTIVE` : Creates a sheet for an interactive dashboard.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetdefinition.html#cfn-quicksight-analysis-sheetdefinition-contenttype
         */
        readonly contentType?: string;
        /**
         * A description of the sheet.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetdefinition.html#cfn-quicksight-analysis-sheetdefinition-description
         */
        readonly description?: string;
        /**
         * The list of filter controls that are on a sheet.
         *
         * For more information, see [Adding filter controls to analysis sheets](https://docs.aws.amazon.com/quicksight/latest/user/filter-controls.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetdefinition.html#cfn-quicksight-analysis-sheetdefinition-filtercontrols
         */
        readonly filterControls?: Array<CfnAnalysis.FilterControlProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * Layouts define how the components of a sheet are arranged.
         *
         * For more information, see [Types of layout](https://docs.aws.amazon.com/quicksight/latest/user/types-of-layout.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetdefinition.html#cfn-quicksight-analysis-sheetdefinition-layouts
         */
        readonly layouts?: Array<cdk.IResolvable | CfnAnalysis.LayoutProperty> | cdk.IResolvable;
        /**
         * The name of the sheet.
         *
         * This name is displayed on the sheet's tab in the Amazon QuickSight console.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetdefinition.html#cfn-quicksight-analysis-sheetdefinition-name
         */
        readonly name?: string;
        /**
         * The list of parameter controls that are on a sheet.
         *
         * For more information, see [Using a Control with a Parameter in Amazon QuickSight](https://docs.aws.amazon.com/quicksight/latest/user/parameters-controls.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetdefinition.html#cfn-quicksight-analysis-sheetdefinition-parametercontrols
         */
        readonly parameterControls?: Array<cdk.IResolvable | CfnAnalysis.ParameterControlProperty> | cdk.IResolvable;
        /**
         * The control layouts of the sheet.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetdefinition.html#cfn-quicksight-analysis-sheetdefinition-sheetcontrollayouts
         */
        readonly sheetControlLayouts?: Array<cdk.IResolvable | CfnAnalysis.SheetControlLayoutProperty> | cdk.IResolvable;
        /**
         * The unique identifier of a sheet.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetdefinition.html#cfn-quicksight-analysis-sheetdefinition-sheetid
         */
        readonly sheetId: string;
        /**
         * The text boxes that are on a sheet.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetdefinition.html#cfn-quicksight-analysis-sheetdefinition-textboxes
         */
        readonly textBoxes?: Array<cdk.IResolvable | CfnAnalysis.SheetTextBoxProperty> | cdk.IResolvable;
        /**
         * The title of the sheet.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetdefinition.html#cfn-quicksight-analysis-sheetdefinition-title
         */
        readonly title?: string;
        /**
         * A list of the visuals that are on a sheet.
         *
         * Visual placement is determined by the layout of the sheet.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetdefinition.html#cfn-quicksight-analysis-sheetdefinition-visuals
         */
        readonly visuals?: Array<cdk.IResolvable | CfnAnalysis.VisualProperty> | cdk.IResolvable;
    }
    /**
     * The control of a parameter that users can interact with in a dashboard or an analysis.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametercontrol.html
     */
    interface ParameterControlProperty {
        /**
         * A control from a date parameter that specifies date and time.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametercontrol.html#cfn-quicksight-analysis-parametercontrol-datetimepicker
         */
        readonly dateTimePicker?: cdk.IResolvable | CfnAnalysis.ParameterDateTimePickerControlProperty;
        /**
         * A control to display a dropdown list with buttons that are used to select a single value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametercontrol.html#cfn-quicksight-analysis-parametercontrol-dropdown
         */
        readonly dropdown?: cdk.IResolvable | CfnAnalysis.ParameterDropDownControlProperty;
        /**
         * A control to display a list with buttons or boxes that are used to select either a single value or multiple values.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametercontrol.html#cfn-quicksight-analysis-parametercontrol-list
         */
        readonly list?: cdk.IResolvable | CfnAnalysis.ParameterListControlProperty;
        /**
         * A control to display a horizontal toggle bar.
         *
         * This is used to change a value by sliding the toggle.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametercontrol.html#cfn-quicksight-analysis-parametercontrol-slider
         */
        readonly slider?: cdk.IResolvable | CfnAnalysis.ParameterSliderControlProperty;
        /**
         * A control to display a text box that is used to enter multiple entries.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametercontrol.html#cfn-quicksight-analysis-parametercontrol-textarea
         */
        readonly textArea?: cdk.IResolvable | CfnAnalysis.ParameterTextAreaControlProperty;
        /**
         * A control to display a text box that is used to enter a single entry.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametercontrol.html#cfn-quicksight-analysis-parametercontrol-textfield
         */
        readonly textField?: cdk.IResolvable | CfnAnalysis.ParameterTextFieldControlProperty;
    }
    /**
     * A control to display a horizontal toggle bar.
     *
     * This is used to change a value by sliding the toggle.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterslidercontrol.html
     */
    interface ParameterSliderControlProperty {
        /**
         * The display options of a control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterslidercontrol.html#cfn-quicksight-analysis-parameterslidercontrol-displayoptions
         */
        readonly displayOptions?: cdk.IResolvable | CfnAnalysis.SliderControlDisplayOptionsProperty;
        /**
         * The smaller value that is displayed at the left of the slider.
         *
         * @default - 0
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterslidercontrol.html#cfn-quicksight-analysis-parameterslidercontrol-maximumvalue
         */
        readonly maximumValue: number;
        /**
         * The larger value that is displayed at the right of the slider.
         *
         * @default - 0
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterslidercontrol.html#cfn-quicksight-analysis-parameterslidercontrol-minimumvalue
         */
        readonly minimumValue: number;
        /**
         * The ID of the `ParameterSliderControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterslidercontrol.html#cfn-quicksight-analysis-parameterslidercontrol-parametercontrolid
         */
        readonly parameterControlId: string;
        /**
         * The source parameter name of the `ParameterSliderControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterslidercontrol.html#cfn-quicksight-analysis-parameterslidercontrol-sourceparametername
         */
        readonly sourceParameterName: string;
        /**
         * The number of increments that the slider bar is divided into.
         *
         * @default - 0
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterslidercontrol.html#cfn-quicksight-analysis-parameterslidercontrol-stepsize
         */
        readonly stepSize: number;
        /**
         * The title of the `ParameterSliderControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterslidercontrol.html#cfn-quicksight-analysis-parameterslidercontrol-title
         */
        readonly title: string;
    }
    /**
     * The display options of a control.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-slidercontroldisplayoptions.html
     */
    interface SliderControlDisplayOptionsProperty {
        /**
         * The configuration of info icon label options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-slidercontroldisplayoptions.html#cfn-quicksight-analysis-slidercontroldisplayoptions-infoiconlabeloptions
         */
        readonly infoIconLabelOptions?: cdk.IResolvable | CfnAnalysis.SheetControlInfoIconLabelOptionsProperty;
        /**
         * The options to configure the title visibility, name, and font size.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-slidercontroldisplayoptions.html#cfn-quicksight-analysis-slidercontroldisplayoptions-titleoptions
         */
        readonly titleOptions?: cdk.IResolvable | CfnAnalysis.LabelOptionsProperty;
    }
    /**
     * The share label options for the labels.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-labeloptions.html
     */
    interface LabelOptionsProperty {
        /**
         * The text for the label.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-labeloptions.html#cfn-quicksight-analysis-labeloptions-customlabel
         */
        readonly customLabel?: string;
        /**
         * The font configuration of the label.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-labeloptions.html#cfn-quicksight-analysis-labeloptions-fontconfiguration
         */
        readonly fontConfiguration?: CfnAnalysis.FontConfigurationProperty | cdk.IResolvable;
        /**
         * Determines whether or not the label is visible.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-labeloptions.html#cfn-quicksight-analysis-labeloptions-visibility
         */
        readonly visibility?: string;
    }
    /**
     * Configures the display properties of the given text.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fontconfiguration.html
     */
    interface FontConfigurationProperty {
        /**
         * Determines the color of the text.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fontconfiguration.html#cfn-quicksight-analysis-fontconfiguration-fontcolor
         */
        readonly fontColor?: string;
        /**
         * Determines the appearance of decorative lines on the text.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fontconfiguration.html#cfn-quicksight-analysis-fontconfiguration-fontdecoration
         */
        readonly fontDecoration?: string;
        /**
         * The option that determines the text display size.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fontconfiguration.html#cfn-quicksight-analysis-fontconfiguration-fontsize
         */
        readonly fontSize?: CfnAnalysis.FontSizeProperty | cdk.IResolvable;
        /**
         * Determines the text display face that is inherited by the given font family.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fontconfiguration.html#cfn-quicksight-analysis-fontconfiguration-fontstyle
         */
        readonly fontStyle?: string;
        /**
         * The option that determines the text display weight, or boldness.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fontconfiguration.html#cfn-quicksight-analysis-fontconfiguration-fontweight
         */
        readonly fontWeight?: CfnAnalysis.FontWeightProperty | cdk.IResolvable;
    }
    /**
     * The option that determines the text display size.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fontsize.html
     */
    interface FontSizeProperty {
        /**
         * The lexical name for the text size, proportional to its surrounding context.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fontsize.html#cfn-quicksight-analysis-fontsize-relative
         */
        readonly relative?: string;
    }
    /**
     * The option that determines the text display weight, or boldness.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fontweight.html
     */
    interface FontWeightProperty {
        /**
         * The lexical name for the level of boldness of the text display.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fontweight.html#cfn-quicksight-analysis-fontweight-name
         */
        readonly name?: string;
    }
    /**
     * A control to display info icons for filters and parameters.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetcontrolinfoiconlabeloptions.html
     */
    interface SheetControlInfoIconLabelOptionsProperty {
        /**
         * The text content of info icon.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetcontrolinfoiconlabeloptions.html#cfn-quicksight-analysis-sheetcontrolinfoiconlabeloptions-infoicontext
         */
        readonly infoIconText?: string;
        /**
         * The visibility configuration of info icon label options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetcontrolinfoiconlabeloptions.html#cfn-quicksight-analysis-sheetcontrolinfoiconlabeloptions-visibility
         */
        readonly visibility?: string;
    }
    /**
     * A control to display a text box that is used to enter multiple entries.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametertextareacontrol.html
     */
    interface ParameterTextAreaControlProperty {
        /**
         * The delimiter that is used to separate the lines in text.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametertextareacontrol.html#cfn-quicksight-analysis-parametertextareacontrol-delimiter
         */
        readonly delimiter?: string;
        /**
         * The display options of a control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametertextareacontrol.html#cfn-quicksight-analysis-parametertextareacontrol-displayoptions
         */
        readonly displayOptions?: cdk.IResolvable | CfnAnalysis.TextAreaControlDisplayOptionsProperty;
        /**
         * The ID of the `ParameterTextAreaControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametertextareacontrol.html#cfn-quicksight-analysis-parametertextareacontrol-parametercontrolid
         */
        readonly parameterControlId: string;
        /**
         * The source parameter name of the `ParameterTextAreaControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametertextareacontrol.html#cfn-quicksight-analysis-parametertextareacontrol-sourceparametername
         */
        readonly sourceParameterName: string;
        /**
         * The title of the `ParameterTextAreaControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametertextareacontrol.html#cfn-quicksight-analysis-parametertextareacontrol-title
         */
        readonly title: string;
    }
    /**
     * The display options of a control.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-textareacontroldisplayoptions.html
     */
    interface TextAreaControlDisplayOptionsProperty {
        /**
         * The configuration of info icon label options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-textareacontroldisplayoptions.html#cfn-quicksight-analysis-textareacontroldisplayoptions-infoiconlabeloptions
         */
        readonly infoIconLabelOptions?: cdk.IResolvable | CfnAnalysis.SheetControlInfoIconLabelOptionsProperty;
        /**
         * The configuration of the placeholder options in a text area control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-textareacontroldisplayoptions.html#cfn-quicksight-analysis-textareacontroldisplayoptions-placeholderoptions
         */
        readonly placeholderOptions?: cdk.IResolvable | CfnAnalysis.TextControlPlaceholderOptionsProperty;
        /**
         * The options to configure the title visibility, name, and font size.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-textareacontroldisplayoptions.html#cfn-quicksight-analysis-textareacontroldisplayoptions-titleoptions
         */
        readonly titleOptions?: cdk.IResolvable | CfnAnalysis.LabelOptionsProperty;
    }
    /**
     * The configuration of the placeholder options in a text control.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-textcontrolplaceholderoptions.html
     */
    interface TextControlPlaceholderOptionsProperty {
        /**
         * The visibility configuration of the placeholder options in a text control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-textcontrolplaceholderoptions.html#cfn-quicksight-analysis-textcontrolplaceholderoptions-visibility
         */
        readonly visibility?: string;
    }
    /**
     * A control to display a dropdown list with buttons that are used to select a single value.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdropdowncontrol.html
     */
    interface ParameterDropDownControlProperty {
        /**
         * The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdropdowncontrol.html#cfn-quicksight-analysis-parameterdropdowncontrol-cascadingcontrolconfiguration
         */
        readonly cascadingControlConfiguration?: CfnAnalysis.CascadingControlConfigurationProperty | cdk.IResolvable;
        /**
         * The display options of a control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdropdowncontrol.html#cfn-quicksight-analysis-parameterdropdowncontrol-displayoptions
         */
        readonly displayOptions?: CfnAnalysis.DropDownControlDisplayOptionsProperty | cdk.IResolvable;
        /**
         * The ID of the `ParameterDropDownControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdropdowncontrol.html#cfn-quicksight-analysis-parameterdropdowncontrol-parametercontrolid
         */
        readonly parameterControlId: string;
        /**
         * A list of selectable values that are used in a control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdropdowncontrol.html#cfn-quicksight-analysis-parameterdropdowncontrol-selectablevalues
         */
        readonly selectableValues?: cdk.IResolvable | CfnAnalysis.ParameterSelectableValuesProperty;
        /**
         * The source parameter name of the `ParameterDropDownControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdropdowncontrol.html#cfn-quicksight-analysis-parameterdropdowncontrol-sourceparametername
         */
        readonly sourceParameterName: string;
        /**
         * The title of the `ParameterDropDownControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdropdowncontrol.html#cfn-quicksight-analysis-parameterdropdowncontrol-title
         */
        readonly title: string;
        /**
         * The type parameter name of the `ParameterDropDownControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdropdowncontrol.html#cfn-quicksight-analysis-parameterdropdowncontrol-type
         */
        readonly type?: string;
    }
    /**
     * The display options of a control.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-dropdowncontroldisplayoptions.html
     */
    interface DropDownControlDisplayOptionsProperty {
        /**
         * The configuration of info icon label options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-dropdowncontroldisplayoptions.html#cfn-quicksight-analysis-dropdowncontroldisplayoptions-infoiconlabeloptions
         */
        readonly infoIconLabelOptions?: cdk.IResolvable | CfnAnalysis.SheetControlInfoIconLabelOptionsProperty;
        /**
         * The configuration of the `Select all` options in a dropdown control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-dropdowncontroldisplayoptions.html#cfn-quicksight-analysis-dropdowncontroldisplayoptions-selectalloptions
         */
        readonly selectAllOptions?: cdk.IResolvable | CfnAnalysis.ListControlSelectAllOptionsProperty;
        /**
         * The options to configure the title visibility, name, and font size.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-dropdowncontroldisplayoptions.html#cfn-quicksight-analysis-dropdowncontroldisplayoptions-titleoptions
         */
        readonly titleOptions?: cdk.IResolvable | CfnAnalysis.LabelOptionsProperty;
    }
    /**
     * The configuration of the `Select all` options in a list control.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-listcontrolselectalloptions.html
     */
    interface ListControlSelectAllOptionsProperty {
        /**
         * The visibility configuration of the `Select all` options in a list control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-listcontrolselectalloptions.html#cfn-quicksight-analysis-listcontrolselectalloptions-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-cascadingcontrolconfiguration.html
     */
    interface CascadingControlConfigurationProperty {
        /**
         * A list of source controls that determine the values that are used in the current control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-cascadingcontrolconfiguration.html#cfn-quicksight-analysis-cascadingcontrolconfiguration-sourcecontrols
         */
        readonly sourceControls?: Array<CfnAnalysis.CascadingControlSourceProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * The source controls that are used in a `CascadingControlConfiguration` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-cascadingcontrolsource.html
     */
    interface CascadingControlSourceProperty {
        /**
         * The column identifier that determines which column to look up for the source sheet control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-cascadingcontrolsource.html#cfn-quicksight-analysis-cascadingcontrolsource-columntomatch
         */
        readonly columnToMatch?: CfnAnalysis.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * The source sheet control ID of a `CascadingControlSource` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-cascadingcontrolsource.html#cfn-quicksight-analysis-cascadingcontrolsource-sourcesheetcontrolid
         */
        readonly sourceSheetControlId?: string;
    }
    /**
     * A list of selectable values that are used in a control.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterselectablevalues.html
     */
    interface ParameterSelectableValuesProperty {
        /**
         * The column identifier that fetches values from the data set.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterselectablevalues.html#cfn-quicksight-analysis-parameterselectablevalues-linktodatasetcolumn
         */
        readonly linkToDataSetColumn?: CfnAnalysis.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * The values that are used in `ParameterSelectableValues` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterselectablevalues.html#cfn-quicksight-analysis-parameterselectablevalues-values
         */
        readonly values?: Array<string>;
    }
    /**
     * A control to display a text box that is used to enter a single entry.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametertextfieldcontrol.html
     */
    interface ParameterTextFieldControlProperty {
        /**
         * The display options of a control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametertextfieldcontrol.html#cfn-quicksight-analysis-parametertextfieldcontrol-displayoptions
         */
        readonly displayOptions?: cdk.IResolvable | CfnAnalysis.TextFieldControlDisplayOptionsProperty;
        /**
         * The ID of the `ParameterTextFieldControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametertextfieldcontrol.html#cfn-quicksight-analysis-parametertextfieldcontrol-parametercontrolid
         */
        readonly parameterControlId: string;
        /**
         * The source parameter name of the `ParameterTextFieldControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametertextfieldcontrol.html#cfn-quicksight-analysis-parametertextfieldcontrol-sourceparametername
         */
        readonly sourceParameterName: string;
        /**
         * The title of the `ParameterTextFieldControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametertextfieldcontrol.html#cfn-quicksight-analysis-parametertextfieldcontrol-title
         */
        readonly title: string;
    }
    /**
     * The display options of a control.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-textfieldcontroldisplayoptions.html
     */
    interface TextFieldControlDisplayOptionsProperty {
        /**
         * The configuration of info icon label options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-textfieldcontroldisplayoptions.html#cfn-quicksight-analysis-textfieldcontroldisplayoptions-infoiconlabeloptions
         */
        readonly infoIconLabelOptions?: cdk.IResolvable | CfnAnalysis.SheetControlInfoIconLabelOptionsProperty;
        /**
         * The configuration of the placeholder options in a text field control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-textfieldcontroldisplayoptions.html#cfn-quicksight-analysis-textfieldcontroldisplayoptions-placeholderoptions
         */
        readonly placeholderOptions?: cdk.IResolvable | CfnAnalysis.TextControlPlaceholderOptionsProperty;
        /**
         * The options to configure the title visibility, name, and font size.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-textfieldcontroldisplayoptions.html#cfn-quicksight-analysis-textfieldcontroldisplayoptions-titleoptions
         */
        readonly titleOptions?: cdk.IResolvable | CfnAnalysis.LabelOptionsProperty;
    }
    /**
     * A control to display a list with buttons or boxes that are used to select either a single value or multiple values.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterlistcontrol.html
     */
    interface ParameterListControlProperty {
        /**
         * The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterlistcontrol.html#cfn-quicksight-analysis-parameterlistcontrol-cascadingcontrolconfiguration
         */
        readonly cascadingControlConfiguration?: CfnAnalysis.CascadingControlConfigurationProperty | cdk.IResolvable;
        /**
         * The display options of a control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterlistcontrol.html#cfn-quicksight-analysis-parameterlistcontrol-displayoptions
         */
        readonly displayOptions?: cdk.IResolvable | CfnAnalysis.ListControlDisplayOptionsProperty;
        /**
         * The ID of the `ParameterListControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterlistcontrol.html#cfn-quicksight-analysis-parameterlistcontrol-parametercontrolid
         */
        readonly parameterControlId: string;
        /**
         * A list of selectable values that are used in a control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterlistcontrol.html#cfn-quicksight-analysis-parameterlistcontrol-selectablevalues
         */
        readonly selectableValues?: cdk.IResolvable | CfnAnalysis.ParameterSelectableValuesProperty;
        /**
         * The source parameter name of the `ParameterListControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterlistcontrol.html#cfn-quicksight-analysis-parameterlistcontrol-sourceparametername
         */
        readonly sourceParameterName: string;
        /**
         * The title of the `ParameterListControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterlistcontrol.html#cfn-quicksight-analysis-parameterlistcontrol-title
         */
        readonly title: string;
        /**
         * The type of `ParameterListControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterlistcontrol.html#cfn-quicksight-analysis-parameterlistcontrol-type
         */
        readonly type?: string;
    }
    /**
     * The display options of a control.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-listcontroldisplayoptions.html
     */
    interface ListControlDisplayOptionsProperty {
        /**
         * The configuration of info icon label options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-listcontroldisplayoptions.html#cfn-quicksight-analysis-listcontroldisplayoptions-infoiconlabeloptions
         */
        readonly infoIconLabelOptions?: cdk.IResolvable | CfnAnalysis.SheetControlInfoIconLabelOptionsProperty;
        /**
         * The configuration of the search options in a list control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-listcontroldisplayoptions.html#cfn-quicksight-analysis-listcontroldisplayoptions-searchoptions
         */
        readonly searchOptions?: cdk.IResolvable | CfnAnalysis.ListControlSearchOptionsProperty;
        /**
         * The configuration of the `Select all` options in a list control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-listcontroldisplayoptions.html#cfn-quicksight-analysis-listcontroldisplayoptions-selectalloptions
         */
        readonly selectAllOptions?: cdk.IResolvable | CfnAnalysis.ListControlSelectAllOptionsProperty;
        /**
         * The options to configure the title visibility, name, and font size.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-listcontroldisplayoptions.html#cfn-quicksight-analysis-listcontroldisplayoptions-titleoptions
         */
        readonly titleOptions?: cdk.IResolvable | CfnAnalysis.LabelOptionsProperty;
    }
    /**
     * The configuration of the search options in a list control.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-listcontrolsearchoptions.html
     */
    interface ListControlSearchOptionsProperty {
        /**
         * The visibility configuration of the search options in a list control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-listcontrolsearchoptions.html#cfn-quicksight-analysis-listcontrolsearchoptions-visibility
         */
        readonly visibility?: string;
    }
    /**
     * A control from a date parameter that specifies date and time.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdatetimepickercontrol.html
     */
    interface ParameterDateTimePickerControlProperty {
        /**
         * The display options of a control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdatetimepickercontrol.html#cfn-quicksight-analysis-parameterdatetimepickercontrol-displayoptions
         */
        readonly displayOptions?: CfnAnalysis.DateTimePickerControlDisplayOptionsProperty | cdk.IResolvable;
        /**
         * The ID of the `ParameterDateTimePickerControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdatetimepickercontrol.html#cfn-quicksight-analysis-parameterdatetimepickercontrol-parametercontrolid
         */
        readonly parameterControlId: string;
        /**
         * The name of the `ParameterDateTimePickerControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdatetimepickercontrol.html#cfn-quicksight-analysis-parameterdatetimepickercontrol-sourceparametername
         */
        readonly sourceParameterName: string;
        /**
         * The title of the `ParameterDateTimePickerControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdatetimepickercontrol.html#cfn-quicksight-analysis-parameterdatetimepickercontrol-title
         */
        readonly title: string;
    }
    /**
     * The display options of a control.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimepickercontroldisplayoptions.html
     */
    interface DateTimePickerControlDisplayOptionsProperty {
        /**
         * Customize how dates are formatted in controls.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimepickercontroldisplayoptions.html#cfn-quicksight-analysis-datetimepickercontroldisplayoptions-datetimeformat
         */
        readonly dateTimeFormat?: string;
        /**
         * The configuration of info icon label options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimepickercontroldisplayoptions.html#cfn-quicksight-analysis-datetimepickercontroldisplayoptions-infoiconlabeloptions
         */
        readonly infoIconLabelOptions?: cdk.IResolvable | CfnAnalysis.SheetControlInfoIconLabelOptionsProperty;
        /**
         * The options to configure the title visibility, name, and font size.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimepickercontroldisplayoptions.html#cfn-quicksight-analysis-datetimepickercontroldisplayoptions-titleoptions
         */
        readonly titleOptions?: cdk.IResolvable | CfnAnalysis.LabelOptionsProperty;
    }
    /**
     * A text box.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheettextbox.html
     */
    interface SheetTextBoxProperty {
        /**
         * The content that is displayed in the text box.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheettextbox.html#cfn-quicksight-analysis-sheettextbox-content
         */
        readonly content?: string;
        /**
         * The unique identifier for a text box.
         *
         * This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have text boxes that share identifiers.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheettextbox.html#cfn-quicksight-analysis-sheettextbox-sheettextboxid
         */
        readonly sheetTextBoxId: string;
    }
    /**
     * A `Layout` defines the placement of elements within a sheet.
     *
     * For more information, see [Types of layout](https://docs.aws.amazon.com/quicksight/latest/user/types-of-layout.html) in the *Amazon QuickSight User Guide* .
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-layout.html
     */
    interface LayoutProperty {
        /**
         * The configuration that determines what the type of layout for a sheet.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-layout.html#cfn-quicksight-analysis-layout-configuration
         */
        readonly configuration: cdk.IResolvable | CfnAnalysis.LayoutConfigurationProperty;
    }
    /**
     * The configuration that determines what the type of layout will be used on a sheet.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-layoutconfiguration.html
     */
    interface LayoutConfigurationProperty {
        /**
         * A free-form is optimized for a fixed width and has more control over the exact placement of layout elements.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-layoutconfiguration.html#cfn-quicksight-analysis-layoutconfiguration-freeformlayout
         */
        readonly freeFormLayout?: CfnAnalysis.FreeFormLayoutConfigurationProperty | cdk.IResolvable;
        /**
         * A type of layout that can be used on a sheet.
         *
         * In a grid layout, visuals snap to a grid with standard spacing and alignment. Dashboards are displayed as designed, with options to fit to screen or view at actual size. A grid layout can be configured to behave in one of two ways when the viewport is resized: `FIXED` or `RESPONSIVE` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-layoutconfiguration.html#cfn-quicksight-analysis-layoutconfiguration-gridlayout
         */
        readonly gridLayout?: CfnAnalysis.GridLayoutConfigurationProperty | cdk.IResolvable;
        /**
         * A section based layout organizes visuals into multiple sections and has customized header, footer and page break.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-layoutconfiguration.html#cfn-quicksight-analysis-layoutconfiguration-sectionbasedlayout
         */
        readonly sectionBasedLayout?: cdk.IResolvable | CfnAnalysis.SectionBasedLayoutConfigurationProperty;
    }
    /**
     * The configuration for a grid layout. Also called a tiled layout.
     *
     * Visuals snap to a grid with standard spacing and alignment. Dashboards are displayed as designed, with options to fit to screen or view at actual size.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutconfiguration.html
     */
    interface GridLayoutConfigurationProperty {
        /**
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutconfiguration.html#cfn-quicksight-analysis-gridlayoutconfiguration-canvassizeoptions
         */
        readonly canvasSizeOptions?: CfnAnalysis.GridLayoutCanvasSizeOptionsProperty | cdk.IResolvable;
        /**
         * The elements that are included in a grid layout.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutconfiguration.html#cfn-quicksight-analysis-gridlayoutconfiguration-elements
         */
        readonly elements: Array<CfnAnalysis.GridLayoutElementProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * An element within a grid layout.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutelement.html
     */
    interface GridLayoutElementProperty {
        /**
         * The column index for the upper left corner of an element.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutelement.html#cfn-quicksight-analysis-gridlayoutelement-columnindex
         */
        readonly columnIndex?: number;
        /**
         * The width of a grid element expressed as a number of grid columns.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutelement.html#cfn-quicksight-analysis-gridlayoutelement-columnspan
         */
        readonly columnSpan: number;
        /**
         * A unique identifier for an element within a grid layout.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutelement.html#cfn-quicksight-analysis-gridlayoutelement-elementid
         */
        readonly elementId: string;
        /**
         * The type of element.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutelement.html#cfn-quicksight-analysis-gridlayoutelement-elementtype
         */
        readonly elementType: string;
        /**
         * The row index for the upper left corner of an element.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutelement.html#cfn-quicksight-analysis-gridlayoutelement-rowindex
         */
        readonly rowIndex?: number;
        /**
         * The height of a grid element expressed as a number of grid rows.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutelement.html#cfn-quicksight-analysis-gridlayoutelement-rowspan
         */
        readonly rowSpan: number;
    }
    /**
     * The configuration of a free-form layout.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutconfiguration.html
     */
    interface FreeFormLayoutConfigurationProperty {
        /**
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutconfiguration.html#cfn-quicksight-analysis-freeformlayoutconfiguration-canvassizeoptions
         */
        readonly canvasSizeOptions?: CfnAnalysis.FreeFormLayoutCanvasSizeOptionsProperty | cdk.IResolvable;
        /**
         * The elements that are included in a free-form layout.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutconfiguration.html#cfn-quicksight-analysis-freeformlayoutconfiguration-elements
         */
        readonly elements: Array<CfnAnalysis.FreeFormLayoutElementProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * An element within a free-form layout.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelement.html
     */
    interface FreeFormLayoutElementProperty {
        /**
         * The background style configuration of a free-form layout element.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelement.html#cfn-quicksight-analysis-freeformlayoutelement-backgroundstyle
         */
        readonly backgroundStyle?: CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty | cdk.IResolvable;
        /**
         * The border style configuration of a free-form layout element.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelement.html#cfn-quicksight-analysis-freeformlayoutelement-borderstyle
         */
        readonly borderStyle?: CfnAnalysis.FreeFormLayoutElementBorderStyleProperty | cdk.IResolvable;
        /**
         * A unique identifier for an element within a free-form layout.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelement.html#cfn-quicksight-analysis-freeformlayoutelement-elementid
         */
        readonly elementId: string;
        /**
         * The type of element.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelement.html#cfn-quicksight-analysis-freeformlayoutelement-elementtype
         */
        readonly elementType: string;
        /**
         * The height of an element within a free-form layout.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelement.html#cfn-quicksight-analysis-freeformlayoutelement-height
         */
        readonly height: string;
        /**
         * The loading animation configuration of a free-form layout element.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelement.html#cfn-quicksight-analysis-freeformlayoutelement-loadinganimation
         */
        readonly loadingAnimation?: cdk.IResolvable | CfnAnalysis.LoadingAnimationProperty;
        /**
         * The rendering rules that determine when an element should be displayed within a free-form layout.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelement.html#cfn-quicksight-analysis-freeformlayoutelement-renderingrules
         */
        readonly renderingRules?: Array<cdk.IResolvable | CfnAnalysis.SheetElementRenderingRuleProperty> | cdk.IResolvable;
        /**
         * The border style configuration of a free-form layout element.
         *
         * This border style is used when the element is selected.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelement.html#cfn-quicksight-analysis-freeformlayoutelement-selectedborderstyle
         */
        readonly selectedBorderStyle?: CfnAnalysis.FreeFormLayoutElementBorderStyleProperty | cdk.IResolvable;
        /**
         * The visibility of an element within a free-form layout.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelement.html#cfn-quicksight-analysis-freeformlayoutelement-visibility
         */
        readonly visibility?: string;
        /**
         * The width of an element within a free-form layout.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelement.html#cfn-quicksight-analysis-freeformlayoutelement-width
         */
        readonly width: string;
        /**
         * The x-axis coordinate of the element.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelement.html#cfn-quicksight-analysis-freeformlayoutelement-xaxislocation
         */
        readonly xAxisLocation: string;
        /**
         * The y-axis coordinate of the element.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelement.html#cfn-quicksight-analysis-freeformlayoutelement-yaxislocation
         */
        readonly yAxisLocation: string;
    }
    /**
     * The background style configuration of a free-form layout element.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelementborderstyle.html
     */
    interface FreeFormLayoutElementBorderStyleProperty {
        /**
         * The border color of a free-form layout element.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelementborderstyle.html#cfn-quicksight-analysis-freeformlayoutelementborderstyle-color
         */
        readonly color?: string;
        /**
         * The border visibility of a free-form layout element.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelementborderstyle.html#cfn-quicksight-analysis-freeformlayoutelementborderstyle-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The rendering rules of a sheet that uses a free-form layout.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetelementrenderingrule.html
     */
    interface SheetElementRenderingRuleProperty {
        /**
         * The override configuration of the rendering rules of a sheet.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetelementrenderingrule.html#cfn-quicksight-analysis-sheetelementrenderingrule-configurationoverrides
         */
        readonly configurationOverrides: cdk.IResolvable | CfnAnalysis.SheetElementConfigurationOverridesProperty;
        /**
         * The expression of the rendering rules of a sheet.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetelementrenderingrule.html#cfn-quicksight-analysis-sheetelementrenderingrule-expression
         */
        readonly expression: string;
    }
    /**
     * The override configuration of the rendering rules of a sheet.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetelementconfigurationoverrides.html
     */
    interface SheetElementConfigurationOverridesProperty {
        /**
         * Determines whether or not the overrides are visible. Choose one of the following options:.
         *
         * - `VISIBLE`
         * - `HIDDEN`
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetelementconfigurationoverrides.html#cfn-quicksight-analysis-sheetelementconfigurationoverrides-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The configuration of loading animation in free-form layout.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-loadinganimation.html
     */
    interface LoadingAnimationProperty {
        /**
         * The visibility configuration of `LoadingAnimation` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-loadinganimation.html#cfn-quicksight-analysis-loadinganimation-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The background style configuration of a free-form layout element.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelementbackgroundstyle.html
     */
    interface FreeFormLayoutElementBackgroundStyleProperty {
        /**
         * The background color of a free-form layout element.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelementbackgroundstyle.html#cfn-quicksight-analysis-freeformlayoutelementbackgroundstyle-color
         */
        readonly color?: string;
        /**
         * The background visibility of a free-form layout element.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelementbackgroundstyle.html#cfn-quicksight-analysis-freeformlayoutelementbackgroundstyle-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The configuration for a section-based layout.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionbasedlayoutconfiguration.html
     */
    interface SectionBasedLayoutConfigurationProperty {
        /**
         * A list of body section configurations.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionbasedlayoutconfiguration.html#cfn-quicksight-analysis-sectionbasedlayoutconfiguration-bodysections
         */
        readonly bodySections: Array<CfnAnalysis.BodySectionConfigurationProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The options for the canvas of a section-based layout.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionbasedlayoutconfiguration.html#cfn-quicksight-analysis-sectionbasedlayoutconfiguration-canvassizeoptions
         */
        readonly canvasSizeOptions: cdk.IResolvable | CfnAnalysis.SectionBasedLayoutCanvasSizeOptionsProperty;
        /**
         * A list of footer section configurations.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionbasedlayoutconfiguration.html#cfn-quicksight-analysis-sectionbasedlayoutconfiguration-footersections
         */
        readonly footerSections: Array<CfnAnalysis.HeaderFooterSectionConfigurationProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * A list of header section configurations.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionbasedlayoutconfiguration.html#cfn-quicksight-analysis-sectionbasedlayoutconfiguration-headersections
         */
        readonly headerSections: Array<CfnAnalysis.HeaderFooterSectionConfigurationProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * The configuration of a header or footer section.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-headerfootersectionconfiguration.html
     */
    interface HeaderFooterSectionConfigurationProperty {
        /**
         * The layout configuration of the header or footer section.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-headerfootersectionconfiguration.html#cfn-quicksight-analysis-headerfootersectionconfiguration-layout
         */
        readonly layout: cdk.IResolvable | CfnAnalysis.SectionLayoutConfigurationProperty;
        /**
         * The unique identifier of the header or footer section.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-headerfootersectionconfiguration.html#cfn-quicksight-analysis-headerfootersectionconfiguration-sectionid
         */
        readonly sectionId: string;
        /**
         * The style options of a header or footer section.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-headerfootersectionconfiguration.html#cfn-quicksight-analysis-headerfootersectionconfiguration-style
         */
        readonly style?: cdk.IResolvable | CfnAnalysis.SectionStyleProperty;
    }
    /**
     * The layout configuration of a section.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionlayoutconfiguration.html
     */
    interface SectionLayoutConfigurationProperty {
        /**
         * The free-form layout configuration of a section.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionlayoutconfiguration.html#cfn-quicksight-analysis-sectionlayoutconfiguration-freeformlayout
         */
        readonly freeFormLayout: CfnAnalysis.FreeFormSectionLayoutConfigurationProperty | cdk.IResolvable;
    }
    /**
     * The free-form layout configuration of a section.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformsectionlayoutconfiguration.html
     */
    interface FreeFormSectionLayoutConfigurationProperty {
        /**
         * The elements that are included in the free-form layout.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformsectionlayoutconfiguration.html#cfn-quicksight-analysis-freeformsectionlayoutconfiguration-elements
         */
        readonly elements: Array<CfnAnalysis.FreeFormLayoutElementProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * The options that style a section.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionstyle.html
     */
    interface SectionStyleProperty {
        /**
         * The height of a section.
         *
         * Heights can only be defined for header and footer sections. The default height margin is 0.5 inches.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionstyle.html#cfn-quicksight-analysis-sectionstyle-height
         */
        readonly height?: string;
        /**
         * The spacing between section content and its top, bottom, left, and right edges.
         *
         * There is no padding by default.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionstyle.html#cfn-quicksight-analysis-sectionstyle-padding
         */
        readonly padding?: cdk.IResolvable | CfnAnalysis.SpacingProperty;
    }
    /**
     * The configuration of a body section.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-bodysectionconfiguration.html
     */
    interface BodySectionConfigurationProperty {
        /**
         * The configuration of content in a body section.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-bodysectionconfiguration.html#cfn-quicksight-analysis-bodysectionconfiguration-content
         */
        readonly content: CfnAnalysis.BodySectionContentProperty | cdk.IResolvable;
        /**
         * The configuration of a page break for a section.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-bodysectionconfiguration.html#cfn-quicksight-analysis-bodysectionconfiguration-pagebreakconfiguration
         */
        readonly pageBreakConfiguration?: cdk.IResolvable | CfnAnalysis.SectionPageBreakConfigurationProperty;
        /**
         * The unique identifier of a body section.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-bodysectionconfiguration.html#cfn-quicksight-analysis-bodysectionconfiguration-sectionid
         */
        readonly sectionId: string;
        /**
         * The style options of a body section.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-bodysectionconfiguration.html#cfn-quicksight-analysis-bodysectionconfiguration-style
         */
        readonly style?: cdk.IResolvable | CfnAnalysis.SectionStyleProperty;
    }
    /**
     * The configuration of content in a body section.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-bodysectioncontent.html
     */
    interface BodySectionContentProperty {
        /**
         * The layout configuration of a body section.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-bodysectioncontent.html#cfn-quicksight-analysis-bodysectioncontent-layout
         */
        readonly layout?: cdk.IResolvable | CfnAnalysis.SectionLayoutConfigurationProperty;
    }
    /**
     * The configuration of a page break for a section.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionpagebreakconfiguration.html
     */
    interface SectionPageBreakConfigurationProperty {
        /**
         * The configuration of a page break after a section.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionpagebreakconfiguration.html#cfn-quicksight-analysis-sectionpagebreakconfiguration-after
         */
        readonly after?: cdk.IResolvable | CfnAnalysis.SectionAfterPageBreakProperty;
    }
    /**
     * The configuration of a page break after a section.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionafterpagebreak.html
     */
    interface SectionAfterPageBreakProperty {
        /**
         * The option that enables or disables a page break at the end of a section.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionafterpagebreak.html#cfn-quicksight-analysis-sectionafterpagebreak-status
         */
        readonly status?: string;
    }
    /**
     * The control of a filter that is used to interact with a dashboard or an analysis.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtercontrol.html
     */
    interface FilterControlProperty {
        /**
         * A control from a date filter that is used to specify date and time.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtercontrol.html#cfn-quicksight-analysis-filtercontrol-datetimepicker
         */
        readonly dateTimePicker?: CfnAnalysis.FilterDateTimePickerControlProperty | cdk.IResolvable;
        /**
         * A control to display a dropdown list with buttons that are used to select a single value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtercontrol.html#cfn-quicksight-analysis-filtercontrol-dropdown
         */
        readonly dropdown?: CfnAnalysis.FilterDropDownControlProperty | cdk.IResolvable;
        /**
         * A control to display a list of buttons or boxes.
         *
         * This is used to select either a single value or multiple values.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtercontrol.html#cfn-quicksight-analysis-filtercontrol-list
         */
        readonly list?: CfnAnalysis.FilterListControlProperty | cdk.IResolvable;
        /**
         * A control from a date filter that is used to specify the relative date.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtercontrol.html#cfn-quicksight-analysis-filtercontrol-relativedatetime
         */
        readonly relativeDateTime?: CfnAnalysis.FilterRelativeDateTimeControlProperty | cdk.IResolvable;
        /**
         * A control to display a horizontal toggle bar.
         *
         * This is used to change a value by sliding the toggle.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtercontrol.html#cfn-quicksight-analysis-filtercontrol-slider
         */
        readonly slider?: CfnAnalysis.FilterSliderControlProperty | cdk.IResolvable;
        /**
         * A control to display a text box that is used to enter multiple entries.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtercontrol.html#cfn-quicksight-analysis-filtercontrol-textarea
         */
        readonly textArea?: CfnAnalysis.FilterTextAreaControlProperty | cdk.IResolvable;
        /**
         * A control to display a text box that is used to enter a single entry.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtercontrol.html#cfn-quicksight-analysis-filtercontrol-textfield
         */
        readonly textField?: CfnAnalysis.FilterTextFieldControlProperty | cdk.IResolvable;
    }
    /**
     * A control to display a horizontal toggle bar.
     *
     * This is used to change a value by sliding the toggle.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterslidercontrol.html
     */
    interface FilterSliderControlProperty {
        /**
         * The display options of a control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterslidercontrol.html#cfn-quicksight-analysis-filterslidercontrol-displayoptions
         */
        readonly displayOptions?: cdk.IResolvable | CfnAnalysis.SliderControlDisplayOptionsProperty;
        /**
         * The ID of the `FilterSliderControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterslidercontrol.html#cfn-quicksight-analysis-filterslidercontrol-filtercontrolid
         */
        readonly filterControlId: string;
        /**
         * The smaller value that is displayed at the left of the slider.
         *
         * @default - 0
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterslidercontrol.html#cfn-quicksight-analysis-filterslidercontrol-maximumvalue
         */
        readonly maximumValue: number;
        /**
         * The larger value that is displayed at the right of the slider.
         *
         * @default - 0
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterslidercontrol.html#cfn-quicksight-analysis-filterslidercontrol-minimumvalue
         */
        readonly minimumValue: number;
        /**
         * The source filter ID of the `FilterSliderControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterslidercontrol.html#cfn-quicksight-analysis-filterslidercontrol-sourcefilterid
         */
        readonly sourceFilterId: string;
        /**
         * The number of increments that the slider bar is divided into.
         *
         * @default - 0
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterslidercontrol.html#cfn-quicksight-analysis-filterslidercontrol-stepsize
         */
        readonly stepSize: number;
        /**
         * The title of the `FilterSliderControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterslidercontrol.html#cfn-quicksight-analysis-filterslidercontrol-title
         */
        readonly title: string;
        /**
         * The type of `FilterSliderControl` . Choose one of the following options:.
         *
         * - `SINGLE_POINT` : Filter against(equals) a single data point.
         * - `RANGE` : Filter data that is in a specified range.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterslidercontrol.html#cfn-quicksight-analysis-filterslidercontrol-type
         */
        readonly type?: string;
    }
    /**
     * A control to display a text box that is used to enter multiple entries.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtertextareacontrol.html
     */
    interface FilterTextAreaControlProperty {
        /**
         * The delimiter that is used to separate the lines in text.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtertextareacontrol.html#cfn-quicksight-analysis-filtertextareacontrol-delimiter
         */
        readonly delimiter?: string;
        /**
         * The display options of a control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtertextareacontrol.html#cfn-quicksight-analysis-filtertextareacontrol-displayoptions
         */
        readonly displayOptions?: cdk.IResolvable | CfnAnalysis.TextAreaControlDisplayOptionsProperty;
        /**
         * The ID of the `FilterTextAreaControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtertextareacontrol.html#cfn-quicksight-analysis-filtertextareacontrol-filtercontrolid
         */
        readonly filterControlId: string;
        /**
         * The source filter ID of the `FilterTextAreaControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtertextareacontrol.html#cfn-quicksight-analysis-filtertextareacontrol-sourcefilterid
         */
        readonly sourceFilterId: string;
        /**
         * The title of the `FilterTextAreaControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtertextareacontrol.html#cfn-quicksight-analysis-filtertextareacontrol-title
         */
        readonly title: string;
    }
    /**
     * A control to display a dropdown list with buttons that are used to select a single value.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterdropdowncontrol.html
     */
    interface FilterDropDownControlProperty {
        /**
         * The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterdropdowncontrol.html#cfn-quicksight-analysis-filterdropdowncontrol-cascadingcontrolconfiguration
         */
        readonly cascadingControlConfiguration?: CfnAnalysis.CascadingControlConfigurationProperty | cdk.IResolvable;
        /**
         * The display options of the `FilterDropDownControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterdropdowncontrol.html#cfn-quicksight-analysis-filterdropdowncontrol-displayoptions
         */
        readonly displayOptions?: CfnAnalysis.DropDownControlDisplayOptionsProperty | cdk.IResolvable;
        /**
         * The ID of the `FilterDropDownControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterdropdowncontrol.html#cfn-quicksight-analysis-filterdropdowncontrol-filtercontrolid
         */
        readonly filterControlId: string;
        /**
         * A list of selectable values that are used in a control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterdropdowncontrol.html#cfn-quicksight-analysis-filterdropdowncontrol-selectablevalues
         */
        readonly selectableValues?: CfnAnalysis.FilterSelectableValuesProperty | cdk.IResolvable;
        /**
         * The source filter ID of the `FilterDropDownControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterdropdowncontrol.html#cfn-quicksight-analysis-filterdropdowncontrol-sourcefilterid
         */
        readonly sourceFilterId: string;
        /**
         * The title of the `FilterDropDownControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterdropdowncontrol.html#cfn-quicksight-analysis-filterdropdowncontrol-title
         */
        readonly title: string;
        /**
         * The type of the `FilterDropDownControl` . Choose one of the following options:.
         *
         * - `MULTI_SELECT` : The user can select multiple entries from a dropdown menu.
         * - `SINGLE_SELECT` : The user can select a single entry from a dropdown menu.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterdropdowncontrol.html#cfn-quicksight-analysis-filterdropdowncontrol-type
         */
        readonly type?: string;
    }
    /**
     * A list of selectable values that are used in a control.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterselectablevalues.html
     */
    interface FilterSelectableValuesProperty {
        /**
         * The values that are used in the `FilterSelectableValues` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterselectablevalues.html#cfn-quicksight-analysis-filterselectablevalues-values
         */
        readonly values?: Array<string>;
    }
    /**
     * A control to display a text box that is used to enter a single entry.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtertextfieldcontrol.html
     */
    interface FilterTextFieldControlProperty {
        /**
         * The display options of a control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtertextfieldcontrol.html#cfn-quicksight-analysis-filtertextfieldcontrol-displayoptions
         */
        readonly displayOptions?: cdk.IResolvable | CfnAnalysis.TextFieldControlDisplayOptionsProperty;
        /**
         * The ID of the `FilterTextFieldControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtertextfieldcontrol.html#cfn-quicksight-analysis-filtertextfieldcontrol-filtercontrolid
         */
        readonly filterControlId: string;
        /**
         * The source filter ID of the `FilterTextFieldControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtertextfieldcontrol.html#cfn-quicksight-analysis-filtertextfieldcontrol-sourcefilterid
         */
        readonly sourceFilterId: string;
        /**
         * The title of the `FilterTextFieldControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtertextfieldcontrol.html#cfn-quicksight-analysis-filtertextfieldcontrol-title
         */
        readonly title: string;
    }
    /**
     * A control to display a list of buttons or boxes.
     *
     * This is used to select either a single value or multiple values.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterlistcontrol.html
     */
    interface FilterListControlProperty {
        /**
         * The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterlistcontrol.html#cfn-quicksight-analysis-filterlistcontrol-cascadingcontrolconfiguration
         */
        readonly cascadingControlConfiguration?: CfnAnalysis.CascadingControlConfigurationProperty | cdk.IResolvable;
        /**
         * The display options of a control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterlistcontrol.html#cfn-quicksight-analysis-filterlistcontrol-displayoptions
         */
        readonly displayOptions?: cdk.IResolvable | CfnAnalysis.ListControlDisplayOptionsProperty;
        /**
         * The ID of the `FilterListControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterlistcontrol.html#cfn-quicksight-analysis-filterlistcontrol-filtercontrolid
         */
        readonly filterControlId: string;
        /**
         * A list of selectable values that are used in a control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterlistcontrol.html#cfn-quicksight-analysis-filterlistcontrol-selectablevalues
         */
        readonly selectableValues?: CfnAnalysis.FilterSelectableValuesProperty | cdk.IResolvable;
        /**
         * The source filter ID of the `FilterListControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterlistcontrol.html#cfn-quicksight-analysis-filterlistcontrol-sourcefilterid
         */
        readonly sourceFilterId: string;
        /**
         * The title of the `FilterListControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterlistcontrol.html#cfn-quicksight-analysis-filterlistcontrol-title
         */
        readonly title: string;
        /**
         * The type of `FilterListControl` . Choose one of the following options:.
         *
         * - `MULTI_SELECT` : The user can select multiple entries from the list.
         * - `SINGLE_SELECT` : The user can select a single entry from the list.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterlistcontrol.html#cfn-quicksight-analysis-filterlistcontrol-type
         */
        readonly type?: string;
    }
    /**
     * A control from a date filter that is used to specify date and time.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterdatetimepickercontrol.html
     */
    interface FilterDateTimePickerControlProperty {
        /**
         * The display options of a control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterdatetimepickercontrol.html#cfn-quicksight-analysis-filterdatetimepickercontrol-displayoptions
         */
        readonly displayOptions?: CfnAnalysis.DateTimePickerControlDisplayOptionsProperty | cdk.IResolvable;
        /**
         * The ID of the `FilterDateTimePickerControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterdatetimepickercontrol.html#cfn-quicksight-analysis-filterdatetimepickercontrol-filtercontrolid
         */
        readonly filterControlId: string;
        /**
         * The source filter ID of the `FilterDateTimePickerControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterdatetimepickercontrol.html#cfn-quicksight-analysis-filterdatetimepickercontrol-sourcefilterid
         */
        readonly sourceFilterId: string;
        /**
         * The title of the `FilterDateTimePickerControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterdatetimepickercontrol.html#cfn-quicksight-analysis-filterdatetimepickercontrol-title
         */
        readonly title: string;
        /**
         * The date time picker type of a `FilterDateTimePickerControl` . Choose one of the following options:.
         *
         * - `SINGLE_VALUED` : The filter condition is a fixed date.
         * - `DATE_RANGE` : The filter condition is a date time range.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterdatetimepickercontrol.html#cfn-quicksight-analysis-filterdatetimepickercontrol-type
         */
        readonly type?: string;
    }
    /**
     * A control from a date filter that is used to specify the relative date.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterrelativedatetimecontrol.html
     */
    interface FilterRelativeDateTimeControlProperty {
        /**
         * The display options of a control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterrelativedatetimecontrol.html#cfn-quicksight-analysis-filterrelativedatetimecontrol-displayoptions
         */
        readonly displayOptions?: cdk.IResolvable | CfnAnalysis.RelativeDateTimeControlDisplayOptionsProperty;
        /**
         * The ID of the `FilterTextAreaControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterrelativedatetimecontrol.html#cfn-quicksight-analysis-filterrelativedatetimecontrol-filtercontrolid
         */
        readonly filterControlId: string;
        /**
         * The source filter ID of the `FilterTextAreaControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterrelativedatetimecontrol.html#cfn-quicksight-analysis-filterrelativedatetimecontrol-sourcefilterid
         */
        readonly sourceFilterId: string;
        /**
         * The title of the `FilterTextAreaControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterrelativedatetimecontrol.html#cfn-quicksight-analysis-filterrelativedatetimecontrol-title
         */
        readonly title: string;
    }
    /**
     * The display options of a control.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-relativedatetimecontroldisplayoptions.html
     */
    interface RelativeDateTimeControlDisplayOptionsProperty {
        /**
         * Customize how dates are formatted in controls.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-relativedatetimecontroldisplayoptions.html#cfn-quicksight-analysis-relativedatetimecontroldisplayoptions-datetimeformat
         */
        readonly dateTimeFormat?: string;
        /**
         * The configuration of info icon label options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-relativedatetimecontroldisplayoptions.html#cfn-quicksight-analysis-relativedatetimecontroldisplayoptions-infoiconlabeloptions
         */
        readonly infoIconLabelOptions?: cdk.IResolvable | CfnAnalysis.SheetControlInfoIconLabelOptionsProperty;
        /**
         * The options to configure the title visibility, name, and font size.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-relativedatetimecontroldisplayoptions.html#cfn-quicksight-analysis-relativedatetimecontroldisplayoptions-titleoptions
         */
        readonly titleOptions?: cdk.IResolvable | CfnAnalysis.LabelOptionsProperty;
    }
    /**
     * A grid layout to define the placement of sheet control.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetcontrollayout.html
     */
    interface SheetControlLayoutProperty {
        /**
         * The configuration that determines the elements and canvas size options of sheet control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetcontrollayout.html#cfn-quicksight-analysis-sheetcontrollayout-configuration
         */
        readonly configuration: cdk.IResolvable | CfnAnalysis.SheetControlLayoutConfigurationProperty;
    }
    /**
     * The configuration that determines the elements and canvas size options of sheet control.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetcontrollayoutconfiguration.html
     */
    interface SheetControlLayoutConfigurationProperty {
        /**
         * The configuration that determines the elements and canvas size options of sheet control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetcontrollayoutconfiguration.html#cfn-quicksight-analysis-sheetcontrollayoutconfiguration-gridlayout
         */
        readonly gridLayout?: CfnAnalysis.GridLayoutConfigurationProperty | cdk.IResolvable;
    }
    /**
     * A visual displayed on a sheet in an analysis, dashboard, or template.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html
     */
    interface VisualProperty {
        /**
         * A bar chart.
         *
         * For more information, see [Using bar charts](https://docs.aws.amazon.com/quicksight/latest/user/bar-charts.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-barchartvisual
         */
        readonly barChartVisual?: CfnAnalysis.BarChartVisualProperty | cdk.IResolvable;
        /**
         * A box plot.
         *
         * For more information, see [Using box plots](https://docs.aws.amazon.com/quicksight/latest/user/box-plots.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-boxplotvisual
         */
        readonly boxPlotVisual?: CfnAnalysis.BoxPlotVisualProperty | cdk.IResolvable;
        /**
         * A combo chart.
         *
         * For more information, see [Using combo charts](https://docs.aws.amazon.com/quicksight/latest/user/combo-charts.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-combochartvisual
         */
        readonly comboChartVisual?: CfnAnalysis.ComboChartVisualProperty | cdk.IResolvable;
        /**
         * A visual that contains custom content.
         *
         * For more information, see [Using custom visual content](https://docs.aws.amazon.com/quicksight/latest/user/custom-visual-content.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-customcontentvisual
         */
        readonly customContentVisual?: CfnAnalysis.CustomContentVisualProperty | cdk.IResolvable;
        /**
         * An empty visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-emptyvisual
         */
        readonly emptyVisual?: CfnAnalysis.EmptyVisualProperty | cdk.IResolvable;
        /**
         * A filled map.
         *
         * For more information, see [Creating filled maps](https://docs.aws.amazon.com/quicksight/latest/user/filled-maps.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-filledmapvisual
         */
        readonly filledMapVisual?: CfnAnalysis.FilledMapVisualProperty | cdk.IResolvable;
        /**
         * A funnel chart.
         *
         * For more information, see [Using funnel charts](https://docs.aws.amazon.com/quicksight/latest/user/funnel-visual-content.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-funnelchartvisual
         */
        readonly funnelChartVisual?: CfnAnalysis.FunnelChartVisualProperty | cdk.IResolvable;
        /**
         * A gauge chart.
         *
         * For more information, see [Using gauge charts](https://docs.aws.amazon.com/quicksight/latest/user/gauge-chart.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-gaugechartvisual
         */
        readonly gaugeChartVisual?: CfnAnalysis.GaugeChartVisualProperty | cdk.IResolvable;
        /**
         * A geospatial map or a points on map visual.
         *
         * For more information, see [Creating point maps](https://docs.aws.amazon.com/quicksight/latest/user/point-maps.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-geospatialmapvisual
         */
        readonly geospatialMapVisual?: CfnAnalysis.GeospatialMapVisualProperty | cdk.IResolvable;
        /**
         * A heat map.
         *
         * For more information, see [Using heat maps](https://docs.aws.amazon.com/quicksight/latest/user/heat-map.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-heatmapvisual
         */
        readonly heatMapVisual?: CfnAnalysis.HeatMapVisualProperty | cdk.IResolvable;
        /**
         * A histogram.
         *
         * For more information, see [Using histograms](https://docs.aws.amazon.com/quicksight/latest/user/histogram-charts.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-histogramvisual
         */
        readonly histogramVisual?: CfnAnalysis.HistogramVisualProperty | cdk.IResolvable;
        /**
         * An insight visual.
         *
         * For more information, see [Working with insights](https://docs.aws.amazon.com/quicksight/latest/user/computational-insights.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-insightvisual
         */
        readonly insightVisual?: CfnAnalysis.InsightVisualProperty | cdk.IResolvable;
        /**
         * A key performance indicator (KPI).
         *
         * For more information, see [Using KPIs](https://docs.aws.amazon.com/quicksight/latest/user/kpi.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-kpivisual
         */
        readonly kpiVisual?: cdk.IResolvable | CfnAnalysis.KPIVisualProperty;
        /**
         * A line chart.
         *
         * For more information, see [Using line charts](https://docs.aws.amazon.com/quicksight/latest/user/line-charts.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-linechartvisual
         */
        readonly lineChartVisual?: cdk.IResolvable | CfnAnalysis.LineChartVisualProperty;
        /**
         * A pie or donut chart.
         *
         * For more information, see [Using pie charts](https://docs.aws.amazon.com/quicksight/latest/user/pie-chart.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-piechartvisual
         */
        readonly pieChartVisual?: cdk.IResolvable | CfnAnalysis.PieChartVisualProperty;
        /**
         * A pivot table.
         *
         * For more information, see [Using pivot tables](https://docs.aws.amazon.com/quicksight/latest/user/pivot-table.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-pivottablevisual
         */
        readonly pivotTableVisual?: cdk.IResolvable | CfnAnalysis.PivotTableVisualProperty;
        /**
         * A radar chart visual.
         *
         * For more information, see [Using radar charts](https://docs.aws.amazon.com/quicksight/latest/user/radar-chart.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-radarchartvisual
         */
        readonly radarChartVisual?: cdk.IResolvable | CfnAnalysis.RadarChartVisualProperty;
        /**
         * A sankey diagram.
         *
         * For more information, see [Using Sankey diagrams](https://docs.aws.amazon.com/quicksight/latest/user/sankey-diagram.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-sankeydiagramvisual
         */
        readonly sankeyDiagramVisual?: cdk.IResolvable | CfnAnalysis.SankeyDiagramVisualProperty;
        /**
         * A scatter plot.
         *
         * For more information, see [Using scatter plots](https://docs.aws.amazon.com/quicksight/latest/user/scatter-plot.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-scatterplotvisual
         */
        readonly scatterPlotVisual?: cdk.IResolvable | CfnAnalysis.ScatterPlotVisualProperty;
        /**
         * A table visual.
         *
         * For more information, see [Using tables as visuals](https://docs.aws.amazon.com/quicksight/latest/user/tabular.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-tablevisual
         */
        readonly tableVisual?: cdk.IResolvable | CfnAnalysis.TableVisualProperty;
        /**
         * A tree map.
         *
         * For more information, see [Using tree maps](https://docs.aws.amazon.com/quicksight/latest/user/tree-map.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-treemapvisual
         */
        readonly treeMapVisual?: cdk.IResolvable | CfnAnalysis.TreeMapVisualProperty;
        /**
         * A waterfall chart.
         *
         * For more information, see [Using waterfall charts](https://docs.aws.amazon.com/quicksight/latest/user/waterfall-chart.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-waterfallvisual
         */
        readonly waterfallVisual?: cdk.IResolvable | CfnAnalysis.WaterfallVisualProperty;
        /**
         * A word cloud.
         *
         * For more information, see [Using word clouds](https://docs.aws.amazon.com/quicksight/latest/user/word-cloud.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-wordcloudvisual
         */
        readonly wordCloudVisual?: cdk.IResolvable | CfnAnalysis.WordCloudVisualProperty;
    }
    /**
     * A funnel chart.
     *
     * For more information, see [Using funnel charts](https://docs.aws.amazon.com/quicksight/latest/user/funnel-visual-content.html) in the *Amazon QuickSight User Guide* .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartvisual.html
     */
    interface FunnelChartVisualProperty {
        /**
         * The list of custom actions that are configured for a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartvisual.html#cfn-quicksight-analysis-funnelchartvisual-actions
         */
        readonly actions?: Array<cdk.IResolvable | CfnAnalysis.VisualCustomActionProperty> | cdk.IResolvable;
        /**
         * The configuration of a `FunnelChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartvisual.html#cfn-quicksight-analysis-funnelchartvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnAnalysis.FunnelChartConfigurationProperty | cdk.IResolvable;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartvisual.html#cfn-quicksight-analysis-funnelchartvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnAnalysis.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The subtitle that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartvisual.html#cfn-quicksight-analysis-funnelchartvisual-subtitle
         */
        readonly subtitle?: cdk.IResolvable | CfnAnalysis.VisualSubtitleLabelOptionsProperty;
        /**
         * The title that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartvisual.html#cfn-quicksight-analysis-funnelchartvisual-title
         */
        readonly title?: cdk.IResolvable | CfnAnalysis.VisualTitleLabelOptionsProperty;
        /**
         * The unique identifier of a visual.
         *
         * This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartvisual.html#cfn-quicksight-analysis-funnelchartvisual-visualid
         */
        readonly visualId: string;
    }
    /**
     * The subtitle label options for a visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualsubtitlelabeloptions.html
     */
    interface VisualSubtitleLabelOptionsProperty {
        /**
         * The long text format of the subtitle label, such as plain text or rich text.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualsubtitlelabeloptions.html#cfn-quicksight-analysis-visualsubtitlelabeloptions-formattext
         */
        readonly formatText?: cdk.IResolvable | CfnAnalysis.LongFormatTextProperty;
        /**
         * The visibility of the subtitle label.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualsubtitlelabeloptions.html#cfn-quicksight-analysis-visualsubtitlelabeloptions-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The text format for a subtitle.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-longformattext.html
     */
    interface LongFormatTextProperty {
        /**
         * Plain text format.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-longformattext.html#cfn-quicksight-analysis-longformattext-plaintext
         */
        readonly plainText?: string;
        /**
         * Rich text.
         *
         * Examples of rich text include bold, underline, and italics.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-longformattext.html#cfn-quicksight-analysis-longformattext-richtext
         */
        readonly richText?: string;
    }
    /**
     * The configuration of a `FunnelChartVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartconfiguration.html
     */
    interface FunnelChartConfigurationProperty {
        /**
         * The label options of the categories that are displayed in a `FunnelChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartconfiguration.html#cfn-quicksight-analysis-funnelchartconfiguration-categorylabeloptions
         */
        readonly categoryLabelOptions?: CfnAnalysis.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The options that determine the presentation of the data labels.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartconfiguration.html#cfn-quicksight-analysis-funnelchartconfiguration-datalabeloptions
         */
        readonly dataLabelOptions?: CfnAnalysis.FunnelChartDataLabelOptionsProperty | cdk.IResolvable;
        /**
         * The field well configuration of a `FunnelChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartconfiguration.html#cfn-quicksight-analysis-funnelchartconfiguration-fieldwells
         */
        readonly fieldWells?: CfnAnalysis.FunnelChartFieldWellsProperty | cdk.IResolvable;
        /**
         * The sort configuration of a `FunnelChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartconfiguration.html#cfn-quicksight-analysis-funnelchartconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: CfnAnalysis.FunnelChartSortConfigurationProperty | cdk.IResolvable;
        /**
         * The tooltip configuration of a `FunnelChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartconfiguration.html#cfn-quicksight-analysis-funnelchartconfiguration-tooltip
         */
        readonly tooltip?: cdk.IResolvable | CfnAnalysis.TooltipOptionsProperty;
        /**
         * The label options for the values that are displayed in a `FunnelChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartconfiguration.html#cfn-quicksight-analysis-funnelchartconfiguration-valuelabeloptions
         */
        readonly valueLabelOptions?: CfnAnalysis.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The visual palette configuration of a `FunnelChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartconfiguration.html#cfn-quicksight-analysis-funnelchartconfiguration-visualpalette
         */
        readonly visualPalette?: cdk.IResolvable | CfnAnalysis.VisualPaletteProperty;
    }
    /**
     * The sort configuration of a `FunnelChartVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartsortconfiguration.html
     */
    interface FunnelChartSortConfigurationProperty {
        /**
         * The limit on the number of categories displayed.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartsortconfiguration.html#cfn-quicksight-analysis-funnelchartsortconfiguration-categoryitemslimit
         */
        readonly categoryItemsLimit?: cdk.IResolvable | CfnAnalysis.ItemsLimitConfigurationProperty;
        /**
         * The sort configuration of the category fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartsortconfiguration.html#cfn-quicksight-analysis-funnelchartsortconfiguration-categorysort
         */
        readonly categorySort?: Array<CfnAnalysis.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * The limit configuration of the visual display for an axis.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-itemslimitconfiguration.html
     */
    interface ItemsLimitConfigurationProperty {
        /**
         * The limit on how many items of a field are showed in the chart.
         *
         * For example, the number of slices that are displayed in a pie chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-itemslimitconfiguration.html#cfn-quicksight-analysis-itemslimitconfiguration-itemslimit
         */
        readonly itemsLimit?: number;
        /**
         * The `Show other` of an axis in the chart. Choose one of the following options:.
         *
         * - `INCLUDE`
         * - `EXCLUDE`
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-itemslimitconfiguration.html#cfn-quicksight-analysis-itemslimitconfiguration-othercategories
         */
        readonly otherCategories?: string;
    }
    /**
     * The field sort options in a chart configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldsortoptions.html
     */
    interface FieldSortOptionsProperty {
        /**
         * The sort configuration for a column that is not used in a field well.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldsortoptions.html#cfn-quicksight-analysis-fieldsortoptions-columnsort
         */
        readonly columnSort?: CfnAnalysis.ColumnSortProperty | cdk.IResolvable;
        /**
         * The sort configuration for a field in a field well.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldsortoptions.html#cfn-quicksight-analysis-fieldsortoptions-fieldsort
         */
        readonly fieldSort?: CfnAnalysis.FieldSortProperty | cdk.IResolvable;
    }
    /**
     * The sort configuration for a field in a field well.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldsort.html
     */
    interface FieldSortProperty {
        /**
         * The sort direction. Choose one of the following options:.
         *
         * - `ASC` : Ascending
         * - `DESC` : Descending
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldsort.html#cfn-quicksight-analysis-fieldsort-direction
         */
        readonly direction: string;
        /**
         * The sort configuration target field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldsort.html#cfn-quicksight-analysis-fieldsort-fieldid
         */
        readonly fieldId: string;
    }
    /**
     * The sort configuration for a column that is not used in a field well.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnsort.html
     */
    interface ColumnSortProperty {
        /**
         * The aggregation function that is defined in the column sort.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnsort.html#cfn-quicksight-analysis-columnsort-aggregationfunction
         */
        readonly aggregationFunction?: CfnAnalysis.AggregationFunctionProperty | cdk.IResolvable;
        /**
         * The sort direction.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnsort.html#cfn-quicksight-analysis-columnsort-direction
         */
        readonly direction: string;
        /**
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnsort.html#cfn-quicksight-analysis-columnsort-sortby
         */
        readonly sortBy: CfnAnalysis.ColumnIdentifierProperty | cdk.IResolvable;
    }
    /**
     * The options that determine the presentation of the data labels.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartdatalabeloptions.html
     */
    interface FunnelChartDataLabelOptionsProperty {
        /**
         * The visibility of the category labels within the data labels.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartdatalabeloptions.html#cfn-quicksight-analysis-funnelchartdatalabeloptions-categorylabelvisibility
         */
        readonly categoryLabelVisibility?: string;
        /**
         * The color of the data label text.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartdatalabeloptions.html#cfn-quicksight-analysis-funnelchartdatalabeloptions-labelcolor
         */
        readonly labelColor?: string;
        /**
         * The font configuration for the data labels.
         *
         * Only the `FontSize` attribute of the font configuration is used for data labels.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartdatalabeloptions.html#cfn-quicksight-analysis-funnelchartdatalabeloptions-labelfontconfiguration
         */
        readonly labelFontConfiguration?: CfnAnalysis.FontConfigurationProperty | cdk.IResolvable;
        /**
         * Determines the style of the metric labels.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartdatalabeloptions.html#cfn-quicksight-analysis-funnelchartdatalabeloptions-measuredatalabelstyle
         */
        readonly measureDataLabelStyle?: string;
        /**
         * The visibility of the measure labels within the data labels.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartdatalabeloptions.html#cfn-quicksight-analysis-funnelchartdatalabeloptions-measurelabelvisibility
         */
        readonly measureLabelVisibility?: string;
        /**
         * Determines the positioning of the data label relative to a section of the funnel.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartdatalabeloptions.html#cfn-quicksight-analysis-funnelchartdatalabeloptions-position
         */
        readonly position?: string;
        /**
         * The visibility option that determines if data labels are displayed.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartdatalabeloptions.html#cfn-quicksight-analysis-funnelchartdatalabeloptions-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The label options for an axis on a chart.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-chartaxislabeloptions.html
     */
    interface ChartAxisLabelOptionsProperty {
        /**
         * The label options for a chart axis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-chartaxislabeloptions.html#cfn-quicksight-analysis-chartaxislabeloptions-axislabeloptions
         */
        readonly axisLabelOptions?: Array<CfnAnalysis.AxisLabelOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The visibility configuration of the sort icon on a chart's axis label.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-chartaxislabeloptions.html#cfn-quicksight-analysis-chartaxislabeloptions-sorticonvisibility
         */
        readonly sortIconVisibility?: string;
        /**
         * The visibility of an axis label on a chart. Choose one of the following options:.
         *
         * - `VISIBLE` : Shows the axis.
         * - `HIDDEN` : Hides the axis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-chartaxislabeloptions.html#cfn-quicksight-analysis-chartaxislabeloptions-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The label options for a chart axis.
     *
     * You must specify the field that the label is targeted to.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axislabeloptions.html
     */
    interface AxisLabelOptionsProperty {
        /**
         * The options that indicate which field the label belongs to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axislabeloptions.html#cfn-quicksight-analysis-axislabeloptions-applyto
         */
        readonly applyTo?: CfnAnalysis.AxisLabelReferenceOptionsProperty | cdk.IResolvable;
        /**
         * The text for the axis label.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axislabeloptions.html#cfn-quicksight-analysis-axislabeloptions-customlabel
         */
        readonly customLabel?: string;
        /**
         * The font configuration of the axis label.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axislabeloptions.html#cfn-quicksight-analysis-axislabeloptions-fontconfiguration
         */
        readonly fontConfiguration?: CfnAnalysis.FontConfigurationProperty | cdk.IResolvable;
    }
    /**
     * The reference that specifies where the axis label is applied to.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axislabelreferenceoptions.html
     */
    interface AxisLabelReferenceOptionsProperty {
        /**
         * The column that the axis label is targeted to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axislabelreferenceoptions.html#cfn-quicksight-analysis-axislabelreferenceoptions-column
         */
        readonly column: CfnAnalysis.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * The field that the axis label is targeted to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axislabelreferenceoptions.html#cfn-quicksight-analysis-axislabelreferenceoptions-fieldid
         */
        readonly fieldId: string;
    }
    /**
     * The field well configuration of a `FunnelChartVisual` .
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartfieldwells.html
     */
    interface FunnelChartFieldWellsProperty {
        /**
         * The field well configuration of a `FunnelChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartfieldwells.html#cfn-quicksight-analysis-funnelchartfieldwells-funnelchartaggregatedfieldwells
         */
        readonly funnelChartAggregatedFieldWells?: CfnAnalysis.FunnelChartAggregatedFieldWellsProperty | cdk.IResolvable;
    }
    /**
     * The field well configuration of a `FunnelChartVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartaggregatedfieldwells.html
     */
    interface FunnelChartAggregatedFieldWellsProperty {
        /**
         * The category field wells of a funnel chart.
         *
         * Values are grouped by category fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartaggregatedfieldwells.html#cfn-quicksight-analysis-funnelchartaggregatedfieldwells-category
         */
        readonly category?: Array<CfnAnalysis.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The value field wells of a funnel chart.
         *
         * Values are aggregated based on categories.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartaggregatedfieldwells.html#cfn-quicksight-analysis-funnelchartaggregatedfieldwells-values
         */
        readonly values?: Array<cdk.IResolvable | CfnAnalysis.MeasureFieldProperty> | cdk.IResolvable;
    }
    /**
     * The dimension type field.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-dimensionfield.html
     */
    interface DimensionFieldProperty {
        /**
         * The dimension type field with categorical type columns.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-dimensionfield.html#cfn-quicksight-analysis-dimensionfield-categoricaldimensionfield
         */
        readonly categoricalDimensionField?: CfnAnalysis.CategoricalDimensionFieldProperty | cdk.IResolvable;
        /**
         * The dimension type field with date type columns.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-dimensionfield.html#cfn-quicksight-analysis-dimensionfield-datedimensionfield
         */
        readonly dateDimensionField?: CfnAnalysis.DateDimensionFieldProperty | cdk.IResolvable;
        /**
         * The dimension type field with numerical type columns.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-dimensionfield.html#cfn-quicksight-analysis-dimensionfield-numericaldimensionfield
         */
        readonly numericalDimensionField?: cdk.IResolvable | CfnAnalysis.NumericalDimensionFieldProperty;
    }
    /**
     * The dimension type field with date type columns.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datedimensionfield.html
     */
    interface DateDimensionFieldProperty {
        /**
         * The column that is used in the `DateDimensionField` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datedimensionfield.html#cfn-quicksight-analysis-datedimensionfield-column
         */
        readonly column: CfnAnalysis.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * The date granularity of the `DateDimensionField` . Choose one of the following options:.
         *
         * - `YEAR`
         * - `QUARTER`
         * - `MONTH`
         * - `WEEK`
         * - `DAY`
         * - `HOUR`
         * - `MINUTE`
         * - `SECOND`
         * - `MILLISECOND`
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datedimensionfield.html#cfn-quicksight-analysis-datedimensionfield-dategranularity
         */
        readonly dateGranularity?: string;
        /**
         * The custom field ID.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datedimensionfield.html#cfn-quicksight-analysis-datedimensionfield-fieldid
         */
        readonly fieldId: string;
        /**
         * The format configuration of the field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datedimensionfield.html#cfn-quicksight-analysis-datedimensionfield-formatconfiguration
         */
        readonly formatConfiguration?: CfnAnalysis.DateTimeFormatConfigurationProperty | cdk.IResolvable;
        /**
         * The custom hierarchy ID.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datedimensionfield.html#cfn-quicksight-analysis-datedimensionfield-hierarchyid
         */
        readonly hierarchyId?: string;
    }
    /**
     * The dimension type field with numerical type columns.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericaldimensionfield.html
     */
    interface NumericalDimensionFieldProperty {
        /**
         * The column that is used in the `NumericalDimensionField` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericaldimensionfield.html#cfn-quicksight-analysis-numericaldimensionfield-column
         */
        readonly column: CfnAnalysis.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * The custom field ID.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericaldimensionfield.html#cfn-quicksight-analysis-numericaldimensionfield-fieldid
         */
        readonly fieldId: string;
        /**
         * The format configuration of the field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericaldimensionfield.html#cfn-quicksight-analysis-numericaldimensionfield-formatconfiguration
         */
        readonly formatConfiguration?: cdk.IResolvable | CfnAnalysis.NumberFormatConfigurationProperty;
        /**
         * The custom hierarchy ID.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericaldimensionfield.html#cfn-quicksight-analysis-numericaldimensionfield-hierarchyid
         */
        readonly hierarchyId?: string;
    }
    /**
     * The dimension type field with categorical type columns..
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoricaldimensionfield.html
     */
    interface CategoricalDimensionFieldProperty {
        /**
         * The column that is used in the `CategoricalDimensionField` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoricaldimensionfield.html#cfn-quicksight-analysis-categoricaldimensionfield-column
         */
        readonly column: CfnAnalysis.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * The custom field ID.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoricaldimensionfield.html#cfn-quicksight-analysis-categoricaldimensionfield-fieldid
         */
        readonly fieldId: string;
        /**
         * The format configuration of the field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoricaldimensionfield.html#cfn-quicksight-analysis-categoricaldimensionfield-formatconfiguration
         */
        readonly formatConfiguration?: cdk.IResolvable | CfnAnalysis.StringFormatConfigurationProperty;
        /**
         * The custom hierarchy ID.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoricaldimensionfield.html#cfn-quicksight-analysis-categoricaldimensionfield-hierarchyid
         */
        readonly hierarchyId?: string;
    }
    /**
     * The measure (metric) type field.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-measurefield.html
     */
    interface MeasureFieldProperty {
        /**
         * The calculated measure field only used in pivot tables.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-measurefield.html#cfn-quicksight-analysis-measurefield-calculatedmeasurefield
         */
        readonly calculatedMeasureField?: CfnAnalysis.CalculatedMeasureFieldProperty | cdk.IResolvable;
        /**
         * The measure type field with categorical type columns.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-measurefield.html#cfn-quicksight-analysis-measurefield-categoricalmeasurefield
         */
        readonly categoricalMeasureField?: CfnAnalysis.CategoricalMeasureFieldProperty | cdk.IResolvable;
        /**
         * The measure type field with date type columns.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-measurefield.html#cfn-quicksight-analysis-measurefield-datemeasurefield
         */
        readonly dateMeasureField?: CfnAnalysis.DateMeasureFieldProperty | cdk.IResolvable;
        /**
         * The measure type field with numerical type columns.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-measurefield.html#cfn-quicksight-analysis-measurefield-numericalmeasurefield
         */
        readonly numericalMeasureField?: cdk.IResolvable | CfnAnalysis.NumericalMeasureFieldProperty;
    }
    /**
     * The measure type field with date type columns.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datemeasurefield.html
     */
    interface DateMeasureFieldProperty {
        /**
         * The aggregation function of the measure field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datemeasurefield.html#cfn-quicksight-analysis-datemeasurefield-aggregationfunction
         */
        readonly aggregationFunction?: string;
        /**
         * The column that is used in the `DateMeasureField` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datemeasurefield.html#cfn-quicksight-analysis-datemeasurefield-column
         */
        readonly column: CfnAnalysis.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * The custom field ID.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datemeasurefield.html#cfn-quicksight-analysis-datemeasurefield-fieldid
         */
        readonly fieldId: string;
        /**
         * The format configuration of the field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datemeasurefield.html#cfn-quicksight-analysis-datemeasurefield-formatconfiguration
         */
        readonly formatConfiguration?: CfnAnalysis.DateTimeFormatConfigurationProperty | cdk.IResolvable;
    }
    /**
     * The measure type field with numerical type columns.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericalmeasurefield.html
     */
    interface NumericalMeasureFieldProperty {
        /**
         * The aggregation function of the measure field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericalmeasurefield.html#cfn-quicksight-analysis-numericalmeasurefield-aggregationfunction
         */
        readonly aggregationFunction?: cdk.IResolvable | CfnAnalysis.NumericalAggregationFunctionProperty;
        /**
         * The column that is used in the `NumericalMeasureField` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericalmeasurefield.html#cfn-quicksight-analysis-numericalmeasurefield-column
         */
        readonly column: CfnAnalysis.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * The custom field ID.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericalmeasurefield.html#cfn-quicksight-analysis-numericalmeasurefield-fieldid
         */
        readonly fieldId: string;
        /**
         * The format configuration of the field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericalmeasurefield.html#cfn-quicksight-analysis-numericalmeasurefield-formatconfiguration
         */
        readonly formatConfiguration?: cdk.IResolvable | CfnAnalysis.NumberFormatConfigurationProperty;
    }
    /**
     * The measure type field with categorical type columns.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoricalmeasurefield.html
     */
    interface CategoricalMeasureFieldProperty {
        /**
         * The aggregation function of the measure field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoricalmeasurefield.html#cfn-quicksight-analysis-categoricalmeasurefield-aggregationfunction
         */
        readonly aggregationFunction?: string;
        /**
         * The column that is used in the `CategoricalMeasureField` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoricalmeasurefield.html#cfn-quicksight-analysis-categoricalmeasurefield-column
         */
        readonly column: CfnAnalysis.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * The custom field ID.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoricalmeasurefield.html#cfn-quicksight-analysis-categoricalmeasurefield-fieldid
         */
        readonly fieldId: string;
        /**
         * The format configuration of the field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoricalmeasurefield.html#cfn-quicksight-analysis-categoricalmeasurefield-formatconfiguration
         */
        readonly formatConfiguration?: cdk.IResolvable | CfnAnalysis.StringFormatConfigurationProperty;
    }
    /**
     * The table calculation measure field for pivot tables.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-calculatedmeasurefield.html
     */
    interface CalculatedMeasureFieldProperty {
        /**
         * The expression in the table calculation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-calculatedmeasurefield.html#cfn-quicksight-analysis-calculatedmeasurefield-expression
         */
        readonly expression: string;
        /**
         * The custom field ID.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-calculatedmeasurefield.html#cfn-quicksight-analysis-calculatedmeasurefield-fieldid
         */
        readonly fieldId: string;
    }
    /**
     * The display options for the visual tooltip.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tooltipoptions.html
     */
    interface TooltipOptionsProperty {
        /**
         * The setup for the detailed tooltip.
         *
         * The tooltip setup is always saved. The display type is decided based on the tooltip type.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tooltipoptions.html#cfn-quicksight-analysis-tooltipoptions-fieldbasedtooltip
         */
        readonly fieldBasedTooltip?: CfnAnalysis.FieldBasedTooltipProperty | cdk.IResolvable;
        /**
         * The selected type for the tooltip. Choose one of the following options:.
         *
         * - `BASIC` : A basic tooltip.
         * - `DETAILED` : A detailed tooltip.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tooltipoptions.html#cfn-quicksight-analysis-tooltipoptions-selectedtooltiptype
         */
        readonly selectedTooltipType?: string;
        /**
         * Determines whether or not the tooltip is visible.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tooltipoptions.html#cfn-quicksight-analysis-tooltipoptions-tooltipvisibility
         */
        readonly tooltipVisibility?: string;
    }
    /**
     * The setup for the detailed tooltip.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldbasedtooltip.html
     */
    interface FieldBasedTooltipProperty {
        /**
         * The visibility of `Show aggregations` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldbasedtooltip.html#cfn-quicksight-analysis-fieldbasedtooltip-aggregationvisibility
         */
        readonly aggregationVisibility?: string;
        /**
         * The fields configuration in the tooltip.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldbasedtooltip.html#cfn-quicksight-analysis-fieldbasedtooltip-tooltipfields
         */
        readonly tooltipFields?: Array<cdk.IResolvable | CfnAnalysis.TooltipItemProperty> | cdk.IResolvable;
        /**
         * The type for the >tooltip title. Choose one of the following options:.
         *
         * - `NONE` : Doesn't use the primary value as the title.
         * - `PRIMARY_VALUE` : Uses primary value as the title.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldbasedtooltip.html#cfn-quicksight-analysis-fieldbasedtooltip-tooltiptitletype
         */
        readonly tooltipTitleType?: string;
    }
    /**
     * The tooltip.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tooltipitem.html
     */
    interface TooltipItemProperty {
        /**
         * The tooltip item for the columns that are not part of a field well.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tooltipitem.html#cfn-quicksight-analysis-tooltipitem-columntooltipitem
         */
        readonly columnTooltipItem?: CfnAnalysis.ColumnTooltipItemProperty | cdk.IResolvable;
        /**
         * The tooltip item for the fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tooltipitem.html#cfn-quicksight-analysis-tooltipitem-fieldtooltipitem
         */
        readonly fieldTooltipItem?: CfnAnalysis.FieldTooltipItemProperty | cdk.IResolvable;
    }
    /**
     * The tooltip item for the fields.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldtooltipitem.html
     */
    interface FieldTooltipItemProperty {
        /**
         * The unique ID of the field that is targeted by the tooltip.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldtooltipitem.html#cfn-quicksight-analysis-fieldtooltipitem-fieldid
         */
        readonly fieldId: string;
        /**
         * The label of the tooltip item.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldtooltipitem.html#cfn-quicksight-analysis-fieldtooltipitem-label
         */
        readonly label?: string;
        /**
         * The visibility of the tooltip item.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldtooltipitem.html#cfn-quicksight-analysis-fieldtooltipitem-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The tooltip item for the columns that are not part of a field well.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columntooltipitem.html
     */
    interface ColumnTooltipItemProperty {
        /**
         * The aggregation function of the column tooltip item.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columntooltipitem.html#cfn-quicksight-analysis-columntooltipitem-aggregation
         */
        readonly aggregation?: CfnAnalysis.AggregationFunctionProperty | cdk.IResolvable;
        /**
         * The target column of the tooltip item.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columntooltipitem.html#cfn-quicksight-analysis-columntooltipitem-column
         */
        readonly column: CfnAnalysis.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * The label of the tooltip item.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columntooltipitem.html#cfn-quicksight-analysis-columntooltipitem-label
         */
        readonly label?: string;
        /**
         * The visibility of the tooltip item.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columntooltipitem.html#cfn-quicksight-analysis-columntooltipitem-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The visual display options for the visual palette.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualpalette.html
     */
    interface VisualPaletteProperty {
        /**
         * The chart color options for the visual palette.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualpalette.html#cfn-quicksight-analysis-visualpalette-chartcolor
         */
        readonly chartColor?: string;
        /**
         * The color map options for the visual palette.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualpalette.html#cfn-quicksight-analysis-visualpalette-colormap
         */
        readonly colorMap?: Array<CfnAnalysis.DataPathColorProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * The color map that determines the color options for a particular element.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathcolor.html
     */
    interface DataPathColorProperty {
        /**
         * The color that needs to be applied to the element.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathcolor.html#cfn-quicksight-analysis-datapathcolor-color
         */
        readonly color: string;
        /**
         * The element that the color needs to be applied to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathcolor.html#cfn-quicksight-analysis-datapathcolor-element
         */
        readonly element: CfnAnalysis.DataPathValueProperty | cdk.IResolvable;
        /**
         * The time granularity of the field that the color needs to be applied to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathcolor.html#cfn-quicksight-analysis-datapathcolor-timegranularity
         */
        readonly timeGranularity?: string;
    }
    /**
     * The data path that needs to be sorted.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathvalue.html
     */
    interface DataPathValueProperty {
        /**
         * The type configuration of the field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathvalue.html#cfn-quicksight-analysis-datapathvalue-datapathtype
         */
        readonly dataPathType?: CfnAnalysis.DataPathTypeProperty | cdk.IResolvable;
        /**
         * The field ID of the field that needs to be sorted.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathvalue.html#cfn-quicksight-analysis-datapathvalue-fieldid
         */
        readonly fieldId?: string;
        /**
         * The actual value of the field that needs to be sorted.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathvalue.html#cfn-quicksight-analysis-datapathvalue-fieldvalue
         */
        readonly fieldValue?: string;
    }
    /**
     * The type of the data path value.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathtype.html
     */
    interface DataPathTypeProperty {
        /**
         * The type of data path value utilized in a pivot table. Choose one of the following options:.
         *
         * - `HIERARCHY_ROWS_LAYOUT_COLUMN` - The type of data path for the rows layout column, when `RowsLayout` is set to `HIERARCHY` .
         * - `MULTIPLE_ROW_METRICS_COLUMN` - The type of data path for the metric column when the row is set to Metric Placement.
         * - `EMPTY_COLUMN_HEADER` - The type of data path for the column with empty column header, when there is no field in `ColumnsFieldWell` and the row is set to Metric Placement.
         * - `COUNT_METRIC_COLUMN` - The type of data path for the column with `COUNT` as the metric, when there is no field in the `ValuesFieldWell` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathtype.html#cfn-quicksight-analysis-datapathtype-pivottabledatapathtype
         */
        readonly pivotTableDataPathType?: string;
    }
    /**
     * A custom action defined on a visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualcustomaction.html
     */
    interface VisualCustomActionProperty {
        /**
         * A list of `VisualCustomActionOperations` .
         *
         * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualcustomaction.html#cfn-quicksight-analysis-visualcustomaction-actionoperations
         */
        readonly actionOperations: Array<cdk.IResolvable | CfnAnalysis.VisualCustomActionOperationProperty> | cdk.IResolvable;
        /**
         * The ID of the `VisualCustomAction` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualcustomaction.html#cfn-quicksight-analysis-visualcustomaction-customactionid
         */
        readonly customActionId: string;
        /**
         * The name of the `VisualCustomAction` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualcustomaction.html#cfn-quicksight-analysis-visualcustomaction-name
         */
        readonly name: string;
        /**
         * The status of the `VisualCustomAction` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualcustomaction.html#cfn-quicksight-analysis-visualcustomaction-status
         */
        readonly status?: string;
        /**
         * The trigger of the `VisualCustomAction` .
         *
         * Valid values are defined as follows:
         *
         * - `DATA_POINT_CLICK` : Initiates a custom action by a left pointer click on a data point.
         * - `DATA_POINT_MENU` : Initiates a custom action by right pointer click from the menu.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualcustomaction.html#cfn-quicksight-analysis-visualcustomaction-trigger
         */
        readonly trigger: string;
    }
    /**
     * The operation that is defined by the custom action.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualcustomactionoperation.html
     */
    interface VisualCustomActionOperationProperty {
        /**
         * The filter operation that filters data included in a visual or in an entire sheet.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualcustomactionoperation.html#cfn-quicksight-analysis-visualcustomactionoperation-filteroperation
         */
        readonly filterOperation?: CfnAnalysis.CustomActionFilterOperationProperty | cdk.IResolvable;
        /**
         * The navigation operation that navigates between different sheets in the same analysis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualcustomactionoperation.html#cfn-quicksight-analysis-visualcustomactionoperation-navigationoperation
         */
        readonly navigationOperation?: CfnAnalysis.CustomActionNavigationOperationProperty | cdk.IResolvable;
        /**
         * The set parameter operation that sets parameters in custom action.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualcustomactionoperation.html#cfn-quicksight-analysis-visualcustomactionoperation-setparametersoperation
         */
        readonly setParametersOperation?: CfnAnalysis.CustomActionSetParametersOperationProperty | cdk.IResolvable;
        /**
         * The URL operation that opens a link to another webpage.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualcustomactionoperation.html#cfn-quicksight-analysis-visualcustomactionoperation-urloperation
         */
        readonly urlOperation?: CfnAnalysis.CustomActionURLOperationProperty | cdk.IResolvable;
    }
    /**
     * The navigation operation that navigates between different sheets in the same analysis.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customactionnavigationoperation.html
     */
    interface CustomActionNavigationOperationProperty {
        /**
         * The configuration that chooses the navigation target.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customactionnavigationoperation.html#cfn-quicksight-analysis-customactionnavigationoperation-localnavigationconfiguration
         */
        readonly localNavigationConfiguration?: cdk.IResolvable | CfnAnalysis.LocalNavigationConfigurationProperty;
    }
    /**
     * The navigation configuration for `CustomActionNavigationOperation` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-localnavigationconfiguration.html
     */
    interface LocalNavigationConfigurationProperty {
        /**
         * The sheet that is targeted for navigation in the same analysis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-localnavigationconfiguration.html#cfn-quicksight-analysis-localnavigationconfiguration-targetsheetid
         */
        readonly targetSheetId: string;
    }
    /**
     * The set parameter operation that sets parameters in custom action.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customactionsetparametersoperation.html
     */
    interface CustomActionSetParametersOperationProperty {
        /**
         * The parameter that determines the value configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customactionsetparametersoperation.html#cfn-quicksight-analysis-customactionsetparametersoperation-parametervalueconfigurations
         */
        readonly parameterValueConfigurations: Array<cdk.IResolvable | CfnAnalysis.SetParameterValueConfigurationProperty> | cdk.IResolvable;
    }
    /**
     * The configuration of adding parameters in action.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-setparametervalueconfiguration.html
     */
    interface SetParameterValueConfigurationProperty {
        /**
         * The destination parameter name of the `SetParameterValueConfiguration` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-setparametervalueconfiguration.html#cfn-quicksight-analysis-setparametervalueconfiguration-destinationparametername
         */
        readonly destinationParameterName: string;
        /**
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-setparametervalueconfiguration.html#cfn-quicksight-analysis-setparametervalueconfiguration-value
         */
        readonly value: CfnAnalysis.DestinationParameterValueConfigurationProperty | cdk.IResolvable;
    }
    /**
     * The configuration of destination parameter values.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-destinationparametervalueconfiguration.html
     */
    interface DestinationParameterValueConfigurationProperty {
        /**
         * The configuration of custom values for destination parameter in `DestinationParameterValueConfiguration` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-destinationparametervalueconfiguration.html#cfn-quicksight-analysis-destinationparametervalueconfiguration-customvaluesconfiguration
         */
        readonly customValuesConfiguration?: CfnAnalysis.CustomValuesConfigurationProperty | cdk.IResolvable;
        /**
         * The configuration that selects all options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-destinationparametervalueconfiguration.html#cfn-quicksight-analysis-destinationparametervalueconfiguration-selectallvalueoptions
         */
        readonly selectAllValueOptions?: string;
        /**
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-destinationparametervalueconfiguration.html#cfn-quicksight-analysis-destinationparametervalueconfiguration-sourcecolumn
         */
        readonly sourceColumn?: CfnAnalysis.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * The source field ID of the destination parameter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-destinationparametervalueconfiguration.html#cfn-quicksight-analysis-destinationparametervalueconfiguration-sourcefield
         */
        readonly sourceField?: string;
        /**
         * The source parameter name of the destination parameter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-destinationparametervalueconfiguration.html#cfn-quicksight-analysis-destinationparametervalueconfiguration-sourceparametername
         */
        readonly sourceParameterName?: string;
    }
    /**
     * The configuration of custom values for the destination parameter in `DestinationParameterValueConfiguration` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customvaluesconfiguration.html
     */
    interface CustomValuesConfigurationProperty {
        /**
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customvaluesconfiguration.html#cfn-quicksight-analysis-customvaluesconfiguration-customvalues
         */
        readonly customValues: CfnAnalysis.CustomParameterValuesProperty | cdk.IResolvable;
        /**
         * Includes the null value in custom action parameter values.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customvaluesconfiguration.html#cfn-quicksight-analysis-customvaluesconfiguration-includenullvalue
         */
        readonly includeNullValue?: boolean | cdk.IResolvable;
    }
    /**
     * The customized parameter values.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customparametervalues.html
     */
    interface CustomParameterValuesProperty {
        /**
         * A list of datetime-type parameter values.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customparametervalues.html#cfn-quicksight-analysis-customparametervalues-datetimevalues
         */
        readonly dateTimeValues?: Array<string>;
        /**
         * A list of decimal-type parameter values.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customparametervalues.html#cfn-quicksight-analysis-customparametervalues-decimalvalues
         */
        readonly decimalValues?: Array<number> | cdk.IResolvable;
        /**
         * A list of integer-type parameter values.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customparametervalues.html#cfn-quicksight-analysis-customparametervalues-integervalues
         */
        readonly integerValues?: Array<number> | cdk.IResolvable;
        /**
         * A list of string-type parameter values.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customparametervalues.html#cfn-quicksight-analysis-customparametervalues-stringvalues
         */
        readonly stringValues?: Array<string>;
    }
    /**
     * The filter operation that filters data included in a visual or in an entire sheet.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customactionfilteroperation.html
     */
    interface CustomActionFilterOperationProperty {
        /**
         * The configuration that chooses the fields to be filtered.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customactionfilteroperation.html#cfn-quicksight-analysis-customactionfilteroperation-selectedfieldsconfiguration
         */
        readonly selectedFieldsConfiguration: CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty | cdk.IResolvable;
        /**
         * The configuration that chooses the target visuals to be filtered.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customactionfilteroperation.html#cfn-quicksight-analysis-customactionfilteroperation-targetvisualsconfiguration
         */
        readonly targetVisualsConfiguration: CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty | cdk.IResolvable;
    }
    /**
     * The configuration of selected fields in the `CustomActionFilterOperation` .
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filteroperationselectedfieldsconfiguration.html
     */
    interface FilterOperationSelectedFieldsConfigurationProperty {
        /**
         * The selected columns of a dataset.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filteroperationselectedfieldsconfiguration.html#cfn-quicksight-analysis-filteroperationselectedfieldsconfiguration-selectedcolumns
         */
        readonly selectedColumns?: Array<CfnAnalysis.ColumnIdentifierProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * A structure that contains the options that choose which fields are filtered in the `CustomActionFilterOperation` .
         *
         * Valid values are defined as follows:
         *
         * - `ALL_FIELDS` : Applies the filter operation to all fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filteroperationselectedfieldsconfiguration.html#cfn-quicksight-analysis-filteroperationselectedfieldsconfiguration-selectedfieldoptions
         */
        readonly selectedFieldOptions?: string;
        /**
         * Chooses the fields that are filtered in `CustomActionFilterOperation` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filteroperationselectedfieldsconfiguration.html#cfn-quicksight-analysis-filteroperationselectedfieldsconfiguration-selectedfields
         */
        readonly selectedFields?: Array<string>;
    }
    /**
     * The configuration of target visuals that you want to be filtered.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filteroperationtargetvisualsconfiguration.html
     */
    interface FilterOperationTargetVisualsConfigurationProperty {
        /**
         * The configuration of the same-sheet target visuals that you want to be filtered.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filteroperationtargetvisualsconfiguration.html#cfn-quicksight-analysis-filteroperationtargetvisualsconfiguration-samesheettargetvisualconfiguration
         */
        readonly sameSheetTargetVisualConfiguration?: cdk.IResolvable | CfnAnalysis.SameSheetTargetVisualConfigurationProperty;
    }
    /**
     * The configuration of the same-sheet target visuals that you want to be filtered.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-samesheettargetvisualconfiguration.html
     */
    interface SameSheetTargetVisualConfigurationProperty {
        /**
         * The options that choose the target visual in the same sheet.
         *
         * Valid values are defined as follows:
         *
         * - `ALL_VISUALS` : Applies the filter operation to all visuals in the same sheet.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-samesheettargetvisualconfiguration.html#cfn-quicksight-analysis-samesheettargetvisualconfiguration-targetvisualoptions
         */
        readonly targetVisualOptions?: string;
        /**
         * A list of the target visual IDs that are located in the same sheet of the analysis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-samesheettargetvisualconfiguration.html#cfn-quicksight-analysis-samesheettargetvisualconfiguration-targetvisuals
         */
        readonly targetVisuals?: Array<string>;
    }
    /**
     * The URL operation that opens a link to another webpage.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customactionurloperation.html
     */
    interface CustomActionURLOperationProperty {
        /**
         * The target of the `CustomActionURLOperation` .
         *
         * Valid values are defined as follows:
         *
         * - `NEW_TAB` : Opens the target URL in a new browser tab.
         * - `NEW_WINDOW` : Opens the target URL in a new browser window.
         * - `SAME_TAB` : Opens the target URL in the same browser tab.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customactionurloperation.html#cfn-quicksight-analysis-customactionurloperation-urltarget
         */
        readonly urlTarget: string;
        /**
         * THe URL link of the `CustomActionURLOperation` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customactionurloperation.html#cfn-quicksight-analysis-customactionurloperation-urltemplate
         */
        readonly urlTemplate: string;
    }
    /**
     * The title label options for a visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualtitlelabeloptions.html
     */
    interface VisualTitleLabelOptionsProperty {
        /**
         * The short text format of the title label, such as plain text or rich text.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualtitlelabeloptions.html#cfn-quicksight-analysis-visualtitlelabeloptions-formattext
         */
        readonly formatText?: cdk.IResolvable | CfnAnalysis.ShortFormatTextProperty;
        /**
         * The visibility of the title label.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualtitlelabeloptions.html#cfn-quicksight-analysis-visualtitlelabeloptions-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The text format for the title.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-shortformattext.html
     */
    interface ShortFormatTextProperty {
        /**
         * Plain text format.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-shortformattext.html#cfn-quicksight-analysis-shortformattext-plaintext
         */
        readonly plainText?: string;
        /**
         * Rich text.
         *
         * Examples of rich text include bold, underline, and italics.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-shortformattext.html#cfn-quicksight-analysis-shortformattext-richtext
         */
        readonly richText?: string;
    }
    /**
     * The option that determines the hierarchy of the fields for a visual element.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnhierarchy.html
     */
    interface ColumnHierarchyProperty {
        /**
         * The option that determines the hierarchy of any `DateTime` fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnhierarchy.html#cfn-quicksight-analysis-columnhierarchy-datetimehierarchy
         */
        readonly dateTimeHierarchy?: CfnAnalysis.DateTimeHierarchyProperty | cdk.IResolvable;
        /**
         * The option that determines the hierarchy of the fields that are built within a visual's field wells.
         *
         * These fields can't be duplicated to other visuals.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnhierarchy.html#cfn-quicksight-analysis-columnhierarchy-explicithierarchy
         */
        readonly explicitHierarchy?: CfnAnalysis.ExplicitHierarchyProperty | cdk.IResolvable;
        /**
         * The option that determines the hierarchy of the fields that are defined during data preparation.
         *
         * These fields are available to use in any analysis that uses the data source.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnhierarchy.html#cfn-quicksight-analysis-columnhierarchy-predefinedhierarchy
         */
        readonly predefinedHierarchy?: cdk.IResolvable | CfnAnalysis.PredefinedHierarchyProperty;
    }
    /**
     * The option that determines the hierarchy of any `DateTime` fields.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimehierarchy.html
     */
    interface DateTimeHierarchyProperty {
        /**
         * The option that determines the drill down filters for the `DateTime` hierarchy.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimehierarchy.html#cfn-quicksight-analysis-datetimehierarchy-drilldownfilters
         */
        readonly drillDownFilters?: Array<CfnAnalysis.DrillDownFilterProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The hierarchy ID of the `DateTime` hierarchy.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimehierarchy.html#cfn-quicksight-analysis-datetimehierarchy-hierarchyid
         */
        readonly hierarchyId: string;
    }
    /**
     * The drill down filter for the column hierarchies.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-drilldownfilter.html
     */
    interface DrillDownFilterProperty {
        /**
         * The category type drill down filter.
         *
         * This filter is used for string type columns.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-drilldownfilter.html#cfn-quicksight-analysis-drilldownfilter-categoryfilter
         */
        readonly categoryFilter?: CfnAnalysis.CategoryDrillDownFilterProperty | cdk.IResolvable;
        /**
         * The numeric equality type drill down filter.
         *
         * This filter is used for number type columns.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-drilldownfilter.html#cfn-quicksight-analysis-drilldownfilter-numericequalityfilter
         */
        readonly numericEqualityFilter?: cdk.IResolvable | CfnAnalysis.NumericEqualityDrillDownFilterProperty;
        /**
         * The time range drill down filter.
         *
         * This filter is used for date time columns.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-drilldownfilter.html#cfn-quicksight-analysis-drilldownfilter-timerangefilter
         */
        readonly timeRangeFilter?: cdk.IResolvable | CfnAnalysis.TimeRangeDrillDownFilterProperty;
    }
    /**
     * The category drill down filter.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericequalitydrilldownfilter.html
     */
    interface NumericEqualityDrillDownFilterProperty {
        /**
         * The column that the filter is applied to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericequalitydrilldownfilter.html#cfn-quicksight-analysis-numericequalitydrilldownfilter-column
         */
        readonly column: CfnAnalysis.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * The value of the double input numeric drill down filter.
         *
         * @default - 0
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericequalitydrilldownfilter.html#cfn-quicksight-analysis-numericequalitydrilldownfilter-value
         */
        readonly value: number;
    }
    /**
     * The time range drill down filter.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangedrilldownfilter.html
     */
    interface TimeRangeDrillDownFilterProperty {
        /**
         * The column that the filter is applied to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangedrilldownfilter.html#cfn-quicksight-analysis-timerangedrilldownfilter-column
         */
        readonly column: CfnAnalysis.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * The maximum value for the filter value range.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangedrilldownfilter.html#cfn-quicksight-analysis-timerangedrilldownfilter-rangemaximum
         */
        readonly rangeMaximum: string;
        /**
         * The minimum value for the filter value range.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangedrilldownfilter.html#cfn-quicksight-analysis-timerangedrilldownfilter-rangeminimum
         */
        readonly rangeMinimum: string;
        /**
         * The level of time precision that is used to aggregate `DateTime` values.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangedrilldownfilter.html#cfn-quicksight-analysis-timerangedrilldownfilter-timegranularity
         */
        readonly timeGranularity: string;
    }
    /**
     * The numeric equality type drill down filter.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categorydrilldownfilter.html
     */
    interface CategoryDrillDownFilterProperty {
        /**
         * A list of the string inputs that are the values of the category drill down filter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categorydrilldownfilter.html#cfn-quicksight-analysis-categorydrilldownfilter-categoryvalues
         */
        readonly categoryValues: Array<string>;
        /**
         * The column that the filter is applied to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categorydrilldownfilter.html#cfn-quicksight-analysis-categorydrilldownfilter-column
         */
        readonly column: CfnAnalysis.ColumnIdentifierProperty | cdk.IResolvable;
    }
    /**
     * The option that determines the hierarchy of the fields that are built within a visual's field wells.
     *
     * These fields can't be duplicated to other visuals.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-explicithierarchy.html
     */
    interface ExplicitHierarchyProperty {
        /**
         * The list of columns that define the explicit hierarchy.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-explicithierarchy.html#cfn-quicksight-analysis-explicithierarchy-columns
         */
        readonly columns: Array<CfnAnalysis.ColumnIdentifierProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The option that determines the drill down filters for the explicit hierarchy.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-explicithierarchy.html#cfn-quicksight-analysis-explicithierarchy-drilldownfilters
         */
        readonly drillDownFilters?: Array<CfnAnalysis.DrillDownFilterProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The hierarchy ID of the explicit hierarchy.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-explicithierarchy.html#cfn-quicksight-analysis-explicithierarchy-hierarchyid
         */
        readonly hierarchyId: string;
    }
    /**
     * The option that determines the hierarchy of the fields that are defined during data preparation.
     *
     * These fields are available to use in any analysis that uses the data source.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-predefinedhierarchy.html
     */
    interface PredefinedHierarchyProperty {
        /**
         * The list of columns that define the predefined hierarchy.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-predefinedhierarchy.html#cfn-quicksight-analysis-predefinedhierarchy-columns
         */
        readonly columns: Array<CfnAnalysis.ColumnIdentifierProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The option that determines the drill down filters for the predefined hierarchy.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-predefinedhierarchy.html#cfn-quicksight-analysis-predefinedhierarchy-drilldownfilters
         */
        readonly drillDownFilters?: Array<CfnAnalysis.DrillDownFilterProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The hierarchy ID of the predefined hierarchy.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-predefinedhierarchy.html#cfn-quicksight-analysis-predefinedhierarchy-hierarchyid
         */
        readonly hierarchyId: string;
    }
    /**
     * A filled map.
     *
     * For more information, see [Creating filled maps](https://docs.aws.amazon.com/quicksight/latest/user/filled-maps.html) in the *Amazon QuickSight User Guide* .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapvisual.html
     */
    interface FilledMapVisualProperty {
        /**
         * The list of custom actions that are configured for a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapvisual.html#cfn-quicksight-analysis-filledmapvisual-actions
         */
        readonly actions?: Array<cdk.IResolvable | CfnAnalysis.VisualCustomActionProperty> | cdk.IResolvable;
        /**
         * The configuration settings of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapvisual.html#cfn-quicksight-analysis-filledmapvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnAnalysis.FilledMapConfigurationProperty | cdk.IResolvable;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapvisual.html#cfn-quicksight-analysis-filledmapvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnAnalysis.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The conditional formatting of a `FilledMapVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapvisual.html#cfn-quicksight-analysis-filledmapvisual-conditionalformatting
         */
        readonly conditionalFormatting?: CfnAnalysis.FilledMapConditionalFormattingProperty | cdk.IResolvable;
        /**
         * The subtitle that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapvisual.html#cfn-quicksight-analysis-filledmapvisual-subtitle
         */
        readonly subtitle?: cdk.IResolvable | CfnAnalysis.VisualSubtitleLabelOptionsProperty;
        /**
         * The title that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapvisual.html#cfn-quicksight-analysis-filledmapvisual-title
         */
        readonly title?: cdk.IResolvable | CfnAnalysis.VisualTitleLabelOptionsProperty;
        /**
         * The unique identifier of a visual.
         *
         * This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapvisual.html#cfn-quicksight-analysis-filledmapvisual-visualid
         */
        readonly visualId: string;
    }
    /**
     * The conditional formatting of a `FilledMapVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapconditionalformatting.html
     */
    interface FilledMapConditionalFormattingProperty {
        /**
         * Conditional formatting options of a `FilledMapVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapconditionalformatting.html#cfn-quicksight-analysis-filledmapconditionalformatting-conditionalformattingoptions
         */
        readonly conditionalFormattingOptions: Array<CfnAnalysis.FilledMapConditionalFormattingOptionProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * Conditional formatting options of a `FilledMapVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapconditionalformattingoption.html
     */
    interface FilledMapConditionalFormattingOptionProperty {
        /**
         * The conditional formatting that determines the shape of the filled map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapconditionalformattingoption.html#cfn-quicksight-analysis-filledmapconditionalformattingoption-shape
         */
        readonly shape: CfnAnalysis.FilledMapShapeConditionalFormattingProperty | cdk.IResolvable;
    }
    /**
     * The conditional formatting that determines the shape of the filled map.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapshapeconditionalformatting.html
     */
    interface FilledMapShapeConditionalFormattingProperty {
        /**
         * The field ID of the filled map shape.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapshapeconditionalformatting.html#cfn-quicksight-analysis-filledmapshapeconditionalformatting-fieldid
         */
        readonly fieldId: string;
        /**
         * The conditional formatting that determines the background color of a filled map's shape.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapshapeconditionalformatting.html#cfn-quicksight-analysis-filledmapshapeconditionalformatting-format
         */
        readonly format?: cdk.IResolvable | CfnAnalysis.ShapeConditionalFormatProperty;
    }
    /**
     * The shape conditional formatting of a filled map visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-shapeconditionalformat.html
     */
    interface ShapeConditionalFormatProperty {
        /**
         * The conditional formatting for the shape background color of a filled map visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-shapeconditionalformat.html#cfn-quicksight-analysis-shapeconditionalformat-backgroundcolor
         */
        readonly backgroundColor: CfnAnalysis.ConditionalFormattingColorProperty | cdk.IResolvable;
    }
    /**
     * The formatting configuration for the color.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingcolor.html
     */
    interface ConditionalFormattingColorProperty {
        /**
         * Formatting configuration for gradient color.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingcolor.html#cfn-quicksight-analysis-conditionalformattingcolor-gradient
         */
        readonly gradient?: CfnAnalysis.ConditionalFormattingGradientColorProperty | cdk.IResolvable;
        /**
         * Formatting configuration for solid color.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingcolor.html#cfn-quicksight-analysis-conditionalformattingcolor-solid
         */
        readonly solid?: CfnAnalysis.ConditionalFormattingSolidColorProperty | cdk.IResolvable;
    }
    /**
     * Formatting configuration for gradient color.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattinggradientcolor.html
     */
    interface ConditionalFormattingGradientColorProperty {
        /**
         * Determines the color.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattinggradientcolor.html#cfn-quicksight-analysis-conditionalformattinggradientcolor-color
         */
        readonly color: CfnAnalysis.GradientColorProperty | cdk.IResolvable;
        /**
         * The expression that determines the formatting configuration for gradient color.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattinggradientcolor.html#cfn-quicksight-analysis-conditionalformattinggradientcolor-expression
         */
        readonly expression: string;
    }
    /**
     * Determines the gradient color settings.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gradientcolor.html
     */
    interface GradientColorProperty {
        /**
         * The list of gradient color stops.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gradientcolor.html#cfn-quicksight-analysis-gradientcolor-stops
         */
        readonly stops?: Array<CfnAnalysis.GradientStopProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * Determines the gradient stop configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gradientstop.html
     */
    interface GradientStopProperty {
        /**
         * Determines the color.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gradientstop.html#cfn-quicksight-analysis-gradientstop-color
         */
        readonly color?: string;
        /**
         * Determines the data value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gradientstop.html#cfn-quicksight-analysis-gradientstop-datavalue
         */
        readonly dataValue?: number;
        /**
         * Determines gradient offset value.
         *
         * @default - 0
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gradientstop.html#cfn-quicksight-analysis-gradientstop-gradientoffset
         */
        readonly gradientOffset: number;
    }
    /**
     * Formatting configuration for solid color.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingsolidcolor.html
     */
    interface ConditionalFormattingSolidColorProperty {
        /**
         * Determines the color.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingsolidcolor.html#cfn-quicksight-analysis-conditionalformattingsolidcolor-color
         */
        readonly color?: string;
        /**
         * The expression that determines the formatting configuration for solid color.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingsolidcolor.html#cfn-quicksight-analysis-conditionalformattingsolidcolor-expression
         */
        readonly expression: string;
    }
    /**
     * The configuration for a `FilledMapVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapconfiguration.html
     */
    interface FilledMapConfigurationProperty {
        /**
         * The field wells of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapconfiguration.html#cfn-quicksight-analysis-filledmapconfiguration-fieldwells
         */
        readonly fieldWells?: CfnAnalysis.FilledMapFieldWellsProperty | cdk.IResolvable;
        /**
         * The legend display setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapconfiguration.html#cfn-quicksight-analysis-filledmapconfiguration-legend
         */
        readonly legend?: cdk.IResolvable | CfnAnalysis.LegendOptionsProperty;
        /**
         * The map style options of the filled map visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapconfiguration.html#cfn-quicksight-analysis-filledmapconfiguration-mapstyleoptions
         */
        readonly mapStyleOptions?: CfnAnalysis.GeospatialMapStyleOptionsProperty | cdk.IResolvable;
        /**
         * The sort configuration of a `FilledMapVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapconfiguration.html#cfn-quicksight-analysis-filledmapconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: CfnAnalysis.FilledMapSortConfigurationProperty | cdk.IResolvable;
        /**
         * The tooltip display setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapconfiguration.html#cfn-quicksight-analysis-filledmapconfiguration-tooltip
         */
        readonly tooltip?: cdk.IResolvable | CfnAnalysis.TooltipOptionsProperty;
        /**
         * The window options of the filled map visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapconfiguration.html#cfn-quicksight-analysis-filledmapconfiguration-windowoptions
         */
        readonly windowOptions?: CfnAnalysis.GeospatialWindowOptionsProperty | cdk.IResolvable;
    }
    /**
     * The sort configuration of a `FilledMapVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapsortconfiguration.html
     */
    interface FilledMapSortConfigurationProperty {
        /**
         * The sort configuration of the location fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapsortconfiguration.html#cfn-quicksight-analysis-filledmapsortconfiguration-categorysort
         */
        readonly categorySort?: Array<CfnAnalysis.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * The options for the legend setup of a visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-legendoptions.html
     */
    interface LegendOptionsProperty {
        /**
         * The height of the legend.
         *
         * If this value is omitted, a default height is used when rendering.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-legendoptions.html#cfn-quicksight-analysis-legendoptions-height
         */
        readonly height?: string;
        /**
         * The positions for the legend. Choose one of the following options:.
         *
         * - `AUTO`
         * - `RIGHT`
         * - `BOTTOM`
         * - `LEFT`
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-legendoptions.html#cfn-quicksight-analysis-legendoptions-position
         */
        readonly position?: string;
        /**
         * The custom title for the legend.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-legendoptions.html#cfn-quicksight-analysis-legendoptions-title
         */
        readonly title?: cdk.IResolvable | CfnAnalysis.LabelOptionsProperty;
        /**
         * Determines whether or not the legend is visible.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-legendoptions.html#cfn-quicksight-analysis-legendoptions-visibility
         */
        readonly visibility?: string;
        /**
         * The width of the legend.
         *
         * If this value is omitted, a default width is used when rendering.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-legendoptions.html#cfn-quicksight-analysis-legendoptions-width
         */
        readonly width?: string;
    }
    /**
     * The map style options of the geospatial map.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapstyleoptions.html
     */
    interface GeospatialMapStyleOptionsProperty {
        /**
         * The base map style of the geospatial map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapstyleoptions.html#cfn-quicksight-analysis-geospatialmapstyleoptions-basemapstyle
         */
        readonly baseMapStyle?: string;
    }
    /**
     * The field wells of a `FilledMapVisual` .
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapfieldwells.html
     */
    interface FilledMapFieldWellsProperty {
        /**
         * The aggregated field well of the filled map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapfieldwells.html#cfn-quicksight-analysis-filledmapfieldwells-filledmapaggregatedfieldwells
         */
        readonly filledMapAggregatedFieldWells?: CfnAnalysis.FilledMapAggregatedFieldWellsProperty | cdk.IResolvable;
    }
    /**
     * The aggregated field well of the filled map.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapaggregatedfieldwells.html
     */
    interface FilledMapAggregatedFieldWellsProperty {
        /**
         * The aggregated location field well of the filled map.
         *
         * Values are grouped by location fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapaggregatedfieldwells.html#cfn-quicksight-analysis-filledmapaggregatedfieldwells-geospatial
         */
        readonly geospatial?: Array<CfnAnalysis.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The aggregated color field well of a filled map.
         *
         * Values are aggregated based on location fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapaggregatedfieldwells.html#cfn-quicksight-analysis-filledmapaggregatedfieldwells-values
         */
        readonly values?: Array<cdk.IResolvable | CfnAnalysis.MeasureFieldProperty> | cdk.IResolvable;
    }
    /**
     * The window options of the geospatial map visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialwindowoptions.html
     */
    interface GeospatialWindowOptionsProperty {
        /**
         * The bounds options (north, south, west, east) of the geospatial window options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialwindowoptions.html#cfn-quicksight-analysis-geospatialwindowoptions-bounds
         */
        readonly bounds?: CfnAnalysis.GeospatialCoordinateBoundsProperty | cdk.IResolvable;
        /**
         * The map zoom modes (manual, auto) of the geospatial window options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialwindowoptions.html#cfn-quicksight-analysis-geospatialwindowoptions-mapzoommode
         */
        readonly mapZoomMode?: string;
    }
    /**
     * The bound options (north, south, west, east) of the geospatial window options.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialcoordinatebounds.html
     */
    interface GeospatialCoordinateBoundsProperty {
        /**
         * The longitude of the east bound of the geospatial coordinate bounds.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialcoordinatebounds.html#cfn-quicksight-analysis-geospatialcoordinatebounds-east
         */
        readonly east: number;
        /**
         * The latitude of the north bound of the geospatial coordinate bounds.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialcoordinatebounds.html#cfn-quicksight-analysis-geospatialcoordinatebounds-north
         */
        readonly north: number;
        /**
         * The latitude of the south bound of the geospatial coordinate bounds.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialcoordinatebounds.html#cfn-quicksight-analysis-geospatialcoordinatebounds-south
         */
        readonly south: number;
        /**
         * The longitude of the west bound of the geospatial coordinate bounds.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialcoordinatebounds.html#cfn-quicksight-analysis-geospatialcoordinatebounds-west
         */
        readonly west: number;
    }
    /**
     * A box plot.
     *
     * For more information, see [Using box plots](https://docs.aws.amazon.com/quicksight/latest/user/box-plots.html) in the *Amazon QuickSight User Guide* .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotvisual.html
     */
    interface BoxPlotVisualProperty {
        /**
         * The list of custom actions that are configured for a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotvisual.html#cfn-quicksight-analysis-boxplotvisual-actions
         */
        readonly actions?: Array<cdk.IResolvable | CfnAnalysis.VisualCustomActionProperty> | cdk.IResolvable;
        /**
         * The configuration settings of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotvisual.html#cfn-quicksight-analysis-boxplotvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnAnalysis.BoxPlotChartConfigurationProperty | cdk.IResolvable;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotvisual.html#cfn-quicksight-analysis-boxplotvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnAnalysis.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The subtitle that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotvisual.html#cfn-quicksight-analysis-boxplotvisual-subtitle
         */
        readonly subtitle?: cdk.IResolvable | CfnAnalysis.VisualSubtitleLabelOptionsProperty;
        /**
         * The title that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotvisual.html#cfn-quicksight-analysis-boxplotvisual-title
         */
        readonly title?: cdk.IResolvable | CfnAnalysis.VisualTitleLabelOptionsProperty;
        /**
         * The unique identifier of a visual.
         *
         * This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotvisual.html#cfn-quicksight-analysis-boxplotvisual-visualid
         */
        readonly visualId: string;
    }
    /**
     * The configuration of a `BoxPlotVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotchartconfiguration.html
     */
    interface BoxPlotChartConfigurationProperty {
        /**
         * The box plot chart options for a box plot visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotchartconfiguration.html#cfn-quicksight-analysis-boxplotchartconfiguration-boxplotoptions
         */
        readonly boxPlotOptions?: CfnAnalysis.BoxPlotOptionsProperty | cdk.IResolvable;
        /**
         * The label display options (grid line, range, scale, axis step) of a box plot category.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotchartconfiguration.html#cfn-quicksight-analysis-boxplotchartconfiguration-categoryaxis
         */
        readonly categoryAxis?: CfnAnalysis.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * The label options (label text, label visibility and sort Icon visibility) of a box plot category.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotchartconfiguration.html#cfn-quicksight-analysis-boxplotchartconfiguration-categorylabeloptions
         */
        readonly categoryLabelOptions?: CfnAnalysis.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The field wells of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotchartconfiguration.html#cfn-quicksight-analysis-boxplotchartconfiguration-fieldwells
         */
        readonly fieldWells?: CfnAnalysis.BoxPlotFieldWellsProperty | cdk.IResolvable;
        /**
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotchartconfiguration.html#cfn-quicksight-analysis-boxplotchartconfiguration-legend
         */
        readonly legend?: cdk.IResolvable | CfnAnalysis.LegendOptionsProperty;
        /**
         * The label display options (grid line, range, scale, axis step) of a box plot category.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotchartconfiguration.html#cfn-quicksight-analysis-boxplotchartconfiguration-primaryyaxisdisplayoptions
         */
        readonly primaryYAxisDisplayOptions?: CfnAnalysis.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * The label options (label text, label visibility and sort icon visibility) of a box plot value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotchartconfiguration.html#cfn-quicksight-analysis-boxplotchartconfiguration-primaryyaxislabeloptions
         */
        readonly primaryYAxisLabelOptions?: CfnAnalysis.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The reference line setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotchartconfiguration.html#cfn-quicksight-analysis-boxplotchartconfiguration-referencelines
         */
        readonly referenceLines?: Array<cdk.IResolvable | CfnAnalysis.ReferenceLineProperty> | cdk.IResolvable;
        /**
         * The sort configuration of a `BoxPlotVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotchartconfiguration.html#cfn-quicksight-analysis-boxplotchartconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: CfnAnalysis.BoxPlotSortConfigurationProperty | cdk.IResolvable;
        /**
         * The tooltip display setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotchartconfiguration.html#cfn-quicksight-analysis-boxplotchartconfiguration-tooltip
         */
        readonly tooltip?: cdk.IResolvable | CfnAnalysis.TooltipOptionsProperty;
        /**
         * The palette (chart color) display setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotchartconfiguration.html#cfn-quicksight-analysis-boxplotchartconfiguration-visualpalette
         */
        readonly visualPalette?: cdk.IResolvable | CfnAnalysis.VisualPaletteProperty;
    }
    /**
     * The sort configuration of a `BoxPlotVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotsortconfiguration.html
     */
    interface BoxPlotSortConfigurationProperty {
        /**
         * The sort configuration of a group by fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotsortconfiguration.html#cfn-quicksight-analysis-boxplotsortconfiguration-categorysort
         */
        readonly categorySort?: Array<CfnAnalysis.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The pagination configuration of a table visual or box plot.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotsortconfiguration.html#cfn-quicksight-analysis-boxplotsortconfiguration-paginationconfiguration
         */
        readonly paginationConfiguration?: cdk.IResolvable | CfnAnalysis.PaginationConfigurationProperty;
    }
    /**
     * The pagination configuration for a table visual or boxplot.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-paginationconfiguration.html
     */
    interface PaginationConfigurationProperty {
        /**
         * Indicates the page number.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-paginationconfiguration.html#cfn-quicksight-analysis-paginationconfiguration-pagenumber
         */
        readonly pageNumber: number;
        /**
         * Indicates how many items render in one page.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-paginationconfiguration.html#cfn-quicksight-analysis-paginationconfiguration-pagesize
         */
        readonly pageSize: number;
    }
    /**
     * The reference line visual display options.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referenceline.html
     */
    interface ReferenceLineProperty {
        /**
         * The data configuration of the reference line.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referenceline.html#cfn-quicksight-analysis-referenceline-dataconfiguration
         */
        readonly dataConfiguration: cdk.IResolvable | CfnAnalysis.ReferenceLineDataConfigurationProperty;
        /**
         * The label configuration of the reference line.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referenceline.html#cfn-quicksight-analysis-referenceline-labelconfiguration
         */
        readonly labelConfiguration?: cdk.IResolvable | CfnAnalysis.ReferenceLineLabelConfigurationProperty;
        /**
         * The status of the reference line. Choose one of the following options:.
         *
         * - `ENABLE`
         * - `DISABLE`
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referenceline.html#cfn-quicksight-analysis-referenceline-status
         */
        readonly status?: string;
        /**
         * The style configuration of the reference line.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referenceline.html#cfn-quicksight-analysis-referenceline-styleconfiguration
         */
        readonly styleConfiguration?: cdk.IResolvable | CfnAnalysis.ReferenceLineStyleConfigurationProperty;
    }
    /**
     * The data configuration of the reference line.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinedataconfiguration.html
     */
    interface ReferenceLineDataConfigurationProperty {
        /**
         * The axis binding type of the reference line. Choose one of the following options:.
         *
         * - `PrimaryY`
         * - `SecondaryY`
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinedataconfiguration.html#cfn-quicksight-analysis-referencelinedataconfiguration-axisbinding
         */
        readonly axisBinding?: string;
        /**
         * The dynamic configuration of the reference line data configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinedataconfiguration.html#cfn-quicksight-analysis-referencelinedataconfiguration-dynamicconfiguration
         */
        readonly dynamicConfiguration?: cdk.IResolvable | CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty;
        /**
         * The series type of the reference line data configuration. Choose one of the following options:.
         *
         * - `BAR`
         * - `LINE`
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinedataconfiguration.html#cfn-quicksight-analysis-referencelinedataconfiguration-seriestype
         */
        readonly seriesType?: string;
        /**
         * The static data configuration of the reference line data configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinedataconfiguration.html#cfn-quicksight-analysis-referencelinedataconfiguration-staticconfiguration
         */
        readonly staticConfiguration?: cdk.IResolvable | CfnAnalysis.ReferenceLineStaticDataConfigurationProperty;
    }
    /**
     * The dynamic configuration of the reference line data configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinedynamicdataconfiguration.html
     */
    interface ReferenceLineDynamicDataConfigurationProperty {
        /**
         * The calculation that is used in the dynamic data.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinedynamicdataconfiguration.html#cfn-quicksight-analysis-referencelinedynamicdataconfiguration-calculation
         */
        readonly calculation: cdk.IResolvable | CfnAnalysis.NumericalAggregationFunctionProperty;
        /**
         * The column that the dynamic data targets.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinedynamicdataconfiguration.html#cfn-quicksight-analysis-referencelinedynamicdataconfiguration-column
         */
        readonly column: CfnAnalysis.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * The aggregation function that is used in the dynamic data.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinedynamicdataconfiguration.html#cfn-quicksight-analysis-referencelinedynamicdataconfiguration-measureaggregationfunction
         */
        readonly measureAggregationFunction?: CfnAnalysis.AggregationFunctionProperty | cdk.IResolvable;
    }
    /**
     * The static data configuration of the reference line data configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinestaticdataconfiguration.html
     */
    interface ReferenceLineStaticDataConfigurationProperty {
        /**
         * The double input of the static data.
         *
         * @default - 0
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinestaticdataconfiguration.html#cfn-quicksight-analysis-referencelinestaticdataconfiguration-value
         */
        readonly value: number;
    }
    /**
     * The label configuration of a reference line.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinelabelconfiguration.html
     */
    interface ReferenceLineLabelConfigurationProperty {
        /**
         * The custom label configuration of the label in a reference line.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinelabelconfiguration.html#cfn-quicksight-analysis-referencelinelabelconfiguration-customlabelconfiguration
         */
        readonly customLabelConfiguration?: cdk.IResolvable | CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty;
        /**
         * The font color configuration of the label in a reference line.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinelabelconfiguration.html#cfn-quicksight-analysis-referencelinelabelconfiguration-fontcolor
         */
        readonly fontColor?: string;
        /**
         * The font configuration of the label in a reference line.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinelabelconfiguration.html#cfn-quicksight-analysis-referencelinelabelconfiguration-fontconfiguration
         */
        readonly fontConfiguration?: CfnAnalysis.FontConfigurationProperty | cdk.IResolvable;
        /**
         * The horizontal position configuration of the label in a reference line. Choose one of the following options:.
         *
         * - `LEFT`
         * - `CENTER`
         * - `RIGHT`
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinelabelconfiguration.html#cfn-quicksight-analysis-referencelinelabelconfiguration-horizontalposition
         */
        readonly horizontalPosition?: string;
        /**
         * The value label configuration of the label in a reference line.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinelabelconfiguration.html#cfn-quicksight-analysis-referencelinelabelconfiguration-valuelabelconfiguration
         */
        readonly valueLabelConfiguration?: cdk.IResolvable | CfnAnalysis.ReferenceLineValueLabelConfigurationProperty;
        /**
         * The vertical position configuration of the label in a reference line. Choose one of the following options:.
         *
         * - `ABOVE`
         * - `BELOW`
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinelabelconfiguration.html#cfn-quicksight-analysis-referencelinelabelconfiguration-verticalposition
         */
        readonly verticalPosition?: string;
    }
    /**
     * The value label configuration of the label in a reference line.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinevaluelabelconfiguration.html
     */
    interface ReferenceLineValueLabelConfigurationProperty {
        /**
         * The format configuration of the value label.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinevaluelabelconfiguration.html#cfn-quicksight-analysis-referencelinevaluelabelconfiguration-formatconfiguration
         */
        readonly formatConfiguration?: cdk.IResolvable | CfnAnalysis.NumericFormatConfigurationProperty;
        /**
         * The relative position of the value label. Choose one of the following options:.
         *
         * - `BEFORE_CUSTOM_LABEL`
         * - `AFTER_CUSTOM_LABEL`
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinevaluelabelconfiguration.html#cfn-quicksight-analysis-referencelinevaluelabelconfiguration-relativeposition
         */
        readonly relativePosition?: string;
    }
    /**
     * The configuration for a custom label on a `ReferenceLine` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinecustomlabelconfiguration.html
     */
    interface ReferenceLineCustomLabelConfigurationProperty {
        /**
         * The string text of the custom label.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinecustomlabelconfiguration.html#cfn-quicksight-analysis-referencelinecustomlabelconfiguration-customlabel
         */
        readonly customLabel: string;
    }
    /**
     * The style configuration of the reference line.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinestyleconfiguration.html
     */
    interface ReferenceLineStyleConfigurationProperty {
        /**
         * The hex color of the reference line.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinestyleconfiguration.html#cfn-quicksight-analysis-referencelinestyleconfiguration-color
         */
        readonly color?: string;
        /**
         * The pattern type of the line style. Choose one of the following options:.
         *
         * - `SOLID`
         * - `DASHED`
         * - `DOTTED`
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinestyleconfiguration.html#cfn-quicksight-analysis-referencelinestyleconfiguration-pattern
         */
        readonly pattern?: string;
    }
    /**
     * The display options for the axis label.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdisplayoptions.html
     */
    interface AxisDisplayOptionsProperty {
        /**
         * Determines whether or not the axis line is visible.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdisplayoptions.html#cfn-quicksight-analysis-axisdisplayoptions-axislinevisibility
         */
        readonly axisLineVisibility?: string;
        /**
         * The offset value that determines the starting placement of the axis within a visual's bounds.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdisplayoptions.html#cfn-quicksight-analysis-axisdisplayoptions-axisoffset
         */
        readonly axisOffset?: string;
        /**
         * The data options for an axis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdisplayoptions.html#cfn-quicksight-analysis-axisdisplayoptions-dataoptions
         */
        readonly dataOptions?: CfnAnalysis.AxisDataOptionsProperty | cdk.IResolvable;
        /**
         * Determines whether or not the grid line is visible.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdisplayoptions.html#cfn-quicksight-analysis-axisdisplayoptions-gridlinevisibility
         */
        readonly gridLineVisibility?: string;
        /**
         * The scroll bar options for an axis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdisplayoptions.html#cfn-quicksight-analysis-axisdisplayoptions-scrollbaroptions
         */
        readonly scrollbarOptions?: cdk.IResolvable | CfnAnalysis.ScrollBarOptionsProperty;
        /**
         * The tick label options of an axis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdisplayoptions.html#cfn-quicksight-analysis-axisdisplayoptions-ticklabeloptions
         */
        readonly tickLabelOptions?: CfnAnalysis.AxisTickLabelOptionsProperty | cdk.IResolvable;
    }
    /**
     * The data options for an axis.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdataoptions.html
     */
    interface AxisDataOptionsProperty {
        /**
         * The options for an axis with a date field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdataoptions.html#cfn-quicksight-analysis-axisdataoptions-dateaxisoptions
         */
        readonly dateAxisOptions?: CfnAnalysis.DateAxisOptionsProperty | cdk.IResolvable;
        /**
         * The options for an axis with a numeric field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdataoptions.html#cfn-quicksight-analysis-axisdataoptions-numericaxisoptions
         */
        readonly numericAxisOptions?: cdk.IResolvable | CfnAnalysis.NumericAxisOptionsProperty;
    }
    /**
     * The options that determine how a date axis is displayed.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-dateaxisoptions.html
     */
    interface DateAxisOptionsProperty {
        /**
         * Determines whether or not missing dates are displayed.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-dateaxisoptions.html#cfn-quicksight-analysis-dateaxisoptions-missingdatevisibility
         */
        readonly missingDateVisibility?: string;
    }
    /**
     * The options for an axis with a numeric field.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericaxisoptions.html
     */
    interface NumericAxisOptionsProperty {
        /**
         * The range setup of a numeric axis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericaxisoptions.html#cfn-quicksight-analysis-numericaxisoptions-range
         */
        readonly range?: CfnAnalysis.AxisDisplayRangeProperty | cdk.IResolvable;
        /**
         * The scale setup of a numeric axis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericaxisoptions.html#cfn-quicksight-analysis-numericaxisoptions-scale
         */
        readonly scale?: CfnAnalysis.AxisScaleProperty | cdk.IResolvable;
    }
    /**
     * The scale setup options for a numeric axis display.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisscale.html
     */
    interface AxisScaleProperty {
        /**
         * The linear axis scale setup.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisscale.html#cfn-quicksight-analysis-axisscale-linear
         */
        readonly linear?: CfnAnalysis.AxisLinearScaleProperty | cdk.IResolvable;
        /**
         * The logarithmic axis scale setup.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisscale.html#cfn-quicksight-analysis-axisscale-logarithmic
         */
        readonly logarithmic?: CfnAnalysis.AxisLogarithmicScaleProperty | cdk.IResolvable;
    }
    /**
     * The logarithmic axis scale setup.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axislogarithmicscale.html
     */
    interface AxisLogarithmicScaleProperty {
        /**
         * The base setup of a logarithmic axis scale.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axislogarithmicscale.html#cfn-quicksight-analysis-axislogarithmicscale-base
         */
        readonly base?: number;
    }
    /**
     * The liner axis scale setup.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axislinearscale.html
     */
    interface AxisLinearScaleProperty {
        /**
         * The step count setup of a linear axis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axislinearscale.html#cfn-quicksight-analysis-axislinearscale-stepcount
         */
        readonly stepCount?: number;
        /**
         * The step size setup of a linear axis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axislinearscale.html#cfn-quicksight-analysis-axislinearscale-stepsize
         */
        readonly stepSize?: number;
    }
    /**
     * The range setup of a numeric axis display range.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdisplayrange.html
     */
    interface AxisDisplayRangeProperty {
        /**
         * The data-driven setup of an axis display range.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdisplayrange.html#cfn-quicksight-analysis-axisdisplayrange-datadriven
         */
        readonly dataDriven?: any | cdk.IResolvable;
        /**
         * The minimum and maximum setup of an axis display range.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdisplayrange.html#cfn-quicksight-analysis-axisdisplayrange-minmax
         */
        readonly minMax?: CfnAnalysis.AxisDisplayMinMaxRangeProperty | cdk.IResolvable;
    }
    /**
     * The minimum and maximum setup for an axis display range.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdisplayminmaxrange.html
     */
    interface AxisDisplayMinMaxRangeProperty {
        /**
         * The maximum setup for an axis display range.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdisplayminmaxrange.html#cfn-quicksight-analysis-axisdisplayminmaxrange-maximum
         */
        readonly maximum?: number;
        /**
         * The minimum setup for an axis display range.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdisplayminmaxrange.html#cfn-quicksight-analysis-axisdisplayminmaxrange-minimum
         */
        readonly minimum?: number;
    }
    /**
     * The tick label options of an axis.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisticklabeloptions.html
     */
    interface AxisTickLabelOptionsProperty {
        /**
         * Determines whether or not the axis ticks are visible.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisticklabeloptions.html#cfn-quicksight-analysis-axisticklabeloptions-labeloptions
         */
        readonly labelOptions?: cdk.IResolvable | CfnAnalysis.LabelOptionsProperty;
        /**
         * The rotation angle of the axis tick labels.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisticklabeloptions.html#cfn-quicksight-analysis-axisticklabeloptions-rotationangle
         */
        readonly rotationAngle?: number;
    }
    /**
     * The visual display options for a data zoom scroll bar.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scrollbaroptions.html
     */
    interface ScrollBarOptionsProperty {
        /**
         * The visibility of the data zoom scroll bar.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scrollbaroptions.html#cfn-quicksight-analysis-scrollbaroptions-visibility
         */
        readonly visibility?: string;
        /**
         * The visibility range for the data zoom scroll bar.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scrollbaroptions.html#cfn-quicksight-analysis-scrollbaroptions-visiblerange
         */
        readonly visibleRange?: cdk.IResolvable | CfnAnalysis.VisibleRangeOptionsProperty;
    }
    /**
     * The range options for the data zoom scroll bar.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visiblerangeoptions.html
     */
    interface VisibleRangeOptionsProperty {
        /**
         * The percent range in the visible range.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visiblerangeoptions.html#cfn-quicksight-analysis-visiblerangeoptions-percentrange
         */
        readonly percentRange?: cdk.IResolvable | CfnAnalysis.PercentVisibleRangeProperty;
    }
    /**
     * The percent range in the visible range.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-percentvisiblerange.html
     */
    interface PercentVisibleRangeProperty {
        /**
         * The lower bound of the range.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-percentvisiblerange.html#cfn-quicksight-analysis-percentvisiblerange-from
         */
        readonly from?: number;
        /**
         * The top bound of the range.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-percentvisiblerange.html#cfn-quicksight-analysis-percentvisiblerange-to
         */
        readonly to?: number;
    }
    /**
     * The field wells of a `BoxPlotVisual` .
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotfieldwells.html
     */
    interface BoxPlotFieldWellsProperty {
        /**
         * The aggregated field wells of a box plot.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotfieldwells.html#cfn-quicksight-analysis-boxplotfieldwells-boxplotaggregatedfieldwells
         */
        readonly boxPlotAggregatedFieldWells?: CfnAnalysis.BoxPlotAggregatedFieldWellsProperty | cdk.IResolvable;
    }
    /**
     * The aggregated field well for a box plot.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotaggregatedfieldwells.html
     */
    interface BoxPlotAggregatedFieldWellsProperty {
        /**
         * The group by field well of a box plot chart.
         *
         * Values are grouped based on group by fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotaggregatedfieldwells.html#cfn-quicksight-analysis-boxplotaggregatedfieldwells-groupby
         */
        readonly groupBy?: Array<CfnAnalysis.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The value field well of a box plot chart.
         *
         * Values are aggregated based on group by fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotaggregatedfieldwells.html#cfn-quicksight-analysis-boxplotaggregatedfieldwells-values
         */
        readonly values?: Array<cdk.IResolvable | CfnAnalysis.MeasureFieldProperty> | cdk.IResolvable;
    }
    /**
     * The options of a box plot visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotoptions.html
     */
    interface BoxPlotOptionsProperty {
        /**
         * Determines the visibility of all data points of the box plot.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotoptions.html#cfn-quicksight-analysis-boxplotoptions-alldatapointsvisibility
         */
        readonly allDataPointsVisibility?: string;
        /**
         * Determines the visibility of the outlier in a box plot.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotoptions.html#cfn-quicksight-analysis-boxplotoptions-outliervisibility
         */
        readonly outlierVisibility?: string;
        /**
         * The style options of the box plot.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotoptions.html#cfn-quicksight-analysis-boxplotoptions-styleoptions
         */
        readonly styleOptions?: CfnAnalysis.BoxPlotStyleOptionsProperty | cdk.IResolvable;
    }
    /**
     * The style options of the box plot.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotstyleoptions.html
     */
    interface BoxPlotStyleOptionsProperty {
        /**
         * The fill styles (solid, transparent) of the box plot.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotstyleoptions.html#cfn-quicksight-analysis-boxplotstyleoptions-fillstyle
         */
        readonly fillStyle?: string;
    }
    /**
     * A waterfall chart.
     *
     * For more information, see [Using waterfall charts](https://docs.aws.amazon.com/quicksight/latest/user/waterfall-chart.html) in the *Amazon QuickSight User Guide* .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallvisual.html
     */
    interface WaterfallVisualProperty {
        /**
         * The list of custom actions that are configured for a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallvisual.html#cfn-quicksight-analysis-waterfallvisual-actions
         */
        readonly actions?: Array<cdk.IResolvable | CfnAnalysis.VisualCustomActionProperty> | cdk.IResolvable;
        /**
         * The configuration for a waterfall visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallvisual.html#cfn-quicksight-analysis-waterfallvisual-chartconfiguration
         */
        readonly chartConfiguration?: cdk.IResolvable | CfnAnalysis.WaterfallChartConfigurationProperty;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallvisual.html#cfn-quicksight-analysis-waterfallvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnAnalysis.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The subtitle that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallvisual.html#cfn-quicksight-analysis-waterfallvisual-subtitle
         */
        readonly subtitle?: cdk.IResolvable | CfnAnalysis.VisualSubtitleLabelOptionsProperty;
        /**
         * The title that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallvisual.html#cfn-quicksight-analysis-waterfallvisual-title
         */
        readonly title?: cdk.IResolvable | CfnAnalysis.VisualTitleLabelOptionsProperty;
        /**
         * The unique identifier of a visual.
         *
         * This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallvisual.html#cfn-quicksight-analysis-waterfallvisual-visualid
         */
        readonly visualId: string;
    }
    /**
     * The configuration for a waterfall visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartconfiguration.html
     */
    interface WaterfallChartConfigurationProperty {
        /**
         * The options that determine the presentation of the category axis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartconfiguration.html#cfn-quicksight-analysis-waterfallchartconfiguration-categoryaxisdisplayoptions
         */
        readonly categoryAxisDisplayOptions?: CfnAnalysis.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * The options that determine the presentation of the category axis label.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartconfiguration.html#cfn-quicksight-analysis-waterfallchartconfiguration-categoryaxislabeloptions
         */
        readonly categoryAxisLabelOptions?: CfnAnalysis.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The data label configuration of a waterfall visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartconfiguration.html#cfn-quicksight-analysis-waterfallchartconfiguration-datalabels
         */
        readonly dataLabels?: CfnAnalysis.DataLabelOptionsProperty | cdk.IResolvable;
        /**
         * The field well configuration of a waterfall visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartconfiguration.html#cfn-quicksight-analysis-waterfallchartconfiguration-fieldwells
         */
        readonly fieldWells?: cdk.IResolvable | CfnAnalysis.WaterfallChartFieldWellsProperty;
        /**
         * The legend configuration of a waterfall visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartconfiguration.html#cfn-quicksight-analysis-waterfallchartconfiguration-legend
         */
        readonly legend?: cdk.IResolvable | CfnAnalysis.LegendOptionsProperty;
        /**
         * The options that determine the presentation of the y-axis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartconfiguration.html#cfn-quicksight-analysis-waterfallchartconfiguration-primaryyaxisdisplayoptions
         */
        readonly primaryYAxisDisplayOptions?: CfnAnalysis.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * The options that determine the presentation of the y-axis label.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartconfiguration.html#cfn-quicksight-analysis-waterfallchartconfiguration-primaryyaxislabeloptions
         */
        readonly primaryYAxisLabelOptions?: CfnAnalysis.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The sort configuration of a waterfall visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartconfiguration.html#cfn-quicksight-analysis-waterfallchartconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: cdk.IResolvable | CfnAnalysis.WaterfallChartSortConfigurationProperty;
        /**
         * The visual palette configuration of a waterfall visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartconfiguration.html#cfn-quicksight-analysis-waterfallchartconfiguration-visualpalette
         */
        readonly visualPalette?: cdk.IResolvable | CfnAnalysis.VisualPaletteProperty;
        /**
         * The options that determine the presentation of a waterfall visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartconfiguration.html#cfn-quicksight-analysis-waterfallchartconfiguration-waterfallchartoptions
         */
        readonly waterfallChartOptions?: cdk.IResolvable | CfnAnalysis.WaterfallChartOptionsProperty;
    }
    /**
     * The sort configuration of a waterfall visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartsortconfiguration.html
     */
    interface WaterfallChartSortConfigurationProperty {
        /**
         * The limit on the number of bar groups that are displayed.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartsortconfiguration.html#cfn-quicksight-analysis-waterfallchartsortconfiguration-breakdownitemslimit
         */
        readonly breakdownItemsLimit?: cdk.IResolvable | CfnAnalysis.ItemsLimitConfigurationProperty;
        /**
         * The sort configuration of the category fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartsortconfiguration.html#cfn-quicksight-analysis-waterfallchartsortconfiguration-categorysort
         */
        readonly categorySort?: Array<CfnAnalysis.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * The options that determine the presentation of the data labels.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeloptions.html
     */
    interface DataLabelOptionsProperty {
        /**
         * Determines the visibility of the category field labels.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeloptions.html#cfn-quicksight-analysis-datalabeloptions-categorylabelvisibility
         */
        readonly categoryLabelVisibility?: string;
        /**
         * The option that determines the data label type.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeloptions.html#cfn-quicksight-analysis-datalabeloptions-datalabeltypes
         */
        readonly dataLabelTypes?: Array<CfnAnalysis.DataLabelTypeProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * Determines the color of the data labels.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeloptions.html#cfn-quicksight-analysis-datalabeloptions-labelcolor
         */
        readonly labelColor?: string;
        /**
         * Determines the content of the data labels.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeloptions.html#cfn-quicksight-analysis-datalabeloptions-labelcontent
         */
        readonly labelContent?: string;
        /**
         * Determines the font configuration of the data labels.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeloptions.html#cfn-quicksight-analysis-datalabeloptions-labelfontconfiguration
         */
        readonly labelFontConfiguration?: CfnAnalysis.FontConfigurationProperty | cdk.IResolvable;
        /**
         * Determines the visibility of the measure field labels.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeloptions.html#cfn-quicksight-analysis-datalabeloptions-measurelabelvisibility
         */
        readonly measureLabelVisibility?: string;
        /**
         * Determines whether overlap is enabled or disabled for the data labels.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeloptions.html#cfn-quicksight-analysis-datalabeloptions-overlap
         */
        readonly overlap?: string;
        /**
         * Determines the position of the data labels.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeloptions.html#cfn-quicksight-analysis-datalabeloptions-position
         */
        readonly position?: string;
        /**
         * Determines the visibility of the total.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeloptions.html#cfn-quicksight-analysis-datalabeloptions-totalsvisibility
         */
        readonly totalsVisibility?: string;
        /**
         * Determines the visibility of the data labels.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeloptions.html#cfn-quicksight-analysis-datalabeloptions-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The option that determines the data label type.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeltype.html
     */
    interface DataLabelTypeProperty {
        /**
         * The option that specifies individual data values for labels.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeltype.html#cfn-quicksight-analysis-datalabeltype-datapathlabeltype
         */
        readonly dataPathLabelType?: CfnAnalysis.DataPathLabelTypeProperty | cdk.IResolvable;
        /**
         * Determines the label configuration for the entire field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeltype.html#cfn-quicksight-analysis-datalabeltype-fieldlabeltype
         */
        readonly fieldLabelType?: CfnAnalysis.FieldLabelTypeProperty | cdk.IResolvable;
        /**
         * Determines the label configuration for the maximum value in a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeltype.html#cfn-quicksight-analysis-datalabeltype-maximumlabeltype
         */
        readonly maximumLabelType?: cdk.IResolvable | CfnAnalysis.MaximumLabelTypeProperty;
        /**
         * Determines the label configuration for the minimum value in a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeltype.html#cfn-quicksight-analysis-datalabeltype-minimumlabeltype
         */
        readonly minimumLabelType?: cdk.IResolvable | CfnAnalysis.MinimumLabelTypeProperty;
        /**
         * Determines the label configuration for range end value in a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeltype.html#cfn-quicksight-analysis-datalabeltype-rangeendslabeltype
         */
        readonly rangeEndsLabelType?: cdk.IResolvable | CfnAnalysis.RangeEndsLabelTypeProperty;
    }
    /**
     * The maximum label of a data path label.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-maximumlabeltype.html
     */
    interface MaximumLabelTypeProperty {
        /**
         * The visibility of the maximum label.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-maximumlabeltype.html#cfn-quicksight-analysis-maximumlabeltype-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The option that specifies individual data values for labels.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathlabeltype.html
     */
    interface DataPathLabelTypeProperty {
        /**
         * The field ID of the field that the data label needs to be applied to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathlabeltype.html#cfn-quicksight-analysis-datapathlabeltype-fieldid
         */
        readonly fieldId?: string;
        /**
         * The actual value of the field that is labeled.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathlabeltype.html#cfn-quicksight-analysis-datapathlabeltype-fieldvalue
         */
        readonly fieldValue?: string;
        /**
         * The visibility of the data label.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathlabeltype.html#cfn-quicksight-analysis-datapathlabeltype-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The range ends label type of a data path label.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-rangeendslabeltype.html
     */
    interface RangeEndsLabelTypeProperty {
        /**
         * The visibility of the range ends label.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-rangeendslabeltype.html#cfn-quicksight-analysis-rangeendslabeltype-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The field label type.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldlabeltype.html
     */
    interface FieldLabelTypeProperty {
        /**
         * Indicates the field that is targeted by the field label.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldlabeltype.html#cfn-quicksight-analysis-fieldlabeltype-fieldid
         */
        readonly fieldId?: string;
        /**
         * The visibility of the field label.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldlabeltype.html#cfn-quicksight-analysis-fieldlabeltype-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The minimum label of a data path label.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-minimumlabeltype.html
     */
    interface MinimumLabelTypeProperty {
        /**
         * The visibility of the minimum label.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-minimumlabeltype.html#cfn-quicksight-analysis-minimumlabeltype-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The field well configuration of a waterfall visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartfieldwells.html
     */
    interface WaterfallChartFieldWellsProperty {
        /**
         * The field well configuration of a waterfall visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartfieldwells.html#cfn-quicksight-analysis-waterfallchartfieldwells-waterfallchartaggregatedfieldwells
         */
        readonly waterfallChartAggregatedFieldWells?: cdk.IResolvable | CfnAnalysis.WaterfallChartAggregatedFieldWellsProperty;
    }
    /**
     * The field well configuration of a waterfall visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartaggregatedfieldwells.html
     */
    interface WaterfallChartAggregatedFieldWellsProperty {
        /**
         * The breakdown field wells of a waterfall visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartaggregatedfieldwells.html#cfn-quicksight-analysis-waterfallchartaggregatedfieldwells-breakdowns
         */
        readonly breakdowns?: Array<CfnAnalysis.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The category field wells of a waterfall visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartaggregatedfieldwells.html#cfn-quicksight-analysis-waterfallchartaggregatedfieldwells-categories
         */
        readonly categories?: Array<CfnAnalysis.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The value field wells of a waterfall visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartaggregatedfieldwells.html#cfn-quicksight-analysis-waterfallchartaggregatedfieldwells-values
         */
        readonly values?: Array<cdk.IResolvable | CfnAnalysis.MeasureFieldProperty> | cdk.IResolvable;
    }
    /**
     * The options that determine the presentation of a waterfall visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartoptions.html
     */
    interface WaterfallChartOptionsProperty {
        /**
         * This option determines the total bar label of a waterfall visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartoptions.html#cfn-quicksight-analysis-waterfallchartoptions-totalbarlabel
         */
        readonly totalBarLabel?: string;
    }
    /**
     * A visual that contains custom content.
     *
     * For more information, see [Using custom visual content](https://docs.aws.amazon.com/quicksight/latest/user/custom-visual-content.html) in the *Amazon QuickSight User Guide* .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcontentvisual.html
     */
    interface CustomContentVisualProperty {
        /**
         * The list of custom actions that are configured for a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcontentvisual.html#cfn-quicksight-analysis-customcontentvisual-actions
         */
        readonly actions?: Array<cdk.IResolvable | CfnAnalysis.VisualCustomActionProperty> | cdk.IResolvable;
        /**
         * The configuration of a `CustomContentVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcontentvisual.html#cfn-quicksight-analysis-customcontentvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnAnalysis.CustomContentConfigurationProperty | cdk.IResolvable;
        /**
         * The dataset that is used to create the custom content visual.
         *
         * You can't create a visual without a dataset.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcontentvisual.html#cfn-quicksight-analysis-customcontentvisual-datasetidentifier
         */
        readonly dataSetIdentifier: string;
        /**
         * The subtitle that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcontentvisual.html#cfn-quicksight-analysis-customcontentvisual-subtitle
         */
        readonly subtitle?: cdk.IResolvable | CfnAnalysis.VisualSubtitleLabelOptionsProperty;
        /**
         * The title that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcontentvisual.html#cfn-quicksight-analysis-customcontentvisual-title
         */
        readonly title?: cdk.IResolvable | CfnAnalysis.VisualTitleLabelOptionsProperty;
        /**
         * The unique identifier of a visual.
         *
         * This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcontentvisual.html#cfn-quicksight-analysis-customcontentvisual-visualid
         */
        readonly visualId: string;
    }
    /**
     * The configuration of a `CustomContentVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcontentconfiguration.html
     */
    interface CustomContentConfigurationProperty {
        /**
         * The content type of the custom content visual.
         *
         * You can use this to have the visual render as an image.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcontentconfiguration.html#cfn-quicksight-analysis-customcontentconfiguration-contenttype
         */
        readonly contentType?: string;
        /**
         * The input URL that links to the custom content that you want in the custom visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcontentconfiguration.html#cfn-quicksight-analysis-customcontentconfiguration-contenturl
         */
        readonly contentUrl?: string;
        /**
         * The sizing options for the size of the custom content visual.
         *
         * This structure is required when the `ContentType` of the visual is `'IMAGE'` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcontentconfiguration.html#cfn-quicksight-analysis-customcontentconfiguration-imagescaling
         */
        readonly imageScaling?: string;
    }
    /**
     * A pie or donut chart.
     *
     * The `PieChartVisual` structure describes a visual that is a member of the pie chart family.
     *
     * The following charts can be described by using this structure:
     *
     * - Pie charts
     * - Donut charts
     *
     * For more information, see [Using pie charts](https://docs.aws.amazon.com/quicksight/latest/user/pie-chart.html) in the *Amazon QuickSight User Guide* .
     *
     * For more information, see [Using donut charts](https://docs.aws.amazon.com/quicksight/latest/user/donut-chart.html) in the *Amazon QuickSight User Guide* .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartvisual.html
     */
    interface PieChartVisualProperty {
        /**
         * The list of custom actions that are configured for a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartvisual.html#cfn-quicksight-analysis-piechartvisual-actions
         */
        readonly actions?: Array<cdk.IResolvable | CfnAnalysis.VisualCustomActionProperty> | cdk.IResolvable;
        /**
         * The configuration of a pie chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartvisual.html#cfn-quicksight-analysis-piechartvisual-chartconfiguration
         */
        readonly chartConfiguration?: cdk.IResolvable | CfnAnalysis.PieChartConfigurationProperty;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartvisual.html#cfn-quicksight-analysis-piechartvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnAnalysis.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The subtitle that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartvisual.html#cfn-quicksight-analysis-piechartvisual-subtitle
         */
        readonly subtitle?: cdk.IResolvable | CfnAnalysis.VisualSubtitleLabelOptionsProperty;
        /**
         * The title that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartvisual.html#cfn-quicksight-analysis-piechartvisual-title
         */
        readonly title?: cdk.IResolvable | CfnAnalysis.VisualTitleLabelOptionsProperty;
        /**
         * The unique identifier of a visual.
         *
         * This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartvisual.html#cfn-quicksight-analysis-piechartvisual-visualid
         */
        readonly visualId: string;
    }
    /**
     * The configuration of a pie chart.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartconfiguration.html
     */
    interface PieChartConfigurationProperty {
        /**
         * The label options of the group/color that is displayed in a pie chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartconfiguration.html#cfn-quicksight-analysis-piechartconfiguration-categorylabeloptions
         */
        readonly categoryLabelOptions?: CfnAnalysis.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The contribution analysis (anomaly configuration) setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartconfiguration.html#cfn-quicksight-analysis-piechartconfiguration-contributionanalysisdefaults
         */
        readonly contributionAnalysisDefaults?: Array<CfnAnalysis.ContributionAnalysisDefaultProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The options that determine if visual data labels are displayed.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartconfiguration.html#cfn-quicksight-analysis-piechartconfiguration-datalabels
         */
        readonly dataLabels?: CfnAnalysis.DataLabelOptionsProperty | cdk.IResolvable;
        /**
         * The options that determine the shape of the chart.
         *
         * This option determines whether the chart is a pie chart or a donut chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartconfiguration.html#cfn-quicksight-analysis-piechartconfiguration-donutoptions
         */
        readonly donutOptions?: CfnAnalysis.DonutOptionsProperty | cdk.IResolvable;
        /**
         * The field wells of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartconfiguration.html#cfn-quicksight-analysis-piechartconfiguration-fieldwells
         */
        readonly fieldWells?: cdk.IResolvable | CfnAnalysis.PieChartFieldWellsProperty;
        /**
         * The legend display setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartconfiguration.html#cfn-quicksight-analysis-piechartconfiguration-legend
         */
        readonly legend?: cdk.IResolvable | CfnAnalysis.LegendOptionsProperty;
        /**
         * The small multiples setup for the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartconfiguration.html#cfn-quicksight-analysis-piechartconfiguration-smallmultiplesoptions
         */
        readonly smallMultiplesOptions?: cdk.IResolvable | CfnAnalysis.SmallMultiplesOptionsProperty;
        /**
         * The sort configuration of a pie chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartconfiguration.html#cfn-quicksight-analysis-piechartconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: cdk.IResolvable | CfnAnalysis.PieChartSortConfigurationProperty;
        /**
         * The tooltip display setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartconfiguration.html#cfn-quicksight-analysis-piechartconfiguration-tooltip
         */
        readonly tooltip?: cdk.IResolvable | CfnAnalysis.TooltipOptionsProperty;
        /**
         * The label options for the value that is displayed in a pie chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartconfiguration.html#cfn-quicksight-analysis-piechartconfiguration-valuelabeloptions
         */
        readonly valueLabelOptions?: CfnAnalysis.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The palette (chart color) display setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartconfiguration.html#cfn-quicksight-analysis-piechartconfiguration-visualpalette
         */
        readonly visualPalette?: cdk.IResolvable | CfnAnalysis.VisualPaletteProperty;
    }
    /**
     * The sort configuration of a pie chart.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartsortconfiguration.html
     */
    interface PieChartSortConfigurationProperty {
        /**
         * The limit on the number of categories that are displayed in a pie chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartsortconfiguration.html#cfn-quicksight-analysis-piechartsortconfiguration-categoryitemslimit
         */
        readonly categoryItemsLimit?: cdk.IResolvable | CfnAnalysis.ItemsLimitConfigurationProperty;
        /**
         * The sort configuration of the category fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartsortconfiguration.html#cfn-quicksight-analysis-piechartsortconfiguration-categorysort
         */
        readonly categorySort?: Array<CfnAnalysis.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The limit on the number of small multiples panels that are displayed.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartsortconfiguration.html#cfn-quicksight-analysis-piechartsortconfiguration-smallmultipleslimitconfiguration
         */
        readonly smallMultiplesLimitConfiguration?: cdk.IResolvable | CfnAnalysis.ItemsLimitConfigurationProperty;
        /**
         * The sort configuration of the small multiples field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartsortconfiguration.html#cfn-quicksight-analysis-piechartsortconfiguration-smallmultiplessort
         */
        readonly smallMultiplesSort?: Array<CfnAnalysis.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * The contribution analysis visual display for a line, pie, or bar chart.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-contributionanalysisdefault.html
     */
    interface ContributionAnalysisDefaultProperty {
        /**
         * The dimensions columns that are used in the contribution analysis, usually a list of `ColumnIdentifiers` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-contributionanalysisdefault.html#cfn-quicksight-analysis-contributionanalysisdefault-contributordimensions
         */
        readonly contributorDimensions: Array<CfnAnalysis.ColumnIdentifierProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The measure field that is used in the contribution analysis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-contributionanalysisdefault.html#cfn-quicksight-analysis-contributionanalysisdefault-measurefieldid
         */
        readonly measureFieldId: string;
    }
    /**
     * The field well configuration of a pie chart.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartfieldwells.html
     */
    interface PieChartFieldWellsProperty {
        /**
         * The field well configuration of a pie chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartfieldwells.html#cfn-quicksight-analysis-piechartfieldwells-piechartaggregatedfieldwells
         */
        readonly pieChartAggregatedFieldWells?: cdk.IResolvable | CfnAnalysis.PieChartAggregatedFieldWellsProperty;
    }
    /**
     * The field well configuration of a pie chart.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartaggregatedfieldwells.html
     */
    interface PieChartAggregatedFieldWellsProperty {
        /**
         * The category (group/color) field wells of a pie chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartaggregatedfieldwells.html#cfn-quicksight-analysis-piechartaggregatedfieldwells-category
         */
        readonly category?: Array<CfnAnalysis.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The small multiples field well of a pie chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartaggregatedfieldwells.html#cfn-quicksight-analysis-piechartaggregatedfieldwells-smallmultiples
         */
        readonly smallMultiples?: Array<CfnAnalysis.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The value field wells of a pie chart.
         *
         * Values are aggregated based on categories.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartaggregatedfieldwells.html#cfn-quicksight-analysis-piechartaggregatedfieldwells-values
         */
        readonly values?: Array<cdk.IResolvable | CfnAnalysis.MeasureFieldProperty> | cdk.IResolvable;
    }
    /**
     * The options for configuring a donut chart or pie chart.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-donutoptions.html
     */
    interface DonutOptionsProperty {
        /**
         * The option for define the arc of the chart shape. Valid values are as follows:.
         *
         * - `WHOLE` - A pie chart
         * - `SMALL` - A small-sized donut chart
         * - `MEDIUM` - A medium-sized donut chart
         * - `LARGE` - A large-sized donut chart
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-donutoptions.html#cfn-quicksight-analysis-donutoptions-arcoptions
         */
        readonly arcOptions?: CfnAnalysis.ArcOptionsProperty | cdk.IResolvable;
        /**
         * The label options of the label that is displayed in the center of a donut chart.
         *
         * This option isn't available for pie charts.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-donutoptions.html#cfn-quicksight-analysis-donutoptions-donutcenteroptions
         */
        readonly donutCenterOptions?: CfnAnalysis.DonutCenterOptionsProperty | cdk.IResolvable;
    }
    /**
     * The label options of the label that is displayed in the center of a donut chart.
     *
     * This option isn't available for pie charts.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-donutcenteroptions.html
     */
    interface DonutCenterOptionsProperty {
        /**
         * Determines the visibility of the label in a donut chart.
         *
         * In the Amazon QuickSight console, this option is called `'Show total'` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-donutcenteroptions.html#cfn-quicksight-analysis-donutcenteroptions-labelvisibility
         */
        readonly labelVisibility?: string;
    }
    /**
     * The options that determine the arc thickness of a `GaugeChartVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-arcoptions.html
     */
    interface ArcOptionsProperty {
        /**
         * The arc thickness of a `GaugeChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-arcoptions.html#cfn-quicksight-analysis-arcoptions-arcthickness
         */
        readonly arcThickness?: string;
    }
    /**
     * Options that determine the layout and display options of a chart's small multiples.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-smallmultiplesoptions.html
     */
    interface SmallMultiplesOptionsProperty {
        /**
         * Sets the maximum number of visible columns to display in the grid of small multiples panels.
         *
         * The default is `Auto` , which automatically adjusts the columns in the grid to fit the overall layout and size of the given chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-smallmultiplesoptions.html#cfn-quicksight-analysis-smallmultiplesoptions-maxvisiblecolumns
         */
        readonly maxVisibleColumns?: number;
        /**
         * Sets the maximum number of visible rows to display in the grid of small multiples panels.
         *
         * The default value is `Auto` , which automatically adjusts the rows in the grid to fit the overall layout and size of the given chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-smallmultiplesoptions.html#cfn-quicksight-analysis-smallmultiplesoptions-maxvisiblerows
         */
        readonly maxVisibleRows?: number;
        /**
         * Configures the display options for each small multiples panel.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-smallmultiplesoptions.html#cfn-quicksight-analysis-smallmultiplesoptions-panelconfiguration
         */
        readonly panelConfiguration?: cdk.IResolvable | CfnAnalysis.PanelConfigurationProperty;
        /**
         * The properties of a small multiples X axis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-smallmultiplesoptions.html#cfn-quicksight-analysis-smallmultiplesoptions-xaxis
         */
        readonly xAxis?: cdk.IResolvable | CfnAnalysis.SmallMultiplesAxisPropertiesProperty;
        /**
         * The properties of a small multiples Y axis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-smallmultiplesoptions.html#cfn-quicksight-analysis-smallmultiplesoptions-yaxis
         */
        readonly yAxis?: cdk.IResolvable | CfnAnalysis.SmallMultiplesAxisPropertiesProperty;
    }
    /**
     * A collection of options that configure how each panel displays in a small multiples chart.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-panelconfiguration.html
     */
    interface PanelConfigurationProperty {
        /**
         * Sets the background color for each panel.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-panelconfiguration.html#cfn-quicksight-analysis-panelconfiguration-backgroundcolor
         */
        readonly backgroundColor?: string;
        /**
         * Determines whether or not a background for each small multiples panel is rendered.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-panelconfiguration.html#cfn-quicksight-analysis-panelconfiguration-backgroundvisibility
         */
        readonly backgroundVisibility?: string;
        /**
         * Sets the line color of panel borders.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-panelconfiguration.html#cfn-quicksight-analysis-panelconfiguration-bordercolor
         */
        readonly borderColor?: string;
        /**
         * Sets the line style of panel borders.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-panelconfiguration.html#cfn-quicksight-analysis-panelconfiguration-borderstyle
         */
        readonly borderStyle?: string;
        /**
         * Sets the line thickness of panel borders.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-panelconfiguration.html#cfn-quicksight-analysis-panelconfiguration-borderthickness
         */
        readonly borderThickness?: string;
        /**
         * Determines whether or not each panel displays a border.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-panelconfiguration.html#cfn-quicksight-analysis-panelconfiguration-bordervisibility
         */
        readonly borderVisibility?: string;
        /**
         * Sets the total amount of negative space to display between sibling panels.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-panelconfiguration.html#cfn-quicksight-analysis-panelconfiguration-gutterspacing
         */
        readonly gutterSpacing?: string;
        /**
         * Determines whether or not negative space between sibling panels is rendered.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-panelconfiguration.html#cfn-quicksight-analysis-panelconfiguration-guttervisibility
         */
        readonly gutterVisibility?: string;
        /**
         * Configures the title display within each small multiples panel.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-panelconfiguration.html#cfn-quicksight-analysis-panelconfiguration-title
         */
        readonly title?: cdk.IResolvable | CfnAnalysis.PanelTitleOptionsProperty;
    }
    /**
     * The options that determine the title styles for each small multiples panel.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-paneltitleoptions.html
     */
    interface PanelTitleOptionsProperty {
        /**
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-paneltitleoptions.html#cfn-quicksight-analysis-paneltitleoptions-fontconfiguration
         */
        readonly fontConfiguration?: CfnAnalysis.FontConfigurationProperty | cdk.IResolvable;
        /**
         * Sets the horizontal text alignment of the title within each panel.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-paneltitleoptions.html#cfn-quicksight-analysis-paneltitleoptions-horizontaltextalignment
         */
        readonly horizontalTextAlignment?: string;
        /**
         * Determines whether or not panel titles are displayed.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-paneltitleoptions.html#cfn-quicksight-analysis-paneltitleoptions-visibility
         */
        readonly visibility?: string;
    }
    /**
     * Configures the properties of a chart's axes that are used by small multiples panels.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-smallmultiplesaxisproperties.html
     */
    interface SmallMultiplesAxisPropertiesProperty {
        /**
         * Defines the placement of the axis.
         *
         * By default, axes are rendered `OUTSIDE` of the panels. Axes with `INDEPENDENT` scale are rendered `INSIDE` the panels.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-smallmultiplesaxisproperties.html#cfn-quicksight-analysis-smallmultiplesaxisproperties-placement
         */
        readonly placement?: string;
        /**
         * Determines whether scale of the axes are shared or independent.
         *
         * The default value is `SHARED` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-smallmultiplesaxisproperties.html#cfn-quicksight-analysis-smallmultiplesaxisproperties-scale
         */
        readonly scale?: string;
    }
    /**
     * A key performance indicator (KPI).
     *
     * For more information, see [Using KPIs](https://docs.aws.amazon.com/quicksight/latest/user/kpi.html) in the *Amazon QuickSight User Guide* .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpivisual.html
     */
    interface KPIVisualProperty {
        /**
         * The list of custom actions that are configured for a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpivisual.html#cfn-quicksight-analysis-kpivisual-actions
         */
        readonly actions?: Array<cdk.IResolvable | CfnAnalysis.VisualCustomActionProperty> | cdk.IResolvable;
        /**
         * The configuration of a KPI visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpivisual.html#cfn-quicksight-analysis-kpivisual-chartconfiguration
         */
        readonly chartConfiguration?: cdk.IResolvable | CfnAnalysis.KPIConfigurationProperty;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpivisual.html#cfn-quicksight-analysis-kpivisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnAnalysis.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The conditional formatting of a KPI visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpivisual.html#cfn-quicksight-analysis-kpivisual-conditionalformatting
         */
        readonly conditionalFormatting?: cdk.IResolvable | CfnAnalysis.KPIConditionalFormattingProperty;
        /**
         * The subtitle that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpivisual.html#cfn-quicksight-analysis-kpivisual-subtitle
         */
        readonly subtitle?: cdk.IResolvable | CfnAnalysis.VisualSubtitleLabelOptionsProperty;
        /**
         * The title that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpivisual.html#cfn-quicksight-analysis-kpivisual-title
         */
        readonly title?: cdk.IResolvable | CfnAnalysis.VisualTitleLabelOptionsProperty;
        /**
         * The unique identifier of a visual.
         *
         * This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpivisual.html#cfn-quicksight-analysis-kpivisual-visualid
         */
        readonly visualId: string;
    }
    /**
     * The conditional formatting of a KPI visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiconditionalformatting.html
     */
    interface KPIConditionalFormattingProperty {
        /**
         * The conditional formatting options of a KPI visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiconditionalformatting.html#cfn-quicksight-analysis-kpiconditionalformatting-conditionalformattingoptions
         */
        readonly conditionalFormattingOptions?: Array<cdk.IResolvable | CfnAnalysis.KPIConditionalFormattingOptionProperty> | cdk.IResolvable;
    }
    /**
     * The conditional formatting options of a KPI visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiconditionalformattingoption.html
     */
    interface KPIConditionalFormattingOptionProperty {
        /**
         * The conditional formatting for the actual value of a KPI visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiconditionalformattingoption.html#cfn-quicksight-analysis-kpiconditionalformattingoption-actualvalue
         */
        readonly actualValue?: cdk.IResolvable | CfnAnalysis.KPIActualValueConditionalFormattingProperty;
        /**
         * The conditional formatting for the comparison value of a KPI visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiconditionalformattingoption.html#cfn-quicksight-analysis-kpiconditionalformattingoption-comparisonvalue
         */
        readonly comparisonValue?: cdk.IResolvable | CfnAnalysis.KPIComparisonValueConditionalFormattingProperty;
        /**
         * The conditional formatting for the primary value of a KPI visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiconditionalformattingoption.html#cfn-quicksight-analysis-kpiconditionalformattingoption-primaryvalue
         */
        readonly primaryValue?: cdk.IResolvable | CfnAnalysis.KPIPrimaryValueConditionalFormattingProperty;
        /**
         * The conditional formatting for the progress bar of a KPI visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiconditionalformattingoption.html#cfn-quicksight-analysis-kpiconditionalformattingoption-progressbar
         */
        readonly progressBar?: cdk.IResolvable | CfnAnalysis.KPIProgressBarConditionalFormattingProperty;
    }
    /**
     * The conditional formatting for the primary value of a KPI visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiprimaryvalueconditionalformatting.html
     */
    interface KPIPrimaryValueConditionalFormattingProperty {
        /**
         * The conditional formatting of the primary value's icon.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiprimaryvalueconditionalformatting.html#cfn-quicksight-analysis-kpiprimaryvalueconditionalformatting-icon
         */
        readonly icon?: CfnAnalysis.ConditionalFormattingIconProperty | cdk.IResolvable;
        /**
         * The conditional formatting of the primary value's text color.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiprimaryvalueconditionalformatting.html#cfn-quicksight-analysis-kpiprimaryvalueconditionalformatting-textcolor
         */
        readonly textColor?: CfnAnalysis.ConditionalFormattingColorProperty | cdk.IResolvable;
    }
    /**
     * The formatting configuration for the icon.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingicon.html
     */
    interface ConditionalFormattingIconProperty {
        /**
         * Determines the custom condition for an icon set.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingicon.html#cfn-quicksight-analysis-conditionalformattingicon-customcondition
         */
        readonly customCondition?: CfnAnalysis.ConditionalFormattingCustomIconConditionProperty | cdk.IResolvable;
        /**
         * Formatting configuration for icon set.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingicon.html#cfn-quicksight-analysis-conditionalformattingicon-iconset
         */
        readonly iconSet?: CfnAnalysis.ConditionalFormattingIconSetProperty | cdk.IResolvable;
    }
    /**
     * Determines the custom condition for an icon set.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingcustomiconcondition.html
     */
    interface ConditionalFormattingCustomIconConditionProperty {
        /**
         * Determines the color of the icon.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingcustomiconcondition.html#cfn-quicksight-analysis-conditionalformattingcustomiconcondition-color
         */
        readonly color?: string;
        /**
         * Determines the icon display configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingcustomiconcondition.html#cfn-quicksight-analysis-conditionalformattingcustomiconcondition-displayconfiguration
         */
        readonly displayConfiguration?: CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty | cdk.IResolvable;
        /**
         * The expression that determines the condition of the icon set.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingcustomiconcondition.html#cfn-quicksight-analysis-conditionalformattingcustomiconcondition-expression
         */
        readonly expression: string;
        /**
         * Custom icon options for an icon set.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingcustomiconcondition.html#cfn-quicksight-analysis-conditionalformattingcustomiconcondition-iconoptions
         */
        readonly iconOptions: CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty | cdk.IResolvable;
    }
    /**
     * Determines the icon display configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingicondisplayconfiguration.html
     */
    interface ConditionalFormattingIconDisplayConfigurationProperty {
        /**
         * Determines the icon display configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingicondisplayconfiguration.html#cfn-quicksight-analysis-conditionalformattingicondisplayconfiguration-icondisplayoption
         */
        readonly iconDisplayOption?: string;
    }
    /**
     * Custom icon options for an icon set.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingcustomiconoptions.html
     */
    interface ConditionalFormattingCustomIconOptionsProperty {
        /**
         * Determines the type of icon.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingcustomiconoptions.html#cfn-quicksight-analysis-conditionalformattingcustomiconoptions-icon
         */
        readonly icon?: string;
        /**
         * Determines the Unicode icon type.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingcustomiconoptions.html#cfn-quicksight-analysis-conditionalformattingcustomiconoptions-unicodeicon
         */
        readonly unicodeIcon?: string;
    }
    /**
     * Formatting configuration for icon set.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingiconset.html
     */
    interface ConditionalFormattingIconSetProperty {
        /**
         * The expression that determines the formatting configuration for the icon set.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingiconset.html#cfn-quicksight-analysis-conditionalformattingiconset-expression
         */
        readonly expression: string;
        /**
         * Determines the icon set type.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingiconset.html#cfn-quicksight-analysis-conditionalformattingiconset-iconsettype
         */
        readonly iconSetType?: string;
    }
    /**
     * The conditional formatting for the actual value of a KPI visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiactualvalueconditionalformatting.html
     */
    interface KPIActualValueConditionalFormattingProperty {
        /**
         * The conditional formatting of the actual value's icon.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiactualvalueconditionalformatting.html#cfn-quicksight-analysis-kpiactualvalueconditionalformatting-icon
         */
        readonly icon?: CfnAnalysis.ConditionalFormattingIconProperty | cdk.IResolvable;
        /**
         * The conditional formatting of the actual value's text color.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiactualvalueconditionalformatting.html#cfn-quicksight-analysis-kpiactualvalueconditionalformatting-textcolor
         */
        readonly textColor?: CfnAnalysis.ConditionalFormattingColorProperty | cdk.IResolvable;
    }
    /**
     * The conditional formatting for the comparison value of a KPI visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpicomparisonvalueconditionalformatting.html
     */
    interface KPIComparisonValueConditionalFormattingProperty {
        /**
         * The conditional formatting of the comparison value's icon.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpicomparisonvalueconditionalformatting.html#cfn-quicksight-analysis-kpicomparisonvalueconditionalformatting-icon
         */
        readonly icon?: CfnAnalysis.ConditionalFormattingIconProperty | cdk.IResolvable;
        /**
         * The conditional formatting of the comparison value's text color.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpicomparisonvalueconditionalformatting.html#cfn-quicksight-analysis-kpicomparisonvalueconditionalformatting-textcolor
         */
        readonly textColor?: CfnAnalysis.ConditionalFormattingColorProperty | cdk.IResolvable;
    }
    /**
     * The conditional formatting for the progress bar of a KPI visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiprogressbarconditionalformatting.html
     */
    interface KPIProgressBarConditionalFormattingProperty {
        /**
         * The conditional formatting of the progress bar's foreground color.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiprogressbarconditionalformatting.html#cfn-quicksight-analysis-kpiprogressbarconditionalformatting-foregroundcolor
         */
        readonly foregroundColor?: CfnAnalysis.ConditionalFormattingColorProperty | cdk.IResolvable;
    }
    /**
     * The configuration of a KPI visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiconfiguration.html
     */
    interface KPIConfigurationProperty {
        /**
         * The field well configuration of a KPI visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiconfiguration.html#cfn-quicksight-analysis-kpiconfiguration-fieldwells
         */
        readonly fieldWells?: cdk.IResolvable | CfnAnalysis.KPIFieldWellsProperty;
        /**
         * The options that determine the presentation of a KPI visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiconfiguration.html#cfn-quicksight-analysis-kpiconfiguration-kpioptions
         */
        readonly kpiOptions?: cdk.IResolvable | CfnAnalysis.KPIOptionsProperty;
        /**
         * The sort configuration of a KPI visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiconfiguration.html#cfn-quicksight-analysis-kpiconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: cdk.IResolvable | CfnAnalysis.KPISortConfigurationProperty;
    }
    /**
     * The sort configuration of a KPI visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpisortconfiguration.html
     */
    interface KPISortConfigurationProperty {
        /**
         * The sort configuration of the trend group fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpisortconfiguration.html#cfn-quicksight-analysis-kpisortconfiguration-trendgroupsort
         */
        readonly trendGroupSort?: Array<CfnAnalysis.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * The options that determine the presentation of a KPI visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpioptions.html
     */
    interface KPIOptionsProperty {
        /**
         * The comparison configuration of a KPI visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpioptions.html#cfn-quicksight-analysis-kpioptions-comparison
         */
        readonly comparison?: CfnAnalysis.ComparisonConfigurationProperty | cdk.IResolvable;
        /**
         * The options that determine the primary value display type.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpioptions.html#cfn-quicksight-analysis-kpioptions-primaryvaluedisplaytype
         */
        readonly primaryValueDisplayType?: string;
        /**
         * The options that determine the primary value font configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpioptions.html#cfn-quicksight-analysis-kpioptions-primaryvaluefontconfiguration
         */
        readonly primaryValueFontConfiguration?: CfnAnalysis.FontConfigurationProperty | cdk.IResolvable;
        /**
         * The options that determine the presentation of the progress bar of a KPI visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpioptions.html#cfn-quicksight-analysis-kpioptions-progressbar
         */
        readonly progressBar?: cdk.IResolvable | CfnAnalysis.ProgressBarOptionsProperty;
        /**
         * The options that determine the presentation of the secondary value of a KPI visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpioptions.html#cfn-quicksight-analysis-kpioptions-secondaryvalue
         */
        readonly secondaryValue?: cdk.IResolvable | CfnAnalysis.SecondaryValueOptionsProperty;
        /**
         * The options that determine the secondary value font configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpioptions.html#cfn-quicksight-analysis-kpioptions-secondaryvaluefontconfiguration
         */
        readonly secondaryValueFontConfiguration?: CfnAnalysis.FontConfigurationProperty | cdk.IResolvable;
        /**
         * The options that determine the visibility, color, type, and tooltip visibility of the sparkline of a KPI visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpioptions.html#cfn-quicksight-analysis-kpioptions-sparkline
         */
        readonly sparkline?: cdk.IResolvable | CfnAnalysis.KPISparklineOptionsProperty;
        /**
         * The options that determine the presentation of trend arrows in a KPI visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpioptions.html#cfn-quicksight-analysis-kpioptions-trendarrows
         */
        readonly trendArrows?: cdk.IResolvable | CfnAnalysis.TrendArrowOptionsProperty;
        /**
         * The options that determine the layout a KPI visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpioptions.html#cfn-quicksight-analysis-kpioptions-visuallayoutoptions
         */
        readonly visualLayoutOptions?: cdk.IResolvable | CfnAnalysis.KPIVisualLayoutOptionsProperty;
    }
    /**
     * The options that determine the layout a KPI visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpivisuallayoutoptions.html
     */
    interface KPIVisualLayoutOptionsProperty {
        /**
         * The standard layout of the KPI visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpivisuallayoutoptions.html#cfn-quicksight-analysis-kpivisuallayoutoptions-standardlayout
         */
        readonly standardLayout?: cdk.IResolvable | CfnAnalysis.KPIVisualStandardLayoutProperty;
    }
    /**
     * The standard layout of the KPI visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpivisualstandardlayout.html
     */
    interface KPIVisualStandardLayoutProperty {
        /**
         * The standard layout type.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpivisualstandardlayout.html#cfn-quicksight-analysis-kpivisualstandardlayout-type
         */
        readonly type: string;
    }
    /**
     * The options that determine the presentation of trend arrows in a KPI visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-trendarrowoptions.html
     */
    interface TrendArrowOptionsProperty {
        /**
         * The visibility of the trend arrows.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-trendarrowoptions.html#cfn-quicksight-analysis-trendarrowoptions-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The options that determine the presentation of the secondary value of a KPI visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-secondaryvalueoptions.html
     */
    interface SecondaryValueOptionsProperty {
        /**
         * Determines the visibility of the secondary value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-secondaryvalueoptions.html#cfn-quicksight-analysis-secondaryvalueoptions-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The comparison display configuration of a KPI or gauge chart.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-comparisonconfiguration.html
     */
    interface ComparisonConfigurationProperty {
        /**
         * The format of the comparison.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-comparisonconfiguration.html#cfn-quicksight-analysis-comparisonconfiguration-comparisonformat
         */
        readonly comparisonFormat?: CfnAnalysis.ComparisonFormatConfigurationProperty | cdk.IResolvable;
        /**
         * The method of the comparison. Choose from the following options:.
         *
         * - `DIFFERENCE`
         * - `PERCENT_DIFFERENCE`
         * - `PERCENT`
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-comparisonconfiguration.html#cfn-quicksight-analysis-comparisonconfiguration-comparisonmethod
         */
        readonly comparisonMethod?: string;
    }
    /**
     * The format of the comparison.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-comparisonformatconfiguration.html
     */
    interface ComparisonFormatConfigurationProperty {
        /**
         * The number display format.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-comparisonformatconfiguration.html#cfn-quicksight-analysis-comparisonformatconfiguration-numberdisplayformatconfiguration
         */
        readonly numberDisplayFormatConfiguration?: cdk.IResolvable | CfnAnalysis.NumberDisplayFormatConfigurationProperty;
        /**
         * The percentage display format.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-comparisonformatconfiguration.html#cfn-quicksight-analysis-comparisonformatconfiguration-percentagedisplayformatconfiguration
         */
        readonly percentageDisplayFormatConfiguration?: cdk.IResolvable | CfnAnalysis.PercentageDisplayFormatConfigurationProperty;
    }
    /**
     * The options that determine the presentation of the progress bar of a KPI visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-progressbaroptions.html
     */
    interface ProgressBarOptionsProperty {
        /**
         * The visibility of the progress bar.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-progressbaroptions.html#cfn-quicksight-analysis-progressbaroptions-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The options that determine the visibility, color, type, and tooltip visibility of the sparkline of a KPI visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpisparklineoptions.html
     */
    interface KPISparklineOptionsProperty {
        /**
         * The color of the sparkline.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpisparklineoptions.html#cfn-quicksight-analysis-kpisparklineoptions-color
         */
        readonly color?: string;
        /**
         * The tooltip visibility of the sparkline.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpisparklineoptions.html#cfn-quicksight-analysis-kpisparklineoptions-tooltipvisibility
         */
        readonly tooltipVisibility?: string;
        /**
         * The type of the sparkline.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpisparklineoptions.html#cfn-quicksight-analysis-kpisparklineoptions-type
         */
        readonly type: string;
        /**
         * The visibility of the sparkline.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpisparklineoptions.html#cfn-quicksight-analysis-kpisparklineoptions-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The field well configuration of a KPI visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpifieldwells.html
     */
    interface KPIFieldWellsProperty {
        /**
         * The target value field wells of a KPI visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpifieldwells.html#cfn-quicksight-analysis-kpifieldwells-targetvalues
         */
        readonly targetValues?: Array<cdk.IResolvable | CfnAnalysis.MeasureFieldProperty> | cdk.IResolvable;
        /**
         * The trend group field wells of a KPI visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpifieldwells.html#cfn-quicksight-analysis-kpifieldwells-trendgroups
         */
        readonly trendGroups?: Array<CfnAnalysis.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The value field wells of a KPI visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpifieldwells.html#cfn-quicksight-analysis-kpifieldwells-values
         */
        readonly values?: Array<cdk.IResolvable | CfnAnalysis.MeasureFieldProperty> | cdk.IResolvable;
    }
    /**
     * A histogram.
     *
     * For more information, see [Using histograms](https://docs.aws.amazon.com/quicksight/latest/user/histogram-charts.html) in the *Amazon QuickSight User Guide* .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramvisual.html
     */
    interface HistogramVisualProperty {
        /**
         * The list of custom actions that are configured for a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramvisual.html#cfn-quicksight-analysis-histogramvisual-actions
         */
        readonly actions?: Array<cdk.IResolvable | CfnAnalysis.VisualCustomActionProperty> | cdk.IResolvable;
        /**
         * The configuration for a `HistogramVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramvisual.html#cfn-quicksight-analysis-histogramvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnAnalysis.HistogramConfigurationProperty | cdk.IResolvable;
        /**
         * The subtitle that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramvisual.html#cfn-quicksight-analysis-histogramvisual-subtitle
         */
        readonly subtitle?: cdk.IResolvable | CfnAnalysis.VisualSubtitleLabelOptionsProperty;
        /**
         * The title that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramvisual.html#cfn-quicksight-analysis-histogramvisual-title
         */
        readonly title?: cdk.IResolvable | CfnAnalysis.VisualTitleLabelOptionsProperty;
        /**
         * The unique identifier of a visual.
         *
         * This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramvisual.html#cfn-quicksight-analysis-histogramvisual-visualid
         */
        readonly visualId: string;
    }
    /**
     * The configuration for a `HistogramVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramconfiguration.html
     */
    interface HistogramConfigurationProperty {
        /**
         * The options that determine the presentation of histogram bins.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramconfiguration.html#cfn-quicksight-analysis-histogramconfiguration-binoptions
         */
        readonly binOptions?: CfnAnalysis.HistogramBinOptionsProperty | cdk.IResolvable;
        /**
         * The data label configuration of a histogram.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramconfiguration.html#cfn-quicksight-analysis-histogramconfiguration-datalabels
         */
        readonly dataLabels?: CfnAnalysis.DataLabelOptionsProperty | cdk.IResolvable;
        /**
         * The field well configuration of a histogram.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramconfiguration.html#cfn-quicksight-analysis-histogramconfiguration-fieldwells
         */
        readonly fieldWells?: CfnAnalysis.HistogramFieldWellsProperty | cdk.IResolvable;
        /**
         * The tooltip configuration of a histogram.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramconfiguration.html#cfn-quicksight-analysis-histogramconfiguration-tooltip
         */
        readonly tooltip?: cdk.IResolvable | CfnAnalysis.TooltipOptionsProperty;
        /**
         * The visual palette configuration of a histogram.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramconfiguration.html#cfn-quicksight-analysis-histogramconfiguration-visualpalette
         */
        readonly visualPalette?: cdk.IResolvable | CfnAnalysis.VisualPaletteProperty;
        /**
         * The options that determine the presentation of the x-axis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramconfiguration.html#cfn-quicksight-analysis-histogramconfiguration-xaxisdisplayoptions
         */
        readonly xAxisDisplayOptions?: CfnAnalysis.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * The options that determine the presentation of the x-axis label.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramconfiguration.html#cfn-quicksight-analysis-histogramconfiguration-xaxislabeloptions
         */
        readonly xAxisLabelOptions?: CfnAnalysis.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The options that determine the presentation of the y-axis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramconfiguration.html#cfn-quicksight-analysis-histogramconfiguration-yaxisdisplayoptions
         */
        readonly yAxisDisplayOptions?: CfnAnalysis.AxisDisplayOptionsProperty | cdk.IResolvable;
    }
    /**
     * The options that determine the presentation of histogram bins.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogrambinoptions.html
     */
    interface HistogramBinOptionsProperty {
        /**
         * The options that determine the bin count of a histogram.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogrambinoptions.html#cfn-quicksight-analysis-histogrambinoptions-bincount
         */
        readonly binCount?: CfnAnalysis.BinCountOptionsProperty | cdk.IResolvable;
        /**
         * The options that determine the bin width of a histogram.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogrambinoptions.html#cfn-quicksight-analysis-histogrambinoptions-binwidth
         */
        readonly binWidth?: CfnAnalysis.BinWidthOptionsProperty | cdk.IResolvable;
        /**
         * The options that determine the selected bin type.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogrambinoptions.html#cfn-quicksight-analysis-histogrambinoptions-selectedbintype
         */
        readonly selectedBinType?: string;
        /**
         * The options that determine the bin start value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogrambinoptions.html#cfn-quicksight-analysis-histogrambinoptions-startvalue
         */
        readonly startValue?: number;
    }
    /**
     * The options that determine the bin width of a histogram.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-binwidthoptions.html
     */
    interface BinWidthOptionsProperty {
        /**
         * The options that determine the bin count limit.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-binwidthoptions.html#cfn-quicksight-analysis-binwidthoptions-bincountlimit
         */
        readonly binCountLimit?: number;
        /**
         * The options that determine the bin width value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-binwidthoptions.html#cfn-quicksight-analysis-binwidthoptions-value
         */
        readonly value?: number;
    }
    /**
     * The options that determine the bin count of a histogram.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-bincountoptions.html
     */
    interface BinCountOptionsProperty {
        /**
         * The options that determine the bin count value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-bincountoptions.html#cfn-quicksight-analysis-bincountoptions-value
         */
        readonly value?: number;
    }
    /**
     * The field well configuration of a histogram.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramfieldwells.html
     */
    interface HistogramFieldWellsProperty {
        /**
         * The field well configuration of a histogram.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramfieldwells.html#cfn-quicksight-analysis-histogramfieldwells-histogramaggregatedfieldwells
         */
        readonly histogramAggregatedFieldWells?: CfnAnalysis.HistogramAggregatedFieldWellsProperty | cdk.IResolvable;
    }
    /**
     * The field well configuration of a histogram.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramaggregatedfieldwells.html
     */
    interface HistogramAggregatedFieldWellsProperty {
        /**
         * The value field wells of a histogram.
         *
         * Values are aggregated by `COUNT` or `DISTINCT_COUNT` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramaggregatedfieldwells.html#cfn-quicksight-analysis-histogramaggregatedfieldwells-values
         */
        readonly values?: Array<cdk.IResolvable | CfnAnalysis.MeasureFieldProperty> | cdk.IResolvable;
    }
    /**
     * A table visual.
     *
     * For more information, see [Using tables as visuals](https://docs.aws.amazon.com/quicksight/latest/user/tabular.html) in the *Amazon QuickSight User Guide* .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablevisual.html
     */
    interface TableVisualProperty {
        /**
         * The list of custom actions that are configured for a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablevisual.html#cfn-quicksight-analysis-tablevisual-actions
         */
        readonly actions?: Array<cdk.IResolvable | CfnAnalysis.VisualCustomActionProperty> | cdk.IResolvable;
        /**
         * The configuration settings of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablevisual.html#cfn-quicksight-analysis-tablevisual-chartconfiguration
         */
        readonly chartConfiguration?: cdk.IResolvable | CfnAnalysis.TableConfigurationProperty;
        /**
         * The conditional formatting for a `PivotTableVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablevisual.html#cfn-quicksight-analysis-tablevisual-conditionalformatting
         */
        readonly conditionalFormatting?: cdk.IResolvable | CfnAnalysis.TableConditionalFormattingProperty;
        /**
         * The subtitle that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablevisual.html#cfn-quicksight-analysis-tablevisual-subtitle
         */
        readonly subtitle?: cdk.IResolvable | CfnAnalysis.VisualSubtitleLabelOptionsProperty;
        /**
         * The title that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablevisual.html#cfn-quicksight-analysis-tablevisual-title
         */
        readonly title?: cdk.IResolvable | CfnAnalysis.VisualTitleLabelOptionsProperty;
        /**
         * The unique identifier of a visual.
         *
         * This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablevisual.html#cfn-quicksight-analysis-tablevisual-visualid
         */
        readonly visualId: string;
    }
    /**
     * The conditional formatting for a `PivotTableVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableconditionalformatting.html
     */
    interface TableConditionalFormattingProperty {
        /**
         * Conditional formatting options for a `PivotTableVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableconditionalformatting.html#cfn-quicksight-analysis-tableconditionalformatting-conditionalformattingoptions
         */
        readonly conditionalFormattingOptions?: Array<cdk.IResolvable | CfnAnalysis.TableConditionalFormattingOptionProperty> | cdk.IResolvable;
    }
    /**
     * Conditional formatting options for a `PivotTableVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableconditionalformattingoption.html
     */
    interface TableConditionalFormattingOptionProperty {
        /**
         * The cell conditional formatting option for a table.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableconditionalformattingoption.html#cfn-quicksight-analysis-tableconditionalformattingoption-cell
         */
        readonly cell?: cdk.IResolvable | CfnAnalysis.TableCellConditionalFormattingProperty;
        /**
         * The row conditional formatting option for a table.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableconditionalformattingoption.html#cfn-quicksight-analysis-tableconditionalformattingoption-row
         */
        readonly row?: cdk.IResolvable | CfnAnalysis.TableRowConditionalFormattingProperty;
    }
    /**
     * The conditional formatting of a table row.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablerowconditionalformatting.html
     */
    interface TableRowConditionalFormattingProperty {
        /**
         * The conditional formatting color (solid, gradient) of the background for a table row.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablerowconditionalformatting.html#cfn-quicksight-analysis-tablerowconditionalformatting-backgroundcolor
         */
        readonly backgroundColor?: CfnAnalysis.ConditionalFormattingColorProperty | cdk.IResolvable;
        /**
         * The conditional formatting color (solid, gradient) of the text for a table row.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablerowconditionalformatting.html#cfn-quicksight-analysis-tablerowconditionalformatting-textcolor
         */
        readonly textColor?: CfnAnalysis.ConditionalFormattingColorProperty | cdk.IResolvable;
    }
    /**
     * The cell conditional formatting option for a table.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablecellconditionalformatting.html
     */
    interface TableCellConditionalFormattingProperty {
        /**
         * The field ID of the cell for conditional formatting.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablecellconditionalformatting.html#cfn-quicksight-analysis-tablecellconditionalformatting-fieldid
         */
        readonly fieldId: string;
        /**
         * The text format of the cell for conditional formatting.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablecellconditionalformatting.html#cfn-quicksight-analysis-tablecellconditionalformatting-textformat
         */
        readonly textFormat?: cdk.IResolvable | CfnAnalysis.TextConditionalFormatProperty;
    }
    /**
     * The conditional formatting for the text.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-textconditionalformat.html
     */
    interface TextConditionalFormatProperty {
        /**
         * The conditional formatting for the text background color.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-textconditionalformat.html#cfn-quicksight-analysis-textconditionalformat-backgroundcolor
         */
        readonly backgroundColor?: CfnAnalysis.ConditionalFormattingColorProperty | cdk.IResolvable;
        /**
         * The conditional formatting for the icon.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-textconditionalformat.html#cfn-quicksight-analysis-textconditionalformat-icon
         */
        readonly icon?: CfnAnalysis.ConditionalFormattingIconProperty | cdk.IResolvable;
        /**
         * The conditional formatting for the text color.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-textconditionalformat.html#cfn-quicksight-analysis-textconditionalformat-textcolor
         */
        readonly textColor?: CfnAnalysis.ConditionalFormattingColorProperty | cdk.IResolvable;
    }
    /**
     * The configuration for a `TableVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableconfiguration.html
     */
    interface TableConfigurationProperty {
        /**
         * The field options for a table visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableconfiguration.html#cfn-quicksight-analysis-tableconfiguration-fieldoptions
         */
        readonly fieldOptions?: cdk.IResolvable | CfnAnalysis.TableFieldOptionsProperty;
        /**
         * The field wells of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableconfiguration.html#cfn-quicksight-analysis-tableconfiguration-fieldwells
         */
        readonly fieldWells?: cdk.IResolvable | CfnAnalysis.TableFieldWellsProperty;
        /**
         * The paginated report options for a table visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableconfiguration.html#cfn-quicksight-analysis-tableconfiguration-paginatedreportoptions
         */
        readonly paginatedReportOptions?: cdk.IResolvable | CfnAnalysis.TablePaginatedReportOptionsProperty;
        /**
         * The sort configuration for a `TableVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableconfiguration.html#cfn-quicksight-analysis-tableconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: cdk.IResolvable | CfnAnalysis.TableSortConfigurationProperty;
        /**
         * A collection of inline visualizations to display within a chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableconfiguration.html#cfn-quicksight-analysis-tableconfiguration-tableinlinevisualizations
         */
        readonly tableInlineVisualizations?: Array<cdk.IResolvable | CfnAnalysis.TableInlineVisualizationProperty> | cdk.IResolvable;
        /**
         * The table options for a table visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableconfiguration.html#cfn-quicksight-analysis-tableconfiguration-tableoptions
         */
        readonly tableOptions?: cdk.IResolvable | CfnAnalysis.TableOptionsProperty;
        /**
         * The total options for a table visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableconfiguration.html#cfn-quicksight-analysis-tableconfiguration-totaloptions
         */
        readonly totalOptions?: cdk.IResolvable | CfnAnalysis.TotalOptionsProperty;
    }
    /**
     * The sort configuration for a `TableVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablesortconfiguration.html
     */
    interface TableSortConfigurationProperty {
        /**
         * The pagination configuration (page size, page number) for the table.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablesortconfiguration.html#cfn-quicksight-analysis-tablesortconfiguration-paginationconfiguration
         */
        readonly paginationConfiguration?: cdk.IResolvable | CfnAnalysis.PaginationConfigurationProperty;
        /**
         * The field sort options for rows in the table.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablesortconfiguration.html#cfn-quicksight-analysis-tablesortconfiguration-rowsort
         */
        readonly rowSort?: Array<CfnAnalysis.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * The paginated report options for a table visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablepaginatedreportoptions.html
     */
    interface TablePaginatedReportOptionsProperty {
        /**
         * The visibility of repeating header rows on each page.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablepaginatedreportoptions.html#cfn-quicksight-analysis-tablepaginatedreportoptions-overflowcolumnheadervisibility
         */
        readonly overflowColumnHeaderVisibility?: string;
        /**
         * The visibility of printing table overflow across pages.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablepaginatedreportoptions.html#cfn-quicksight-analysis-tablepaginatedreportoptions-verticaloverflowvisibility
         */
        readonly verticalOverflowVisibility?: string;
    }
    /**
     * The table options for a table visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableoptions.html
     */
    interface TableOptionsProperty {
        /**
         * The table cell style of table cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableoptions.html#cfn-quicksight-analysis-tableoptions-cellstyle
         */
        readonly cellStyle?: cdk.IResolvable | CfnAnalysis.TableCellStyleProperty;
        /**
         * The table cell style of a table header.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableoptions.html#cfn-quicksight-analysis-tableoptions-headerstyle
         */
        readonly headerStyle?: cdk.IResolvable | CfnAnalysis.TableCellStyleProperty;
        /**
         * The orientation (vertical, horizontal) for a table.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableoptions.html#cfn-quicksight-analysis-tableoptions-orientation
         */
        readonly orientation?: string;
        /**
         * The row alternate color options (widget status, row alternate colors) for a table.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableoptions.html#cfn-quicksight-analysis-tableoptions-rowalternatecoloroptions
         */
        readonly rowAlternateColorOptions?: cdk.IResolvable | CfnAnalysis.RowAlternateColorOptionsProperty;
    }
    /**
     * The table cell style for a cell in pivot table or table visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablecellstyle.html
     */
    interface TableCellStyleProperty {
        /**
         * The background color for the table cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablecellstyle.html#cfn-quicksight-analysis-tablecellstyle-backgroundcolor
         */
        readonly backgroundColor?: string;
        /**
         * The borders for the table cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablecellstyle.html#cfn-quicksight-analysis-tablecellstyle-border
         */
        readonly border?: CfnAnalysis.GlobalTableBorderOptionsProperty | cdk.IResolvable;
        /**
         * The font configuration of the table cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablecellstyle.html#cfn-quicksight-analysis-tablecellstyle-fontconfiguration
         */
        readonly fontConfiguration?: CfnAnalysis.FontConfigurationProperty | cdk.IResolvable;
        /**
         * The height color for the table cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablecellstyle.html#cfn-quicksight-analysis-tablecellstyle-height
         */
        readonly height?: number;
        /**
         * The horizontal text alignment (left, center, right, auto) for the table cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablecellstyle.html#cfn-quicksight-analysis-tablecellstyle-horizontaltextalignment
         */
        readonly horizontalTextAlignment?: string;
        /**
         * The text wrap (none, wrap) for the table cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablecellstyle.html#cfn-quicksight-analysis-tablecellstyle-textwrap
         */
        readonly textWrap?: string;
        /**
         * The vertical text alignment (top, middle, bottom) for the table cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablecellstyle.html#cfn-quicksight-analysis-tablecellstyle-verticaltextalignment
         */
        readonly verticalTextAlignment?: string;
        /**
         * The visibility of the table cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablecellstyle.html#cfn-quicksight-analysis-tablecellstyle-visibility
         */
        readonly visibility?: string;
    }
    /**
     * Determines the border options for a table visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-globaltableborderoptions.html
     */
    interface GlobalTableBorderOptionsProperty {
        /**
         * Determines the options for side specific border.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-globaltableborderoptions.html#cfn-quicksight-analysis-globaltableborderoptions-sidespecificborder
         */
        readonly sideSpecificBorder?: cdk.IResolvable | CfnAnalysis.TableSideBorderOptionsProperty;
        /**
         * Determines the options for uniform border.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-globaltableborderoptions.html#cfn-quicksight-analysis-globaltableborderoptions-uniformborder
         */
        readonly uniformBorder?: cdk.IResolvable | CfnAnalysis.TableBorderOptionsProperty;
    }
    /**
     * The border options for a table border.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableborderoptions.html
     */
    interface TableBorderOptionsProperty {
        /**
         * The color of a table border.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableborderoptions.html#cfn-quicksight-analysis-tableborderoptions-color
         */
        readonly color?: string;
        /**
         * The style (none, solid) of a table border.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableborderoptions.html#cfn-quicksight-analysis-tableborderoptions-style
         */
        readonly style?: string;
        /**
         * The thickness of a table border.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableborderoptions.html#cfn-quicksight-analysis-tableborderoptions-thickness
         */
        readonly thickness?: number;
    }
    /**
     * The side border options for a table.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablesideborderoptions.html
     */
    interface TableSideBorderOptionsProperty {
        /**
         * The table border options of the bottom border.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablesideborderoptions.html#cfn-quicksight-analysis-tablesideborderoptions-bottom
         */
        readonly bottom?: cdk.IResolvable | CfnAnalysis.TableBorderOptionsProperty;
        /**
         * The table border options of the inner horizontal border.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablesideborderoptions.html#cfn-quicksight-analysis-tablesideborderoptions-innerhorizontal
         */
        readonly innerHorizontal?: cdk.IResolvable | CfnAnalysis.TableBorderOptionsProperty;
        /**
         * The table border options of the inner vertical border.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablesideborderoptions.html#cfn-quicksight-analysis-tablesideborderoptions-innervertical
         */
        readonly innerVertical?: cdk.IResolvable | CfnAnalysis.TableBorderOptionsProperty;
        /**
         * The table border options of the left border.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablesideborderoptions.html#cfn-quicksight-analysis-tablesideborderoptions-left
         */
        readonly left?: cdk.IResolvable | CfnAnalysis.TableBorderOptionsProperty;
        /**
         * The table border options of the right border.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablesideborderoptions.html#cfn-quicksight-analysis-tablesideborderoptions-right
         */
        readonly right?: cdk.IResolvable | CfnAnalysis.TableBorderOptionsProperty;
        /**
         * The table border options of the top border.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablesideborderoptions.html#cfn-quicksight-analysis-tablesideborderoptions-top
         */
        readonly top?: cdk.IResolvable | CfnAnalysis.TableBorderOptionsProperty;
    }
    /**
     * Determines the row alternate color options.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-rowalternatecoloroptions.html
     */
    interface RowAlternateColorOptionsProperty {
        /**
         * Determines the list of row alternate colors.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-rowalternatecoloroptions.html#cfn-quicksight-analysis-rowalternatecoloroptions-rowalternatecolors
         */
        readonly rowAlternateColors?: Array<string>;
        /**
         * Determines the widget status.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-rowalternatecoloroptions.html#cfn-quicksight-analysis-rowalternatecoloroptions-status
         */
        readonly status?: string;
        /**
         * The primary background color options for alternate rows.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-rowalternatecoloroptions.html#cfn-quicksight-analysis-rowalternatecoloroptions-useprimarybackgroundcolor
         */
        readonly usePrimaryBackgroundColor?: string;
    }
    /**
     * The inline visualization of a specific type to display within a chart.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableinlinevisualization.html
     */
    interface TableInlineVisualizationProperty {
        /**
         * The configuration of the inline visualization of the data bars within a chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableinlinevisualization.html#cfn-quicksight-analysis-tableinlinevisualization-databars
         */
        readonly dataBars?: CfnAnalysis.DataBarsOptionsProperty | cdk.IResolvable;
    }
    /**
     * The options for data bars.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-databarsoptions.html
     */
    interface DataBarsOptionsProperty {
        /**
         * The field ID for the data bars options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-databarsoptions.html#cfn-quicksight-analysis-databarsoptions-fieldid
         */
        readonly fieldId: string;
        /**
         * The color of the negative data bar.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-databarsoptions.html#cfn-quicksight-analysis-databarsoptions-negativecolor
         */
        readonly negativeColor?: string;
        /**
         * The color of the positive data bar.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-databarsoptions.html#cfn-quicksight-analysis-databarsoptions-positivecolor
         */
        readonly positiveColor?: string;
    }
    /**
     * The field wells for a table visual.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldwells.html
     */
    interface TableFieldWellsProperty {
        /**
         * The aggregated field well for the table.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldwells.html#cfn-quicksight-analysis-tablefieldwells-tableaggregatedfieldwells
         */
        readonly tableAggregatedFieldWells?: cdk.IResolvable | CfnAnalysis.TableAggregatedFieldWellsProperty;
        /**
         * The unaggregated field well for the table.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldwells.html#cfn-quicksight-analysis-tablefieldwells-tableunaggregatedfieldwells
         */
        readonly tableUnaggregatedFieldWells?: cdk.IResolvable | CfnAnalysis.TableUnaggregatedFieldWellsProperty;
    }
    /**
     * The unaggregated field well for the table.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableunaggregatedfieldwells.html
     */
    interface TableUnaggregatedFieldWellsProperty {
        /**
         * The values field well for a pivot table.
         *
         * Values are unaggregated for an unaggregated table.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableunaggregatedfieldwells.html#cfn-quicksight-analysis-tableunaggregatedfieldwells-values
         */
        readonly values?: Array<cdk.IResolvable | CfnAnalysis.UnaggregatedFieldProperty> | cdk.IResolvable;
    }
    /**
     * The unaggregated field for a table.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-unaggregatedfield.html
     */
    interface UnaggregatedFieldProperty {
        /**
         * The column that is used in the `UnaggregatedField` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-unaggregatedfield.html#cfn-quicksight-analysis-unaggregatedfield-column
         */
        readonly column: CfnAnalysis.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * The custom field ID.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-unaggregatedfield.html#cfn-quicksight-analysis-unaggregatedfield-fieldid
         */
        readonly fieldId: string;
        /**
         * The format configuration of the field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-unaggregatedfield.html#cfn-quicksight-analysis-unaggregatedfield-formatconfiguration
         */
        readonly formatConfiguration?: CfnAnalysis.FormatConfigurationProperty | cdk.IResolvable;
    }
    /**
     * The aggregated field well for the table.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableaggregatedfieldwells.html
     */
    interface TableAggregatedFieldWellsProperty {
        /**
         * The group by field well for a pivot table.
         *
         * Values are grouped by group by fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableaggregatedfieldwells.html#cfn-quicksight-analysis-tableaggregatedfieldwells-groupby
         */
        readonly groupBy?: Array<CfnAnalysis.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The values field well for a pivot table.
         *
         * Values are aggregated based on group by fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableaggregatedfieldwells.html#cfn-quicksight-analysis-tableaggregatedfieldwells-values
         */
        readonly values?: Array<cdk.IResolvable | CfnAnalysis.MeasureFieldProperty> | cdk.IResolvable;
    }
    /**
     * The field options of a table visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldoptions.html
     */
    interface TableFieldOptionsProperty {
        /**
         * The order of the field IDs that are configured as field options for a table visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldoptions.html#cfn-quicksight-analysis-tablefieldoptions-order
         */
        readonly order?: Array<string>;
        /**
         * The settings for the pinned columns of a table visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldoptions.html#cfn-quicksight-analysis-tablefieldoptions-pinnedfieldoptions
         */
        readonly pinnedFieldOptions?: cdk.IResolvable | CfnAnalysis.TablePinnedFieldOptionsProperty;
        /**
         * The field options to be configured to a table.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldoptions.html#cfn-quicksight-analysis-tablefieldoptions-selectedfieldoptions
         */
        readonly selectedFieldOptions?: Array<cdk.IResolvable | CfnAnalysis.TableFieldOptionProperty> | cdk.IResolvable;
    }
    /**
     * The settings for the pinned columns of a table visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablepinnedfieldoptions.html
     */
    interface TablePinnedFieldOptionsProperty {
        /**
         * A list of columns to be pinned to the left of a table visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablepinnedfieldoptions.html#cfn-quicksight-analysis-tablepinnedfieldoptions-pinnedleftfields
         */
        readonly pinnedLeftFields?: Array<string>;
    }
    /**
     * The options for a table field.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldoption.html
     */
    interface TableFieldOptionProperty {
        /**
         * The custom label for a table field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldoption.html#cfn-quicksight-analysis-tablefieldoption-customlabel
         */
        readonly customLabel?: string;
        /**
         * The field ID for a table field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldoption.html#cfn-quicksight-analysis-tablefieldoption-fieldid
         */
        readonly fieldId: string;
        /**
         * The URL configuration for a table field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldoption.html#cfn-quicksight-analysis-tablefieldoption-urlstyling
         */
        readonly urlStyling?: cdk.IResolvable | CfnAnalysis.TableFieldURLConfigurationProperty;
        /**
         * The visibility of a table field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldoption.html#cfn-quicksight-analysis-tablefieldoption-visibility
         */
        readonly visibility?: string;
        /**
         * The width for a table field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldoption.html#cfn-quicksight-analysis-tablefieldoption-width
         */
        readonly width?: string;
    }
    /**
     * The URL configuration for a table field.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldurlconfiguration.html
     */
    interface TableFieldURLConfigurationProperty {
        /**
         * The image configuration of a table field URL.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldurlconfiguration.html#cfn-quicksight-analysis-tablefieldurlconfiguration-imageconfiguration
         */
        readonly imageConfiguration?: cdk.IResolvable | CfnAnalysis.TableFieldImageConfigurationProperty;
        /**
         * The link configuration of a table field URL.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldurlconfiguration.html#cfn-quicksight-analysis-tablefieldurlconfiguration-linkconfiguration
         */
        readonly linkConfiguration?: cdk.IResolvable | CfnAnalysis.TableFieldLinkConfigurationProperty;
    }
    /**
     * The link configuration of a table field URL.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldlinkconfiguration.html
     */
    interface TableFieldLinkConfigurationProperty {
        /**
         * The URL content (text, icon) for the table link configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldlinkconfiguration.html#cfn-quicksight-analysis-tablefieldlinkconfiguration-content
         */
        readonly content: cdk.IResolvable | CfnAnalysis.TableFieldLinkContentConfigurationProperty;
        /**
         * The URL target (new tab, new window, same tab) for the table link configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldlinkconfiguration.html#cfn-quicksight-analysis-tablefieldlinkconfiguration-target
         */
        readonly target: string;
    }
    /**
     * The URL content (text, icon) for the table link configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldlinkcontentconfiguration.html
     */
    interface TableFieldLinkContentConfigurationProperty {
        /**
         * The custom icon content for the table link content configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldlinkcontentconfiguration.html#cfn-quicksight-analysis-tablefieldlinkcontentconfiguration-customiconcontent
         */
        readonly customIconContent?: cdk.IResolvable | CfnAnalysis.TableFieldCustomIconContentProperty;
        /**
         * The custom text content (value, font configuration) for the table link content configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldlinkcontentconfiguration.html#cfn-quicksight-analysis-tablefieldlinkcontentconfiguration-customtextcontent
         */
        readonly customTextContent?: cdk.IResolvable | CfnAnalysis.TableFieldCustomTextContentProperty;
    }
    /**
     * The custom icon content for the table link content configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldcustomiconcontent.html
     */
    interface TableFieldCustomIconContentProperty {
        /**
         * The icon set type (link) of the custom icon content for table URL link content.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldcustomiconcontent.html#cfn-quicksight-analysis-tablefieldcustomiconcontent-icon
         */
        readonly icon?: string;
    }
    /**
     * The custom text content (value, font configuration) for the table link content configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldcustomtextcontent.html
     */
    interface TableFieldCustomTextContentProperty {
        /**
         * The font configuration of the custom text content for the table URL link content.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldcustomtextcontent.html#cfn-quicksight-analysis-tablefieldcustomtextcontent-fontconfiguration
         */
        readonly fontConfiguration: CfnAnalysis.FontConfigurationProperty | cdk.IResolvable;
        /**
         * The string value of the custom text content for the table URL link content.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldcustomtextcontent.html#cfn-quicksight-analysis-tablefieldcustomtextcontent-value
         */
        readonly value?: string;
    }
    /**
     * The image configuration of a table field URL.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldimageconfiguration.html
     */
    interface TableFieldImageConfigurationProperty {
        /**
         * The sizing options for the table image configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldimageconfiguration.html#cfn-quicksight-analysis-tablefieldimageconfiguration-sizingoptions
         */
        readonly sizingOptions?: cdk.IResolvable | CfnAnalysis.TableCellImageSizingConfigurationProperty;
    }
    /**
     * The sizing options for the table image configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablecellimagesizingconfiguration.html
     */
    interface TableCellImageSizingConfigurationProperty {
        /**
         * The cell scaling configuration of the sizing options for the table image configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablecellimagesizingconfiguration.html#cfn-quicksight-analysis-tablecellimagesizingconfiguration-tablecellimagescalingconfiguration
         */
        readonly tableCellImageScalingConfiguration?: string;
    }
    /**
     * The total options for a table visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-totaloptions.html
     */
    interface TotalOptionsProperty {
        /**
         * The custom label string for the total cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-totaloptions.html#cfn-quicksight-analysis-totaloptions-customlabel
         */
        readonly customLabel?: string;
        /**
         * The placement (start, end) for the total cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-totaloptions.html#cfn-quicksight-analysis-totaloptions-placement
         */
        readonly placement?: string;
        /**
         * The scroll status (pinned, scrolled) for the total cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-totaloptions.html#cfn-quicksight-analysis-totaloptions-scrollstatus
         */
        readonly scrollStatus?: string;
        /**
         * The total aggregation settings for each value field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-totaloptions.html#cfn-quicksight-analysis-totaloptions-totalaggregationoptions
         */
        readonly totalAggregationOptions?: Array<cdk.IResolvable | CfnAnalysis.TotalAggregationOptionProperty> | cdk.IResolvable;
        /**
         * Cell styling options for the total cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-totaloptions.html#cfn-quicksight-analysis-totaloptions-totalcellstyle
         */
        readonly totalCellStyle?: cdk.IResolvable | CfnAnalysis.TableCellStyleProperty;
        /**
         * The visibility configuration for the total cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-totaloptions.html#cfn-quicksight-analysis-totaloptions-totalsvisibility
         */
        readonly totalsVisibility?: string;
    }
    /**
     * The total aggregation settings map of a field id.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-totalaggregationoption.html
     */
    interface TotalAggregationOptionProperty {
        /**
         * The field id that's associated with the total aggregation option.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-totalaggregationoption.html#cfn-quicksight-analysis-totalaggregationoption-fieldid
         */
        readonly fieldId: string;
        /**
         * The total aggregation function that you want to set for a specified field id.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-totalaggregationoption.html#cfn-quicksight-analysis-totalaggregationoption-totalaggregationfunction
         */
        readonly totalAggregationFunction: cdk.IResolvable | CfnAnalysis.TotalAggregationFunctionProperty;
    }
    /**
     * An aggregation function that aggregates the total values of a measure.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-totalaggregationfunction.html
     */
    interface TotalAggregationFunctionProperty {
        /**
         * A built in aggregation function for total values.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-totalaggregationfunction.html#cfn-quicksight-analysis-totalaggregationfunction-simpletotalaggregationfunction
         */
        readonly simpleTotalAggregationFunction?: string;
    }
    /**
     * A pivot table.
     *
     * For more information, see [Using pivot tables](https://docs.aws.amazon.com/quicksight/latest/user/pivot-table.html) in the *Amazon QuickSight User Guide* .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablevisual.html
     */
    interface PivotTableVisualProperty {
        /**
         * The list of custom actions that are configured for a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablevisual.html#cfn-quicksight-analysis-pivottablevisual-actions
         */
        readonly actions?: Array<cdk.IResolvable | CfnAnalysis.VisualCustomActionProperty> | cdk.IResolvable;
        /**
         * The configuration settings of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablevisual.html#cfn-quicksight-analysis-pivottablevisual-chartconfiguration
         */
        readonly chartConfiguration?: cdk.IResolvable | CfnAnalysis.PivotTableConfigurationProperty;
        /**
         * The conditional formatting for a `PivotTableVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablevisual.html#cfn-quicksight-analysis-pivottablevisual-conditionalformatting
         */
        readonly conditionalFormatting?: cdk.IResolvable | CfnAnalysis.PivotTableConditionalFormattingProperty;
        /**
         * The subtitle that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablevisual.html#cfn-quicksight-analysis-pivottablevisual-subtitle
         */
        readonly subtitle?: cdk.IResolvable | CfnAnalysis.VisualSubtitleLabelOptionsProperty;
        /**
         * The title that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablevisual.html#cfn-quicksight-analysis-pivottablevisual-title
         */
        readonly title?: cdk.IResolvable | CfnAnalysis.VisualTitleLabelOptionsProperty;
        /**
         * The unique identifier of a visual.
         *
         * This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablevisual.html#cfn-quicksight-analysis-pivottablevisual-visualid
         */
        readonly visualId: string;
    }
    /**
     * The conditional formatting for a `PivotTableVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableconditionalformatting.html
     */
    interface PivotTableConditionalFormattingProperty {
        /**
         * Conditional formatting options for a `PivotTableVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableconditionalformatting.html#cfn-quicksight-analysis-pivottableconditionalformatting-conditionalformattingoptions
         */
        readonly conditionalFormattingOptions?: Array<cdk.IResolvable | CfnAnalysis.PivotTableConditionalFormattingOptionProperty> | cdk.IResolvable;
    }
    /**
     * Conditional formatting options for a `PivotTableVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableconditionalformattingoption.html
     */
    interface PivotTableConditionalFormattingOptionProperty {
        /**
         * The cell conditional formatting option for a pivot table.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableconditionalformattingoption.html#cfn-quicksight-analysis-pivottableconditionalformattingoption-cell
         */
        readonly cell?: cdk.IResolvable | CfnAnalysis.PivotTableCellConditionalFormattingProperty;
    }
    /**
     * The cell conditional formatting option for a pivot table.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablecellconditionalformatting.html
     */
    interface PivotTableCellConditionalFormattingProperty {
        /**
         * The field ID of the cell for conditional formatting.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablecellconditionalformatting.html#cfn-quicksight-analysis-pivottablecellconditionalformatting-fieldid
         */
        readonly fieldId: string;
        /**
         * The scope of the cell for conditional formatting.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablecellconditionalformatting.html#cfn-quicksight-analysis-pivottablecellconditionalformatting-scope
         */
        readonly scope?: cdk.IResolvable | CfnAnalysis.PivotTableConditionalFormattingScopeProperty;
        /**
         * A list of cell scopes for conditional formatting.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablecellconditionalformatting.html#cfn-quicksight-analysis-pivottablecellconditionalformatting-scopes
         */
        readonly scopes?: Array<cdk.IResolvable | CfnAnalysis.PivotTableConditionalFormattingScopeProperty> | cdk.IResolvable;
        /**
         * The text format of the cell for conditional formatting.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablecellconditionalformatting.html#cfn-quicksight-analysis-pivottablecellconditionalformatting-textformat
         */
        readonly textFormat?: cdk.IResolvable | CfnAnalysis.TextConditionalFormatProperty;
    }
    /**
     * The scope of the cell for conditional formatting.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableconditionalformattingscope.html
     */
    interface PivotTableConditionalFormattingScopeProperty {
        /**
         * The role (field, field total, grand total) of the cell for conditional formatting.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableconditionalformattingscope.html#cfn-quicksight-analysis-pivottableconditionalformattingscope-role
         */
        readonly role?: string;
    }
    /**
     * The configuration for a `PivotTableVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableconfiguration.html
     */
    interface PivotTableConfigurationProperty {
        /**
         * The field options for a pivot table visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableconfiguration.html#cfn-quicksight-analysis-pivottableconfiguration-fieldoptions
         */
        readonly fieldOptions?: cdk.IResolvable | CfnAnalysis.PivotTableFieldOptionsProperty;
        /**
         * The field wells of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableconfiguration.html#cfn-quicksight-analysis-pivottableconfiguration-fieldwells
         */
        readonly fieldWells?: cdk.IResolvable | CfnAnalysis.PivotTableFieldWellsProperty;
        /**
         * The paginated report options for a pivot table visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableconfiguration.html#cfn-quicksight-analysis-pivottableconfiguration-paginatedreportoptions
         */
        readonly paginatedReportOptions?: cdk.IResolvable | CfnAnalysis.PivotTablePaginatedReportOptionsProperty;
        /**
         * The sort configuration for a `PivotTableVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableconfiguration.html#cfn-quicksight-analysis-pivottableconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: cdk.IResolvable | CfnAnalysis.PivotTableSortConfigurationProperty;
        /**
         * The table options for a pivot table visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableconfiguration.html#cfn-quicksight-analysis-pivottableconfiguration-tableoptions
         */
        readonly tableOptions?: cdk.IResolvable | CfnAnalysis.PivotTableOptionsProperty;
        /**
         * The total options for a pivot table visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableconfiguration.html#cfn-quicksight-analysis-pivottableconfiguration-totaloptions
         */
        readonly totalOptions?: cdk.IResolvable | CfnAnalysis.PivotTableTotalOptionsProperty;
    }
    /**
     * The sort configuration for a `PivotTableVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablesortconfiguration.html
     */
    interface PivotTableSortConfigurationProperty {
        /**
         * The field sort options for a pivot table sort configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablesortconfiguration.html#cfn-quicksight-analysis-pivottablesortconfiguration-fieldsortoptions
         */
        readonly fieldSortOptions?: Array<cdk.IResolvable | CfnAnalysis.PivotFieldSortOptionsProperty> | cdk.IResolvable;
    }
    /**
     * The field sort options for a pivot table sort configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivotfieldsortoptions.html
     */
    interface PivotFieldSortOptionsProperty {
        /**
         * The field ID for the field sort options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivotfieldsortoptions.html#cfn-quicksight-analysis-pivotfieldsortoptions-fieldid
         */
        readonly fieldId: string;
        /**
         * The sort by field for the field sort options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivotfieldsortoptions.html#cfn-quicksight-analysis-pivotfieldsortoptions-sortby
         */
        readonly sortBy: cdk.IResolvable | CfnAnalysis.PivotTableSortByProperty;
    }
    /**
     * The sort by field for the field sort options.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablesortby.html
     */
    interface PivotTableSortByProperty {
        /**
         * The column sort (field id, direction) for the pivot table sort by options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablesortby.html#cfn-quicksight-analysis-pivottablesortby-column
         */
        readonly column?: CfnAnalysis.ColumnSortProperty | cdk.IResolvable;
        /**
         * The data path sort (data path value, direction) for the pivot table sort by options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablesortby.html#cfn-quicksight-analysis-pivottablesortby-datapath
         */
        readonly dataPath?: CfnAnalysis.DataPathSortProperty | cdk.IResolvable;
        /**
         * The field sort (field id, direction) for the pivot table sort by options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablesortby.html#cfn-quicksight-analysis-pivottablesortby-field
         */
        readonly field?: CfnAnalysis.FieldSortProperty | cdk.IResolvable;
    }
    /**
     * Allows data paths to be sorted by a specific data value.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathsort.html
     */
    interface DataPathSortProperty {
        /**
         * Determines the sort direction.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathsort.html#cfn-quicksight-analysis-datapathsort-direction
         */
        readonly direction: string;
        /**
         * The list of data paths that need to be sorted.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathsort.html#cfn-quicksight-analysis-datapathsort-sortpaths
         */
        readonly sortPaths: Array<CfnAnalysis.DataPathValueProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * The paginated report options for a pivot table visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablepaginatedreportoptions.html
     */
    interface PivotTablePaginatedReportOptionsProperty {
        /**
         * The visibility of the repeating header rows on each page.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablepaginatedreportoptions.html#cfn-quicksight-analysis-pivottablepaginatedreportoptions-overflowcolumnheadervisibility
         */
        readonly overflowColumnHeaderVisibility?: string;
        /**
         * The visibility of the printing table overflow across pages.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablepaginatedreportoptions.html#cfn-quicksight-analysis-pivottablepaginatedreportoptions-verticaloverflowvisibility
         */
        readonly verticalOverflowVisibility?: string;
    }
    /**
     * The table options for a pivot table visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableoptions.html
     */
    interface PivotTableOptionsProperty {
        /**
         * The table cell style of cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableoptions.html#cfn-quicksight-analysis-pivottableoptions-cellstyle
         */
        readonly cellStyle?: cdk.IResolvable | CfnAnalysis.TableCellStyleProperty;
        /**
         * The visibility setting of a pivot table's collapsed row dimension fields.
         *
         * If the value of this structure is `HIDDEN` , all collapsed columns in a pivot table are automatically hidden. The default value is `VISIBLE` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableoptions.html#cfn-quicksight-analysis-pivottableoptions-collapsedrowdimensionsvisibility
         */
        readonly collapsedRowDimensionsVisibility?: string;
        /**
         * The table cell style of the column header.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableoptions.html#cfn-quicksight-analysis-pivottableoptions-columnheaderstyle
         */
        readonly columnHeaderStyle?: cdk.IResolvable | CfnAnalysis.TableCellStyleProperty;
        /**
         * The visibility of the column names.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableoptions.html#cfn-quicksight-analysis-pivottableoptions-columnnamesvisibility
         */
        readonly columnNamesVisibility?: string;
        /**
         * The default cell width of the pivot table.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableoptions.html#cfn-quicksight-analysis-pivottableoptions-defaultcellwidth
         */
        readonly defaultCellWidth?: string;
        /**
         * The metric placement (row, column) options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableoptions.html#cfn-quicksight-analysis-pivottableoptions-metricplacement
         */
        readonly metricPlacement?: string;
        /**
         * The row alternate color options (widget status, row alternate colors).
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableoptions.html#cfn-quicksight-analysis-pivottableoptions-rowalternatecoloroptions
         */
        readonly rowAlternateColorOptions?: cdk.IResolvable | CfnAnalysis.RowAlternateColorOptionsProperty;
        /**
         * The table cell style of row field names.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableoptions.html#cfn-quicksight-analysis-pivottableoptions-rowfieldnamesstyle
         */
        readonly rowFieldNamesStyle?: cdk.IResolvable | CfnAnalysis.TableCellStyleProperty;
        /**
         * The table cell style of the row headers.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableoptions.html#cfn-quicksight-analysis-pivottableoptions-rowheaderstyle
         */
        readonly rowHeaderStyle?: cdk.IResolvable | CfnAnalysis.TableCellStyleProperty;
        /**
         * The options for the label that is located above the row headers.
         *
         * This option is only applicable when `RowsLayout` is set to `HIERARCHY` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableoptions.html#cfn-quicksight-analysis-pivottableoptions-rowslabeloptions
         */
        readonly rowsLabelOptions?: cdk.IResolvable | CfnAnalysis.PivotTableRowsLabelOptionsProperty;
        /**
         * The layout for the row dimension headers of a pivot table. Choose one of the following options.
         *
         * - `TABULAR` : (Default) Each row field is displayed in a separate column.
         * - `HIERARCHY` : All row fields are displayed in a single column. Indentation is used to differentiate row headers of different fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableoptions.html#cfn-quicksight-analysis-pivottableoptions-rowslayout
         */
        readonly rowsLayout?: string;
        /**
         * The visibility of the single metric options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableoptions.html#cfn-quicksight-analysis-pivottableoptions-singlemetricvisibility
         */
        readonly singleMetricVisibility?: string;
        /**
         * Determines the visibility of the pivot table.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableoptions.html#cfn-quicksight-analysis-pivottableoptions-togglebuttonsvisibility
         */
        readonly toggleButtonsVisibility?: string;
    }
    /**
     * The options for the label thta is located above the row headers.
     *
     * This option is only applicable when `RowsLayout` is set to `HIERARCHY` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablerowslabeloptions.html
     */
    interface PivotTableRowsLabelOptionsProperty {
        /**
         * The custom label string for the rows label.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablerowslabeloptions.html#cfn-quicksight-analysis-pivottablerowslabeloptions-customlabel
         */
        readonly customLabel?: string;
        /**
         * The visibility of the rows label.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablerowslabeloptions.html#cfn-quicksight-analysis-pivottablerowslabeloptions-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The field wells for a pivot table visual.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablefieldwells.html
     */
    interface PivotTableFieldWellsProperty {
        /**
         * The aggregated field well for the pivot table.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablefieldwells.html#cfn-quicksight-analysis-pivottablefieldwells-pivottableaggregatedfieldwells
         */
        readonly pivotTableAggregatedFieldWells?: cdk.IResolvable | CfnAnalysis.PivotTableAggregatedFieldWellsProperty;
    }
    /**
     * The aggregated field well for the pivot table.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableaggregatedfieldwells.html
     */
    interface PivotTableAggregatedFieldWellsProperty {
        /**
         * The columns field well for a pivot table.
         *
         * Values are grouped by columns fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableaggregatedfieldwells.html#cfn-quicksight-analysis-pivottableaggregatedfieldwells-columns
         */
        readonly columns?: Array<CfnAnalysis.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The rows field well for a pivot table.
         *
         * Values are grouped by rows fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableaggregatedfieldwells.html#cfn-quicksight-analysis-pivottableaggregatedfieldwells-rows
         */
        readonly rows?: Array<CfnAnalysis.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The values field well for a pivot table.
         *
         * Values are aggregated based on rows and columns fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableaggregatedfieldwells.html#cfn-quicksight-analysis-pivottableaggregatedfieldwells-values
         */
        readonly values?: Array<cdk.IResolvable | CfnAnalysis.MeasureFieldProperty> | cdk.IResolvable;
    }
    /**
     * The field options for a pivot table visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablefieldoptions.html
     */
    interface PivotTableFieldOptionsProperty {
        /**
         * The collapse state options for the pivot table field options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablefieldoptions.html#cfn-quicksight-analysis-pivottablefieldoptions-collapsestateoptions
         */
        readonly collapseStateOptions?: Array<cdk.IResolvable | CfnAnalysis.PivotTableFieldCollapseStateOptionProperty> | cdk.IResolvable;
        /**
         * The data path options for the pivot table field options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablefieldoptions.html#cfn-quicksight-analysis-pivottablefieldoptions-datapathoptions
         */
        readonly dataPathOptions?: Array<cdk.IResolvable | CfnAnalysis.PivotTableDataPathOptionProperty> | cdk.IResolvable;
        /**
         * The selected field options for the pivot table field options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablefieldoptions.html#cfn-quicksight-analysis-pivottablefieldoptions-selectedfieldoptions
         */
        readonly selectedFieldOptions?: Array<cdk.IResolvable | CfnAnalysis.PivotTableFieldOptionProperty> | cdk.IResolvable;
    }
    /**
     * The collapse state options for the pivot table field options.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablefieldcollapsestateoption.html
     */
    interface PivotTableFieldCollapseStateOptionProperty {
        /**
         * The state of the field target of a pivot table. Choose one of the following options:.
         *
         * - `COLLAPSED`
         * - `EXPANDED`
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablefieldcollapsestateoption.html#cfn-quicksight-analysis-pivottablefieldcollapsestateoption-state
         */
        readonly state?: string;
        /**
         * A tagged-union object that sets the collapse state.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablefieldcollapsestateoption.html#cfn-quicksight-analysis-pivottablefieldcollapsestateoption-target
         */
        readonly target: cdk.IResolvable | CfnAnalysis.PivotTableFieldCollapseStateTargetProperty;
    }
    /**
     * The target of a pivot table field collapse state.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablefieldcollapsestatetarget.html
     */
    interface PivotTableFieldCollapseStateTargetProperty {
        /**
         * The data path of the pivot table's header.
         *
         * Used to set the collapse state.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablefieldcollapsestatetarget.html#cfn-quicksight-analysis-pivottablefieldcollapsestatetarget-fielddatapathvalues
         */
        readonly fieldDataPathValues?: Array<CfnAnalysis.DataPathValueProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The field ID of the pivot table that the collapse state needs to be set to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablefieldcollapsestatetarget.html#cfn-quicksight-analysis-pivottablefieldcollapsestatetarget-fieldid
         */
        readonly fieldId?: string;
    }
    /**
     * The data path options for the pivot table field options.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottabledatapathoption.html
     */
    interface PivotTableDataPathOptionProperty {
        /**
         * The list of data path values for the data path options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottabledatapathoption.html#cfn-quicksight-analysis-pivottabledatapathoption-datapathlist
         */
        readonly dataPathList: Array<CfnAnalysis.DataPathValueProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The width of the data path option.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottabledatapathoption.html#cfn-quicksight-analysis-pivottabledatapathoption-width
         */
        readonly width?: string;
    }
    /**
     * The selected field options for the pivot table field options.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablefieldoption.html
     */
    interface PivotTableFieldOptionProperty {
        /**
         * The custom label of the pivot table field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablefieldoption.html#cfn-quicksight-analysis-pivottablefieldoption-customlabel
         */
        readonly customLabel?: string;
        /**
         * The field ID of the pivot table field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablefieldoption.html#cfn-quicksight-analysis-pivottablefieldoption-fieldid
         */
        readonly fieldId: string;
        /**
         * The visibility of the pivot table field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablefieldoption.html#cfn-quicksight-analysis-pivottablefieldoption-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The total options for a pivot table visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottabletotaloptions.html
     */
    interface PivotTableTotalOptionsProperty {
        /**
         * The column subtotal options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottabletotaloptions.html#cfn-quicksight-analysis-pivottabletotaloptions-columnsubtotaloptions
         */
        readonly columnSubtotalOptions?: cdk.IResolvable | CfnAnalysis.SubtotalOptionsProperty;
        /**
         * The column total options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottabletotaloptions.html#cfn-quicksight-analysis-pivottabletotaloptions-columntotaloptions
         */
        readonly columnTotalOptions?: cdk.IResolvable | CfnAnalysis.PivotTotalOptionsProperty;
        /**
         * The row subtotal options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottabletotaloptions.html#cfn-quicksight-analysis-pivottabletotaloptions-rowsubtotaloptions
         */
        readonly rowSubtotalOptions?: cdk.IResolvable | CfnAnalysis.SubtotalOptionsProperty;
        /**
         * The row total options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottabletotaloptions.html#cfn-quicksight-analysis-pivottabletotaloptions-rowtotaloptions
         */
        readonly rowTotalOptions?: cdk.IResolvable | CfnAnalysis.PivotTotalOptionsProperty;
    }
    /**
     * The subtotal options.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-subtotaloptions.html
     */
    interface SubtotalOptionsProperty {
        /**
         * The custom label string for the subtotal cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-subtotaloptions.html#cfn-quicksight-analysis-subtotaloptions-customlabel
         */
        readonly customLabel?: string;
        /**
         * The field level (all, custom, last) for the subtotal cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-subtotaloptions.html#cfn-quicksight-analysis-subtotaloptions-fieldlevel
         */
        readonly fieldLevel?: string;
        /**
         * The optional configuration of subtotal cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-subtotaloptions.html#cfn-quicksight-analysis-subtotaloptions-fieldleveloptions
         */
        readonly fieldLevelOptions?: Array<cdk.IResolvable | CfnAnalysis.PivotTableFieldSubtotalOptionsProperty> | cdk.IResolvable;
        /**
         * The cell styling options for the subtotals of header cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-subtotaloptions.html#cfn-quicksight-analysis-subtotaloptions-metricheadercellstyle
         */
        readonly metricHeaderCellStyle?: cdk.IResolvable | CfnAnalysis.TableCellStyleProperty;
        /**
         * The style targets options for subtotals.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-subtotaloptions.html#cfn-quicksight-analysis-subtotaloptions-styletargets
         */
        readonly styleTargets?: Array<cdk.IResolvable | CfnAnalysis.TableStyleTargetProperty> | cdk.IResolvable;
        /**
         * The cell styling options for the subtotal cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-subtotaloptions.html#cfn-quicksight-analysis-subtotaloptions-totalcellstyle
         */
        readonly totalCellStyle?: cdk.IResolvable | CfnAnalysis.TableCellStyleProperty;
        /**
         * The visibility configuration for the subtotal cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-subtotaloptions.html#cfn-quicksight-analysis-subtotaloptions-totalsvisibility
         */
        readonly totalsVisibility?: string;
        /**
         * The cell styling options for the subtotals of value cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-subtotaloptions.html#cfn-quicksight-analysis-subtotaloptions-valuecellstyle
         */
        readonly valueCellStyle?: cdk.IResolvable | CfnAnalysis.TableCellStyleProperty;
    }
    /**
     * The optional configuration of subtotals cells.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablefieldsubtotaloptions.html
     */
    interface PivotTableFieldSubtotalOptionsProperty {
        /**
         * The field ID of the subtotal options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablefieldsubtotaloptions.html#cfn-quicksight-analysis-pivottablefieldsubtotaloptions-fieldid
         */
        readonly fieldId?: string;
    }
    /**
     * The table style target.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablestyletarget.html
     */
    interface TableStyleTargetProperty {
        /**
         * The cell type of the table style target.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablestyletarget.html#cfn-quicksight-analysis-tablestyletarget-celltype
         */
        readonly cellType: string;
    }
    /**
     * The optional configuration of totals cells in a `PivotTableVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottotaloptions.html
     */
    interface PivotTotalOptionsProperty {
        /**
         * The custom label string for the total cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottotaloptions.html#cfn-quicksight-analysis-pivottotaloptions-customlabel
         */
        readonly customLabel?: string;
        /**
         * The cell styling options for the total of header cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottotaloptions.html#cfn-quicksight-analysis-pivottotaloptions-metricheadercellstyle
         */
        readonly metricHeaderCellStyle?: cdk.IResolvable | CfnAnalysis.TableCellStyleProperty;
        /**
         * The placement (start, end) for the total cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottotaloptions.html#cfn-quicksight-analysis-pivottotaloptions-placement
         */
        readonly placement?: string;
        /**
         * The scroll status (pinned, scrolled) for the total cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottotaloptions.html#cfn-quicksight-analysis-pivottotaloptions-scrollstatus
         */
        readonly scrollStatus?: string;
        /**
         * The total aggregation options for each value field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottotaloptions.html#cfn-quicksight-analysis-pivottotaloptions-totalaggregationoptions
         */
        readonly totalAggregationOptions?: Array<cdk.IResolvable | CfnAnalysis.TotalAggregationOptionProperty> | cdk.IResolvable;
        /**
         * The cell styling options for the total cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottotaloptions.html#cfn-quicksight-analysis-pivottotaloptions-totalcellstyle
         */
        readonly totalCellStyle?: cdk.IResolvable | CfnAnalysis.TableCellStyleProperty;
        /**
         * The visibility configuration for the total cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottotaloptions.html#cfn-quicksight-analysis-pivottotaloptions-totalsvisibility
         */
        readonly totalsVisibility?: string;
        /**
         * The cell styling options for the totals of value cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottotaloptions.html#cfn-quicksight-analysis-pivottotaloptions-valuecellstyle
         */
        readonly valueCellStyle?: cdk.IResolvable | CfnAnalysis.TableCellStyleProperty;
    }
    /**
     * A geospatial map or a points on map visual.
     *
     * For more information, see [Creating point maps](https://docs.aws.amazon.com/quicksight/latest/user/point-maps.html) in the *Amazon QuickSight User Guide* .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapvisual.html
     */
    interface GeospatialMapVisualProperty {
        /**
         * The list of custom actions that are configured for a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapvisual.html#cfn-quicksight-analysis-geospatialmapvisual-actions
         */
        readonly actions?: Array<cdk.IResolvable | CfnAnalysis.VisualCustomActionProperty> | cdk.IResolvable;
        /**
         * The configuration settings of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapvisual.html#cfn-quicksight-analysis-geospatialmapvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnAnalysis.GeospatialMapConfigurationProperty | cdk.IResolvable;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapvisual.html#cfn-quicksight-analysis-geospatialmapvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnAnalysis.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The subtitle that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapvisual.html#cfn-quicksight-analysis-geospatialmapvisual-subtitle
         */
        readonly subtitle?: cdk.IResolvable | CfnAnalysis.VisualSubtitleLabelOptionsProperty;
        /**
         * The title that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapvisual.html#cfn-quicksight-analysis-geospatialmapvisual-title
         */
        readonly title?: cdk.IResolvable | CfnAnalysis.VisualTitleLabelOptionsProperty;
        /**
         * The unique identifier of a visual.
         *
         * This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapvisual.html#cfn-quicksight-analysis-geospatialmapvisual-visualid
         */
        readonly visualId: string;
    }
    /**
     * The configuration of a `GeospatialMapVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapconfiguration.html
     */
    interface GeospatialMapConfigurationProperty {
        /**
         * The field wells of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapconfiguration.html#cfn-quicksight-analysis-geospatialmapconfiguration-fieldwells
         */
        readonly fieldWells?: CfnAnalysis.GeospatialMapFieldWellsProperty | cdk.IResolvable;
        /**
         * The legend display setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapconfiguration.html#cfn-quicksight-analysis-geospatialmapconfiguration-legend
         */
        readonly legend?: cdk.IResolvable | CfnAnalysis.LegendOptionsProperty;
        /**
         * The map style options of the geospatial map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapconfiguration.html#cfn-quicksight-analysis-geospatialmapconfiguration-mapstyleoptions
         */
        readonly mapStyleOptions?: CfnAnalysis.GeospatialMapStyleOptionsProperty | cdk.IResolvable;
        /**
         * The point style options of the geospatial map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapconfiguration.html#cfn-quicksight-analysis-geospatialmapconfiguration-pointstyleoptions
         */
        readonly pointStyleOptions?: CfnAnalysis.GeospatialPointStyleOptionsProperty | cdk.IResolvable;
        /**
         * The tooltip display setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapconfiguration.html#cfn-quicksight-analysis-geospatialmapconfiguration-tooltip
         */
        readonly tooltip?: cdk.IResolvable | CfnAnalysis.TooltipOptionsProperty;
        /**
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapconfiguration.html#cfn-quicksight-analysis-geospatialmapconfiguration-visualpalette
         */
        readonly visualPalette?: cdk.IResolvable | CfnAnalysis.VisualPaletteProperty;
        /**
         * The window options of the geospatial map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapconfiguration.html#cfn-quicksight-analysis-geospatialmapconfiguration-windowoptions
         */
        readonly windowOptions?: CfnAnalysis.GeospatialWindowOptionsProperty | cdk.IResolvable;
    }
    /**
     * The field wells of a `GeospatialMapVisual` .
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapfieldwells.html
     */
    interface GeospatialMapFieldWellsProperty {
        /**
         * The aggregated field well for a geospatial map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapfieldwells.html#cfn-quicksight-analysis-geospatialmapfieldwells-geospatialmapaggregatedfieldwells
         */
        readonly geospatialMapAggregatedFieldWells?: CfnAnalysis.GeospatialMapAggregatedFieldWellsProperty | cdk.IResolvable;
    }
    /**
     * The aggregated field wells for a geospatial map.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapaggregatedfieldwells.html
     */
    interface GeospatialMapAggregatedFieldWellsProperty {
        /**
         * The color field wells of a geospatial map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapaggregatedfieldwells.html#cfn-quicksight-analysis-geospatialmapaggregatedfieldwells-colors
         */
        readonly colors?: Array<CfnAnalysis.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The geospatial field wells of a geospatial map.
         *
         * Values are grouped by geospatial fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapaggregatedfieldwells.html#cfn-quicksight-analysis-geospatialmapaggregatedfieldwells-geospatial
         */
        readonly geospatial?: Array<CfnAnalysis.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The size field wells of a geospatial map.
         *
         * Values are aggregated based on geospatial fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapaggregatedfieldwells.html#cfn-quicksight-analysis-geospatialmapaggregatedfieldwells-values
         */
        readonly values?: Array<cdk.IResolvable | CfnAnalysis.MeasureFieldProperty> | cdk.IResolvable;
    }
    /**
     * The point style of the geospatial map.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialpointstyleoptions.html
     */
    interface GeospatialPointStyleOptionsProperty {
        /**
         * The cluster marker configuration of the geospatial point style.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialpointstyleoptions.html#cfn-quicksight-analysis-geospatialpointstyleoptions-clustermarkerconfiguration
         */
        readonly clusterMarkerConfiguration?: CfnAnalysis.ClusterMarkerConfigurationProperty | cdk.IResolvable;
        /**
         * The heatmap configuration of the geospatial point style.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialpointstyleoptions.html#cfn-quicksight-analysis-geospatialpointstyleoptions-heatmapconfiguration
         */
        readonly heatmapConfiguration?: CfnAnalysis.GeospatialHeatmapConfigurationProperty | cdk.IResolvable;
        /**
         * The selected point styles (point, cluster) of the geospatial map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialpointstyleoptions.html#cfn-quicksight-analysis-geospatialpointstyleoptions-selectedpointstyle
         */
        readonly selectedPointStyle?: string;
    }
    /**
     * The cluster marker configuration of the geospatial map selected point style.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-clustermarkerconfiguration.html
     */
    interface ClusterMarkerConfigurationProperty {
        /**
         * The cluster marker that is a part of the cluster marker configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-clustermarkerconfiguration.html#cfn-quicksight-analysis-clustermarkerconfiguration-clustermarker
         */
        readonly clusterMarker?: CfnAnalysis.ClusterMarkerProperty | cdk.IResolvable;
    }
    /**
     * The cluster marker that is a part of the cluster marker configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-clustermarker.html
     */
    interface ClusterMarkerProperty {
        /**
         * The simple cluster marker of the cluster marker.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-clustermarker.html#cfn-quicksight-analysis-clustermarker-simpleclustermarker
         */
        readonly simpleClusterMarker?: cdk.IResolvable | CfnAnalysis.SimpleClusterMarkerProperty;
    }
    /**
     * The simple cluster marker of the cluster marker.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-simpleclustermarker.html
     */
    interface SimpleClusterMarkerProperty {
        /**
         * The color of the simple cluster marker.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-simpleclustermarker.html#cfn-quicksight-analysis-simpleclustermarker-color
         */
        readonly color?: string;
    }
    /**
     * The heatmap configuration of the geospatial point style.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialheatmapconfiguration.html
     */
    interface GeospatialHeatmapConfigurationProperty {
        /**
         * The color scale specification for the heatmap point style.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialheatmapconfiguration.html#cfn-quicksight-analysis-geospatialheatmapconfiguration-heatmapcolor
         */
        readonly heatmapColor?: CfnAnalysis.GeospatialHeatmapColorScaleProperty | cdk.IResolvable;
    }
    /**
     * The color scale specification for the heatmap point style.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialheatmapcolorscale.html
     */
    interface GeospatialHeatmapColorScaleProperty {
        /**
         * The list of colors to be used in heatmap point style.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialheatmapcolorscale.html#cfn-quicksight-analysis-geospatialheatmapcolorscale-colors
         */
        readonly colors?: Array<CfnAnalysis.GeospatialHeatmapDataColorProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * The color to be used in the heatmap point style.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialheatmapdatacolor.html
     */
    interface GeospatialHeatmapDataColorProperty {
        /**
         * The hex color to be used in the heatmap point style.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialheatmapdatacolor.html#cfn-quicksight-analysis-geospatialheatmapdatacolor-color
         */
        readonly color: string;
    }
    /**
     * A bar chart.
     *
     * The `BarChartVisual` structure describes a visual that is a member of the bar chart family. The following charts can be described using this structure:
     *
     * - Horizontal bar chart
     * - Vertical bar chart
     * - Horizontal stacked bar chart
     * - Vertical stacked bar chart
     * - Horizontal stacked 100% bar chart
     * - Vertical stacked 100% bar chart
     *
     * For more information, see [Using bar charts](https://docs.aws.amazon.com/quicksight/latest/user/bar-charts.html) in the *Amazon QuickSight User Guide* .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartvisual.html
     */
    interface BarChartVisualProperty {
        /**
         * The list of custom actions that are configured for a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartvisual.html#cfn-quicksight-analysis-barchartvisual-actions
         */
        readonly actions?: Array<cdk.IResolvable | CfnAnalysis.VisualCustomActionProperty> | cdk.IResolvable;
        /**
         * The configuration settings of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartvisual.html#cfn-quicksight-analysis-barchartvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnAnalysis.BarChartConfigurationProperty | cdk.IResolvable;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartvisual.html#cfn-quicksight-analysis-barchartvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnAnalysis.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The subtitle that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartvisual.html#cfn-quicksight-analysis-barchartvisual-subtitle
         */
        readonly subtitle?: cdk.IResolvable | CfnAnalysis.VisualSubtitleLabelOptionsProperty;
        /**
         * The title that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartvisual.html#cfn-quicksight-analysis-barchartvisual-title
         */
        readonly title?: cdk.IResolvable | CfnAnalysis.VisualTitleLabelOptionsProperty;
        /**
         * The unique identifier of a visual.
         *
         * This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartvisual.html#cfn-quicksight-analysis-barchartvisual-visualid
         */
        readonly visualId: string;
    }
    /**
     * The configuration of a `BarChartVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html
     */
    interface BarChartConfigurationProperty {
        /**
         * Determines the arrangement of the bars.
         *
         * The orientation and arrangement of bars determine the type of bar that is used in the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-barsarrangement
         */
        readonly barsArrangement?: string;
        /**
         * The label display options (grid line, range, scale, axis step) for bar chart category.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-categoryaxis
         */
        readonly categoryAxis?: CfnAnalysis.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * The label options (label text, label visibility and sort icon visibility) for a bar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-categorylabeloptions
         */
        readonly categoryLabelOptions?: CfnAnalysis.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The label options (label text, label visibility and sort icon visibility) for a color that is used in a bar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-colorlabeloptions
         */
        readonly colorLabelOptions?: CfnAnalysis.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The contribution analysis (anomaly configuration) setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-contributionanalysisdefaults
         */
        readonly contributionAnalysisDefaults?: Array<CfnAnalysis.ContributionAnalysisDefaultProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The options that determine if visual data labels are displayed.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-datalabels
         */
        readonly dataLabels?: CfnAnalysis.DataLabelOptionsProperty | cdk.IResolvable;
        /**
         * The field wells of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-fieldwells
         */
        readonly fieldWells?: CfnAnalysis.BarChartFieldWellsProperty | cdk.IResolvable;
        /**
         * The legend display setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-legend
         */
        readonly legend?: cdk.IResolvable | CfnAnalysis.LegendOptionsProperty;
        /**
         * The orientation of the bars in a bar chart visual. There are two valid values in this structure:.
         *
         * - `HORIZONTAL` : Used for charts that have horizontal bars. Visuals that use this value are horizontal bar charts, horizontal stacked bar charts, and horizontal stacked 100% bar charts.
         * - `VERTICAL` : Used for charts that have vertical bars. Visuals that use this value are vertical bar charts, vertical stacked bar charts, and vertical stacked 100% bar charts.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-orientation
         */
        readonly orientation?: string;
        /**
         * The reference line setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-referencelines
         */
        readonly referenceLines?: Array<cdk.IResolvable | CfnAnalysis.ReferenceLineProperty> | cdk.IResolvable;
        /**
         * The small multiples setup for the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-smallmultiplesoptions
         */
        readonly smallMultiplesOptions?: cdk.IResolvable | CfnAnalysis.SmallMultiplesOptionsProperty;
        /**
         * The sort configuration of a `BarChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: CfnAnalysis.BarChartSortConfigurationProperty | cdk.IResolvable;
        /**
         * The tooltip display setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-tooltip
         */
        readonly tooltip?: cdk.IResolvable | CfnAnalysis.TooltipOptionsProperty;
        /**
         * The label display options (grid line, range, scale, axis step) for a bar chart value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-valueaxis
         */
        readonly valueAxis?: CfnAnalysis.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * The label options (label text, label visibility and sort icon visibility) for a bar chart value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-valuelabeloptions
         */
        readonly valueLabelOptions?: CfnAnalysis.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The palette (chart color) display setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-visualpalette
         */
        readonly visualPalette?: cdk.IResolvable | CfnAnalysis.VisualPaletteProperty;
    }
    /**
     * sort-configuration-description.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartsortconfiguration.html
     */
    interface BarChartSortConfigurationProperty {
        /**
         * The limit on the number of categories displayed in a bar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartsortconfiguration.html#cfn-quicksight-analysis-barchartsortconfiguration-categoryitemslimit
         */
        readonly categoryItemsLimit?: cdk.IResolvable | CfnAnalysis.ItemsLimitConfigurationProperty;
        /**
         * The sort configuration of category fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartsortconfiguration.html#cfn-quicksight-analysis-barchartsortconfiguration-categorysort
         */
        readonly categorySort?: Array<CfnAnalysis.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The limit on the number of values displayed in a bar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartsortconfiguration.html#cfn-quicksight-analysis-barchartsortconfiguration-coloritemslimit
         */
        readonly colorItemsLimit?: cdk.IResolvable | CfnAnalysis.ItemsLimitConfigurationProperty;
        /**
         * The sort configuration of color fields in a bar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartsortconfiguration.html#cfn-quicksight-analysis-barchartsortconfiguration-colorsort
         */
        readonly colorSort?: Array<CfnAnalysis.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The limit on the number of small multiples panels that are displayed.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartsortconfiguration.html#cfn-quicksight-analysis-barchartsortconfiguration-smallmultipleslimitconfiguration
         */
        readonly smallMultiplesLimitConfiguration?: cdk.IResolvable | CfnAnalysis.ItemsLimitConfigurationProperty;
        /**
         * The sort configuration of the small multiples field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartsortconfiguration.html#cfn-quicksight-analysis-barchartsortconfiguration-smallmultiplessort
         */
        readonly smallMultiplesSort?: Array<CfnAnalysis.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * The field wells of a `BarChartVisual` .
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartfieldwells.html
     */
    interface BarChartFieldWellsProperty {
        /**
         * The aggregated field wells of a bar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartfieldwells.html#cfn-quicksight-analysis-barchartfieldwells-barchartaggregatedfieldwells
         */
        readonly barChartAggregatedFieldWells?: CfnAnalysis.BarChartAggregatedFieldWellsProperty | cdk.IResolvable;
    }
    /**
     * The aggregated field wells of a bar chart.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartaggregatedfieldwells.html
     */
    interface BarChartAggregatedFieldWellsProperty {
        /**
         * The category (y-axis) field well of a bar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartaggregatedfieldwells.html#cfn-quicksight-analysis-barchartaggregatedfieldwells-category
         */
        readonly category?: Array<CfnAnalysis.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The color (group/color) field well of a bar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartaggregatedfieldwells.html#cfn-quicksight-analysis-barchartaggregatedfieldwells-colors
         */
        readonly colors?: Array<CfnAnalysis.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The small multiples field well of a bar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartaggregatedfieldwells.html#cfn-quicksight-analysis-barchartaggregatedfieldwells-smallmultiples
         */
        readonly smallMultiples?: Array<CfnAnalysis.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The value field wells of a bar chart.
         *
         * Values are aggregated by category.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartaggregatedfieldwells.html#cfn-quicksight-analysis-barchartaggregatedfieldwells-values
         */
        readonly values?: Array<cdk.IResolvable | CfnAnalysis.MeasureFieldProperty> | cdk.IResolvable;
    }
    /**
     * A scatter plot.
     *
     * For more information, see [Using scatter plots](https://docs.aws.amazon.com/quicksight/latest/user/scatter-plot.html) in the *Amazon QuickSight User Guide* .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotvisual.html
     */
    interface ScatterPlotVisualProperty {
        /**
         * The list of custom actions that are configured for a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotvisual.html#cfn-quicksight-analysis-scatterplotvisual-actions
         */
        readonly actions?: Array<cdk.IResolvable | CfnAnalysis.VisualCustomActionProperty> | cdk.IResolvable;
        /**
         * The configuration settings of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotvisual.html#cfn-quicksight-analysis-scatterplotvisual-chartconfiguration
         */
        readonly chartConfiguration?: cdk.IResolvable | CfnAnalysis.ScatterPlotConfigurationProperty;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotvisual.html#cfn-quicksight-analysis-scatterplotvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnAnalysis.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The subtitle that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotvisual.html#cfn-quicksight-analysis-scatterplotvisual-subtitle
         */
        readonly subtitle?: cdk.IResolvable | CfnAnalysis.VisualSubtitleLabelOptionsProperty;
        /**
         * The title that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotvisual.html#cfn-quicksight-analysis-scatterplotvisual-title
         */
        readonly title?: cdk.IResolvable | CfnAnalysis.VisualTitleLabelOptionsProperty;
        /**
         * The unique identifier of a visual.
         *
         * This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotvisual.html#cfn-quicksight-analysis-scatterplotvisual-visualid
         */
        readonly visualId: string;
    }
    /**
     * The configuration of a scatter plot.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotconfiguration.html
     */
    interface ScatterPlotConfigurationProperty {
        /**
         * The options that determine if visual data labels are displayed.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotconfiguration.html#cfn-quicksight-analysis-scatterplotconfiguration-datalabels
         */
        readonly dataLabels?: CfnAnalysis.DataLabelOptionsProperty | cdk.IResolvable;
        /**
         * The field wells of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotconfiguration.html#cfn-quicksight-analysis-scatterplotconfiguration-fieldwells
         */
        readonly fieldWells?: cdk.IResolvable | CfnAnalysis.ScatterPlotFieldWellsProperty;
        /**
         * The legend display setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotconfiguration.html#cfn-quicksight-analysis-scatterplotconfiguration-legend
         */
        readonly legend?: cdk.IResolvable | CfnAnalysis.LegendOptionsProperty;
        /**
         * The legend display setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotconfiguration.html#cfn-quicksight-analysis-scatterplotconfiguration-tooltip
         */
        readonly tooltip?: cdk.IResolvable | CfnAnalysis.TooltipOptionsProperty;
        /**
         * The palette (chart color) display setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotconfiguration.html#cfn-quicksight-analysis-scatterplotconfiguration-visualpalette
         */
        readonly visualPalette?: cdk.IResolvable | CfnAnalysis.VisualPaletteProperty;
        /**
         * The label display options (grid line, range, scale, and axis step) of the scatter plot's x-axis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotconfiguration.html#cfn-quicksight-analysis-scatterplotconfiguration-xaxisdisplayoptions
         */
        readonly xAxisDisplayOptions?: CfnAnalysis.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * The label options (label text, label visibility, and sort icon visibility) of the scatter plot's x-axis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotconfiguration.html#cfn-quicksight-analysis-scatterplotconfiguration-xaxislabeloptions
         */
        readonly xAxisLabelOptions?: CfnAnalysis.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The label display options (grid line, range, scale, and axis step) of the scatter plot's y-axis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotconfiguration.html#cfn-quicksight-analysis-scatterplotconfiguration-yaxisdisplayoptions
         */
        readonly yAxisDisplayOptions?: CfnAnalysis.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * The label options (label text, label visibility, and sort icon visibility) of the scatter plot's y-axis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotconfiguration.html#cfn-quicksight-analysis-scatterplotconfiguration-yaxislabeloptions
         */
        readonly yAxisLabelOptions?: CfnAnalysis.ChartAxisLabelOptionsProperty | cdk.IResolvable;
    }
    /**
     * The field well configuration of a scatter plot.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotfieldwells.html
     */
    interface ScatterPlotFieldWellsProperty {
        /**
         * The aggregated field wells of a scatter plot.
         *
         * The x and y-axes of scatter plots with aggregated field wells are aggregated by category, label, or both.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotfieldwells.html#cfn-quicksight-analysis-scatterplotfieldwells-scatterplotcategoricallyaggregatedfieldwells
         */
        readonly scatterPlotCategoricallyAggregatedFieldWells?: cdk.IResolvable | CfnAnalysis.ScatterPlotCategoricallyAggregatedFieldWellsProperty;
        /**
         * The unaggregated field wells of a scatter plot.
         *
         * The x and y-axes of these scatter plots are unaggregated.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotfieldwells.html#cfn-quicksight-analysis-scatterplotfieldwells-scatterplotunaggregatedfieldwells
         */
        readonly scatterPlotUnaggregatedFieldWells?: cdk.IResolvable | CfnAnalysis.ScatterPlotUnaggregatedFieldWellsProperty;
    }
    /**
     * The unaggregated field wells of a scatter plot.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotunaggregatedfieldwells.html
     */
    interface ScatterPlotUnaggregatedFieldWellsProperty {
        /**
         * The category field well of a scatter plot.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotunaggregatedfieldwells.html#cfn-quicksight-analysis-scatterplotunaggregatedfieldwells-category
         */
        readonly category?: Array<CfnAnalysis.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The label field well of a scatter plot.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotunaggregatedfieldwells.html#cfn-quicksight-analysis-scatterplotunaggregatedfieldwells-label
         */
        readonly label?: Array<CfnAnalysis.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The size field well of a scatter plot.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotunaggregatedfieldwells.html#cfn-quicksight-analysis-scatterplotunaggregatedfieldwells-size
         */
        readonly size?: Array<cdk.IResolvable | CfnAnalysis.MeasureFieldProperty> | cdk.IResolvable;
        /**
         * The x-axis field well of a scatter plot.
         *
         * The x-axis is a dimension field and cannot be aggregated.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotunaggregatedfieldwells.html#cfn-quicksight-analysis-scatterplotunaggregatedfieldwells-xaxis
         */
        readonly xAxis?: Array<CfnAnalysis.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The y-axis field well of a scatter plot.
         *
         * The y-axis is a dimension field and cannot be aggregated.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotunaggregatedfieldwells.html#cfn-quicksight-analysis-scatterplotunaggregatedfieldwells-yaxis
         */
        readonly yAxis?: Array<CfnAnalysis.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * The aggregated field well of a scatter plot.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotcategoricallyaggregatedfieldwells.html
     */
    interface ScatterPlotCategoricallyAggregatedFieldWellsProperty {
        /**
         * The category field well of a scatter plot.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotcategoricallyaggregatedfieldwells.html#cfn-quicksight-analysis-scatterplotcategoricallyaggregatedfieldwells-category
         */
        readonly category?: Array<CfnAnalysis.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The label field well of a scatter plot.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotcategoricallyaggregatedfieldwells.html#cfn-quicksight-analysis-scatterplotcategoricallyaggregatedfieldwells-label
         */
        readonly label?: Array<CfnAnalysis.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The size field well of a scatter plot.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotcategoricallyaggregatedfieldwells.html#cfn-quicksight-analysis-scatterplotcategoricallyaggregatedfieldwells-size
         */
        readonly size?: Array<cdk.IResolvable | CfnAnalysis.MeasureFieldProperty> | cdk.IResolvable;
        /**
         * The x-axis field well of a scatter plot.
         *
         * The x-axis is aggregated by category.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotcategoricallyaggregatedfieldwells.html#cfn-quicksight-analysis-scatterplotcategoricallyaggregatedfieldwells-xaxis
         */
        readonly xAxis?: Array<cdk.IResolvable | CfnAnalysis.MeasureFieldProperty> | cdk.IResolvable;
        /**
         * The y-axis field well of a scatter plot.
         *
         * The y-axis is aggregated by category.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotcategoricallyaggregatedfieldwells.html#cfn-quicksight-analysis-scatterplotcategoricallyaggregatedfieldwells-yaxis
         */
        readonly yAxis?: Array<cdk.IResolvable | CfnAnalysis.MeasureFieldProperty> | cdk.IResolvable;
    }
    /**
     * A radar chart visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartvisual.html
     */
    interface RadarChartVisualProperty {
        /**
         * The list of custom actions that are configured for a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartvisual.html#cfn-quicksight-analysis-radarchartvisual-actions
         */
        readonly actions?: Array<cdk.IResolvable | CfnAnalysis.VisualCustomActionProperty> | cdk.IResolvable;
        /**
         * The configuration settings of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartvisual.html#cfn-quicksight-analysis-radarchartvisual-chartconfiguration
         */
        readonly chartConfiguration?: cdk.IResolvable | CfnAnalysis.RadarChartConfigurationProperty;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartvisual.html#cfn-quicksight-analysis-radarchartvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnAnalysis.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The subtitle that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartvisual.html#cfn-quicksight-analysis-radarchartvisual-subtitle
         */
        readonly subtitle?: cdk.IResolvable | CfnAnalysis.VisualSubtitleLabelOptionsProperty;
        /**
         * The title that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartvisual.html#cfn-quicksight-analysis-radarchartvisual-title
         */
        readonly title?: cdk.IResolvable | CfnAnalysis.VisualTitleLabelOptionsProperty;
        /**
         * The unique identifier of a visual.
         *
         * This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartvisual.html#cfn-quicksight-analysis-radarchartvisual-visualid
         */
        readonly visualId: string;
    }
    /**
     * The configuration of a `RadarChartVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html
     */
    interface RadarChartConfigurationProperty {
        /**
         * Determines the visibility of the colors of alternatign bands in a radar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html#cfn-quicksight-analysis-radarchartconfiguration-alternatebandcolorsvisibility
         */
        readonly alternateBandColorsVisibility?: string;
        /**
         * The color of the even-numbered alternate bands of a radar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html#cfn-quicksight-analysis-radarchartconfiguration-alternatebandevencolor
         */
        readonly alternateBandEvenColor?: string;
        /**
         * The color of the odd-numbered alternate bands of a radar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html#cfn-quicksight-analysis-radarchartconfiguration-alternatebandoddcolor
         */
        readonly alternateBandOddColor?: string;
        /**
         * The axis behavior options of a radar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html#cfn-quicksight-analysis-radarchartconfiguration-axesrangescale
         */
        readonly axesRangeScale?: string;
        /**
         * The base sreies settings of a radar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html#cfn-quicksight-analysis-radarchartconfiguration-baseseriessettings
         */
        readonly baseSeriesSettings?: cdk.IResolvable | CfnAnalysis.RadarChartSeriesSettingsProperty;
        /**
         * The category axis of a radar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html#cfn-quicksight-analysis-radarchartconfiguration-categoryaxis
         */
        readonly categoryAxis?: CfnAnalysis.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * The category label options of a radar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html#cfn-quicksight-analysis-radarchartconfiguration-categorylabeloptions
         */
        readonly categoryLabelOptions?: CfnAnalysis.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The color axis of a radar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html#cfn-quicksight-analysis-radarchartconfiguration-coloraxis
         */
        readonly colorAxis?: CfnAnalysis.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * The color label options of a radar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html#cfn-quicksight-analysis-radarchartconfiguration-colorlabeloptions
         */
        readonly colorLabelOptions?: CfnAnalysis.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The field well configuration of a `RadarChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html#cfn-quicksight-analysis-radarchartconfiguration-fieldwells
         */
        readonly fieldWells?: cdk.IResolvable | CfnAnalysis.RadarChartFieldWellsProperty;
        /**
         * The legend display setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html#cfn-quicksight-analysis-radarchartconfiguration-legend
         */
        readonly legend?: cdk.IResolvable | CfnAnalysis.LegendOptionsProperty;
        /**
         * The shape of the radar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html#cfn-quicksight-analysis-radarchartconfiguration-shape
         */
        readonly shape?: string;
        /**
         * The sort configuration of a `RadarChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html#cfn-quicksight-analysis-radarchartconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: cdk.IResolvable | CfnAnalysis.RadarChartSortConfigurationProperty;
        /**
         * The start angle of a radar chart's axis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html#cfn-quicksight-analysis-radarchartconfiguration-startangle
         */
        readonly startAngle?: number;
        /**
         * The palette (chart color) display setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html#cfn-quicksight-analysis-radarchartconfiguration-visualpalette
         */
        readonly visualPalette?: cdk.IResolvable | CfnAnalysis.VisualPaletteProperty;
    }
    /**
     * The sort configuration of a `RadarChartVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartsortconfiguration.html
     */
    interface RadarChartSortConfigurationProperty {
        /**
         * The category items limit for a radar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartsortconfiguration.html#cfn-quicksight-analysis-radarchartsortconfiguration-categoryitemslimit
         */
        readonly categoryItemsLimit?: cdk.IResolvable | CfnAnalysis.ItemsLimitConfigurationProperty;
        /**
         * The category sort options of a radar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartsortconfiguration.html#cfn-quicksight-analysis-radarchartsortconfiguration-categorysort
         */
        readonly categorySort?: Array<CfnAnalysis.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The color items limit of a radar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartsortconfiguration.html#cfn-quicksight-analysis-radarchartsortconfiguration-coloritemslimit
         */
        readonly colorItemsLimit?: cdk.IResolvable | CfnAnalysis.ItemsLimitConfigurationProperty;
        /**
         * The color sort configuration of a radar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartsortconfiguration.html#cfn-quicksight-analysis-radarchartsortconfiguration-colorsort
         */
        readonly colorSort?: Array<CfnAnalysis.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * The series settings of a radar chart.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartseriessettings.html
     */
    interface RadarChartSeriesSettingsProperty {
        /**
         * The area style settings of a radar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartseriessettings.html#cfn-quicksight-analysis-radarchartseriessettings-areastylesettings
         */
        readonly areaStyleSettings?: cdk.IResolvable | CfnAnalysis.RadarChartAreaStyleSettingsProperty;
    }
    /**
     * The configured style settings of a radar chart.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartareastylesettings.html
     */
    interface RadarChartAreaStyleSettingsProperty {
        /**
         * The visibility settings of a radar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartareastylesettings.html#cfn-quicksight-analysis-radarchartareastylesettings-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The field wells of a radar chart visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartfieldwells.html
     */
    interface RadarChartFieldWellsProperty {
        /**
         * The aggregated field wells of a radar chart visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartfieldwells.html#cfn-quicksight-analysis-radarchartfieldwells-radarchartaggregatedfieldwells
         */
        readonly radarChartAggregatedFieldWells?: cdk.IResolvable | CfnAnalysis.RadarChartAggregatedFieldWellsProperty;
    }
    /**
     * The aggregated field well configuration of a `RadarChartVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartaggregatedfieldwells.html
     */
    interface RadarChartAggregatedFieldWellsProperty {
        /**
         * The aggregated field well categories of a radar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartaggregatedfieldwells.html#cfn-quicksight-analysis-radarchartaggregatedfieldwells-category
         */
        readonly category?: Array<CfnAnalysis.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The color that are assigned to the aggregated field wells of a radar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartaggregatedfieldwells.html#cfn-quicksight-analysis-radarchartaggregatedfieldwells-color
         */
        readonly color?: Array<CfnAnalysis.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The values that are assigned to the aggregated field wells of a radar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartaggregatedfieldwells.html#cfn-quicksight-analysis-radarchartaggregatedfieldwells-values
         */
        readonly values?: Array<cdk.IResolvable | CfnAnalysis.MeasureFieldProperty> | cdk.IResolvable;
    }
    /**
     * A heat map.
     *
     * For more information, see [Using heat maps](https://docs.aws.amazon.com/quicksight/latest/user/heat-map.html) in the *Amazon QuickSight User Guide* .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapvisual.html
     */
    interface HeatMapVisualProperty {
        /**
         * The list of custom actions that are configured for a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapvisual.html#cfn-quicksight-analysis-heatmapvisual-actions
         */
        readonly actions?: Array<cdk.IResolvable | CfnAnalysis.VisualCustomActionProperty> | cdk.IResolvable;
        /**
         * The configuration of a heat map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapvisual.html#cfn-quicksight-analysis-heatmapvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnAnalysis.HeatMapConfigurationProperty | cdk.IResolvable;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapvisual.html#cfn-quicksight-analysis-heatmapvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnAnalysis.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The subtitle that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapvisual.html#cfn-quicksight-analysis-heatmapvisual-subtitle
         */
        readonly subtitle?: cdk.IResolvable | CfnAnalysis.VisualSubtitleLabelOptionsProperty;
        /**
         * The title that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapvisual.html#cfn-quicksight-analysis-heatmapvisual-title
         */
        readonly title?: cdk.IResolvable | CfnAnalysis.VisualTitleLabelOptionsProperty;
        /**
         * The unique identifier of a visual.
         *
         * This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapvisual.html#cfn-quicksight-analysis-heatmapvisual-visualid
         */
        readonly visualId: string;
    }
    /**
     * The configuration of a heat map.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapconfiguration.html
     */
    interface HeatMapConfigurationProperty {
        /**
         * The color options (gradient color, point of divergence) in a heat map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapconfiguration.html#cfn-quicksight-analysis-heatmapconfiguration-colorscale
         */
        readonly colorScale?: CfnAnalysis.ColorScaleProperty | cdk.IResolvable;
        /**
         * The label options of the column that is displayed in a heat map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapconfiguration.html#cfn-quicksight-analysis-heatmapconfiguration-columnlabeloptions
         */
        readonly columnLabelOptions?: CfnAnalysis.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The options that determine if visual data labels are displayed.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapconfiguration.html#cfn-quicksight-analysis-heatmapconfiguration-datalabels
         */
        readonly dataLabels?: CfnAnalysis.DataLabelOptionsProperty | cdk.IResolvable;
        /**
         * The field wells of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapconfiguration.html#cfn-quicksight-analysis-heatmapconfiguration-fieldwells
         */
        readonly fieldWells?: CfnAnalysis.HeatMapFieldWellsProperty | cdk.IResolvable;
        /**
         * The legend display setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapconfiguration.html#cfn-quicksight-analysis-heatmapconfiguration-legend
         */
        readonly legend?: cdk.IResolvable | CfnAnalysis.LegendOptionsProperty;
        /**
         * The label options of the row that is displayed in a `heat map` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapconfiguration.html#cfn-quicksight-analysis-heatmapconfiguration-rowlabeloptions
         */
        readonly rowLabelOptions?: CfnAnalysis.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The sort configuration of a heat map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapconfiguration.html#cfn-quicksight-analysis-heatmapconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: CfnAnalysis.HeatMapSortConfigurationProperty | cdk.IResolvable;
        /**
         * The tooltip display setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapconfiguration.html#cfn-quicksight-analysis-heatmapconfiguration-tooltip
         */
        readonly tooltip?: cdk.IResolvable | CfnAnalysis.TooltipOptionsProperty;
    }
    /**
     * The sort configuration of a heat map.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapsortconfiguration.html
     */
    interface HeatMapSortConfigurationProperty {
        /**
         * The limit on the number of columns that are displayed in a heat map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapsortconfiguration.html#cfn-quicksight-analysis-heatmapsortconfiguration-heatmapcolumnitemslimitconfiguration
         */
        readonly heatMapColumnItemsLimitConfiguration?: cdk.IResolvable | CfnAnalysis.ItemsLimitConfigurationProperty;
        /**
         * The column sort configuration for heat map for columns that aren't a part of a field well.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapsortconfiguration.html#cfn-quicksight-analysis-heatmapsortconfiguration-heatmapcolumnsort
         */
        readonly heatMapColumnSort?: Array<CfnAnalysis.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The limit on the number of rows that are displayed in a heat map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapsortconfiguration.html#cfn-quicksight-analysis-heatmapsortconfiguration-heatmaprowitemslimitconfiguration
         */
        readonly heatMapRowItemsLimitConfiguration?: cdk.IResolvable | CfnAnalysis.ItemsLimitConfigurationProperty;
        /**
         * The field sort configuration of the rows fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapsortconfiguration.html#cfn-quicksight-analysis-heatmapsortconfiguration-heatmaprowsort
         */
        readonly heatMapRowSort?: Array<CfnAnalysis.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * The field well configuration of a heat map.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapfieldwells.html
     */
    interface HeatMapFieldWellsProperty {
        /**
         * The aggregated field wells of a heat map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapfieldwells.html#cfn-quicksight-analysis-heatmapfieldwells-heatmapaggregatedfieldwells
         */
        readonly heatMapAggregatedFieldWells?: CfnAnalysis.HeatMapAggregatedFieldWellsProperty | cdk.IResolvable;
    }
    /**
     * The aggregated field wells of a heat map.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapaggregatedfieldwells.html
     */
    interface HeatMapAggregatedFieldWellsProperty {
        /**
         * The columns field well of a heat map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapaggregatedfieldwells.html#cfn-quicksight-analysis-heatmapaggregatedfieldwells-columns
         */
        readonly columns?: Array<CfnAnalysis.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The rows field well of a heat map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapaggregatedfieldwells.html#cfn-quicksight-analysis-heatmapaggregatedfieldwells-rows
         */
        readonly rows?: Array<CfnAnalysis.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The values field well of a heat map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapaggregatedfieldwells.html#cfn-quicksight-analysis-heatmapaggregatedfieldwells-values
         */
        readonly values?: Array<cdk.IResolvable | CfnAnalysis.MeasureFieldProperty> | cdk.IResolvable;
    }
    /**
     * Determines the color scale that is applied to the visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-colorscale.html
     */
    interface ColorScaleProperty {
        /**
         * Determines the color fill type.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-colorscale.html#cfn-quicksight-analysis-colorscale-colorfilltype
         */
        readonly colorFillType: string;
        /**
         * Determines the list of colors that are applied to the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-colorscale.html#cfn-quicksight-analysis-colorscale-colors
         */
        readonly colors: Array<CfnAnalysis.DataColorProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * Determines the color that is applied to null values.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-colorscale.html#cfn-quicksight-analysis-colorscale-nullvaluecolor
         */
        readonly nullValueColor?: CfnAnalysis.DataColorProperty | cdk.IResolvable;
    }
    /**
     * Determines the color that is applied to a particular data value.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datacolor.html
     */
    interface DataColorProperty {
        /**
         * The color that is applied to the data value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datacolor.html#cfn-quicksight-analysis-datacolor-color
         */
        readonly color?: string;
        /**
         * The data value that the color is applied to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datacolor.html#cfn-quicksight-analysis-datacolor-datavalue
         */
        readonly dataValue?: number;
    }
    /**
     * A tree map.
     *
     * For more information, see [Using tree maps](https://docs.aws.amazon.com/quicksight/latest/user/tree-map.html) in the *Amazon QuickSight User Guide* .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapvisual.html
     */
    interface TreeMapVisualProperty {
        /**
         * The list of custom actions that are configured for a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapvisual.html#cfn-quicksight-analysis-treemapvisual-actions
         */
        readonly actions?: Array<cdk.IResolvable | CfnAnalysis.VisualCustomActionProperty> | cdk.IResolvable;
        /**
         * The configuration settings of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapvisual.html#cfn-quicksight-analysis-treemapvisual-chartconfiguration
         */
        readonly chartConfiguration?: cdk.IResolvable | CfnAnalysis.TreeMapConfigurationProperty;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapvisual.html#cfn-quicksight-analysis-treemapvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnAnalysis.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The subtitle that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapvisual.html#cfn-quicksight-analysis-treemapvisual-subtitle
         */
        readonly subtitle?: cdk.IResolvable | CfnAnalysis.VisualSubtitleLabelOptionsProperty;
        /**
         * The title that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapvisual.html#cfn-quicksight-analysis-treemapvisual-title
         */
        readonly title?: cdk.IResolvable | CfnAnalysis.VisualTitleLabelOptionsProperty;
        /**
         * The unique identifier of a visual.
         *
         * This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapvisual.html#cfn-quicksight-analysis-treemapvisual-visualid
         */
        readonly visualId: string;
    }
    /**
     * The configuration of a tree map.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapconfiguration.html
     */
    interface TreeMapConfigurationProperty {
        /**
         * The label options (label text, label visibility) for the colors displayed in a tree map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapconfiguration.html#cfn-quicksight-analysis-treemapconfiguration-colorlabeloptions
         */
        readonly colorLabelOptions?: CfnAnalysis.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The color options (gradient color, point of divergence) of a tree map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapconfiguration.html#cfn-quicksight-analysis-treemapconfiguration-colorscale
         */
        readonly colorScale?: CfnAnalysis.ColorScaleProperty | cdk.IResolvable;
        /**
         * The options that determine if visual data labels are displayed.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapconfiguration.html#cfn-quicksight-analysis-treemapconfiguration-datalabels
         */
        readonly dataLabels?: CfnAnalysis.DataLabelOptionsProperty | cdk.IResolvable;
        /**
         * The field wells of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapconfiguration.html#cfn-quicksight-analysis-treemapconfiguration-fieldwells
         */
        readonly fieldWells?: cdk.IResolvable | CfnAnalysis.TreeMapFieldWellsProperty;
        /**
         * The label options (label text, label visibility) of the groups that are displayed in a tree map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapconfiguration.html#cfn-quicksight-analysis-treemapconfiguration-grouplabeloptions
         */
        readonly groupLabelOptions?: CfnAnalysis.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The legend display setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapconfiguration.html#cfn-quicksight-analysis-treemapconfiguration-legend
         */
        readonly legend?: cdk.IResolvable | CfnAnalysis.LegendOptionsProperty;
        /**
         * The label options (label text, label visibility) of the sizes that are displayed in a tree map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapconfiguration.html#cfn-quicksight-analysis-treemapconfiguration-sizelabeloptions
         */
        readonly sizeLabelOptions?: CfnAnalysis.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The sort configuration of a tree map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapconfiguration.html#cfn-quicksight-analysis-treemapconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: cdk.IResolvable | CfnAnalysis.TreeMapSortConfigurationProperty;
        /**
         * The tooltip display setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapconfiguration.html#cfn-quicksight-analysis-treemapconfiguration-tooltip
         */
        readonly tooltip?: cdk.IResolvable | CfnAnalysis.TooltipOptionsProperty;
    }
    /**
     * The sort configuration of a tree map.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapsortconfiguration.html
     */
    interface TreeMapSortConfigurationProperty {
        /**
         * The limit on the number of groups that are displayed.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapsortconfiguration.html#cfn-quicksight-analysis-treemapsortconfiguration-treemapgroupitemslimitconfiguration
         */
        readonly treeMapGroupItemsLimitConfiguration?: cdk.IResolvable | CfnAnalysis.ItemsLimitConfigurationProperty;
        /**
         * The sort configuration of group by fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapsortconfiguration.html#cfn-quicksight-analysis-treemapsortconfiguration-treemapsort
         */
        readonly treeMapSort?: Array<CfnAnalysis.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * The field wells of a tree map.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapfieldwells.html
     */
    interface TreeMapFieldWellsProperty {
        /**
         * The aggregated field wells of a tree map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapfieldwells.html#cfn-quicksight-analysis-treemapfieldwells-treemapaggregatedfieldwells
         */
        readonly treeMapAggregatedFieldWells?: cdk.IResolvable | CfnAnalysis.TreeMapAggregatedFieldWellsProperty;
    }
    /**
     * Aggregated field wells of a tree map.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapaggregatedfieldwells.html
     */
    interface TreeMapAggregatedFieldWellsProperty {
        /**
         * The color field well of a tree map.
         *
         * Values are grouped by aggregations based on group by fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapaggregatedfieldwells.html#cfn-quicksight-analysis-treemapaggregatedfieldwells-colors
         */
        readonly colors?: Array<cdk.IResolvable | CfnAnalysis.MeasureFieldProperty> | cdk.IResolvable;
        /**
         * The group by field well of a tree map.
         *
         * Values are grouped based on group by fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapaggregatedfieldwells.html#cfn-quicksight-analysis-treemapaggregatedfieldwells-groups
         */
        readonly groups?: Array<CfnAnalysis.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The size field well of a tree map.
         *
         * Values are aggregated based on group by fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapaggregatedfieldwells.html#cfn-quicksight-analysis-treemapaggregatedfieldwells-sizes
         */
        readonly sizes?: Array<cdk.IResolvable | CfnAnalysis.MeasureFieldProperty> | cdk.IResolvable;
    }
    /**
     * A combo chart.
     *
     * The `ComboChartVisual` includes stacked bar combo charts and clustered bar combo charts
     *
     * For more information, see [Using combo charts](https://docs.aws.amazon.com/quicksight/latest/user/combo-charts.html) in the *Amazon QuickSight User Guide* .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartvisual.html
     */
    interface ComboChartVisualProperty {
        /**
         * The list of custom actions that are configured for a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartvisual.html#cfn-quicksight-analysis-combochartvisual-actions
         */
        readonly actions?: Array<cdk.IResolvable | CfnAnalysis.VisualCustomActionProperty> | cdk.IResolvable;
        /**
         * The configuration settings of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartvisual.html#cfn-quicksight-analysis-combochartvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnAnalysis.ComboChartConfigurationProperty | cdk.IResolvable;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartvisual.html#cfn-quicksight-analysis-combochartvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnAnalysis.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The subtitle that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartvisual.html#cfn-quicksight-analysis-combochartvisual-subtitle
         */
        readonly subtitle?: cdk.IResolvable | CfnAnalysis.VisualSubtitleLabelOptionsProperty;
        /**
         * The title that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartvisual.html#cfn-quicksight-analysis-combochartvisual-title
         */
        readonly title?: cdk.IResolvable | CfnAnalysis.VisualTitleLabelOptionsProperty;
        /**
         * The unique identifier of a visual.
         *
         * This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartvisual.html#cfn-quicksight-analysis-combochartvisual-visualid
         */
        readonly visualId: string;
    }
    /**
     * The configuration of a `ComboChartVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html
     */
    interface ComboChartConfigurationProperty {
        /**
         * The options that determine if visual data labels are displayed.
         *
         * The data label options for a bar in a combo chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-bardatalabels
         */
        readonly barDataLabels?: CfnAnalysis.DataLabelOptionsProperty | cdk.IResolvable;
        /**
         * Determines the bar arrangement in a combo chart. The following are valid values in this structure:.
         *
         * - `CLUSTERED` : For clustered bar combo charts.
         * - `STACKED` : For stacked bar combo charts.
         * - `STACKED_PERCENT` : Do not use. If you use this value, the operation returns a validation error.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-barsarrangement
         */
        readonly barsArrangement?: string;
        /**
         * The category axis of a combo chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-categoryaxis
         */
        readonly categoryAxis?: CfnAnalysis.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * The label options (label text, label visibility, and sort icon visibility) of a combo chart category (group/color) field well.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-categorylabeloptions
         */
        readonly categoryLabelOptions?: CfnAnalysis.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The label options (label text, label visibility, and sort icon visibility) of a combo chart's color field well.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-colorlabeloptions
         */
        readonly colorLabelOptions?: CfnAnalysis.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The field wells of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-fieldwells
         */
        readonly fieldWells?: CfnAnalysis.ComboChartFieldWellsProperty | cdk.IResolvable;
        /**
         * The legend display setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-legend
         */
        readonly legend?: cdk.IResolvable | CfnAnalysis.LegendOptionsProperty;
        /**
         * The options that determine if visual data labels are displayed.
         *
         * The data label options for a line in a combo chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-linedatalabels
         */
        readonly lineDataLabels?: CfnAnalysis.DataLabelOptionsProperty | cdk.IResolvable;
        /**
         * The label display options (grid line, range, scale, and axis step) of a combo chart's primary y-axis (bar) field well.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-primaryyaxisdisplayoptions
         */
        readonly primaryYAxisDisplayOptions?: CfnAnalysis.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * The label options (label text, label visibility, and sort icon visibility) of a combo chart's primary y-axis (bar) field well.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-primaryyaxislabeloptions
         */
        readonly primaryYAxisLabelOptions?: CfnAnalysis.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The reference line setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-referencelines
         */
        readonly referenceLines?: Array<cdk.IResolvable | CfnAnalysis.ReferenceLineProperty> | cdk.IResolvable;
        /**
         * The label display options (grid line, range, scale, axis step) of a combo chart's secondary y-axis (line) field well.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-secondaryyaxisdisplayoptions
         */
        readonly secondaryYAxisDisplayOptions?: CfnAnalysis.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * The label options (label text, label visibility, and sort icon visibility) of a combo chart's secondary y-axis(line) field well.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-secondaryyaxislabeloptions
         */
        readonly secondaryYAxisLabelOptions?: CfnAnalysis.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The sort configuration of a `ComboChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: CfnAnalysis.ComboChartSortConfigurationProperty | cdk.IResolvable;
        /**
         * The legend display setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-tooltip
         */
        readonly tooltip?: cdk.IResolvable | CfnAnalysis.TooltipOptionsProperty;
        /**
         * The palette (chart color) display setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-visualpalette
         */
        readonly visualPalette?: cdk.IResolvable | CfnAnalysis.VisualPaletteProperty;
    }
    /**
     * The sort configuration of a `ComboChartVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartsortconfiguration.html
     */
    interface ComboChartSortConfigurationProperty {
        /**
         * The item limit configuration for the category field well of a combo chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartsortconfiguration.html#cfn-quicksight-analysis-combochartsortconfiguration-categoryitemslimit
         */
        readonly categoryItemsLimit?: cdk.IResolvable | CfnAnalysis.ItemsLimitConfigurationProperty;
        /**
         * The sort configuration of the category field well in a combo chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartsortconfiguration.html#cfn-quicksight-analysis-combochartsortconfiguration-categorysort
         */
        readonly categorySort?: Array<CfnAnalysis.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The item limit configuration of the color field well in a combo chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartsortconfiguration.html#cfn-quicksight-analysis-combochartsortconfiguration-coloritemslimit
         */
        readonly colorItemsLimit?: cdk.IResolvable | CfnAnalysis.ItemsLimitConfigurationProperty;
        /**
         * The sort configuration of the color field well in a combo chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartsortconfiguration.html#cfn-quicksight-analysis-combochartsortconfiguration-colorsort
         */
        readonly colorSort?: Array<CfnAnalysis.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * The field wells of the visual.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartfieldwells.html
     */
    interface ComboChartFieldWellsProperty {
        /**
         * The aggregated field wells of a combo chart.
         *
         * Combo charts only have aggregated field wells. Columns in a combo chart are aggregated by category.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartfieldwells.html#cfn-quicksight-analysis-combochartfieldwells-combochartaggregatedfieldwells
         */
        readonly comboChartAggregatedFieldWells?: CfnAnalysis.ComboChartAggregatedFieldWellsProperty | cdk.IResolvable;
    }
    /**
     * The aggregated field wells of a combo chart.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartaggregatedfieldwells.html
     */
    interface ComboChartAggregatedFieldWellsProperty {
        /**
         * The aggregated `BarValues` field well of a combo chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartaggregatedfieldwells.html#cfn-quicksight-analysis-combochartaggregatedfieldwells-barvalues
         */
        readonly barValues?: Array<cdk.IResolvable | CfnAnalysis.MeasureFieldProperty> | cdk.IResolvable;
        /**
         * The aggregated category field wells of a combo chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartaggregatedfieldwells.html#cfn-quicksight-analysis-combochartaggregatedfieldwells-category
         */
        readonly category?: Array<CfnAnalysis.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The aggregated colors field well of a combo chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartaggregatedfieldwells.html#cfn-quicksight-analysis-combochartaggregatedfieldwells-colors
         */
        readonly colors?: Array<CfnAnalysis.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The aggregated `LineValues` field well of a combo chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartaggregatedfieldwells.html#cfn-quicksight-analysis-combochartaggregatedfieldwells-linevalues
         */
        readonly lineValues?: Array<cdk.IResolvable | CfnAnalysis.MeasureFieldProperty> | cdk.IResolvable;
    }
    /**
     * A word cloud.
     *
     * For more information, see [Using word clouds](https://docs.aws.amazon.com/quicksight/latest/user/word-cloud.html) in the *Amazon QuickSight User Guide* .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudvisual.html
     */
    interface WordCloudVisualProperty {
        /**
         * The list of custom actions that are configured for a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudvisual.html#cfn-quicksight-analysis-wordcloudvisual-actions
         */
        readonly actions?: Array<cdk.IResolvable | CfnAnalysis.VisualCustomActionProperty> | cdk.IResolvable;
        /**
         * The configuration settings of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudvisual.html#cfn-quicksight-analysis-wordcloudvisual-chartconfiguration
         */
        readonly chartConfiguration?: cdk.IResolvable | CfnAnalysis.WordCloudChartConfigurationProperty;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudvisual.html#cfn-quicksight-analysis-wordcloudvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnAnalysis.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The subtitle that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudvisual.html#cfn-quicksight-analysis-wordcloudvisual-subtitle
         */
        readonly subtitle?: cdk.IResolvable | CfnAnalysis.VisualSubtitleLabelOptionsProperty;
        /**
         * The title that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudvisual.html#cfn-quicksight-analysis-wordcloudvisual-title
         */
        readonly title?: cdk.IResolvable | CfnAnalysis.VisualTitleLabelOptionsProperty;
        /**
         * The unique identifier of a visual.
         *
         * This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudvisual.html#cfn-quicksight-analysis-wordcloudvisual-visualid
         */
        readonly visualId: string;
    }
    /**
     * The configuration of a word cloud visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudchartconfiguration.html
     */
    interface WordCloudChartConfigurationProperty {
        /**
         * The label options (label text, label visibility, and sort icon visibility) for the word cloud category.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudchartconfiguration.html#cfn-quicksight-analysis-wordcloudchartconfiguration-categorylabeloptions
         */
        readonly categoryLabelOptions?: CfnAnalysis.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The field wells of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudchartconfiguration.html#cfn-quicksight-analysis-wordcloudchartconfiguration-fieldwells
         */
        readonly fieldWells?: cdk.IResolvable | CfnAnalysis.WordCloudFieldWellsProperty;
        /**
         * The sort configuration of a word cloud visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudchartconfiguration.html#cfn-quicksight-analysis-wordcloudchartconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: cdk.IResolvable | CfnAnalysis.WordCloudSortConfigurationProperty;
        /**
         * The options for a word cloud visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudchartconfiguration.html#cfn-quicksight-analysis-wordcloudchartconfiguration-wordcloudoptions
         */
        readonly wordCloudOptions?: cdk.IResolvable | CfnAnalysis.WordCloudOptionsProperty;
    }
    /**
     * The sort configuration of a word cloud visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudsortconfiguration.html
     */
    interface WordCloudSortConfigurationProperty {
        /**
         * The limit on the number of groups that are displayed in a word cloud.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudsortconfiguration.html#cfn-quicksight-analysis-wordcloudsortconfiguration-categoryitemslimit
         */
        readonly categoryItemsLimit?: cdk.IResolvable | CfnAnalysis.ItemsLimitConfigurationProperty;
        /**
         * The sort configuration of group by fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudsortconfiguration.html#cfn-quicksight-analysis-wordcloudsortconfiguration-categorysort
         */
        readonly categorySort?: Array<CfnAnalysis.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * The field wells of a word cloud visual.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudfieldwells.html
     */
    interface WordCloudFieldWellsProperty {
        /**
         * The aggregated field wells of a word cloud.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudfieldwells.html#cfn-quicksight-analysis-wordcloudfieldwells-wordcloudaggregatedfieldwells
         */
        readonly wordCloudAggregatedFieldWells?: cdk.IResolvable | CfnAnalysis.WordCloudAggregatedFieldWellsProperty;
    }
    /**
     * The aggregated field wells of a word cloud.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudaggregatedfieldwells.html
     */
    interface WordCloudAggregatedFieldWellsProperty {
        /**
         * The group by field well of a word cloud.
         *
         * Values are grouped by group by fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudaggregatedfieldwells.html#cfn-quicksight-analysis-wordcloudaggregatedfieldwells-groupby
         */
        readonly groupBy?: Array<CfnAnalysis.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The size field well of a word cloud.
         *
         * Values are aggregated based on group by fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudaggregatedfieldwells.html#cfn-quicksight-analysis-wordcloudaggregatedfieldwells-size
         */
        readonly size?: Array<cdk.IResolvable | CfnAnalysis.MeasureFieldProperty> | cdk.IResolvable;
    }
    /**
     * The word cloud options for a word cloud visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudoptions.html
     */
    interface WordCloudOptionsProperty {
        /**
         * The cloud layout options (fluid, normal) of a word cloud.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudoptions.html#cfn-quicksight-analysis-wordcloudoptions-cloudlayout
         */
        readonly cloudLayout?: string;
        /**
         * The length limit of each word from 1-100.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudoptions.html#cfn-quicksight-analysis-wordcloudoptions-maximumstringlength
         */
        readonly maximumStringLength?: number;
        /**
         * The word casing options (lower_case, existing_case) for the words in a word cloud.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudoptions.html#cfn-quicksight-analysis-wordcloudoptions-wordcasing
         */
        readonly wordCasing?: string;
        /**
         * The word orientation options (horizontal, horizontal_and_vertical) for the words in a word cloud.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudoptions.html#cfn-quicksight-analysis-wordcloudoptions-wordorientation
         */
        readonly wordOrientation?: string;
        /**
         * The word padding options (none, small, medium, large) for the words in a word cloud.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudoptions.html#cfn-quicksight-analysis-wordcloudoptions-wordpadding
         */
        readonly wordPadding?: string;
        /**
         * The word scaling options (emphasize, normal) for the words in a word cloud.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudoptions.html#cfn-quicksight-analysis-wordcloudoptions-wordscaling
         */
        readonly wordScaling?: string;
    }
    /**
     * An insight visual.
     *
     * For more information, see [Working with insights](https://docs.aws.amazon.com/quicksight/latest/user/computational-insights.html) in the *Amazon QuickSight User Guide* .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-insightvisual.html
     */
    interface InsightVisualProperty {
        /**
         * The list of custom actions that are configured for a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-insightvisual.html#cfn-quicksight-analysis-insightvisual-actions
         */
        readonly actions?: Array<cdk.IResolvable | CfnAnalysis.VisualCustomActionProperty> | cdk.IResolvable;
        /**
         * The dataset that is used in the insight visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-insightvisual.html#cfn-quicksight-analysis-insightvisual-datasetidentifier
         */
        readonly dataSetIdentifier: string;
        /**
         * The configuration of an insight visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-insightvisual.html#cfn-quicksight-analysis-insightvisual-insightconfiguration
         */
        readonly insightConfiguration?: CfnAnalysis.InsightConfigurationProperty | cdk.IResolvable;
        /**
         * The subtitle that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-insightvisual.html#cfn-quicksight-analysis-insightvisual-subtitle
         */
        readonly subtitle?: cdk.IResolvable | CfnAnalysis.VisualSubtitleLabelOptionsProperty;
        /**
         * The title that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-insightvisual.html#cfn-quicksight-analysis-insightvisual-title
         */
        readonly title?: cdk.IResolvable | CfnAnalysis.VisualTitleLabelOptionsProperty;
        /**
         * The unique identifier of a visual.
         *
         * This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-insightvisual.html#cfn-quicksight-analysis-insightvisual-visualid
         */
        readonly visualId: string;
    }
    /**
     * The configuration of an insight visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-insightconfiguration.html
     */
    interface InsightConfigurationProperty {
        /**
         * The computations configurations of the insight visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-insightconfiguration.html#cfn-quicksight-analysis-insightconfiguration-computations
         */
        readonly computations?: Array<CfnAnalysis.ComputationProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The custom narrative of the insight visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-insightconfiguration.html#cfn-quicksight-analysis-insightconfiguration-customnarrative
         */
        readonly customNarrative?: CfnAnalysis.CustomNarrativeOptionsProperty | cdk.IResolvable;
    }
    /**
     * The computation union that is used in an insight visual.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-computation.html
     */
    interface ComputationProperty {
        /**
         * The forecast computation configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-computation.html#cfn-quicksight-analysis-computation-forecast
         */
        readonly forecast?: CfnAnalysis.ForecastComputationProperty | cdk.IResolvable;
        /**
         * The growth rate computation configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-computation.html#cfn-quicksight-analysis-computation-growthrate
         */
        readonly growthRate?: CfnAnalysis.GrowthRateComputationProperty | cdk.IResolvable;
        /**
         * The maximum and minimum computation configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-computation.html#cfn-quicksight-analysis-computation-maximumminimum
         */
        readonly maximumMinimum?: cdk.IResolvable | CfnAnalysis.MaximumMinimumComputationProperty;
        /**
         * The metric comparison computation configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-computation.html#cfn-quicksight-analysis-computation-metriccomparison
         */
        readonly metricComparison?: cdk.IResolvable | CfnAnalysis.MetricComparisonComputationProperty;
        /**
         * The period over period computation configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-computation.html#cfn-quicksight-analysis-computation-periodoverperiod
         */
        readonly periodOverPeriod?: cdk.IResolvable | CfnAnalysis.PeriodOverPeriodComputationProperty;
        /**
         * The period to `DataSetIdentifier` computation configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-computation.html#cfn-quicksight-analysis-computation-periodtodate
         */
        readonly periodToDate?: cdk.IResolvable | CfnAnalysis.PeriodToDateComputationProperty;
        /**
         * The top movers and bottom movers computation configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-computation.html#cfn-quicksight-analysis-computation-topbottommovers
         */
        readonly topBottomMovers?: cdk.IResolvable | CfnAnalysis.TopBottomMoversComputationProperty;
        /**
         * The top ranked and bottom ranked computation configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-computation.html#cfn-quicksight-analysis-computation-topbottomranked
         */
        readonly topBottomRanked?: cdk.IResolvable | CfnAnalysis.TopBottomRankedComputationProperty;
        /**
         * The total aggregation computation configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-computation.html#cfn-quicksight-analysis-computation-totalaggregation
         */
        readonly totalAggregation?: cdk.IResolvable | CfnAnalysis.TotalAggregationComputationProperty;
        /**
         * The unique values computation configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-computation.html#cfn-quicksight-analysis-computation-uniquevalues
         */
        readonly uniqueValues?: cdk.IResolvable | CfnAnalysis.UniqueValuesComputationProperty;
    }
    /**
     * The period to date computation configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-periodtodatecomputation.html
     */
    interface PeriodToDateComputationProperty {
        /**
         * The ID for a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-periodtodatecomputation.html#cfn-quicksight-analysis-periodtodatecomputation-computationid
         */
        readonly computationId: string;
        /**
         * The name of a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-periodtodatecomputation.html#cfn-quicksight-analysis-periodtodatecomputation-name
         */
        readonly name?: string;
        /**
         * The time granularity setup of period to date computation. Choose from the following options:.
         *
         * - YEAR: Year to date.
         * - MONTH: Month to date.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-periodtodatecomputation.html#cfn-quicksight-analysis-periodtodatecomputation-periodtimegranularity
         */
        readonly periodTimeGranularity?: string;
        /**
         * The time field that is used in a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-periodtodatecomputation.html#cfn-quicksight-analysis-periodtodatecomputation-time
         */
        readonly time?: CfnAnalysis.DimensionFieldProperty | cdk.IResolvable;
        /**
         * The value field that is used in a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-periodtodatecomputation.html#cfn-quicksight-analysis-periodtodatecomputation-value
         */
        readonly value?: cdk.IResolvable | CfnAnalysis.MeasureFieldProperty;
    }
    /**
     * The growth rate computation configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-growthratecomputation.html
     */
    interface GrowthRateComputationProperty {
        /**
         * The ID for a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-growthratecomputation.html#cfn-quicksight-analysis-growthratecomputation-computationid
         */
        readonly computationId: string;
        /**
         * The name of a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-growthratecomputation.html#cfn-quicksight-analysis-growthratecomputation-name
         */
        readonly name?: string;
        /**
         * The period size setup of a growth rate computation.
         *
         * @default - 0
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-growthratecomputation.html#cfn-quicksight-analysis-growthratecomputation-periodsize
         */
        readonly periodSize?: number;
        /**
         * The time field that is used in a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-growthratecomputation.html#cfn-quicksight-analysis-growthratecomputation-time
         */
        readonly time?: CfnAnalysis.DimensionFieldProperty | cdk.IResolvable;
        /**
         * The value field that is used in a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-growthratecomputation.html#cfn-quicksight-analysis-growthratecomputation-value
         */
        readonly value?: cdk.IResolvable | CfnAnalysis.MeasureFieldProperty;
    }
    /**
     * The top ranked and bottom ranked computation configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottomrankedcomputation.html
     */
    interface TopBottomRankedComputationProperty {
        /**
         * The category field that is used in a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottomrankedcomputation.html#cfn-quicksight-analysis-topbottomrankedcomputation-category
         */
        readonly category?: CfnAnalysis.DimensionFieldProperty | cdk.IResolvable;
        /**
         * The ID for a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottomrankedcomputation.html#cfn-quicksight-analysis-topbottomrankedcomputation-computationid
         */
        readonly computationId: string;
        /**
         * The name of a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottomrankedcomputation.html#cfn-quicksight-analysis-topbottomrankedcomputation-name
         */
        readonly name?: string;
        /**
         * The result size of a top and bottom ranked computation.
         *
         * @default - 0
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottomrankedcomputation.html#cfn-quicksight-analysis-topbottomrankedcomputation-resultsize
         */
        readonly resultSize?: number;
        /**
         * The computation type. Choose one of the following options:.
         *
         * - TOP: A top ranked computation.
         * - BOTTOM: A bottom ranked computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottomrankedcomputation.html#cfn-quicksight-analysis-topbottomrankedcomputation-type
         */
        readonly type: string;
        /**
         * The value field that is used in a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottomrankedcomputation.html#cfn-quicksight-analysis-topbottomrankedcomputation-value
         */
        readonly value?: cdk.IResolvable | CfnAnalysis.MeasureFieldProperty;
    }
    /**
     * The total aggregation computation configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-totalaggregationcomputation.html
     */
    interface TotalAggregationComputationProperty {
        /**
         * The ID for a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-totalaggregationcomputation.html#cfn-quicksight-analysis-totalaggregationcomputation-computationid
         */
        readonly computationId: string;
        /**
         * The name of a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-totalaggregationcomputation.html#cfn-quicksight-analysis-totalaggregationcomputation-name
         */
        readonly name?: string;
        /**
         * The value field that is used in a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-totalaggregationcomputation.html#cfn-quicksight-analysis-totalaggregationcomputation-value
         */
        readonly value?: cdk.IResolvable | CfnAnalysis.MeasureFieldProperty;
    }
    /**
     * The forecast computation configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastcomputation.html
     */
    interface ForecastComputationProperty {
        /**
         * The ID for a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastcomputation.html#cfn-quicksight-analysis-forecastcomputation-computationid
         */
        readonly computationId: string;
        /**
         * The custom seasonality value setup of a forecast computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastcomputation.html#cfn-quicksight-analysis-forecastcomputation-customseasonalityvalue
         */
        readonly customSeasonalityValue?: number;
        /**
         * The lower boundary setup of a forecast computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastcomputation.html#cfn-quicksight-analysis-forecastcomputation-lowerboundary
         */
        readonly lowerBoundary?: number;
        /**
         * The name of a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastcomputation.html#cfn-quicksight-analysis-forecastcomputation-name
         */
        readonly name?: string;
        /**
         * The periods backward setup of a forecast computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastcomputation.html#cfn-quicksight-analysis-forecastcomputation-periodsbackward
         */
        readonly periodsBackward?: number;
        /**
         * The periods forward setup of a forecast computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastcomputation.html#cfn-quicksight-analysis-forecastcomputation-periodsforward
         */
        readonly periodsForward?: number;
        /**
         * The prediction interval setup of a forecast computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastcomputation.html#cfn-quicksight-analysis-forecastcomputation-predictioninterval
         */
        readonly predictionInterval?: number;
        /**
         * The seasonality setup of a forecast computation. Choose one of the following options:.
         *
         * - `AUTOMATIC`
         * - `CUSTOM` : Checks the custom seasonality value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastcomputation.html#cfn-quicksight-analysis-forecastcomputation-seasonality
         */
        readonly seasonality?: string;
        /**
         * The time field that is used in a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastcomputation.html#cfn-quicksight-analysis-forecastcomputation-time
         */
        readonly time?: CfnAnalysis.DimensionFieldProperty | cdk.IResolvable;
        /**
         * The upper boundary setup of a forecast computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastcomputation.html#cfn-quicksight-analysis-forecastcomputation-upperboundary
         */
        readonly upperBoundary?: number;
        /**
         * The value field that is used in a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastcomputation.html#cfn-quicksight-analysis-forecastcomputation-value
         */
        readonly value?: cdk.IResolvable | CfnAnalysis.MeasureFieldProperty;
    }
    /**
     * The maximum and minimum computation configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-maximumminimumcomputation.html
     */
    interface MaximumMinimumComputationProperty {
        /**
         * The ID for a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-maximumminimumcomputation.html#cfn-quicksight-analysis-maximumminimumcomputation-computationid
         */
        readonly computationId: string;
        /**
         * The name of a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-maximumminimumcomputation.html#cfn-quicksight-analysis-maximumminimumcomputation-name
         */
        readonly name?: string;
        /**
         * The time field that is used in a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-maximumminimumcomputation.html#cfn-quicksight-analysis-maximumminimumcomputation-time
         */
        readonly time?: CfnAnalysis.DimensionFieldProperty | cdk.IResolvable;
        /**
         * The type of computation. Choose one of the following options:.
         *
         * - MAXIMUM: A maximum computation.
         * - MINIMUM: A minimum computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-maximumminimumcomputation.html#cfn-quicksight-analysis-maximumminimumcomputation-type
         */
        readonly type: string;
        /**
         * The value field that is used in a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-maximumminimumcomputation.html#cfn-quicksight-analysis-maximumminimumcomputation-value
         */
        readonly value?: cdk.IResolvable | CfnAnalysis.MeasureFieldProperty;
    }
    /**
     * The period over period computation configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-periodoverperiodcomputation.html
     */
    interface PeriodOverPeriodComputationProperty {
        /**
         * The ID for a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-periodoverperiodcomputation.html#cfn-quicksight-analysis-periodoverperiodcomputation-computationid
         */
        readonly computationId: string;
        /**
         * The name of a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-periodoverperiodcomputation.html#cfn-quicksight-analysis-periodoverperiodcomputation-name
         */
        readonly name?: string;
        /**
         * The time field that is used in a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-periodoverperiodcomputation.html#cfn-quicksight-analysis-periodoverperiodcomputation-time
         */
        readonly time?: CfnAnalysis.DimensionFieldProperty | cdk.IResolvable;
        /**
         * The value field that is used in a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-periodoverperiodcomputation.html#cfn-quicksight-analysis-periodoverperiodcomputation-value
         */
        readonly value?: cdk.IResolvable | CfnAnalysis.MeasureFieldProperty;
    }
    /**
     * The metric comparison computation configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-metriccomparisoncomputation.html
     */
    interface MetricComparisonComputationProperty {
        /**
         * The ID for a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-metriccomparisoncomputation.html#cfn-quicksight-analysis-metriccomparisoncomputation-computationid
         */
        readonly computationId: string;
        /**
         * The field that is used in a metric comparison from value setup.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-metriccomparisoncomputation.html#cfn-quicksight-analysis-metriccomparisoncomputation-fromvalue
         */
        readonly fromValue?: cdk.IResolvable | CfnAnalysis.MeasureFieldProperty;
        /**
         * The name of a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-metriccomparisoncomputation.html#cfn-quicksight-analysis-metriccomparisoncomputation-name
         */
        readonly name?: string;
        /**
         * The field that is used in a metric comparison to value setup.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-metriccomparisoncomputation.html#cfn-quicksight-analysis-metriccomparisoncomputation-targetvalue
         */
        readonly targetValue?: cdk.IResolvable | CfnAnalysis.MeasureFieldProperty;
        /**
         * The time field that is used in a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-metriccomparisoncomputation.html#cfn-quicksight-analysis-metriccomparisoncomputation-time
         */
        readonly time?: CfnAnalysis.DimensionFieldProperty | cdk.IResolvable;
    }
    /**
     * The top movers and bottom movers computation setup.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottommoverscomputation.html
     */
    interface TopBottomMoversComputationProperty {
        /**
         * The category field that is used in a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottommoverscomputation.html#cfn-quicksight-analysis-topbottommoverscomputation-category
         */
        readonly category?: CfnAnalysis.DimensionFieldProperty | cdk.IResolvable;
        /**
         * The ID for a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottommoverscomputation.html#cfn-quicksight-analysis-topbottommoverscomputation-computationid
         */
        readonly computationId: string;
        /**
         * The mover size setup of the top and bottom movers computation.
         *
         * @default - 0
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottommoverscomputation.html#cfn-quicksight-analysis-topbottommoverscomputation-moversize
         */
        readonly moverSize?: number;
        /**
         * The name of a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottommoverscomputation.html#cfn-quicksight-analysis-topbottommoverscomputation-name
         */
        readonly name?: string;
        /**
         * The sort order setup of the top and bottom movers computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottommoverscomputation.html#cfn-quicksight-analysis-topbottommoverscomputation-sortorder
         */
        readonly sortOrder?: string;
        /**
         * The time field that is used in a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottommoverscomputation.html#cfn-quicksight-analysis-topbottommoverscomputation-time
         */
        readonly time?: CfnAnalysis.DimensionFieldProperty | cdk.IResolvable;
        /**
         * The computation type. Choose from the following options:.
         *
         * - TOP: Top movers computation.
         * - BOTTOM: Bottom movers computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottommoverscomputation.html#cfn-quicksight-analysis-topbottommoverscomputation-type
         */
        readonly type: string;
        /**
         * The value field that is used in a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottommoverscomputation.html#cfn-quicksight-analysis-topbottommoverscomputation-value
         */
        readonly value?: cdk.IResolvable | CfnAnalysis.MeasureFieldProperty;
    }
    /**
     * The unique values computation configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-uniquevaluescomputation.html
     */
    interface UniqueValuesComputationProperty {
        /**
         * The category field that is used in a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-uniquevaluescomputation.html#cfn-quicksight-analysis-uniquevaluescomputation-category
         */
        readonly category?: CfnAnalysis.DimensionFieldProperty | cdk.IResolvable;
        /**
         * The ID for a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-uniquevaluescomputation.html#cfn-quicksight-analysis-uniquevaluescomputation-computationid
         */
        readonly computationId: string;
        /**
         * The name of a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-uniquevaluescomputation.html#cfn-quicksight-analysis-uniquevaluescomputation-name
         */
        readonly name?: string;
    }
    /**
     * The custom narrative options.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customnarrativeoptions.html
     */
    interface CustomNarrativeOptionsProperty {
        /**
         * The string input of custom narrative.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customnarrativeoptions.html#cfn-quicksight-analysis-customnarrativeoptions-narrative
         */
        readonly narrative: string;
    }
    /**
     * A sankey diagram.
     *
     * For more information, see [Using Sankey diagrams](https://docs.aws.amazon.com/quicksight/latest/user/sankey-diagram.html) in the *Amazon QuickSight User Guide* .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramvisual.html
     */
    interface SankeyDiagramVisualProperty {
        /**
         * The list of custom actions that are configured for a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramvisual.html#cfn-quicksight-analysis-sankeydiagramvisual-actions
         */
        readonly actions?: Array<cdk.IResolvable | CfnAnalysis.VisualCustomActionProperty> | cdk.IResolvable;
        /**
         * The configuration of a sankey diagram.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramvisual.html#cfn-quicksight-analysis-sankeydiagramvisual-chartconfiguration
         */
        readonly chartConfiguration?: cdk.IResolvable | CfnAnalysis.SankeyDiagramChartConfigurationProperty;
        /**
         * The subtitle that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramvisual.html#cfn-quicksight-analysis-sankeydiagramvisual-subtitle
         */
        readonly subtitle?: cdk.IResolvable | CfnAnalysis.VisualSubtitleLabelOptionsProperty;
        /**
         * The title that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramvisual.html#cfn-quicksight-analysis-sankeydiagramvisual-title
         */
        readonly title?: cdk.IResolvable | CfnAnalysis.VisualTitleLabelOptionsProperty;
        /**
         * The unique identifier of a visual.
         *
         * This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramvisual.html#cfn-quicksight-analysis-sankeydiagramvisual-visualid
         */
        readonly visualId: string;
    }
    /**
     * The configuration of a sankey diagram.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramchartconfiguration.html
     */
    interface SankeyDiagramChartConfigurationProperty {
        /**
         * The data label configuration of a sankey diagram.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramchartconfiguration.html#cfn-quicksight-analysis-sankeydiagramchartconfiguration-datalabels
         */
        readonly dataLabels?: CfnAnalysis.DataLabelOptionsProperty | cdk.IResolvable;
        /**
         * The field well configuration of a sankey diagram.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramchartconfiguration.html#cfn-quicksight-analysis-sankeydiagramchartconfiguration-fieldwells
         */
        readonly fieldWells?: cdk.IResolvable | CfnAnalysis.SankeyDiagramFieldWellsProperty;
        /**
         * The sort configuration of a sankey diagram.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramchartconfiguration.html#cfn-quicksight-analysis-sankeydiagramchartconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: cdk.IResolvable | CfnAnalysis.SankeyDiagramSortConfigurationProperty;
    }
    /**
     * The sort configuration of a sankey diagram.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramsortconfiguration.html
     */
    interface SankeyDiagramSortConfigurationProperty {
        /**
         * The limit on the number of destination nodes that are displayed in a sankey diagram.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramsortconfiguration.html#cfn-quicksight-analysis-sankeydiagramsortconfiguration-destinationitemslimit
         */
        readonly destinationItemsLimit?: cdk.IResolvable | CfnAnalysis.ItemsLimitConfigurationProperty;
        /**
         * The limit on the number of source nodes that are displayed in a sankey diagram.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramsortconfiguration.html#cfn-quicksight-analysis-sankeydiagramsortconfiguration-sourceitemslimit
         */
        readonly sourceItemsLimit?: cdk.IResolvable | CfnAnalysis.ItemsLimitConfigurationProperty;
        /**
         * The sort configuration of the weight fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramsortconfiguration.html#cfn-quicksight-analysis-sankeydiagramsortconfiguration-weightsort
         */
        readonly weightSort?: Array<CfnAnalysis.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * The field well configuration of a sankey diagram.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramfieldwells.html
     */
    interface SankeyDiagramFieldWellsProperty {
        /**
         * The field well configuration of a sankey diagram.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramfieldwells.html#cfn-quicksight-analysis-sankeydiagramfieldwells-sankeydiagramaggregatedfieldwells
         */
        readonly sankeyDiagramAggregatedFieldWells?: cdk.IResolvable | CfnAnalysis.SankeyDiagramAggregatedFieldWellsProperty;
    }
    /**
     * The field well configuration of a sankey diagram.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramaggregatedfieldwells.html
     */
    interface SankeyDiagramAggregatedFieldWellsProperty {
        /**
         * The destination field wells of a sankey diagram.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramaggregatedfieldwells.html#cfn-quicksight-analysis-sankeydiagramaggregatedfieldwells-destination
         */
        readonly destination?: Array<CfnAnalysis.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The source field wells of a sankey diagram.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramaggregatedfieldwells.html#cfn-quicksight-analysis-sankeydiagramaggregatedfieldwells-source
         */
        readonly source?: Array<CfnAnalysis.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The weight field wells of a sankey diagram.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramaggregatedfieldwells.html#cfn-quicksight-analysis-sankeydiagramaggregatedfieldwells-weight
         */
        readonly weight?: Array<cdk.IResolvable | CfnAnalysis.MeasureFieldProperty> | cdk.IResolvable;
    }
    /**
     * A gauge chart.
     *
     * For more information, see [Using gauge charts](https://docs.aws.amazon.com/quicksight/latest/user/gauge-chart.html) in the *Amazon QuickSight User Guide* .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartvisual.html
     */
    interface GaugeChartVisualProperty {
        /**
         * The list of custom actions that are configured for a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartvisual.html#cfn-quicksight-analysis-gaugechartvisual-actions
         */
        readonly actions?: Array<cdk.IResolvable | CfnAnalysis.VisualCustomActionProperty> | cdk.IResolvable;
        /**
         * The configuration of a `GaugeChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartvisual.html#cfn-quicksight-analysis-gaugechartvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnAnalysis.GaugeChartConfigurationProperty | cdk.IResolvable;
        /**
         * The conditional formatting of a `GaugeChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartvisual.html#cfn-quicksight-analysis-gaugechartvisual-conditionalformatting
         */
        readonly conditionalFormatting?: CfnAnalysis.GaugeChartConditionalFormattingProperty | cdk.IResolvable;
        /**
         * The subtitle that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartvisual.html#cfn-quicksight-analysis-gaugechartvisual-subtitle
         */
        readonly subtitle?: cdk.IResolvable | CfnAnalysis.VisualSubtitleLabelOptionsProperty;
        /**
         * The title that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartvisual.html#cfn-quicksight-analysis-gaugechartvisual-title
         */
        readonly title?: cdk.IResolvable | CfnAnalysis.VisualTitleLabelOptionsProperty;
        /**
         * The unique identifier of a visual.
         *
         * This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartvisual.html#cfn-quicksight-analysis-gaugechartvisual-visualid
         */
        readonly visualId: string;
    }
    /**
     * The conditional formatting of a `GaugeChartVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartconditionalformatting.html
     */
    interface GaugeChartConditionalFormattingProperty {
        /**
         * Conditional formatting options of a `GaugeChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartconditionalformatting.html#cfn-quicksight-analysis-gaugechartconditionalformatting-conditionalformattingoptions
         */
        readonly conditionalFormattingOptions?: Array<CfnAnalysis.GaugeChartConditionalFormattingOptionProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * Conditional formatting options of a `GaugeChartVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartconditionalformattingoption.html
     */
    interface GaugeChartConditionalFormattingOptionProperty {
        /**
         * The options that determine the presentation of the arc of a `GaugeChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartconditionalformattingoption.html#cfn-quicksight-analysis-gaugechartconditionalformattingoption-arc
         */
        readonly arc?: CfnAnalysis.GaugeChartArcConditionalFormattingProperty | cdk.IResolvable;
        /**
         * The conditional formatting for the primary value of a `GaugeChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartconditionalformattingoption.html#cfn-quicksight-analysis-gaugechartconditionalformattingoption-primaryvalue
         */
        readonly primaryValue?: CfnAnalysis.GaugeChartPrimaryValueConditionalFormattingProperty | cdk.IResolvable;
    }
    /**
     * The options that determine the presentation of the arc of a `GaugeChartVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartarcconditionalformatting.html
     */
    interface GaugeChartArcConditionalFormattingProperty {
        /**
         * The conditional formatting of the arc foreground color.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartarcconditionalformatting.html#cfn-quicksight-analysis-gaugechartarcconditionalformatting-foregroundcolor
         */
        readonly foregroundColor?: CfnAnalysis.ConditionalFormattingColorProperty | cdk.IResolvable;
    }
    /**
     * The conditional formatting for the primary value of a `GaugeChartVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartprimaryvalueconditionalformatting.html
     */
    interface GaugeChartPrimaryValueConditionalFormattingProperty {
        /**
         * The conditional formatting of the primary value icon.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartprimaryvalueconditionalformatting.html#cfn-quicksight-analysis-gaugechartprimaryvalueconditionalformatting-icon
         */
        readonly icon?: CfnAnalysis.ConditionalFormattingIconProperty | cdk.IResolvable;
        /**
         * The conditional formatting of the primary value text color.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartprimaryvalueconditionalformatting.html#cfn-quicksight-analysis-gaugechartprimaryvalueconditionalformatting-textcolor
         */
        readonly textColor?: CfnAnalysis.ConditionalFormattingColorProperty | cdk.IResolvable;
    }
    /**
     * The configuration of a `GaugeChartVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartconfiguration.html
     */
    interface GaugeChartConfigurationProperty {
        /**
         * The data label configuration of a `GaugeChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartconfiguration.html#cfn-quicksight-analysis-gaugechartconfiguration-datalabels
         */
        readonly dataLabels?: CfnAnalysis.DataLabelOptionsProperty | cdk.IResolvable;
        /**
         * The field well configuration of a `GaugeChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartconfiguration.html#cfn-quicksight-analysis-gaugechartconfiguration-fieldwells
         */
        readonly fieldWells?: CfnAnalysis.GaugeChartFieldWellsProperty | cdk.IResolvable;
        /**
         * The options that determine the presentation of the `GaugeChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartconfiguration.html#cfn-quicksight-analysis-gaugechartconfiguration-gaugechartoptions
         */
        readonly gaugeChartOptions?: CfnAnalysis.GaugeChartOptionsProperty | cdk.IResolvable;
        /**
         * The tooltip configuration of a `GaugeChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartconfiguration.html#cfn-quicksight-analysis-gaugechartconfiguration-tooltipoptions
         */
        readonly tooltipOptions?: cdk.IResolvable | CfnAnalysis.TooltipOptionsProperty;
        /**
         * The visual palette configuration of a `GaugeChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartconfiguration.html#cfn-quicksight-analysis-gaugechartconfiguration-visualpalette
         */
        readonly visualPalette?: cdk.IResolvable | CfnAnalysis.VisualPaletteProperty;
    }
    /**
     * The field well configuration of a `GaugeChartVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartfieldwells.html
     */
    interface GaugeChartFieldWellsProperty {
        /**
         * The target value field wells of a `GaugeChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartfieldwells.html#cfn-quicksight-analysis-gaugechartfieldwells-targetvalues
         */
        readonly targetValues?: Array<cdk.IResolvable | CfnAnalysis.MeasureFieldProperty> | cdk.IResolvable;
        /**
         * The value field wells of a `GaugeChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartfieldwells.html#cfn-quicksight-analysis-gaugechartfieldwells-values
         */
        readonly values?: Array<cdk.IResolvable | CfnAnalysis.MeasureFieldProperty> | cdk.IResolvable;
    }
    /**
     * The options that determine the presentation of the `GaugeChartVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartoptions.html
     */
    interface GaugeChartOptionsProperty {
        /**
         * The arc configuration of a `GaugeChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartoptions.html#cfn-quicksight-analysis-gaugechartoptions-arc
         */
        readonly arc?: CfnAnalysis.ArcConfigurationProperty | cdk.IResolvable;
        /**
         * The arc axis configuration of a `GaugeChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartoptions.html#cfn-quicksight-analysis-gaugechartoptions-arcaxis
         */
        readonly arcAxis?: CfnAnalysis.ArcAxisConfigurationProperty | cdk.IResolvable;
        /**
         * The comparison configuration of a `GaugeChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartoptions.html#cfn-quicksight-analysis-gaugechartoptions-comparison
         */
        readonly comparison?: CfnAnalysis.ComparisonConfigurationProperty | cdk.IResolvable;
        /**
         * The options that determine the primary value display type.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartoptions.html#cfn-quicksight-analysis-gaugechartoptions-primaryvaluedisplaytype
         */
        readonly primaryValueDisplayType?: string;
        /**
         * The options that determine the primary value font configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartoptions.html#cfn-quicksight-analysis-gaugechartoptions-primaryvaluefontconfiguration
         */
        readonly primaryValueFontConfiguration?: CfnAnalysis.FontConfigurationProperty | cdk.IResolvable;
    }
    /**
     * The arc configuration of a `GaugeChartVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-arcconfiguration.html
     */
    interface ArcConfigurationProperty {
        /**
         * The option that determines the arc angle of a `GaugeChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-arcconfiguration.html#cfn-quicksight-analysis-arcconfiguration-arcangle
         */
        readonly arcAngle?: number;
        /**
         * The options that determine the arc thickness of a `GaugeChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-arcconfiguration.html#cfn-quicksight-analysis-arcconfiguration-arcthickness
         */
        readonly arcThickness?: string;
    }
    /**
     * The arc axis configuration of a `GaugeChartVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-arcaxisconfiguration.html
     */
    interface ArcAxisConfigurationProperty {
        /**
         * The arc axis range of a `GaugeChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-arcaxisconfiguration.html#cfn-quicksight-analysis-arcaxisconfiguration-range
         */
        readonly range?: CfnAnalysis.ArcAxisDisplayRangeProperty | cdk.IResolvable;
        /**
         * The reserved range of the arc axis.
         *
         * @default - 0
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-arcaxisconfiguration.html#cfn-quicksight-analysis-arcaxisconfiguration-reserverange
         */
        readonly reserveRange?: number;
    }
    /**
     * The arc axis range of a `GaugeChartVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-arcaxisdisplayrange.html
     */
    interface ArcAxisDisplayRangeProperty {
        /**
         * The maximum value of the arc axis range.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-arcaxisdisplayrange.html#cfn-quicksight-analysis-arcaxisdisplayrange-max
         */
        readonly max?: number;
        /**
         * The minimum value of the arc axis range.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-arcaxisdisplayrange.html#cfn-quicksight-analysis-arcaxisdisplayrange-min
         */
        readonly min?: number;
    }
    /**
     * A line chart.
     *
     * For more information, see [Using line charts](https://docs.aws.amazon.com/quicksight/latest/user/line-charts.html) in the *Amazon QuickSight User Guide* .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartvisual.html
     */
    interface LineChartVisualProperty {
        /**
         * The list of custom actions that are configured for a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartvisual.html#cfn-quicksight-analysis-linechartvisual-actions
         */
        readonly actions?: Array<cdk.IResolvable | CfnAnalysis.VisualCustomActionProperty> | cdk.IResolvable;
        /**
         * The configuration of a line chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartvisual.html#cfn-quicksight-analysis-linechartvisual-chartconfiguration
         */
        readonly chartConfiguration?: cdk.IResolvable | CfnAnalysis.LineChartConfigurationProperty;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartvisual.html#cfn-quicksight-analysis-linechartvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnAnalysis.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The subtitle that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartvisual.html#cfn-quicksight-analysis-linechartvisual-subtitle
         */
        readonly subtitle?: cdk.IResolvable | CfnAnalysis.VisualSubtitleLabelOptionsProperty;
        /**
         * The title that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartvisual.html#cfn-quicksight-analysis-linechartvisual-title
         */
        readonly title?: cdk.IResolvable | CfnAnalysis.VisualTitleLabelOptionsProperty;
        /**
         * The unique identifier of a visual.
         *
         * This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartvisual.html#cfn-quicksight-analysis-linechartvisual-visualid
         */
        readonly visualId: string;
    }
    /**
     * The configuration of a line chart.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html
     */
    interface LineChartConfigurationProperty {
        /**
         * The default configuration of a line chart's contribution analysis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-contributionanalysisdefaults
         */
        readonly contributionAnalysisDefaults?: Array<CfnAnalysis.ContributionAnalysisDefaultProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The data label configuration of a line chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-datalabels
         */
        readonly dataLabels?: CfnAnalysis.DataLabelOptionsProperty | cdk.IResolvable;
        /**
         * The options that determine the default presentation of all line series in `LineChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-defaultseriessettings
         */
        readonly defaultSeriesSettings?: cdk.IResolvable | CfnAnalysis.LineChartDefaultSeriesSettingsProperty;
        /**
         * The field well configuration of a line chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-fieldwells
         */
        readonly fieldWells?: cdk.IResolvable | CfnAnalysis.LineChartFieldWellsProperty;
        /**
         * The forecast configuration of a line chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-forecastconfigurations
         */
        readonly forecastConfigurations?: Array<CfnAnalysis.ForecastConfigurationProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The legend configuration of a line chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-legend
         */
        readonly legend?: cdk.IResolvable | CfnAnalysis.LegendOptionsProperty;
        /**
         * The series axis configuration of a line chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-primaryyaxisdisplayoptions
         */
        readonly primaryYAxisDisplayOptions?: cdk.IResolvable | CfnAnalysis.LineSeriesAxisDisplayOptionsProperty;
        /**
         * The options that determine the presentation of the y-axis label.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-primaryyaxislabeloptions
         */
        readonly primaryYAxisLabelOptions?: CfnAnalysis.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The reference lines configuration of a line chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-referencelines
         */
        readonly referenceLines?: Array<cdk.IResolvable | CfnAnalysis.ReferenceLineProperty> | cdk.IResolvable;
        /**
         * The series axis configuration of a line chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-secondaryyaxisdisplayoptions
         */
        readonly secondaryYAxisDisplayOptions?: cdk.IResolvable | CfnAnalysis.LineSeriesAxisDisplayOptionsProperty;
        /**
         * The options that determine the presentation of the secondary y-axis label.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-secondaryyaxislabeloptions
         */
        readonly secondaryYAxisLabelOptions?: CfnAnalysis.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The series item configuration of a line chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-series
         */
        readonly series?: Array<cdk.IResolvable | CfnAnalysis.SeriesItemProperty> | cdk.IResolvable;
        /**
         * The small multiples setup for the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-smallmultiplesoptions
         */
        readonly smallMultiplesOptions?: cdk.IResolvable | CfnAnalysis.SmallMultiplesOptionsProperty;
        /**
         * The sort configuration of a line chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: cdk.IResolvable | CfnAnalysis.LineChartSortConfigurationProperty;
        /**
         * The tooltip configuration of a line chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-tooltip
         */
        readonly tooltip?: cdk.IResolvable | CfnAnalysis.TooltipOptionsProperty;
        /**
         * Determines the type of the line chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-type
         */
        readonly type?: string;
        /**
         * The visual palette configuration of a line chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-visualpalette
         */
        readonly visualPalette?: cdk.IResolvable | CfnAnalysis.VisualPaletteProperty;
        /**
         * The options that determine the presentation of the x-axis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-xaxisdisplayoptions
         */
        readonly xAxisDisplayOptions?: CfnAnalysis.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * The options that determine the presentation of the x-axis label.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-xaxislabeloptions
         */
        readonly xAxisLabelOptions?: CfnAnalysis.ChartAxisLabelOptionsProperty | cdk.IResolvable;
    }
    /**
     * The sort configuration of a line chart.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartsortconfiguration.html
     */
    interface LineChartSortConfigurationProperty {
        /**
         * The limit on the number of categories that are displayed in a line chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartsortconfiguration.html#cfn-quicksight-analysis-linechartsortconfiguration-categoryitemslimitconfiguration
         */
        readonly categoryItemsLimitConfiguration?: cdk.IResolvable | CfnAnalysis.ItemsLimitConfigurationProperty;
        /**
         * The sort configuration of the category fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartsortconfiguration.html#cfn-quicksight-analysis-linechartsortconfiguration-categorysort
         */
        readonly categorySort?: Array<CfnAnalysis.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The limit on the number of lines that are displayed in a line chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartsortconfiguration.html#cfn-quicksight-analysis-linechartsortconfiguration-coloritemslimitconfiguration
         */
        readonly colorItemsLimitConfiguration?: cdk.IResolvable | CfnAnalysis.ItemsLimitConfigurationProperty;
        /**
         * The limit on the number of small multiples panels that are displayed.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartsortconfiguration.html#cfn-quicksight-analysis-linechartsortconfiguration-smallmultipleslimitconfiguration
         */
        readonly smallMultiplesLimitConfiguration?: cdk.IResolvable | CfnAnalysis.ItemsLimitConfigurationProperty;
        /**
         * The sort configuration of the small multiples field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartsortconfiguration.html#cfn-quicksight-analysis-linechartsortconfiguration-smallmultiplessort
         */
        readonly smallMultiplesSort?: Array<CfnAnalysis.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * The series axis configuration of a line chart.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-lineseriesaxisdisplayoptions.html
     */
    interface LineSeriesAxisDisplayOptionsProperty {
        /**
         * The options that determine the presentation of the line series axis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-lineseriesaxisdisplayoptions.html#cfn-quicksight-analysis-lineseriesaxisdisplayoptions-axisoptions
         */
        readonly axisOptions?: CfnAnalysis.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * The configuration options that determine how missing data is treated during the rendering of a line chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-lineseriesaxisdisplayoptions.html#cfn-quicksight-analysis-lineseriesaxisdisplayoptions-missingdataconfigurations
         */
        readonly missingDataConfigurations?: Array<cdk.IResolvable | CfnAnalysis.MissingDataConfigurationProperty> | cdk.IResolvable;
    }
    /**
     * The configuration options that determine how missing data is treated during the rendering of a line chart.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-missingdataconfiguration.html
     */
    interface MissingDataConfigurationProperty {
        /**
         * The treatment option that determines how missing data should be rendered. Choose from the following options:.
         *
         * - `INTERPOLATE` : Interpolate missing values between the prior and the next known value.
         * - `SHOW_AS_ZERO` : Show missing values as the value `0` .
         * - `SHOW_AS_BLANK` : Display a blank space when rendering missing data.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-missingdataconfiguration.html#cfn-quicksight-analysis-missingdataconfiguration-treatmentoption
         */
        readonly treatmentOption?: string;
    }
    /**
     * The options that determine the default presentation of all line series in `LineChartVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartdefaultseriessettings.html
     */
    interface LineChartDefaultSeriesSettingsProperty {
        /**
         * The axis to which you are binding all line series to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartdefaultseriessettings.html#cfn-quicksight-analysis-linechartdefaultseriessettings-axisbinding
         */
        readonly axisBinding?: string;
        /**
         * Line styles options for all line series in the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartdefaultseriessettings.html#cfn-quicksight-analysis-linechartdefaultseriessettings-linestylesettings
         */
        readonly lineStyleSettings?: cdk.IResolvable | CfnAnalysis.LineChartLineStyleSettingsProperty;
        /**
         * Marker styles options for all line series in the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartdefaultseriessettings.html#cfn-quicksight-analysis-linechartdefaultseriessettings-markerstylesettings
         */
        readonly markerStyleSettings?: cdk.IResolvable | CfnAnalysis.LineChartMarkerStyleSettingsProperty;
    }
    /**
     * Line styles options for a line series in `LineChartVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartlinestylesettings.html
     */
    interface LineChartLineStyleSettingsProperty {
        /**
         * Interpolation style for line series.
         *
         * - `LINEAR` : Show as default, linear style.
         * - `SMOOTH` : Show as a smooth curve.
         * - `STEPPED` : Show steps in line.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartlinestylesettings.html#cfn-quicksight-analysis-linechartlinestylesettings-lineinterpolation
         */
        readonly lineInterpolation?: string;
        /**
         * Line style for line series.
         *
         * - `SOLID` : Show as a solid line.
         * - `DOTTED` : Show as a dotted line.
         * - `DASHED` : Show as a dashed line.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartlinestylesettings.html#cfn-quicksight-analysis-linechartlinestylesettings-linestyle
         */
        readonly lineStyle?: string;
        /**
         * Configuration option that determines whether to show the line for the series.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartlinestylesettings.html#cfn-quicksight-analysis-linechartlinestylesettings-linevisibility
         */
        readonly lineVisibility?: string;
        /**
         * Width that determines the line thickness.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartlinestylesettings.html#cfn-quicksight-analysis-linechartlinestylesettings-linewidth
         */
        readonly lineWidth?: string;
    }
    /**
     * Marker styles options for a line series in `LineChartVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartmarkerstylesettings.html
     */
    interface LineChartMarkerStyleSettingsProperty {
        /**
         * Color of marker in the series.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartmarkerstylesettings.html#cfn-quicksight-analysis-linechartmarkerstylesettings-markercolor
         */
        readonly markerColor?: string;
        /**
         * Shape option for markers in the series.
         *
         * - `CIRCLE` : Show marker as a circle.
         * - `TRIANGLE` : Show marker as a triangle.
         * - `SQUARE` : Show marker as a square.
         * - `DIAMOND` : Show marker as a diamond.
         * - `ROUNDED_SQUARE` : Show marker as a rounded square.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartmarkerstylesettings.html#cfn-quicksight-analysis-linechartmarkerstylesettings-markershape
         */
        readonly markerShape?: string;
        /**
         * Size of marker in the series.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartmarkerstylesettings.html#cfn-quicksight-analysis-linechartmarkerstylesettings-markersize
         */
        readonly markerSize?: string;
        /**
         * Configuration option that determines whether to show the markers in the series.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartmarkerstylesettings.html#cfn-quicksight-analysis-linechartmarkerstylesettings-markervisibility
         */
        readonly markerVisibility?: string;
    }
    /**
     * The forecast configuration that is used in a line chart's display properties.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastconfiguration.html
     */
    interface ForecastConfigurationProperty {
        /**
         * The forecast properties setup of a forecast in the line chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastconfiguration.html#cfn-quicksight-analysis-forecastconfiguration-forecastproperties
         */
        readonly forecastProperties?: cdk.IResolvable | CfnAnalysis.TimeBasedForecastPropertiesProperty;
        /**
         * The forecast scenario of a forecast in the line chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastconfiguration.html#cfn-quicksight-analysis-forecastconfiguration-scenario
         */
        readonly scenario?: CfnAnalysis.ForecastScenarioProperty | cdk.IResolvable;
    }
    /**
     * The forecast properties setup of a forecast in the line chart.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timebasedforecastproperties.html
     */
    interface TimeBasedForecastPropertiesProperty {
        /**
         * The lower boundary setup of a forecast computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timebasedforecastproperties.html#cfn-quicksight-analysis-timebasedforecastproperties-lowerboundary
         */
        readonly lowerBoundary?: number;
        /**
         * The periods backward setup of a forecast computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timebasedforecastproperties.html#cfn-quicksight-analysis-timebasedforecastproperties-periodsbackward
         */
        readonly periodsBackward?: number;
        /**
         * The periods forward setup of a forecast computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timebasedforecastproperties.html#cfn-quicksight-analysis-timebasedforecastproperties-periodsforward
         */
        readonly periodsForward?: number;
        /**
         * The prediction interval setup of a forecast computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timebasedforecastproperties.html#cfn-quicksight-analysis-timebasedforecastproperties-predictioninterval
         */
        readonly predictionInterval?: number;
        /**
         * The seasonality setup of a forecast computation. Choose one of the following options:.
         *
         * - `NULL` : The input is set to `NULL` .
         * - `NON_NULL` : The input is set to a custom value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timebasedforecastproperties.html#cfn-quicksight-analysis-timebasedforecastproperties-seasonality
         */
        readonly seasonality?: number;
        /**
         * The upper boundary setup of a forecast computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timebasedforecastproperties.html#cfn-quicksight-analysis-timebasedforecastproperties-upperboundary
         */
        readonly upperBoundary?: number;
    }
    /**
     * The forecast scenario of a forecast in the line chart.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastscenario.html
     */
    interface ForecastScenarioProperty {
        /**
         * The what-if analysis forecast setup with the target date.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastscenario.html#cfn-quicksight-analysis-forecastscenario-whatifpointscenario
         */
        readonly whatIfPointScenario?: cdk.IResolvable | CfnAnalysis.WhatIfPointScenarioProperty;
        /**
         * The what-if analysis forecast setup with the date range.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastscenario.html#cfn-quicksight-analysis-forecastscenario-whatifrangescenario
         */
        readonly whatIfRangeScenario?: cdk.IResolvable | CfnAnalysis.WhatIfRangeScenarioProperty;
    }
    /**
     * Provides the forecast to meet the target for a particular date range.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-whatifrangescenario.html
     */
    interface WhatIfRangeScenarioProperty {
        /**
         * The end date in the date range that you need the forecast results for.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-whatifrangescenario.html#cfn-quicksight-analysis-whatifrangescenario-enddate
         */
        readonly endDate: string;
        /**
         * The start date in the date range that you need the forecast results for.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-whatifrangescenario.html#cfn-quicksight-analysis-whatifrangescenario-startdate
         */
        readonly startDate: string;
        /**
         * The target value that you want to meet for the provided date range.
         *
         * @default - 0
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-whatifrangescenario.html#cfn-quicksight-analysis-whatifrangescenario-value
         */
        readonly value: number;
    }
    /**
     * Provides the forecast to meet the target for a particular date.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-whatifpointscenario.html
     */
    interface WhatIfPointScenarioProperty {
        /**
         * The date that you need the forecast results for.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-whatifpointscenario.html#cfn-quicksight-analysis-whatifpointscenario-date
         */
        readonly date: string;
        /**
         * The target value that you want to meet for the provided date.
         *
         * @default - 0
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-whatifpointscenario.html#cfn-quicksight-analysis-whatifpointscenario-value
         */
        readonly value: number;
    }
    /**
     * The series item configuration of a line chart.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-seriesitem.html
     */
    interface SeriesItemProperty {
        /**
         * The data field series item configuration of a line chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-seriesitem.html#cfn-quicksight-analysis-seriesitem-datafieldseriesitem
         */
        readonly dataFieldSeriesItem?: CfnAnalysis.DataFieldSeriesItemProperty | cdk.IResolvable;
        /**
         * The field series item configuration of a line chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-seriesitem.html#cfn-quicksight-analysis-seriesitem-fieldseriesitem
         */
        readonly fieldSeriesItem?: CfnAnalysis.FieldSeriesItemProperty | cdk.IResolvable;
    }
    /**
     * The field series item configuration of a line chart.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldseriesitem.html
     */
    interface FieldSeriesItemProperty {
        /**
         * The axis that you are binding the field to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldseriesitem.html#cfn-quicksight-analysis-fieldseriesitem-axisbinding
         */
        readonly axisBinding: string;
        /**
         * The field ID of the field for which you are setting the axis binding.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldseriesitem.html#cfn-quicksight-analysis-fieldseriesitem-fieldid
         */
        readonly fieldId: string;
        /**
         * The options that determine the presentation of line series associated to the field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldseriesitem.html#cfn-quicksight-analysis-fieldseriesitem-settings
         */
        readonly settings?: cdk.IResolvable | CfnAnalysis.LineChartSeriesSettingsProperty;
    }
    /**
     * The options that determine the presentation of a line series in the visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartseriessettings.html
     */
    interface LineChartSeriesSettingsProperty {
        /**
         * Line styles options for a line series in `LineChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartseriessettings.html#cfn-quicksight-analysis-linechartseriessettings-linestylesettings
         */
        readonly lineStyleSettings?: cdk.IResolvable | CfnAnalysis.LineChartLineStyleSettingsProperty;
        /**
         * Marker styles options for a line series in `LineChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartseriessettings.html#cfn-quicksight-analysis-linechartseriessettings-markerstylesettings
         */
        readonly markerStyleSettings?: cdk.IResolvable | CfnAnalysis.LineChartMarkerStyleSettingsProperty;
    }
    /**
     * The data field series item configuration of a line chart.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datafieldseriesitem.html
     */
    interface DataFieldSeriesItemProperty {
        /**
         * The axis that you are binding the field to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datafieldseriesitem.html#cfn-quicksight-analysis-datafieldseriesitem-axisbinding
         */
        readonly axisBinding: string;
        /**
         * The field ID of the field that you are setting the axis binding to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datafieldseriesitem.html#cfn-quicksight-analysis-datafieldseriesitem-fieldid
         */
        readonly fieldId: string;
        /**
         * The field value of the field that you are setting the axis binding to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datafieldseriesitem.html#cfn-quicksight-analysis-datafieldseriesitem-fieldvalue
         */
        readonly fieldValue?: string;
        /**
         * The options that determine the presentation of line series associated to the field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datafieldseriesitem.html#cfn-quicksight-analysis-datafieldseriesitem-settings
         */
        readonly settings?: cdk.IResolvable | CfnAnalysis.LineChartSeriesSettingsProperty;
    }
    /**
     * The field well configuration of a line chart.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartfieldwells.html
     */
    interface LineChartFieldWellsProperty {
        /**
         * The field well configuration of a line chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartfieldwells.html#cfn-quicksight-analysis-linechartfieldwells-linechartaggregatedfieldwells
         */
        readonly lineChartAggregatedFieldWells?: cdk.IResolvable | CfnAnalysis.LineChartAggregatedFieldWellsProperty;
    }
    /**
     * The field well configuration of a line chart.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartaggregatedfieldwells.html
     */
    interface LineChartAggregatedFieldWellsProperty {
        /**
         * The category field wells of a line chart.
         *
         * Values are grouped by category fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartaggregatedfieldwells.html#cfn-quicksight-analysis-linechartaggregatedfieldwells-category
         */
        readonly category?: Array<CfnAnalysis.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The color field wells of a line chart.
         *
         * Values are grouped by category fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartaggregatedfieldwells.html#cfn-quicksight-analysis-linechartaggregatedfieldwells-colors
         */
        readonly colors?: Array<CfnAnalysis.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The small multiples field well of a line chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartaggregatedfieldwells.html#cfn-quicksight-analysis-linechartaggregatedfieldwells-smallmultiples
         */
        readonly smallMultiples?: Array<CfnAnalysis.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The value field wells of a line chart.
         *
         * Values are aggregated based on categories.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartaggregatedfieldwells.html#cfn-quicksight-analysis-linechartaggregatedfieldwells-values
         */
        readonly values?: Array<cdk.IResolvable | CfnAnalysis.MeasureFieldProperty> | cdk.IResolvable;
    }
    /**
     * An empty visual.
     *
     * Empty visuals are used in layouts but have not been configured to show any data. A new visual created in the Amazon QuickSight console is considered an `EmptyVisual` until a visual type is selected.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-emptyvisual.html
     */
    interface EmptyVisualProperty {
        /**
         * The list of custom actions that are configured for a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-emptyvisual.html#cfn-quicksight-analysis-emptyvisual-actions
         */
        readonly actions?: Array<cdk.IResolvable | CfnAnalysis.VisualCustomActionProperty> | cdk.IResolvable;
        /**
         * The data set that is used in the empty visual.
         *
         * Every visual requires a dataset to render.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-emptyvisual.html#cfn-quicksight-analysis-emptyvisual-datasetidentifier
         */
        readonly dataSetIdentifier: string;
        /**
         * The unique identifier of a visual.
         *
         * This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-emptyvisual.html#cfn-quicksight-analysis-emptyvisual-visualid
         */
        readonly visualId: string;
    }
    /**
     * The declaration definition of a parameter.
     *
     * For more information, see [Parameters in Amazon QuickSight](https://docs.aws.amazon.com/quicksight/latest/user/parameters-in-quicksight.html) in the *Amazon QuickSight User Guide* .
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdeclaration.html
     */
    interface ParameterDeclarationProperty {
        /**
         * A parameter declaration for the `DateTime` data type.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdeclaration.html#cfn-quicksight-analysis-parameterdeclaration-datetimeparameterdeclaration
         */
        readonly dateTimeParameterDeclaration?: CfnAnalysis.DateTimeParameterDeclarationProperty | cdk.IResolvable;
        /**
         * A parameter declaration for the `Decimal` data type.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdeclaration.html#cfn-quicksight-analysis-parameterdeclaration-decimalparameterdeclaration
         */
        readonly decimalParameterDeclaration?: CfnAnalysis.DecimalParameterDeclarationProperty | cdk.IResolvable;
        /**
         * A parameter declaration for the `Integer` data type.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdeclaration.html#cfn-quicksight-analysis-parameterdeclaration-integerparameterdeclaration
         */
        readonly integerParameterDeclaration?: CfnAnalysis.IntegerParameterDeclarationProperty | cdk.IResolvable;
        /**
         * A parameter declaration for the `String` data type.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdeclaration.html#cfn-quicksight-analysis-parameterdeclaration-stringparameterdeclaration
         */
        readonly stringParameterDeclaration?: cdk.IResolvable | CfnAnalysis.StringParameterDeclarationProperty;
    }
    /**
     * A parameter declaration for the `String` data type.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringparameterdeclaration.html
     */
    interface StringParameterDeclarationProperty {
        /**
         * The default values of a parameter.
         *
         * If the parameter is a single-value parameter, a maximum of one default value can be provided.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringparameterdeclaration.html#cfn-quicksight-analysis-stringparameterdeclaration-defaultvalues
         */
        readonly defaultValues?: cdk.IResolvable | CfnAnalysis.StringDefaultValuesProperty;
        /**
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringparameterdeclaration.html#cfn-quicksight-analysis-stringparameterdeclaration-mappeddatasetparameters
         */
        readonly mappedDataSetParameters?: Array<cdk.IResolvable | CfnAnalysis.MappedDataSetParameterProperty> | cdk.IResolvable;
        /**
         * The name of the parameter that is being declared.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringparameterdeclaration.html#cfn-quicksight-analysis-stringparameterdeclaration-name
         */
        readonly name: string;
        /**
         * The value type determines whether the parameter is a single-value or multi-value parameter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringparameterdeclaration.html#cfn-quicksight-analysis-stringparameterdeclaration-parametervaluetype
         */
        readonly parameterValueType: string;
        /**
         * The configuration that defines the default value of a `String` parameter when a value has not been set.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringparameterdeclaration.html#cfn-quicksight-analysis-stringparameterdeclaration-valuewhenunset
         */
        readonly valueWhenUnset?: cdk.IResolvable | CfnAnalysis.StringValueWhenUnsetConfigurationProperty;
    }
    /**
     * A dataset parameter that is mapped to an analysis parameter.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-mappeddatasetparameter.html
     */
    interface MappedDataSetParameterProperty {
        /**
         * A unique name that identifies a dataset within the analysis or dashboard.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-mappeddatasetparameter.html#cfn-quicksight-analysis-mappeddatasetparameter-datasetidentifier
         */
        readonly dataSetIdentifier: string;
        /**
         * The name of the dataset parameter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-mappeddatasetparameter.html#cfn-quicksight-analysis-mappeddatasetparameter-datasetparametername
         */
        readonly dataSetParameterName: string;
    }
    /**
     * The default values of the `StringParameterDeclaration` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringdefaultvalues.html
     */
    interface StringDefaultValuesProperty {
        /**
         * The dynamic value of the `StringDefaultValues` .
         *
         * Different defaults displayed according to users, groups, and values mapping.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringdefaultvalues.html#cfn-quicksight-analysis-stringdefaultvalues-dynamicvalue
         */
        readonly dynamicValue?: CfnAnalysis.DynamicDefaultValueProperty | cdk.IResolvable;
        /**
         * The static values of the `DecimalDefaultValues` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringdefaultvalues.html#cfn-quicksight-analysis-stringdefaultvalues-staticvalues
         */
        readonly staticValues?: Array<string>;
    }
    /**
     * Defines different defaults to the users or groups based on mapping.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-dynamicdefaultvalue.html
     */
    interface DynamicDefaultValueProperty {
        /**
         * The column that contains the default value of each user or group.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-dynamicdefaultvalue.html#cfn-quicksight-analysis-dynamicdefaultvalue-defaultvaluecolumn
         */
        readonly defaultValueColumn: CfnAnalysis.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * The column that contains the group name.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-dynamicdefaultvalue.html#cfn-quicksight-analysis-dynamicdefaultvalue-groupnamecolumn
         */
        readonly groupNameColumn?: CfnAnalysis.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * The column that contains the username.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-dynamicdefaultvalue.html#cfn-quicksight-analysis-dynamicdefaultvalue-usernamecolumn
         */
        readonly userNameColumn?: CfnAnalysis.ColumnIdentifierProperty | cdk.IResolvable;
    }
    /**
     * The configuration that defines the default value of a `String` parameter when a value has not been set.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringvaluewhenunsetconfiguration.html
     */
    interface StringValueWhenUnsetConfigurationProperty {
        /**
         * A custom value that's used when the value of a parameter isn't set.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringvaluewhenunsetconfiguration.html#cfn-quicksight-analysis-stringvaluewhenunsetconfiguration-customvalue
         */
        readonly customValue?: string;
        /**
         * The built-in options for default values. The value can be one of the following:.
         *
         * - `RECOMMENDED` : The recommended value.
         * - `NULL` : The `NULL` value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringvaluewhenunsetconfiguration.html#cfn-quicksight-analysis-stringvaluewhenunsetconfiguration-valuewhenunsetoption
         */
        readonly valueWhenUnsetOption?: string;
    }
    /**
     * A parameter declaration for the `DateTime` data type.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimeparameterdeclaration.html
     */
    interface DateTimeParameterDeclarationProperty {
        /**
         * The default values of a parameter.
         *
         * If the parameter is a single-value parameter, a maximum of one default value can be provided.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimeparameterdeclaration.html#cfn-quicksight-analysis-datetimeparameterdeclaration-defaultvalues
         */
        readonly defaultValues?: CfnAnalysis.DateTimeDefaultValuesProperty | cdk.IResolvable;
        /**
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimeparameterdeclaration.html#cfn-quicksight-analysis-datetimeparameterdeclaration-mappeddatasetparameters
         */
        readonly mappedDataSetParameters?: Array<cdk.IResolvable | CfnAnalysis.MappedDataSetParameterProperty> | cdk.IResolvable;
        /**
         * The name of the parameter that is being declared.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimeparameterdeclaration.html#cfn-quicksight-analysis-datetimeparameterdeclaration-name
         */
        readonly name: string;
        /**
         * The level of time precision that is used to aggregate `DateTime` values.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimeparameterdeclaration.html#cfn-quicksight-analysis-datetimeparameterdeclaration-timegranularity
         */
        readonly timeGranularity?: string;
        /**
         * The configuration that defines the default value of a `DateTime` parameter when a value has not been set.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimeparameterdeclaration.html#cfn-quicksight-analysis-datetimeparameterdeclaration-valuewhenunset
         */
        readonly valueWhenUnset?: CfnAnalysis.DateTimeValueWhenUnsetConfigurationProperty | cdk.IResolvable;
    }
    /**
     * The default values of the `DateTimeParameterDeclaration` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimedefaultvalues.html
     */
    interface DateTimeDefaultValuesProperty {
        /**
         * The dynamic value of the `DataTimeDefaultValues` .
         *
         * Different defaults are displayed according to users, groups, and values mapping.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimedefaultvalues.html#cfn-quicksight-analysis-datetimedefaultvalues-dynamicvalue
         */
        readonly dynamicValue?: CfnAnalysis.DynamicDefaultValueProperty | cdk.IResolvable;
        /**
         * The rolling date of the `DataTimeDefaultValues` .
         *
         * The date is determined from the dataset based on input expression.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimedefaultvalues.html#cfn-quicksight-analysis-datetimedefaultvalues-rollingdate
         */
        readonly rollingDate?: cdk.IResolvable | CfnAnalysis.RollingDateConfigurationProperty;
        /**
         * The static values of the `DataTimeDefaultValues` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimedefaultvalues.html#cfn-quicksight-analysis-datetimedefaultvalues-staticvalues
         */
        readonly staticValues?: Array<string>;
    }
    /**
     * The configuration that defines the default value of a `DateTime` parameter when a value has not been set.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimevaluewhenunsetconfiguration.html
     */
    interface DateTimeValueWhenUnsetConfigurationProperty {
        /**
         * A custom value that's used when the value of a parameter isn't set.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimevaluewhenunsetconfiguration.html#cfn-quicksight-analysis-datetimevaluewhenunsetconfiguration-customvalue
         */
        readonly customValue?: string;
        /**
         * The built-in options for default values. The value can be one of the following:.
         *
         * - `RECOMMENDED` : The recommended value.
         * - `NULL` : The `NULL` value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimevaluewhenunsetconfiguration.html#cfn-quicksight-analysis-datetimevaluewhenunsetconfiguration-valuewhenunsetoption
         */
        readonly valueWhenUnsetOption?: string;
    }
    /**
     * A parameter declaration for the `Decimal` data type.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimalparameterdeclaration.html
     */
    interface DecimalParameterDeclarationProperty {
        /**
         * The default values of a parameter.
         *
         * If the parameter is a single-value parameter, a maximum of one default value can be provided.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimalparameterdeclaration.html#cfn-quicksight-analysis-decimalparameterdeclaration-defaultvalues
         */
        readonly defaultValues?: CfnAnalysis.DecimalDefaultValuesProperty | cdk.IResolvable;
        /**
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimalparameterdeclaration.html#cfn-quicksight-analysis-decimalparameterdeclaration-mappeddatasetparameters
         */
        readonly mappedDataSetParameters?: Array<cdk.IResolvable | CfnAnalysis.MappedDataSetParameterProperty> | cdk.IResolvable;
        /**
         * The name of the parameter that is being declared.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimalparameterdeclaration.html#cfn-quicksight-analysis-decimalparameterdeclaration-name
         */
        readonly name: string;
        /**
         * The value type determines whether the parameter is a single-value or multi-value parameter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimalparameterdeclaration.html#cfn-quicksight-analysis-decimalparameterdeclaration-parametervaluetype
         */
        readonly parameterValueType: string;
        /**
         * The configuration that defines the default value of a `Decimal` parameter when a value has not been set.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimalparameterdeclaration.html#cfn-quicksight-analysis-decimalparameterdeclaration-valuewhenunset
         */
        readonly valueWhenUnset?: CfnAnalysis.DecimalValueWhenUnsetConfigurationProperty | cdk.IResolvable;
    }
    /**
     * The default values of the `DecimalParameterDeclaration` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimaldefaultvalues.html
     */
    interface DecimalDefaultValuesProperty {
        /**
         * The dynamic value of the `DecimalDefaultValues` .
         *
         * Different defaults are displayed according to users, groups, and values mapping.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimaldefaultvalues.html#cfn-quicksight-analysis-decimaldefaultvalues-dynamicvalue
         */
        readonly dynamicValue?: CfnAnalysis.DynamicDefaultValueProperty | cdk.IResolvable;
        /**
         * The static values of the `DecimalDefaultValues` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimaldefaultvalues.html#cfn-quicksight-analysis-decimaldefaultvalues-staticvalues
         */
        readonly staticValues?: Array<number> | cdk.IResolvable;
    }
    /**
     * The configuration that defines the default value of a `Decimal` parameter when a value has not been set.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimalvaluewhenunsetconfiguration.html
     */
    interface DecimalValueWhenUnsetConfigurationProperty {
        /**
         * A custom value that's used when the value of a parameter isn't set.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimalvaluewhenunsetconfiguration.html#cfn-quicksight-analysis-decimalvaluewhenunsetconfiguration-customvalue
         */
        readonly customValue?: number;
        /**
         * The built-in options for default values. The value can be one of the following:.
         *
         * - `RECOMMENDED` : The recommended value.
         * - `NULL` : The `NULL` value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimalvaluewhenunsetconfiguration.html#cfn-quicksight-analysis-decimalvaluewhenunsetconfiguration-valuewhenunsetoption
         */
        readonly valueWhenUnsetOption?: string;
    }
    /**
     * A parameter declaration for the `Integer` data type.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integerparameterdeclaration.html
     */
    interface IntegerParameterDeclarationProperty {
        /**
         * The default values of a parameter.
         *
         * If the parameter is a single-value parameter, a maximum of one default value can be provided.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integerparameterdeclaration.html#cfn-quicksight-analysis-integerparameterdeclaration-defaultvalues
         */
        readonly defaultValues?: CfnAnalysis.IntegerDefaultValuesProperty | cdk.IResolvable;
        /**
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integerparameterdeclaration.html#cfn-quicksight-analysis-integerparameterdeclaration-mappeddatasetparameters
         */
        readonly mappedDataSetParameters?: Array<cdk.IResolvable | CfnAnalysis.MappedDataSetParameterProperty> | cdk.IResolvable;
        /**
         * The name of the parameter that is being declared.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integerparameterdeclaration.html#cfn-quicksight-analysis-integerparameterdeclaration-name
         */
        readonly name: string;
        /**
         * The value type determines whether the parameter is a single-value or multi-value parameter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integerparameterdeclaration.html#cfn-quicksight-analysis-integerparameterdeclaration-parametervaluetype
         */
        readonly parameterValueType: string;
        /**
         * A parameter declaration for the `Integer` data type.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integerparameterdeclaration.html#cfn-quicksight-analysis-integerparameterdeclaration-valuewhenunset
         */
        readonly valueWhenUnset?: CfnAnalysis.IntegerValueWhenUnsetConfigurationProperty | cdk.IResolvable;
    }
    /**
     * The default values of the `IntegerParameterDeclaration` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integerdefaultvalues.html
     */
    interface IntegerDefaultValuesProperty {
        /**
         * The dynamic value of the `IntegerDefaultValues` .
         *
         * Different defaults are displayed according to users, groups, and values mapping.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integerdefaultvalues.html#cfn-quicksight-analysis-integerdefaultvalues-dynamicvalue
         */
        readonly dynamicValue?: CfnAnalysis.DynamicDefaultValueProperty | cdk.IResolvable;
        /**
         * The static values of the `IntegerDefaultValues` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integerdefaultvalues.html#cfn-quicksight-analysis-integerdefaultvalues-staticvalues
         */
        readonly staticValues?: Array<number> | cdk.IResolvable;
    }
    /**
     * A parameter declaration for the `Integer` data type.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integervaluewhenunsetconfiguration.html
     */
    interface IntegerValueWhenUnsetConfigurationProperty {
        /**
         * A custom value that's used when the value of a parameter isn't set.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integervaluewhenunsetconfiguration.html#cfn-quicksight-analysis-integervaluewhenunsetconfiguration-customvalue
         */
        readonly customValue?: number;
        /**
         * The built-in options for default values. The value can be one of the following:.
         *
         * - `RECOMMENDED` : The recommended value.
         * - `NULL` : The `NULL` value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integervaluewhenunsetconfiguration.html#cfn-quicksight-analysis-integervaluewhenunsetconfiguration-valuewhenunsetoption
         */
        readonly valueWhenUnsetOption?: string;
    }
    /**
     * An array of analysis level configurations.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-assetoptions.html
     */
    interface AssetOptionsProperty {
        /**
         * Determines the timezone for the analysis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-assetoptions.html#cfn-quicksight-analysis-assetoptions-timezone
         */
        readonly timezone?: string;
        /**
         * Determines the week start day for an analysis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-assetoptions.html#cfn-quicksight-analysis-assetoptions-weekstart
         */
        readonly weekStart?: string;
    }
    /**
     * Permission for the resource.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-resourcepermission.html
     */
    interface ResourcePermissionProperty {
        /**
         * The IAM action to grant or revoke permissions on.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-resourcepermission.html#cfn-quicksight-analysis-resourcepermission-actions
         */
        readonly actions: Array<string>;
        /**
         * The Amazon Resource Name (ARN) of the principal. This can be one of the following:.
         *
         * - The ARN of an Amazon QuickSight user or group associated with a data source or dataset. (This is common.)
         * - The ARN of an Amazon QuickSight user, group, or namespace associated with an analysis, dashboard, template, or theme. (This is common.)
         * - The ARN of an AWS account root: This is an IAM ARN rather than a Amazon QuickSight ARN. Use this option only to share resources (templates) across AWS accounts . (This is less common.)
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-resourcepermission.html#cfn-quicksight-analysis-resourcepermission-principal
         */
        readonly principal: string;
        /**
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-resourcepermission.html#cfn-quicksight-analysis-resourcepermission-resource
         */
        readonly resource?: string;
    }
    /**
     * Analysis error.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysiserror.html
     */
    interface AnalysisErrorProperty {
        /**
         * The message associated with the analysis error.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysiserror.html#cfn-quicksight-analysis-analysiserror-message
         */
        readonly message?: string;
        /**
         * The type of the analysis error.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysiserror.html#cfn-quicksight-analysis-analysiserror-type
         */
        readonly type?: string;
        /**
         * Lists the violated entities that caused the analysis error.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysiserror.html#cfn-quicksight-analysis-analysiserror-violatedentities
         */
        readonly violatedEntities?: Array<CfnAnalysis.EntityProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * An object, structure, or sub-structure of an analysis, template, or dashboard.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-entity.html
     */
    interface EntityProperty {
        /**
         * The hierarchical path of the entity within the analysis, template, or dashboard definition tree.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-entity.html#cfn-quicksight-analysis-entity-path
         */
        readonly path?: string;
    }
    /**
     * A *sheet* , which is an object that contains a set of visuals that are viewed together on one page in Amazon QuickSight.
     *
     * Every analysis and dashboard contains at least one sheet. Each sheet contains at least one visualization widget, for example a chart, pivot table, or narrative insight. Sheets can be associated with other components, such as controls, filters, and so on.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheet.html
     */
    interface SheetProperty {
        /**
         * The name of a sheet.
         *
         * This name is displayed on the sheet's tab in the Amazon QuickSight console.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheet.html#cfn-quicksight-analysis-sheet-name
         */
        readonly name?: string;
        /**
         * The unique identifier associated with a sheet.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheet.html#cfn-quicksight-analysis-sheet-sheetid
         */
        readonly sheetId?: string;
    }
    /**
     * The option to relax the validation that is required to create and update analyses, dashboards, and templates with definition objects.
     *
     * When you set this value to `LENIENT` , validation is skipped for specific errors.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-validationstrategy.html
     */
    interface ValidationStrategyProperty {
        /**
         * The mode of validation for the asset to be created or updated.
         *
         * When you set this value to `STRICT` , strict validation for every error is enforced. When you set this value to `LENIENT` , validation is skipped for specific UI errors.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-validationstrategy.html#cfn-quicksight-analysis-validationstrategy-mode
         */
        readonly mode: string;
    }
}
/**
 * Properties for defining a `CfnAnalysis`
 *
 * @struct
 * @stability external
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html
 */
export interface CfnAnalysisProps {
    /**
     * The ID for the analysis that you're creating.
     *
     * This ID displays in the URL of the analysis.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-analysisid
     */
    readonly analysisId: string;
    /**
     * The ID of the AWS account where you are creating an analysis.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-awsaccountid
     */
    readonly awsAccountId: string;
    /**
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-definition
     */
    readonly definition?: CfnAnalysis.AnalysisDefinitionProperty | cdk.IResolvable;
    /**
     * Errors associated with the analysis.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-errors
     */
    readonly errors?: Array<CfnAnalysis.AnalysisErrorProperty | cdk.IResolvable> | cdk.IResolvable;
    /**
     * A descriptive name for the analysis that you're creating.
     *
     * This name displays for the analysis in the Amazon QuickSight console.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-name
     */
    readonly name: string;
    /**
     * The parameter names and override values that you want to use.
     *
     * An analysis can have any parameter type, and some parameters might accept multiple values.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-parameters
     */
    readonly parameters?: cdk.IResolvable | CfnAnalysis.ParametersProperty;
    /**
     * A structure that describes the principals and the resource-level permissions on an analysis.
     *
     * You can use the `Permissions` structure to grant permissions by providing a list of AWS Identity and Access Management (IAM) action information for each principal listed by Amazon Resource Name (ARN).
     *
     * To specify no permissions, omit `Permissions` .
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-permissions
     */
    readonly permissions?: Array<cdk.IResolvable | CfnAnalysis.ResourcePermissionProperty> | cdk.IResolvable;
    /**
     * A list of the associated sheets with the unique identifier and name of each sheet.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-sheets
     */
    readonly sheets?: Array<cdk.IResolvable | CfnAnalysis.SheetProperty> | cdk.IResolvable;
    /**
     * A source entity to use for the analysis that you're creating.
     *
     * This metadata structure contains details that describe a source template and one or more datasets.
     *
     * Either a `SourceEntity` or a `Definition` must be provided in order for the request to be valid.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-sourceentity
     */
    readonly sourceEntity?: CfnAnalysis.AnalysisSourceEntityProperty | cdk.IResolvable;
    /**
     * Status associated with the analysis.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-status
     */
    readonly status?: string;
    /**
     * Contains a map of the key-value pairs for the resource tag or tags assigned to the analysis.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-tags
     */
    readonly tags?: Array<cdk.CfnTag>;
    /**
     * The ARN for the theme to apply to the analysis that you're creating.
     *
     * To see the theme in the Amazon QuickSight console, make sure that you have access to it.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-themearn
     */
    readonly themeArn?: string;
    /**
     * The option to relax the validation that is required to create and update analyses, dashboards, and templates with definition objects.
     *
     * When you set this value to `LENIENT` , validation is skipped for specific errors.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-validationstrategy
     */
    readonly validationStrategy?: cdk.IResolvable | CfnAnalysis.ValidationStrategyProperty;
}
/**
 * Creates a dashboard from a template. To first create a template, see the `CreateTemplate` API operation.
 *
 * A dashboard is an entity in Amazon QuickSight that identifies Amazon QuickSight reports, created from analyses. You can share Amazon QuickSight dashboards. With the right permissions, you can create scheduled email reports from them. If you have the correct permissions, you can create a dashboard from a template that exists in a different AWS account .
 *
 * @cloudformationResource AWS::QuickSight::Dashboard
 * @stability external
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html
 */
export declare class CfnDashboard extends cdk.CfnResource implements cdk.IInspectable, cdk.ITaggable {
    /**
     * The CloudFormation resource type name for this resource class.
     */
    static readonly CFN_RESOURCE_TYPE_NAME: string;
    /**
     * Build a CfnDashboard from CloudFormation properties
     *
     * A factory method that creates a new instance of this class from an object
     * containing the CloudFormation properties of this resource.
     * Used in the @aws-cdk/cloudformation-include module.
     *
     * @internal
     */
    static _fromCloudFormation(scope: constructs.Construct, id: string, resourceAttributes: any, options: cfn_parse.FromCloudFormationOptions): CfnDashboard;
    /**
     * The Amazon Resource Name (ARN) of the dashboard.
     *
     * @cloudformationAttribute Arn
     */
    readonly attrArn: string;
    /**
     * The time this dashboard version was created.
     *
     * @cloudformationAttribute CreatedTime
     */
    readonly attrCreatedTime: string;
    /**
     * The time that the dashboard was last published.
     *
     * @cloudformationAttribute LastPublishedTime
     */
    readonly attrLastPublishedTime: string;
    /**
     * The time that the dashboard was last updated.
     *
     * @cloudformationAttribute LastUpdatedTime
     */
    readonly attrLastUpdatedTime: string;
    /**
     * The version of the dashboard.
     *
     * @cloudformationAttribute Version
     */
    readonly attrVersion: cdk.IResolvable;
    /**
     * @cloudformationAttribute Version.Arn
     */
    readonly attrVersionArn: string;
    /**
     * @cloudformationAttribute Version.CreatedTime
     */
    readonly attrVersionCreatedTime: string;
    /**
     * @cloudformationAttribute Version.DataSetArns
     */
    readonly attrVersionDataSetArns: Array<string>;
    /**
     * @cloudformationAttribute Version.Description
     */
    readonly attrVersionDescription: string;
    /**
     * @cloudformationAttribute Version.Errors
     */
    readonly attrVersionErrors: cdk.IResolvable;
    /**
     * @cloudformationAttribute Version.Sheets
     */
    readonly attrVersionSheets: cdk.IResolvable;
    /**
     * @cloudformationAttribute Version.SourceEntityArn
     */
    readonly attrVersionSourceEntityArn: string;
    /**
     * @cloudformationAttribute Version.Status
     */
    readonly attrVersionStatus: string;
    /**
     * @cloudformationAttribute Version.ThemeArn
     */
    readonly attrVersionThemeArn: string;
    /**
     * @cloudformationAttribute Version.VersionNumber
     */
    readonly attrVersionVersionNumber: cdk.IResolvable;
    /**
     * The ID of the AWS account where you want to create the dashboard.
     */
    awsAccountId: string;
    /**
     * The ID for the dashboard, also added to the IAM policy.
     */
    dashboardId: string;
    /**
     * Options for publishing the dashboard when you create it:.
     */
    dashboardPublishOptions?: CfnDashboard.DashboardPublishOptionsProperty | cdk.IResolvable;
    definition?: CfnDashboard.DashboardVersionDefinitionProperty | cdk.IResolvable;
    /**
     * A structure that contains the link sharing configurations that you want to apply overrides to.
     */
    linkSharingConfiguration?: cdk.IResolvable | CfnDashboard.LinkSharingConfigurationProperty;
    /**
     * The display name of the dashboard.
     */
    name: string;
    /**
     * The parameters for the creation of the dashboard, which you want to use to override the default settings.
     */
    parameters?: cdk.IResolvable | CfnDashboard.ParametersProperty;
    /**
     * A structure that contains the permissions of the dashboard.
     */
    permissions?: Array<cdk.IResolvable | CfnDashboard.ResourcePermissionProperty> | cdk.IResolvable;
    /**
     * The entity that you are using as a source when you create the dashboard.
     */
    sourceEntity?: CfnDashboard.DashboardSourceEntityProperty | cdk.IResolvable;
    /**
     * Tag Manager which manages the tags for this resource
     */
    readonly tags: cdk.TagManager;
    /**
     * Contains a map of the key-value pairs for the resource tag or tags assigned to the dashboard.
     */
    tagsRaw?: Array<cdk.CfnTag>;
    /**
     * The Amazon Resource Name (ARN) of the theme that is being used for this dashboard.
     */
    themeArn?: string;
    /**
     * The option to relax the validation that is required to create and update analyses, dashboards, and templates with definition objects.
     */
    validationStrategy?: cdk.IResolvable | CfnDashboard.ValidationStrategyProperty;
    /**
     * A description for the first version of the dashboard being created.
     */
    versionDescription?: string;
    /**
     * @param scope Scope in which this resource is defined
     * @param id Construct identifier for this resource (unique in its scope)
     * @param props Resource properties
     */
    constructor(scope: constructs.Construct, id: string, props: CfnDashboardProps);
    protected get cfnProperties(): Record<string, any>;
    /**
     * Examines the CloudFormation resource and discloses attributes
     *
     * @param inspector tree inspector to collect and process attributes
     */
    inspect(inspector: cdk.TreeInspector): void;
    protected renderProperties(props: Record<string, any>): Record<string, any>;
}
export declare namespace CfnDashboard {
    /**
     * Dashboard publish options.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardpublishoptions.html
     */
    interface DashboardPublishOptionsProperty {
        /**
         * Ad hoc (one-time) filtering option.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardpublishoptions.html#cfn-quicksight-dashboard-dashboardpublishoptions-adhocfilteringoption
         */
        readonly adHocFilteringOption?: CfnDashboard.AdHocFilteringOptionProperty | cdk.IResolvable;
        /**
         * The drill-down options of data points in a dashboard.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardpublishoptions.html#cfn-quicksight-dashboard-dashboardpublishoptions-datapointdrillupdownoption
         */
        readonly dataPointDrillUpDownOption?: CfnDashboard.DataPointDrillUpDownOptionProperty | cdk.IResolvable;
        /**
         * The data point menu label options of a dashboard.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardpublishoptions.html#cfn-quicksight-dashboard-dashboardpublishoptions-datapointmenulabeloption
         */
        readonly dataPointMenuLabelOption?: CfnDashboard.DataPointMenuLabelOptionProperty | cdk.IResolvable;
        /**
         * The data point tool tip options of a dashboard.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardpublishoptions.html#cfn-quicksight-dashboard-dashboardpublishoptions-datapointtooltipoption
         */
        readonly dataPointTooltipOption?: CfnDashboard.DataPointTooltipOptionProperty | cdk.IResolvable;
        /**
         * Export to .csv option.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardpublishoptions.html#cfn-quicksight-dashboard-dashboardpublishoptions-exporttocsvoption
         */
        readonly exportToCsvOption?: CfnDashboard.ExportToCSVOptionProperty | cdk.IResolvable;
        /**
         * Determines if hidden fields are exported with a dashboard.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardpublishoptions.html#cfn-quicksight-dashboard-dashboardpublishoptions-exportwithhiddenfieldsoption
         */
        readonly exportWithHiddenFieldsOption?: CfnDashboard.ExportWithHiddenFieldsOptionProperty | cdk.IResolvable;
        /**
         * Sheet controls option.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardpublishoptions.html#cfn-quicksight-dashboard-dashboardpublishoptions-sheetcontrolsoption
         */
        readonly sheetControlsOption?: cdk.IResolvable | CfnDashboard.SheetControlsOptionProperty;
        /**
         * The sheet layout maximization options of a dashbaord.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardpublishoptions.html#cfn-quicksight-dashboard-dashboardpublishoptions-sheetlayoutelementmaximizationoption
         */
        readonly sheetLayoutElementMaximizationOption?: cdk.IResolvable | CfnDashboard.SheetLayoutElementMaximizationOptionProperty;
        /**
         * The axis sort options of a dashboard.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardpublishoptions.html#cfn-quicksight-dashboard-dashboardpublishoptions-visualaxissortoption
         */
        readonly visualAxisSortOption?: cdk.IResolvable | CfnDashboard.VisualAxisSortOptionProperty;
        /**
         * The menu options of a visual in a dashboard.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardpublishoptions.html#cfn-quicksight-dashboard-dashboardpublishoptions-visualmenuoption
         */
        readonly visualMenuOption?: cdk.IResolvable | CfnDashboard.VisualMenuOptionProperty;
        /**
         * The visual publish options of a visual in a dashboard.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardpublishoptions.html#cfn-quicksight-dashboard-dashboardpublishoptions-visualpublishoptions
         */
        readonly visualPublishOptions?: CfnDashboard.DashboardVisualPublishOptionsProperty | cdk.IResolvable;
    }
    /**
     * Sheet controls option.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetcontrolsoption.html
     */
    interface SheetControlsOptionProperty {
        /**
         * Visibility state.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetcontrolsoption.html#cfn-quicksight-dashboard-sheetcontrolsoption-visibilitystate
         */
        readonly visibilityState?: string;
    }
    /**
     * Export to .csv option.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-exporttocsvoption.html
     */
    interface ExportToCSVOptionProperty {
        /**
         * Availability status.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-exporttocsvoption.html#cfn-quicksight-dashboard-exporttocsvoption-availabilitystatus
         */
        readonly availabilityStatus?: string;
    }
    /**
     * The data point menu options of a dashboard.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapointmenulabeloption.html
     */
    interface DataPointMenuLabelOptionProperty {
        /**
         * The status of the data point menu options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapointmenulabeloption.html#cfn-quicksight-dashboard-datapointmenulabeloption-availabilitystatus
         */
        readonly availabilityStatus?: string;
    }
    /**
     * The drill down options for data points in a dashbaord.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapointdrillupdownoption.html
     */
    interface DataPointDrillUpDownOptionProperty {
        /**
         * The status of the drill down options of data points.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapointdrillupdownoption.html#cfn-quicksight-dashboard-datapointdrillupdownoption-availabilitystatus
         */
        readonly availabilityStatus?: string;
    }
    /**
     * An ad hoc (one-time) filtering option.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-adhocfilteringoption.html
     */
    interface AdHocFilteringOptionProperty {
        /**
         * Availability status.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-adhocfilteringoption.html#cfn-quicksight-dashboard-adhocfilteringoption-availabilitystatus
         */
        readonly availabilityStatus?: string;
    }
    /**
     * The visual publish options of a visual in a dashboard.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardvisualpublishoptions.html
     */
    interface DashboardVisualPublishOptionsProperty {
        /**
         * Determines if hidden fields are included in an exported dashboard.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardvisualpublishoptions.html#cfn-quicksight-dashboard-dashboardvisualpublishoptions-exporthiddenfieldsoption
         */
        readonly exportHiddenFieldsOption?: CfnDashboard.ExportHiddenFieldsOptionProperty | cdk.IResolvable;
    }
    /**
     * Determines if hidden fields are included in an exported dashboard.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-exporthiddenfieldsoption.html
     */
    interface ExportHiddenFieldsOptionProperty {
        /**
         * The status of the export hidden fields options of a dashbaord.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-exporthiddenfieldsoption.html#cfn-quicksight-dashboard-exporthiddenfieldsoption-availabilitystatus
         */
        readonly availabilityStatus?: string;
    }
    /**
     * The menu options for a visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualmenuoption.html
     */
    interface VisualMenuOptionProperty {
        /**
         * The availaiblity status of a visual's menu options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualmenuoption.html#cfn-quicksight-dashboard-visualmenuoption-availabilitystatus
         */
        readonly availabilityStatus?: string;
    }
    /**
     * The data point tooltip options.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapointtooltipoption.html
     */
    interface DataPointTooltipOptionProperty {
        /**
         * The status of the data point tool tip options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapointtooltipoption.html#cfn-quicksight-dashboard-datapointtooltipoption-availabilitystatus
         */
        readonly availabilityStatus?: string;
    }
    /**
     * The axis sort options for a visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualaxissortoption.html
     */
    interface VisualAxisSortOptionProperty {
        /**
         * The availaiblity status of a visual's axis sort options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualaxissortoption.html#cfn-quicksight-dashboard-visualaxissortoption-availabilitystatus
         */
        readonly availabilityStatus?: string;
    }
    /**
     * Determines whether or not hidden fields are visible on exported dashbaords.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-exportwithhiddenfieldsoption.html
     */
    interface ExportWithHiddenFieldsOptionProperty {
        /**
         * The status of the export with hidden fields options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-exportwithhiddenfieldsoption.html#cfn-quicksight-dashboard-exportwithhiddenfieldsoption-availabilitystatus
         */
        readonly availabilityStatus?: string;
    }
    /**
     * The sheet layout maximization options of a dashbaord.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetlayoutelementmaximizationoption.html
     */
    interface SheetLayoutElementMaximizationOptionProperty {
        /**
         * The status of the sheet layout maximization options of a dashbaord.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetlayoutelementmaximizationoption.html#cfn-quicksight-dashboard-sheetlayoutelementmaximizationoption-availabilitystatus
         */
        readonly availabilityStatus?: string;
    }
    /**
     * A list of Amazon QuickSight parameters and the list's override values.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameters.html
     */
    interface ParametersProperty {
        /**
         * The parameters that have a data type of date-time.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameters.html#cfn-quicksight-dashboard-parameters-datetimeparameters
         */
        readonly dateTimeParameters?: Array<CfnDashboard.DateTimeParameterProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The parameters that have a data type of decimal.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameters.html#cfn-quicksight-dashboard-parameters-decimalparameters
         */
        readonly decimalParameters?: Array<CfnDashboard.DecimalParameterProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The parameters that have a data type of integer.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameters.html#cfn-quicksight-dashboard-parameters-integerparameters
         */
        readonly integerParameters?: Array<CfnDashboard.IntegerParameterProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The parameters that have a data type of string.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameters.html#cfn-quicksight-dashboard-parameters-stringparameters
         */
        readonly stringParameters?: Array<cdk.IResolvable | CfnDashboard.StringParameterProperty> | cdk.IResolvable;
    }
    /**
     * A string parameter.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringparameter.html
     */
    interface StringParameterProperty {
        /**
         * A display name for a string parameter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringparameter.html#cfn-quicksight-dashboard-stringparameter-name
         */
        readonly name: string;
        /**
         * The values of a string parameter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringparameter.html#cfn-quicksight-dashboard-stringparameter-values
         */
        readonly values: Array<string>;
    }
    /**
     * A decimal parameter.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimalparameter.html
     */
    interface DecimalParameterProperty {
        /**
         * A display name for the decimal parameter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimalparameter.html#cfn-quicksight-dashboard-decimalparameter-name
         */
        readonly name: string;
        /**
         * The values for the decimal parameter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimalparameter.html#cfn-quicksight-dashboard-decimalparameter-values
         */
        readonly values: Array<number> | cdk.IResolvable;
    }
    /**
     * An integer parameter.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integerparameter.html
     */
    interface IntegerParameterProperty {
        /**
         * The name of the integer parameter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integerparameter.html#cfn-quicksight-dashboard-integerparameter-name
         */
        readonly name: string;
        /**
         * The values for the integer parameter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integerparameter.html#cfn-quicksight-dashboard-integerparameter-values
         */
        readonly values: Array<number> | cdk.IResolvable;
    }
    /**
     * A date-time parameter.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimeparameter.html
     */
    interface DateTimeParameterProperty {
        /**
         * A display name for the date-time parameter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimeparameter.html#cfn-quicksight-dashboard-datetimeparameter-name
         */
        readonly name: string;
        /**
         * The values for the date-time parameter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimeparameter.html#cfn-quicksight-dashboard-datetimeparameter-values
         */
        readonly values: Array<string>;
    }
    /**
     * Dashboard source entity.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardsourceentity.html
     */
    interface DashboardSourceEntityProperty {
        /**
         * Source template.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardsourceentity.html#cfn-quicksight-dashboard-dashboardsourceentity-sourcetemplate
         */
        readonly sourceTemplate?: CfnDashboard.DashboardSourceTemplateProperty | cdk.IResolvable;
    }
    /**
     * Dashboard source template.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardsourcetemplate.html
     */
    interface DashboardSourceTemplateProperty {
        /**
         * The Amazon Resource Name (ARN) of the resource.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardsourcetemplate.html#cfn-quicksight-dashboard-dashboardsourcetemplate-arn
         */
        readonly arn: string;
        /**
         * Dataset references.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardsourcetemplate.html#cfn-quicksight-dashboard-dashboardsourcetemplate-datasetreferences
         */
        readonly dataSetReferences: Array<CfnDashboard.DataSetReferenceProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * Dataset reference.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datasetreference.html
     */
    interface DataSetReferenceProperty {
        /**
         * Dataset Amazon Resource Name (ARN).
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datasetreference.html#cfn-quicksight-dashboard-datasetreference-datasetarn
         */
        readonly dataSetArn: string;
        /**
         * Dataset placeholder.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datasetreference.html#cfn-quicksight-dashboard-datasetreference-datasetplaceholder
         */
        readonly dataSetPlaceholder: string;
    }
    /**
     * The contents of a dashboard.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversiondefinition.html
     */
    interface DashboardVersionDefinitionProperty {
        /**
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversiondefinition.html#cfn-quicksight-dashboard-dashboardversiondefinition-analysisdefaults
         */
        readonly analysisDefaults?: CfnDashboard.AnalysisDefaultsProperty | cdk.IResolvable;
        /**
         * An array of calculated field definitions for the dashboard.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversiondefinition.html#cfn-quicksight-dashboard-dashboardversiondefinition-calculatedfields
         */
        readonly calculatedFields?: Array<CfnDashboard.CalculatedFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * An array of dashboard-level column configurations.
         *
         * Column configurations are used to set the default formatting for a column that is used throughout a dashboard.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversiondefinition.html#cfn-quicksight-dashboard-dashboardversiondefinition-columnconfigurations
         */
        readonly columnConfigurations?: Array<CfnDashboard.ColumnConfigurationProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * An array of dataset identifier declarations.
         *
         * With this mapping,you can use dataset identifiers instead of dataset Amazon Resource Names (ARNs) throughout the dashboard's sub-structures.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversiondefinition.html#cfn-quicksight-dashboard-dashboardversiondefinition-datasetidentifierdeclarations
         */
        readonly dataSetIdentifierDeclarations: Array<CfnDashboard.DataSetIdentifierDeclarationProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The filter definitions for a dashboard.
         *
         * For more information, see [Filtering Data in Amazon QuickSight](https://docs.aws.amazon.com/quicksight/latest/user/adding-a-filter.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversiondefinition.html#cfn-quicksight-dashboard-dashboardversiondefinition-filtergroups
         */
        readonly filterGroups?: Array<CfnDashboard.FilterGroupProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * An array of option definitions for a dashboard.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversiondefinition.html#cfn-quicksight-dashboard-dashboardversiondefinition-options
         */
        readonly options?: CfnDashboard.AssetOptionsProperty | cdk.IResolvable;
        /**
         * The parameter declarations for a dashboard.
         *
         * Parameters are named variables that can transfer a value for use by an action or an object.
         *
         * For more information, see [Parameters in Amazon QuickSight](https://docs.aws.amazon.com/quicksight/latest/user/parameters-in-quicksight.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversiondefinition.html#cfn-quicksight-dashboard-dashboardversiondefinition-parameterdeclarations
         */
        readonly parameterDeclarations?: Array<cdk.IResolvable | CfnDashboard.ParameterDeclarationProperty> | cdk.IResolvable;
        /**
         * An array of sheet definitions for a dashboard.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversiondefinition.html#cfn-quicksight-dashboard-dashboardversiondefinition-sheets
         */
        readonly sheets?: Array<cdk.IResolvable | CfnDashboard.SheetDefinitionProperty> | cdk.IResolvable;
    }
    /**
     * A grouping of individual filters. Filter groups are applied to the same group of visuals.
     *
     * For more information, see [Adding filter conditions (group filters) with AND and OR operators](https://docs.aws.amazon.com/quicksight/latest/user/add-a-compound-filter.html) in the *Amazon QuickSight User Guide* .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtergroup.html
     */
    interface FilterGroupProperty {
        /**
         * The filter new feature which can apply filter group to all data sets. Choose one of the following options:.
         *
         * - `ALL_DATASETS`
         * - `SINGLE_DATASET`
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtergroup.html#cfn-quicksight-dashboard-filtergroup-crossdataset
         */
        readonly crossDataset: string;
        /**
         * The value that uniquely identifies a `FilterGroup` within a dashboard, template, or analysis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtergroup.html#cfn-quicksight-dashboard-filtergroup-filtergroupid
         */
        readonly filterGroupId: string;
        /**
         * The list of filters that are present in a `FilterGroup` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtergroup.html#cfn-quicksight-dashboard-filtergroup-filters
         */
        readonly filters: Array<CfnDashboard.FilterProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The configuration that specifies what scope to apply to a `FilterGroup` .
         *
         * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtergroup.html#cfn-quicksight-dashboard-filtergroup-scopeconfiguration
         */
        readonly scopeConfiguration: CfnDashboard.FilterScopeConfigurationProperty | cdk.IResolvable;
        /**
         * The status of the `FilterGroup` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtergroup.html#cfn-quicksight-dashboard-filtergroup-status
         */
        readonly status?: string;
    }
    /**
     * With a `Filter` , you can remove portions of data from a particular visual or view.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filter.html
     */
    interface FilterProperty {
        /**
         * A `CategoryFilter` filters text values.
         *
         * For more information, see [Adding text filters](https://docs.aws.amazon.com/quicksight/latest/user/add-a-text-filter-data-prep.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filter.html#cfn-quicksight-dashboard-filter-categoryfilter
         */
        readonly categoryFilter?: CfnDashboard.CategoryFilterProperty | cdk.IResolvable;
        /**
         * A `NumericEqualityFilter` filters numeric values that equal or do not equal a given numeric value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filter.html#cfn-quicksight-dashboard-filter-numericequalityfilter
         */
        readonly numericEqualityFilter?: cdk.IResolvable | CfnDashboard.NumericEqualityFilterProperty;
        /**
         * A `NumericRangeFilter` filters numeric values that are either inside or outside a given numeric range.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filter.html#cfn-quicksight-dashboard-filter-numericrangefilter
         */
        readonly numericRangeFilter?: cdk.IResolvable | CfnDashboard.NumericRangeFilterProperty;
        /**
         * A `RelativeDatesFilter` filters date values that are relative to a given date.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filter.html#cfn-quicksight-dashboard-filter-relativedatesfilter
         */
        readonly relativeDatesFilter?: cdk.IResolvable | CfnDashboard.RelativeDatesFilterProperty;
        /**
         * A `TimeEqualityFilter` filters date-time values that equal or do not equal a given date/time value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filter.html#cfn-quicksight-dashboard-filter-timeequalityfilter
         */
        readonly timeEqualityFilter?: cdk.IResolvable | CfnDashboard.TimeEqualityFilterProperty;
        /**
         * A `TimeRangeFilter` filters date-time values that are either inside or outside a given date/time range.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filter.html#cfn-quicksight-dashboard-filter-timerangefilter
         */
        readonly timeRangeFilter?: cdk.IResolvable | CfnDashboard.TimeRangeFilterProperty;
        /**
         * A `TopBottomFilter` filters data to the top or bottom values for a given column.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filter.html#cfn-quicksight-dashboard-filter-topbottomfilter
         */
        readonly topBottomFilter?: cdk.IResolvable | CfnDashboard.TopBottomFilterProperty;
    }
    /**
     * A `NumericEqualityFilter` filters values that are equal to the specified value.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericequalityfilter.html
     */
    interface NumericEqualityFilterProperty {
        /**
         * The aggregation function of the filter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericequalityfilter.html#cfn-quicksight-dashboard-numericequalityfilter-aggregationfunction
         */
        readonly aggregationFunction?: CfnDashboard.AggregationFunctionProperty | cdk.IResolvable;
        /**
         * The column that the filter is applied to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericequalityfilter.html#cfn-quicksight-dashboard-numericequalityfilter-column
         */
        readonly column: CfnDashboard.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericequalityfilter.html#cfn-quicksight-dashboard-numericequalityfilter-filterid
         */
        readonly filterId: string;
        /**
         * The match operator that is used to determine if a filter should be applied.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericequalityfilter.html#cfn-quicksight-dashboard-numericequalityfilter-matchoperator
         */
        readonly matchOperator: string;
        /**
         * This option determines how null values should be treated when filtering data.
         *
         * - `ALL_VALUES` : Include null values in filtered results.
         * - `NULLS_ONLY` : Only include null values in filtered results.
         * - `NON_NULLS_ONLY` : Exclude null values from filtered results.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericequalityfilter.html#cfn-quicksight-dashboard-numericequalityfilter-nulloption
         */
        readonly nullOption: string;
        /**
         * The parameter whose value should be used for the filter value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericequalityfilter.html#cfn-quicksight-dashboard-numericequalityfilter-parametername
         */
        readonly parameterName?: string;
        /**
         * Select all of the values. Null is not the assigned value of select all.
         *
         * - `FILTER_ALL_VALUES`
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericequalityfilter.html#cfn-quicksight-dashboard-numericequalityfilter-selectalloptions
         */
        readonly selectAllOptions?: string;
        /**
         * The input value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericequalityfilter.html#cfn-quicksight-dashboard-numericequalityfilter-value
         */
        readonly value?: number;
    }
    /**
     * An aggregation function aggregates values from a dimension or measure.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-aggregationfunction.html
     */
    interface AggregationFunctionProperty {
        /**
         * Aggregation for attributes.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-aggregationfunction.html#cfn-quicksight-dashboard-aggregationfunction-attributeaggregationfunction
         */
        readonly attributeAggregationFunction?: CfnDashboard.AttributeAggregationFunctionProperty | cdk.IResolvable;
        /**
         * Aggregation for categorical values.
         *
         * - `COUNT` : Aggregate by the total number of values, including duplicates.
         * - `DISTINCT_COUNT` : Aggregate by the total number of distinct values.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-aggregationfunction.html#cfn-quicksight-dashboard-aggregationfunction-categoricalaggregationfunction
         */
        readonly categoricalAggregationFunction?: string;
        /**
         * Aggregation for date values.
         *
         * - `COUNT` : Aggregate by the total number of values, including duplicates.
         * - `DISTINCT_COUNT` : Aggregate by the total number of distinct values.
         * - `MIN` : Select the smallest date value.
         * - `MAX` : Select the largest date value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-aggregationfunction.html#cfn-quicksight-dashboard-aggregationfunction-dateaggregationfunction
         */
        readonly dateAggregationFunction?: string;
        /**
         * Aggregation for numerical values.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-aggregationfunction.html#cfn-quicksight-dashboard-aggregationfunction-numericalaggregationfunction
         */
        readonly numericalAggregationFunction?: cdk.IResolvable | CfnDashboard.NumericalAggregationFunctionProperty;
    }
    /**
     * Aggregation for attributes.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-attributeaggregationfunction.html
     */
    interface AttributeAggregationFunctionProperty {
        /**
         * The built-in aggregation functions for attributes.
         *
         * - `UNIQUE_VALUE` : Returns the unique value for a field, aggregated by the dimension fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-attributeaggregationfunction.html#cfn-quicksight-dashboard-attributeaggregationfunction-simpleattributeaggregation
         */
        readonly simpleAttributeAggregation?: string;
        /**
         * Used by the `UNIQUE_VALUE` aggregation function.
         *
         * If there are multiple values for the field used by the aggregation, the value for this property will be returned instead. Defaults to '*'.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-attributeaggregationfunction.html#cfn-quicksight-dashboard-attributeaggregationfunction-valueformultiplevalues
         */
        readonly valueForMultipleValues?: string;
    }
    /**
     * Aggregation for numerical values.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericalaggregationfunction.html
     */
    interface NumericalAggregationFunctionProperty {
        /**
         * An aggregation based on the percentile of values in a dimension or measure.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericalaggregationfunction.html#cfn-quicksight-dashboard-numericalaggregationfunction-percentileaggregation
         */
        readonly percentileAggregation?: cdk.IResolvable | CfnDashboard.PercentileAggregationProperty;
        /**
         * Built-in aggregation functions for numerical values.
         *
         * - `SUM` : The sum of a dimension or measure.
         * - `AVERAGE` : The average of a dimension or measure.
         * - `MIN` : The minimum value of a dimension or measure.
         * - `MAX` : The maximum value of a dimension or measure.
         * - `COUNT` : The count of a dimension or measure.
         * - `DISTINCT_COUNT` : The count of distinct values in a dimension or measure.
         * - `VAR` : The variance of a dimension or measure.
         * - `VARP` : The partitioned variance of a dimension or measure.
         * - `STDEV` : The standard deviation of a dimension or measure.
         * - `STDEVP` : The partitioned standard deviation of a dimension or measure.
         * - `MEDIAN` : The median value of a dimension or measure.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericalaggregationfunction.html#cfn-quicksight-dashboard-numericalaggregationfunction-simplenumericalaggregation
         */
        readonly simpleNumericalAggregation?: string;
    }
    /**
     * An aggregation based on the percentile of values in a dimension or measure.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-percentileaggregation.html
     */
    interface PercentileAggregationProperty {
        /**
         * The percentile value.
         *
         * This value can be any numeric constant 0–100. A percentile value of 50 computes the median value of the measure.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-percentileaggregation.html#cfn-quicksight-dashboard-percentileaggregation-percentilevalue
         */
        readonly percentileValue?: number;
    }
    /**
     * A column of a data set.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnidentifier.html
     */
    interface ColumnIdentifierProperty {
        /**
         * The name of the column.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnidentifier.html#cfn-quicksight-dashboard-columnidentifier-columnname
         */
        readonly columnName: string;
        /**
         * The data set that the column belongs to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnidentifier.html#cfn-quicksight-dashboard-columnidentifier-datasetidentifier
         */
        readonly dataSetIdentifier: string;
    }
    /**
     * A `NumericRangeFilter` filters values that are within the value range.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericrangefilter.html
     */
    interface NumericRangeFilterProperty {
        /**
         * The aggregation function of the filter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericrangefilter.html#cfn-quicksight-dashboard-numericrangefilter-aggregationfunction
         */
        readonly aggregationFunction?: CfnDashboard.AggregationFunctionProperty | cdk.IResolvable;
        /**
         * The column that the filter is applied to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericrangefilter.html#cfn-quicksight-dashboard-numericrangefilter-column
         */
        readonly column: CfnDashboard.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericrangefilter.html#cfn-quicksight-dashboard-numericrangefilter-filterid
         */
        readonly filterId: string;
        /**
         * Determines whether the maximum value in the filter value range should be included in the filtered results.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericrangefilter.html#cfn-quicksight-dashboard-numericrangefilter-includemaximum
         */
        readonly includeMaximum?: boolean | cdk.IResolvable;
        /**
         * Determines whether the minimum value in the filter value range should be included in the filtered results.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericrangefilter.html#cfn-quicksight-dashboard-numericrangefilter-includeminimum
         */
        readonly includeMinimum?: boolean | cdk.IResolvable;
        /**
         * This option determines how null values should be treated when filtering data.
         *
         * - `ALL_VALUES` : Include null values in filtered results.
         * - `NULLS_ONLY` : Only include null values in filtered results.
         * - `NON_NULLS_ONLY` : Exclude null values from filtered results.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericrangefilter.html#cfn-quicksight-dashboard-numericrangefilter-nulloption
         */
        readonly nullOption: string;
        /**
         * The maximum value for the filter value range.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericrangefilter.html#cfn-quicksight-dashboard-numericrangefilter-rangemaximum
         */
        readonly rangeMaximum?: cdk.IResolvable | CfnDashboard.NumericRangeFilterValueProperty;
        /**
         * The minimum value for the filter value range.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericrangefilter.html#cfn-quicksight-dashboard-numericrangefilter-rangeminimum
         */
        readonly rangeMinimum?: cdk.IResolvable | CfnDashboard.NumericRangeFilterValueProperty;
        /**
         * Select all of the values. Null is not the assigned value of select all.
         *
         * - `FILTER_ALL_VALUES`
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericrangefilter.html#cfn-quicksight-dashboard-numericrangefilter-selectalloptions
         */
        readonly selectAllOptions?: string;
    }
    /**
     * The value input pf the numeric range filter.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericrangefiltervalue.html
     */
    interface NumericRangeFilterValueProperty {
        /**
         * The parameter that is used in the numeric range.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericrangefiltervalue.html#cfn-quicksight-dashboard-numericrangefiltervalue-parameter
         */
        readonly parameter?: string;
        /**
         * The static value of the numeric range filter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericrangefiltervalue.html#cfn-quicksight-dashboard-numericrangefiltervalue-staticvalue
         */
        readonly staticValue?: number;
    }
    /**
     * A `TimeRangeFilter` filters values that are between two specified values.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangefilter.html
     */
    interface TimeRangeFilterProperty {
        /**
         * The column that the filter is applied to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangefilter.html#cfn-quicksight-dashboard-timerangefilter-column
         */
        readonly column: CfnDashboard.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * The exclude period of the time range filter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangefilter.html#cfn-quicksight-dashboard-timerangefilter-excludeperiodconfiguration
         */
        readonly excludePeriodConfiguration?: CfnDashboard.ExcludePeriodConfigurationProperty | cdk.IResolvable;
        /**
         * An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangefilter.html#cfn-quicksight-dashboard-timerangefilter-filterid
         */
        readonly filterId: string;
        /**
         * Determines whether the maximum value in the filter value range should be included in the filtered results.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangefilter.html#cfn-quicksight-dashboard-timerangefilter-includemaximum
         */
        readonly includeMaximum?: boolean | cdk.IResolvable;
        /**
         * Determines whether the minimum value in the filter value range should be included in the filtered results.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangefilter.html#cfn-quicksight-dashboard-timerangefilter-includeminimum
         */
        readonly includeMinimum?: boolean | cdk.IResolvable;
        /**
         * This option determines how null values should be treated when filtering data.
         *
         * - `ALL_VALUES` : Include null values in filtered results.
         * - `NULLS_ONLY` : Only include null values in filtered results.
         * - `NON_NULLS_ONLY` : Exclude null values from filtered results.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangefilter.html#cfn-quicksight-dashboard-timerangefilter-nulloption
         */
        readonly nullOption: string;
        /**
         * The maximum value for the filter value range.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangefilter.html#cfn-quicksight-dashboard-timerangefilter-rangemaximumvalue
         */
        readonly rangeMaximumValue?: cdk.IResolvable | CfnDashboard.TimeRangeFilterValueProperty;
        /**
         * The minimum value for the filter value range.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangefilter.html#cfn-quicksight-dashboard-timerangefilter-rangeminimumvalue
         */
        readonly rangeMinimumValue?: cdk.IResolvable | CfnDashboard.TimeRangeFilterValueProperty;
        /**
         * The level of time precision that is used to aggregate `DateTime` values.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangefilter.html#cfn-quicksight-dashboard-timerangefilter-timegranularity
         */
        readonly timeGranularity?: string;
    }
    /**
     * The value of a time range filter.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangefiltervalue.html
     */
    interface TimeRangeFilterValueProperty {
        /**
         * The parameter type input value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangefiltervalue.html#cfn-quicksight-dashboard-timerangefiltervalue-parameter
         */
        readonly parameter?: string;
        /**
         * The rolling date input value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangefiltervalue.html#cfn-quicksight-dashboard-timerangefiltervalue-rollingdate
         */
        readonly rollingDate?: cdk.IResolvable | CfnDashboard.RollingDateConfigurationProperty;
        /**
         * The static input value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangefiltervalue.html#cfn-quicksight-dashboard-timerangefiltervalue-staticvalue
         */
        readonly staticValue?: string;
    }
    /**
     * The rolling date configuration of a date time filter.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-rollingdateconfiguration.html
     */
    interface RollingDateConfigurationProperty {
        /**
         * The data set that is used in the rolling date configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-rollingdateconfiguration.html#cfn-quicksight-dashboard-rollingdateconfiguration-datasetidentifier
         */
        readonly dataSetIdentifier?: string;
        /**
         * The expression of the rolling date configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-rollingdateconfiguration.html#cfn-quicksight-dashboard-rollingdateconfiguration-expression
         */
        readonly expression: string;
    }
    /**
     * The exclude period of `TimeRangeFilter` or `RelativeDatesFilter` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-excludeperiodconfiguration.html
     */
    interface ExcludePeriodConfigurationProperty {
        /**
         * The amount or number of the exclude period.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-excludeperiodconfiguration.html#cfn-quicksight-dashboard-excludeperiodconfiguration-amount
         */
        readonly amount: number;
        /**
         * The granularity or unit (day, month, year) of the exclude period.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-excludeperiodconfiguration.html#cfn-quicksight-dashboard-excludeperiodconfiguration-granularity
         */
        readonly granularity: string;
        /**
         * The status of the exclude period. Choose from the following options:.
         *
         * - `ENABLED`
         * - `DISABLED`
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-excludeperiodconfiguration.html#cfn-quicksight-dashboard-excludeperiodconfiguration-status
         */
        readonly status?: string;
    }
    /**
     * A `RelativeDatesFilter` filters relative dates values.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-relativedatesfilter.html
     */
    interface RelativeDatesFilterProperty {
        /**
         * The date configuration of the filter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-relativedatesfilter.html#cfn-quicksight-dashboard-relativedatesfilter-anchordateconfiguration
         */
        readonly anchorDateConfiguration: CfnDashboard.AnchorDateConfigurationProperty | cdk.IResolvable;
        /**
         * The column that the filter is applied to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-relativedatesfilter.html#cfn-quicksight-dashboard-relativedatesfilter-column
         */
        readonly column: CfnDashboard.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * The configuration for the exclude period of the filter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-relativedatesfilter.html#cfn-quicksight-dashboard-relativedatesfilter-excludeperiodconfiguration
         */
        readonly excludePeriodConfiguration?: CfnDashboard.ExcludePeriodConfigurationProperty | cdk.IResolvable;
        /**
         * An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-relativedatesfilter.html#cfn-quicksight-dashboard-relativedatesfilter-filterid
         */
        readonly filterId: string;
        /**
         * The minimum granularity (period granularity) of the relative dates filter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-relativedatesfilter.html#cfn-quicksight-dashboard-relativedatesfilter-minimumgranularity
         */
        readonly minimumGranularity?: string;
        /**
         * This option determines how null values should be treated when filtering data.
         *
         * - `ALL_VALUES` : Include null values in filtered results.
         * - `NULLS_ONLY` : Only include null values in filtered results.
         * - `NON_NULLS_ONLY` : Exclude null values from filtered results.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-relativedatesfilter.html#cfn-quicksight-dashboard-relativedatesfilter-nulloption
         */
        readonly nullOption: string;
        /**
         * The parameter whose value should be used for the filter value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-relativedatesfilter.html#cfn-quicksight-dashboard-relativedatesfilter-parametername
         */
        readonly parameterName?: string;
        /**
         * The range date type of the filter. Choose one of the options below:.
         *
         * - `PREVIOUS`
         * - `THIS`
         * - `LAST`
         * - `NOW`
         * - `NEXT`
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-relativedatesfilter.html#cfn-quicksight-dashboard-relativedatesfilter-relativedatetype
         */
        readonly relativeDateType: string;
        /**
         * The date value of the filter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-relativedatesfilter.html#cfn-quicksight-dashboard-relativedatesfilter-relativedatevalue
         */
        readonly relativeDateValue?: number;
        /**
         * The level of time precision that is used to aggregate `DateTime` values.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-relativedatesfilter.html#cfn-quicksight-dashboard-relativedatesfilter-timegranularity
         */
        readonly timeGranularity: string;
    }
    /**
     * The date configuration of the filter.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-anchordateconfiguration.html
     */
    interface AnchorDateConfigurationProperty {
        /**
         * The options for the date configuration. Choose one of the options below:.
         *
         * - `NOW`
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-anchordateconfiguration.html#cfn-quicksight-dashboard-anchordateconfiguration-anchoroption
         */
        readonly anchorOption?: string;
        /**
         * The name of the parameter that is used for the anchor date configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-anchordateconfiguration.html#cfn-quicksight-dashboard-anchordateconfiguration-parametername
         */
        readonly parameterName?: string;
    }
    /**
     * A `TopBottomFilter` filters values that are at the top or the bottom.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottomfilter.html
     */
    interface TopBottomFilterProperty {
        /**
         * The aggregation and sort configuration of the top bottom filter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottomfilter.html#cfn-quicksight-dashboard-topbottomfilter-aggregationsortconfigurations
         */
        readonly aggregationSortConfigurations: Array<CfnDashboard.AggregationSortConfigurationProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The column that the filter is applied to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottomfilter.html#cfn-quicksight-dashboard-topbottomfilter-column
         */
        readonly column: CfnDashboard.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottomfilter.html#cfn-quicksight-dashboard-topbottomfilter-filterid
         */
        readonly filterId: string;
        /**
         * The number of items to include in the top bottom filter results.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottomfilter.html#cfn-quicksight-dashboard-topbottomfilter-limit
         */
        readonly limit?: number;
        /**
         * The parameter whose value should be used for the filter value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottomfilter.html#cfn-quicksight-dashboard-topbottomfilter-parametername
         */
        readonly parameterName?: string;
        /**
         * The level of time precision that is used to aggregate `DateTime` values.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottomfilter.html#cfn-quicksight-dashboard-topbottomfilter-timegranularity
         */
        readonly timeGranularity?: string;
    }
    /**
     * The configuration options to sort aggregated values.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-aggregationsortconfiguration.html
     */
    interface AggregationSortConfigurationProperty {
        /**
         * The function that aggregates the values in `Column` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-aggregationsortconfiguration.html#cfn-quicksight-dashboard-aggregationsortconfiguration-aggregationfunction
         */
        readonly aggregationFunction?: CfnDashboard.AggregationFunctionProperty | cdk.IResolvable;
        /**
         * The column that determines the sort order of aggregated values.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-aggregationsortconfiguration.html#cfn-quicksight-dashboard-aggregationsortconfiguration-column
         */
        readonly column: CfnDashboard.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * The sort direction of values.
         *
         * - `ASC` : Sort in ascending order.
         * - `DESC` : Sort in descending order.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-aggregationsortconfiguration.html#cfn-quicksight-dashboard-aggregationsortconfiguration-sortdirection
         */
        readonly sortDirection: string;
    }
    /**
     * A `TimeEqualityFilter` filters values that are equal to a given value.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timeequalityfilter.html
     */
    interface TimeEqualityFilterProperty {
        /**
         * The column that the filter is applied to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timeequalityfilter.html#cfn-quicksight-dashboard-timeequalityfilter-column
         */
        readonly column: CfnDashboard.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timeequalityfilter.html#cfn-quicksight-dashboard-timeequalityfilter-filterid
         */
        readonly filterId: string;
        /**
         * The parameter whose value should be used for the filter value.
         *
         * This field is mutually exclusive to `Value` and `RollingDate` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timeequalityfilter.html#cfn-quicksight-dashboard-timeequalityfilter-parametername
         */
        readonly parameterName?: string;
        /**
         * The rolling date input for the `TimeEquality` filter.
         *
         * This field is mutually exclusive to `Value` and `ParameterName` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timeequalityfilter.html#cfn-quicksight-dashboard-timeequalityfilter-rollingdate
         */
        readonly rollingDate?: cdk.IResolvable | CfnDashboard.RollingDateConfigurationProperty;
        /**
         * The level of time precision that is used to aggregate `DateTime` values.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timeequalityfilter.html#cfn-quicksight-dashboard-timeequalityfilter-timegranularity
         */
        readonly timeGranularity?: string;
        /**
         * The value of a `TimeEquality` filter.
         *
         * This field is mutually exclusive to `RollingDate` and `ParameterName` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timeequalityfilter.html#cfn-quicksight-dashboard-timeequalityfilter-value
         */
        readonly value?: string;
    }
    /**
     * A `CategoryFilter` filters text values.
     *
     * For more information, see [Adding text filters](https://docs.aws.amazon.com/quicksight/latest/user/add-a-text-filter-data-prep.html) in the *Amazon QuickSight User Guide* .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoryfilter.html
     */
    interface CategoryFilterProperty {
        /**
         * The column that the filter is applied to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoryfilter.html#cfn-quicksight-dashboard-categoryfilter-column
         */
        readonly column: CfnDashboard.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * The configuration for a `CategoryFilter` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoryfilter.html#cfn-quicksight-dashboard-categoryfilter-configuration
         */
        readonly configuration: CfnDashboard.CategoryFilterConfigurationProperty | cdk.IResolvable;
        /**
         * An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoryfilter.html#cfn-quicksight-dashboard-categoryfilter-filterid
         */
        readonly filterId: string;
    }
    /**
     * The configuration for a `CategoryFilter` .
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoryfilterconfiguration.html
     */
    interface CategoryFilterConfigurationProperty {
        /**
         * A custom filter that filters based on a single value.
         *
         * This filter can be partially matched.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoryfilterconfiguration.html#cfn-quicksight-dashboard-categoryfilterconfiguration-customfilterconfiguration
         */
        readonly customFilterConfiguration?: CfnDashboard.CustomFilterConfigurationProperty | cdk.IResolvable;
        /**
         * A list of custom filter values.
         *
         * In the Amazon QuickSight console, this filter type is called a custom filter list.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoryfilterconfiguration.html#cfn-quicksight-dashboard-categoryfilterconfiguration-customfilterlistconfiguration
         */
        readonly customFilterListConfiguration?: CfnDashboard.CustomFilterListConfigurationProperty | cdk.IResolvable;
        /**
         * A list of filter configurations.
         *
         * In the Amazon QuickSight console, this filter type is called a filter list.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoryfilterconfiguration.html#cfn-quicksight-dashboard-categoryfilterconfiguration-filterlistconfiguration
         */
        readonly filterListConfiguration?: CfnDashboard.FilterListConfigurationProperty | cdk.IResolvable;
    }
    /**
     * A list of custom filter values.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customfilterlistconfiguration.html
     */
    interface CustomFilterListConfigurationProperty {
        /**
         * The list of category values for the filter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customfilterlistconfiguration.html#cfn-quicksight-dashboard-customfilterlistconfiguration-categoryvalues
         */
        readonly categoryValues?: Array<string>;
        /**
         * The match operator that is used to determine if a filter should be applied.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customfilterlistconfiguration.html#cfn-quicksight-dashboard-customfilterlistconfiguration-matchoperator
         */
        readonly matchOperator: string;
        /**
         * This option determines how null values should be treated when filtering data.
         *
         * - `ALL_VALUES` : Include null values in filtered results.
         * - `NULLS_ONLY` : Only include null values in filtered results.
         * - `NON_NULLS_ONLY` : Exclude null values from filtered results.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customfilterlistconfiguration.html#cfn-quicksight-dashboard-customfilterlistconfiguration-nulloption
         */
        readonly nullOption: string;
        /**
         * Select all of the values. Null is not the assigned value of select all.
         *
         * - `FILTER_ALL_VALUES`
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customfilterlistconfiguration.html#cfn-quicksight-dashboard-customfilterlistconfiguration-selectalloptions
         */
        readonly selectAllOptions?: string;
    }
    /**
     * A custom filter that filters based on a single value.
     *
     * This filter can be partially matched.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customfilterconfiguration.html
     */
    interface CustomFilterConfigurationProperty {
        /**
         * The category value for the filter.
         *
         * This field is mutually exclusive to `ParameterName` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customfilterconfiguration.html#cfn-quicksight-dashboard-customfilterconfiguration-categoryvalue
         */
        readonly categoryValue?: string;
        /**
         * The match operator that is used to determine if a filter should be applied.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customfilterconfiguration.html#cfn-quicksight-dashboard-customfilterconfiguration-matchoperator
         */
        readonly matchOperator: string;
        /**
         * This option determines how null values should be treated when filtering data.
         *
         * - `ALL_VALUES` : Include null values in filtered results.
         * - `NULLS_ONLY` : Only include null values in filtered results.
         * - `NON_NULLS_ONLY` : Exclude null values from filtered results.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customfilterconfiguration.html#cfn-quicksight-dashboard-customfilterconfiguration-nulloption
         */
        readonly nullOption: string;
        /**
         * The parameter whose value should be used for the filter value.
         *
         * This field is mutually exclusive to `CategoryValue` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customfilterconfiguration.html#cfn-quicksight-dashboard-customfilterconfiguration-parametername
         */
        readonly parameterName?: string;
        /**
         * Select all of the values. Null is not the assigned value of select all.
         *
         * - `FILTER_ALL_VALUES`
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customfilterconfiguration.html#cfn-quicksight-dashboard-customfilterconfiguration-selectalloptions
         */
        readonly selectAllOptions?: string;
    }
    /**
     * A list of filter configurations.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterlistconfiguration.html
     */
    interface FilterListConfigurationProperty {
        /**
         * The list of category values for the filter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterlistconfiguration.html#cfn-quicksight-dashboard-filterlistconfiguration-categoryvalues
         */
        readonly categoryValues?: Array<string>;
        /**
         * The match operator that is used to determine if a filter should be applied.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterlistconfiguration.html#cfn-quicksight-dashboard-filterlistconfiguration-matchoperator
         */
        readonly matchOperator: string;
        /**
         * This option determines how null values should be treated when filtering data.
         *
         * - `ALL_VALUES` : Include null values in filtered results.
         * - `NULLS_ONLY` : Only include null values in filtered results.
         * - `NON_NULLS_ONLY` : Exclude null values from filtered results.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterlistconfiguration.html#cfn-quicksight-dashboard-filterlistconfiguration-nulloption
         */
        readonly nullOption?: string;
        /**
         * Select all of the values. Null is not the assigned value of select all.
         *
         * - `FILTER_ALL_VALUES`
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterlistconfiguration.html#cfn-quicksight-dashboard-filterlistconfiguration-selectalloptions
         */
        readonly selectAllOptions?: string;
    }
    /**
     * The scope configuration for a `FilterGroup` .
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterscopeconfiguration.html
     */
    interface FilterScopeConfigurationProperty {
        /**
         * The configuration for applying a filter to all sheets.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterscopeconfiguration.html#cfn-quicksight-dashboard-filterscopeconfiguration-allsheets
         */
        readonly allSheets?: any | cdk.IResolvable;
        /**
         * The configuration for applying a filter to specific sheets.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterscopeconfiguration.html#cfn-quicksight-dashboard-filterscopeconfiguration-selectedsheets
         */
        readonly selectedSheets?: cdk.IResolvable | CfnDashboard.SelectedSheetsFilterScopeConfigurationProperty;
    }
    /**
     * The configuration for applying a filter to specific sheets or visuals.
     *
     * You can apply this filter to multiple visuals that are on one sheet or to all visuals on a sheet.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-selectedsheetsfilterscopeconfiguration.html
     */
    interface SelectedSheetsFilterScopeConfigurationProperty {
        /**
         * The sheet ID and visual IDs of the sheet and visuals that the filter is applied to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-selectedsheetsfilterscopeconfiguration.html#cfn-quicksight-dashboard-selectedsheetsfilterscopeconfiguration-sheetvisualscopingconfigurations
         */
        readonly sheetVisualScopingConfigurations?: Array<cdk.IResolvable | CfnDashboard.SheetVisualScopingConfigurationProperty> | cdk.IResolvable;
    }
    /**
     * The filter that is applied to the options.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetvisualscopingconfiguration.html
     */
    interface SheetVisualScopingConfigurationProperty {
        /**
         * The scope of the applied entities. Choose one of the following options:.
         *
         * - `ALL_VISUALS`
         * - `SELECTED_VISUALS`
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetvisualscopingconfiguration.html#cfn-quicksight-dashboard-sheetvisualscopingconfiguration-scope
         */
        readonly scope: string;
        /**
         * The selected sheet that the filter is applied to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetvisualscopingconfiguration.html#cfn-quicksight-dashboard-sheetvisualscopingconfiguration-sheetid
         */
        readonly sheetId: string;
        /**
         * The selected visuals that the filter is applied to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetvisualscopingconfiguration.html#cfn-quicksight-dashboard-sheetvisualscopingconfiguration-visualids
         */
        readonly visualIds?: Array<string>;
    }
    /**
     * The calculated field of an analysis.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-calculatedfield.html
     */
    interface CalculatedFieldProperty {
        /**
         * The data set that is used in this calculated field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-calculatedfield.html#cfn-quicksight-dashboard-calculatedfield-datasetidentifier
         */
        readonly dataSetIdentifier: string;
        /**
         * The expression of the calculated field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-calculatedfield.html#cfn-quicksight-dashboard-calculatedfield-expression
         */
        readonly expression: string;
        /**
         * The name of the calculated field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-calculatedfield.html#cfn-quicksight-dashboard-calculatedfield-name
         */
        readonly name: string;
    }
    /**
     * A data set.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datasetidentifierdeclaration.html
     */
    interface DataSetIdentifierDeclarationProperty {
        /**
         * The Amazon Resource Name (ARN) of the data set.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datasetidentifierdeclaration.html#cfn-quicksight-dashboard-datasetidentifierdeclaration-datasetarn
         */
        readonly dataSetArn: string;
        /**
         * The identifier of the data set, typically the data set's name.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datasetidentifierdeclaration.html#cfn-quicksight-dashboard-datasetidentifierdeclaration-identifier
         */
        readonly identifier: string;
    }
    /**
     * The general configuration of a column.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnconfiguration.html
     */
    interface ColumnConfigurationProperty {
        /**
         * The color configurations of the column.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnconfiguration.html#cfn-quicksight-dashboard-columnconfiguration-colorsconfiguration
         */
        readonly colorsConfiguration?: CfnDashboard.ColorsConfigurationProperty | cdk.IResolvable;
        /**
         * The column.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnconfiguration.html#cfn-quicksight-dashboard-columnconfiguration-column
         */
        readonly column: CfnDashboard.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * The format configuration of a column.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnconfiguration.html#cfn-quicksight-dashboard-columnconfiguration-formatconfiguration
         */
        readonly formatConfiguration?: CfnDashboard.FormatConfigurationProperty | cdk.IResolvable;
        /**
         * The role of the column.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnconfiguration.html#cfn-quicksight-dashboard-columnconfiguration-role
         */
        readonly role?: string;
    }
    /**
     * The formatting configuration for all types of field.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-formatconfiguration.html
     */
    interface FormatConfigurationProperty {
        /**
         * Formatting configuration for `DateTime` fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-formatconfiguration.html#cfn-quicksight-dashboard-formatconfiguration-datetimeformatconfiguration
         */
        readonly dateTimeFormatConfiguration?: CfnDashboard.DateTimeFormatConfigurationProperty | cdk.IResolvable;
        /**
         * Formatting configuration for number fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-formatconfiguration.html#cfn-quicksight-dashboard-formatconfiguration-numberformatconfiguration
         */
        readonly numberFormatConfiguration?: cdk.IResolvable | CfnDashboard.NumberFormatConfigurationProperty;
        /**
         * Formatting configuration for string fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-formatconfiguration.html#cfn-quicksight-dashboard-formatconfiguration-stringformatconfiguration
         */
        readonly stringFormatConfiguration?: cdk.IResolvable | CfnDashboard.StringFormatConfigurationProperty;
    }
    /**
     * Formatting configuration for number fields.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numberformatconfiguration.html
     */
    interface NumberFormatConfigurationProperty {
        /**
         * The options that determine the numeric format configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numberformatconfiguration.html#cfn-quicksight-dashboard-numberformatconfiguration-formatconfiguration
         */
        readonly formatConfiguration?: cdk.IResolvable | CfnDashboard.NumericFormatConfigurationProperty;
    }
    /**
     * The options that determine the numeric format configuration.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericformatconfiguration.html
     */
    interface NumericFormatConfigurationProperty {
        /**
         * The options that determine the currency display format configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericformatconfiguration.html#cfn-quicksight-dashboard-numericformatconfiguration-currencydisplayformatconfiguration
         */
        readonly currencyDisplayFormatConfiguration?: CfnDashboard.CurrencyDisplayFormatConfigurationProperty | cdk.IResolvable;
        /**
         * The options that determine the number display format configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericformatconfiguration.html#cfn-quicksight-dashboard-numericformatconfiguration-numberdisplayformatconfiguration
         */
        readonly numberDisplayFormatConfiguration?: cdk.IResolvable | CfnDashboard.NumberDisplayFormatConfigurationProperty;
        /**
         * The options that determine the percentage display format configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericformatconfiguration.html#cfn-quicksight-dashboard-numericformatconfiguration-percentagedisplayformatconfiguration
         */
        readonly percentageDisplayFormatConfiguration?: cdk.IResolvable | CfnDashboard.PercentageDisplayFormatConfigurationProperty;
    }
    /**
     * The options that determine the number display format configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numberdisplayformatconfiguration.html
     */
    interface NumberDisplayFormatConfigurationProperty {
        /**
         * The option that determines the decimal places configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numberdisplayformatconfiguration.html#cfn-quicksight-dashboard-numberdisplayformatconfiguration-decimalplacesconfiguration
         */
        readonly decimalPlacesConfiguration?: CfnDashboard.DecimalPlacesConfigurationProperty | cdk.IResolvable;
        /**
         * The options that determine the negative value configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numberdisplayformatconfiguration.html#cfn-quicksight-dashboard-numberdisplayformatconfiguration-negativevalueconfiguration
         */
        readonly negativeValueConfiguration?: cdk.IResolvable | CfnDashboard.NegativeValueConfigurationProperty;
        /**
         * The options that determine the null value format configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numberdisplayformatconfiguration.html#cfn-quicksight-dashboard-numberdisplayformatconfiguration-nullvalueformatconfiguration
         */
        readonly nullValueFormatConfiguration?: cdk.IResolvable | CfnDashboard.NullValueFormatConfigurationProperty;
        /**
         * Determines the number scale value of the number format.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numberdisplayformatconfiguration.html#cfn-quicksight-dashboard-numberdisplayformatconfiguration-numberscale
         */
        readonly numberScale?: string;
        /**
         * Determines the prefix value of the number format.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numberdisplayformatconfiguration.html#cfn-quicksight-dashboard-numberdisplayformatconfiguration-prefix
         */
        readonly prefix?: string;
        /**
         * The options that determine the numeric separator configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numberdisplayformatconfiguration.html#cfn-quicksight-dashboard-numberdisplayformatconfiguration-separatorconfiguration
         */
        readonly separatorConfiguration?: cdk.IResolvable | CfnDashboard.NumericSeparatorConfigurationProperty;
        /**
         * Determines the suffix value of the number format.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numberdisplayformatconfiguration.html#cfn-quicksight-dashboard-numberdisplayformatconfiguration-suffix
         */
        readonly suffix?: string;
    }
    /**
     * The options that determine the negative value configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-negativevalueconfiguration.html
     */
    interface NegativeValueConfigurationProperty {
        /**
         * Determines the display mode of the negative value configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-negativevalueconfiguration.html#cfn-quicksight-dashboard-negativevalueconfiguration-displaymode
         */
        readonly displayMode: string;
    }
    /**
     * The option that determines the decimal places configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimalplacesconfiguration.html
     */
    interface DecimalPlacesConfigurationProperty {
        /**
         * The values of the decimal places.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimalplacesconfiguration.html#cfn-quicksight-dashboard-decimalplacesconfiguration-decimalplaces
         */
        readonly decimalPlaces: number;
    }
    /**
     * The options that determine the null value format configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-nullvalueformatconfiguration.html
     */
    interface NullValueFormatConfigurationProperty {
        /**
         * Determines the null string of null values.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-nullvalueformatconfiguration.html#cfn-quicksight-dashboard-nullvalueformatconfiguration-nullstring
         */
        readonly nullString: string;
    }
    /**
     * The options that determine the numeric separator configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericseparatorconfiguration.html
     */
    interface NumericSeparatorConfigurationProperty {
        /**
         * Determines the decimal separator.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericseparatorconfiguration.html#cfn-quicksight-dashboard-numericseparatorconfiguration-decimalseparator
         */
        readonly decimalSeparator?: string;
        /**
         * The options that determine the thousands separator configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericseparatorconfiguration.html#cfn-quicksight-dashboard-numericseparatorconfiguration-thousandsseparator
         */
        readonly thousandsSeparator?: cdk.IResolvable | CfnDashboard.ThousandSeparatorOptionsProperty;
    }
    /**
     * The options that determine the thousands separator configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-thousandseparatoroptions.html
     */
    interface ThousandSeparatorOptionsProperty {
        /**
         * Determines the thousands separator symbol.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-thousandseparatoroptions.html#cfn-quicksight-dashboard-thousandseparatoroptions-symbol
         */
        readonly symbol?: string;
        /**
         * Determines the visibility of the thousands separator.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-thousandseparatoroptions.html#cfn-quicksight-dashboard-thousandseparatoroptions-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The options that determine the currency display format configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-currencydisplayformatconfiguration.html
     */
    interface CurrencyDisplayFormatConfigurationProperty {
        /**
         * The option that determines the decimal places configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-currencydisplayformatconfiguration.html#cfn-quicksight-dashboard-currencydisplayformatconfiguration-decimalplacesconfiguration
         */
        readonly decimalPlacesConfiguration?: CfnDashboard.DecimalPlacesConfigurationProperty | cdk.IResolvable;
        /**
         * The options that determine the negative value configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-currencydisplayformatconfiguration.html#cfn-quicksight-dashboard-currencydisplayformatconfiguration-negativevalueconfiguration
         */
        readonly negativeValueConfiguration?: cdk.IResolvable | CfnDashboard.NegativeValueConfigurationProperty;
        /**
         * The options that determine the null value format configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-currencydisplayformatconfiguration.html#cfn-quicksight-dashboard-currencydisplayformatconfiguration-nullvalueformatconfiguration
         */
        readonly nullValueFormatConfiguration?: cdk.IResolvable | CfnDashboard.NullValueFormatConfigurationProperty;
        /**
         * Determines the number scale value for the currency format.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-currencydisplayformatconfiguration.html#cfn-quicksight-dashboard-currencydisplayformatconfiguration-numberscale
         */
        readonly numberScale?: string;
        /**
         * Determines the prefix value of the currency format.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-currencydisplayformatconfiguration.html#cfn-quicksight-dashboard-currencydisplayformatconfiguration-prefix
         */
        readonly prefix?: string;
        /**
         * The options that determine the numeric separator configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-currencydisplayformatconfiguration.html#cfn-quicksight-dashboard-currencydisplayformatconfiguration-separatorconfiguration
         */
        readonly separatorConfiguration?: cdk.IResolvable | CfnDashboard.NumericSeparatorConfigurationProperty;
        /**
         * Determines the suffix value of the currency format.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-currencydisplayformatconfiguration.html#cfn-quicksight-dashboard-currencydisplayformatconfiguration-suffix
         */
        readonly suffix?: string;
        /**
         * Determines the symbol for the currency format.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-currencydisplayformatconfiguration.html#cfn-quicksight-dashboard-currencydisplayformatconfiguration-symbol
         */
        readonly symbol?: string;
    }
    /**
     * The options that determine the percentage display format configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-percentagedisplayformatconfiguration.html
     */
    interface PercentageDisplayFormatConfigurationProperty {
        /**
         * The option that determines the decimal places configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-percentagedisplayformatconfiguration.html#cfn-quicksight-dashboard-percentagedisplayformatconfiguration-decimalplacesconfiguration
         */
        readonly decimalPlacesConfiguration?: CfnDashboard.DecimalPlacesConfigurationProperty | cdk.IResolvable;
        /**
         * The options that determine the negative value configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-percentagedisplayformatconfiguration.html#cfn-quicksight-dashboard-percentagedisplayformatconfiguration-negativevalueconfiguration
         */
        readonly negativeValueConfiguration?: cdk.IResolvable | CfnDashboard.NegativeValueConfigurationProperty;
        /**
         * The options that determine the null value format configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-percentagedisplayformatconfiguration.html#cfn-quicksight-dashboard-percentagedisplayformatconfiguration-nullvalueformatconfiguration
         */
        readonly nullValueFormatConfiguration?: cdk.IResolvable | CfnDashboard.NullValueFormatConfigurationProperty;
        /**
         * Determines the prefix value of the percentage format.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-percentagedisplayformatconfiguration.html#cfn-quicksight-dashboard-percentagedisplayformatconfiguration-prefix
         */
        readonly prefix?: string;
        /**
         * The options that determine the numeric separator configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-percentagedisplayformatconfiguration.html#cfn-quicksight-dashboard-percentagedisplayformatconfiguration-separatorconfiguration
         */
        readonly separatorConfiguration?: cdk.IResolvable | CfnDashboard.NumericSeparatorConfigurationProperty;
        /**
         * Determines the suffix value of the percentage format.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-percentagedisplayformatconfiguration.html#cfn-quicksight-dashboard-percentagedisplayformatconfiguration-suffix
         */
        readonly suffix?: string;
    }
    /**
     * Formatting configuration for `DateTime` fields.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimeformatconfiguration.html
     */
    interface DateTimeFormatConfigurationProperty {
        /**
         * Determines the `DateTime` format.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimeformatconfiguration.html#cfn-quicksight-dashboard-datetimeformatconfiguration-datetimeformat
         */
        readonly dateTimeFormat?: string;
        /**
         * The options that determine the null value format configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimeformatconfiguration.html#cfn-quicksight-dashboard-datetimeformatconfiguration-nullvalueformatconfiguration
         */
        readonly nullValueFormatConfiguration?: cdk.IResolvable | CfnDashboard.NullValueFormatConfigurationProperty;
        /**
         * The formatting configuration for numeric `DateTime` fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimeformatconfiguration.html#cfn-quicksight-dashboard-datetimeformatconfiguration-numericformatconfiguration
         */
        readonly numericFormatConfiguration?: cdk.IResolvable | CfnDashboard.NumericFormatConfigurationProperty;
    }
    /**
     * Formatting configuration for string fields.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringformatconfiguration.html
     */
    interface StringFormatConfigurationProperty {
        /**
         * The options that determine the null value format configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringformatconfiguration.html#cfn-quicksight-dashboard-stringformatconfiguration-nullvalueformatconfiguration
         */
        readonly nullValueFormatConfiguration?: cdk.IResolvable | CfnDashboard.NullValueFormatConfigurationProperty;
        /**
         * The formatting configuration for numeric strings.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringformatconfiguration.html#cfn-quicksight-dashboard-stringformatconfiguration-numericformatconfiguration
         */
        readonly numericFormatConfiguration?: cdk.IResolvable | CfnDashboard.NumericFormatConfigurationProperty;
    }
    /**
     * The color configurations for a column.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-colorsconfiguration.html
     */
    interface ColorsConfigurationProperty {
        /**
         * A list of up to 50 custom colors.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-colorsconfiguration.html#cfn-quicksight-dashboard-colorsconfiguration-customcolors
         */
        readonly customColors?: Array<CfnDashboard.CustomColorProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * Determines the color that's applied to a particular data value in a column.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcolor.html
     */
    interface CustomColorProperty {
        /**
         * The color that is applied to the data value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcolor.html#cfn-quicksight-dashboard-customcolor-color
         */
        readonly color: string;
        /**
         * The data value that the color is applied to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcolor.html#cfn-quicksight-dashboard-customcolor-fieldvalue
         */
        readonly fieldValue?: string;
        /**
         * The value of a special data value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcolor.html#cfn-quicksight-dashboard-customcolor-specialvalue
         */
        readonly specialValue?: string;
    }
    /**
     * The configuration for default analysis settings.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-analysisdefaults.html
     */
    interface AnalysisDefaultsProperty {
        /**
         * The configuration for default new sheet settings.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-analysisdefaults.html#cfn-quicksight-dashboard-analysisdefaults-defaultnewsheetconfiguration
         */
        readonly defaultNewSheetConfiguration: CfnDashboard.DefaultNewSheetConfigurationProperty | cdk.IResolvable;
    }
    /**
     * The configuration for default new sheet settings.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultnewsheetconfiguration.html
     */
    interface DefaultNewSheetConfigurationProperty {
        /**
         * The options that determine the default settings for interactive layout configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultnewsheetconfiguration.html#cfn-quicksight-dashboard-defaultnewsheetconfiguration-interactivelayoutconfiguration
         */
        readonly interactiveLayoutConfiguration?: CfnDashboard.DefaultInteractiveLayoutConfigurationProperty | cdk.IResolvable;
        /**
         * The options that determine the default settings for a paginated layout configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultnewsheetconfiguration.html#cfn-quicksight-dashboard-defaultnewsheetconfiguration-paginatedlayoutconfiguration
         */
        readonly paginatedLayoutConfiguration?: CfnDashboard.DefaultPaginatedLayoutConfigurationProperty | cdk.IResolvable;
        /**
         * The option that determines the sheet content type.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultnewsheetconfiguration.html#cfn-quicksight-dashboard-defaultnewsheetconfiguration-sheetcontenttype
         */
        readonly sheetContentType?: string;
    }
    /**
     * The options that determine the default settings for interactive layout configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultinteractivelayoutconfiguration.html
     */
    interface DefaultInteractiveLayoutConfigurationProperty {
        /**
         * The options that determine the default settings of a free-form layout configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultinteractivelayoutconfiguration.html#cfn-quicksight-dashboard-defaultinteractivelayoutconfiguration-freeform
         */
        readonly freeForm?: CfnDashboard.DefaultFreeFormLayoutConfigurationProperty | cdk.IResolvable;
        /**
         * The options that determine the default settings for a grid layout configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultinteractivelayoutconfiguration.html#cfn-quicksight-dashboard-defaultinteractivelayoutconfiguration-grid
         */
        readonly grid?: CfnDashboard.DefaultGridLayoutConfigurationProperty | cdk.IResolvable;
    }
    /**
     * The options that determine the default settings of a free-form layout configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultfreeformlayoutconfiguration.html
     */
    interface DefaultFreeFormLayoutConfigurationProperty {
        /**
         * Determines the screen canvas size options for a free-form layout.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultfreeformlayoutconfiguration.html#cfn-quicksight-dashboard-defaultfreeformlayoutconfiguration-canvassizeoptions
         */
        readonly canvasSizeOptions: CfnDashboard.FreeFormLayoutCanvasSizeOptionsProperty | cdk.IResolvable;
    }
    /**
     * Configuration options for the canvas of a free-form layout.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutcanvassizeoptions.html
     */
    interface FreeFormLayoutCanvasSizeOptionsProperty {
        /**
         * The options that determine the sizing of the canvas used in a free-form layout.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutcanvassizeoptions.html#cfn-quicksight-dashboard-freeformlayoutcanvassizeoptions-screencanvassizeoptions
         */
        readonly screenCanvasSizeOptions?: CfnDashboard.FreeFormLayoutScreenCanvasSizeOptionsProperty | cdk.IResolvable;
    }
    /**
     * The options that determine the sizing of the canvas used in a free-form layout.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutscreencanvassizeoptions.html
     */
    interface FreeFormLayoutScreenCanvasSizeOptionsProperty {
        /**
         * The width that the view port will be optimized for when the layout renders.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutscreencanvassizeoptions.html#cfn-quicksight-dashboard-freeformlayoutscreencanvassizeoptions-optimizedviewportwidth
         */
        readonly optimizedViewPortWidth: string;
    }
    /**
     * The options that determine the default settings for a grid layout configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultgridlayoutconfiguration.html
     */
    interface DefaultGridLayoutConfigurationProperty {
        /**
         * Determines the screen canvas size options for a grid layout.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultgridlayoutconfiguration.html#cfn-quicksight-dashboard-defaultgridlayoutconfiguration-canvassizeoptions
         */
        readonly canvasSizeOptions: CfnDashboard.GridLayoutCanvasSizeOptionsProperty | cdk.IResolvable;
    }
    /**
     * Configuration options for the canvas of a grid layout.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutcanvassizeoptions.html
     */
    interface GridLayoutCanvasSizeOptionsProperty {
        /**
         * The options that determine the sizing of the canvas used in a grid layout.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutcanvassizeoptions.html#cfn-quicksight-dashboard-gridlayoutcanvassizeoptions-screencanvassizeoptions
         */
        readonly screenCanvasSizeOptions?: CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty | cdk.IResolvable;
    }
    /**
     * The options that determine the sizing of the canvas used in a grid layout.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutscreencanvassizeoptions.html
     */
    interface GridLayoutScreenCanvasSizeOptionsProperty {
        /**
         * The width that the view port will be optimized for when the layout renders.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutscreencanvassizeoptions.html#cfn-quicksight-dashboard-gridlayoutscreencanvassizeoptions-optimizedviewportwidth
         */
        readonly optimizedViewPortWidth?: string;
        /**
         * This value determines the layout behavior when the viewport is resized.
         *
         * - `FIXED` : A fixed width will be used when optimizing the layout. In the Amazon QuickSight console, this option is called `Classic` .
         * - `RESPONSIVE` : The width of the canvas will be responsive and optimized to the view port. In the Amazon QuickSight console, this option is called `Tiled` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutscreencanvassizeoptions.html#cfn-quicksight-dashboard-gridlayoutscreencanvassizeoptions-resizeoption
         */
        readonly resizeOption: string;
    }
    /**
     * The options that determine the default settings for a paginated layout configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultpaginatedlayoutconfiguration.html
     */
    interface DefaultPaginatedLayoutConfigurationProperty {
        /**
         * The options that determine the default settings for a section-based layout configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultpaginatedlayoutconfiguration.html#cfn-quicksight-dashboard-defaultpaginatedlayoutconfiguration-sectionbased
         */
        readonly sectionBased?: CfnDashboard.DefaultSectionBasedLayoutConfigurationProperty | cdk.IResolvable;
    }
    /**
     * The options that determine the default settings for a section-based layout configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultsectionbasedlayoutconfiguration.html
     */
    interface DefaultSectionBasedLayoutConfigurationProperty {
        /**
         * Determines the screen canvas size options for a section-based layout.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultsectionbasedlayoutconfiguration.html#cfn-quicksight-dashboard-defaultsectionbasedlayoutconfiguration-canvassizeoptions
         */
        readonly canvasSizeOptions: cdk.IResolvable | CfnDashboard.SectionBasedLayoutCanvasSizeOptionsProperty;
    }
    /**
     * The options for the canvas of a section-based layout.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionbasedlayoutcanvassizeoptions.html
     */
    interface SectionBasedLayoutCanvasSizeOptionsProperty {
        /**
         * The options for a paper canvas of a section-based layout.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionbasedlayoutcanvassizeoptions.html#cfn-quicksight-dashboard-sectionbasedlayoutcanvassizeoptions-papercanvassizeoptions
         */
        readonly paperCanvasSizeOptions?: cdk.IResolvable | CfnDashboard.SectionBasedLayoutPaperCanvasSizeOptionsProperty;
    }
    /**
     * The options for a paper canvas of a section-based layout.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionbasedlayoutpapercanvassizeoptions.html
     */
    interface SectionBasedLayoutPaperCanvasSizeOptionsProperty {
        /**
         * Defines the spacing between the canvas content and the top, bottom, left, and right edges.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionbasedlayoutpapercanvassizeoptions.html#cfn-quicksight-dashboard-sectionbasedlayoutpapercanvassizeoptions-papermargin
         */
        readonly paperMargin?: cdk.IResolvable | CfnDashboard.SpacingProperty;
        /**
         * The paper orientation that is used to define canvas dimensions. Choose one of the following options:.
         *
         * - PORTRAIT
         * - LANDSCAPE
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionbasedlayoutpapercanvassizeoptions.html#cfn-quicksight-dashboard-sectionbasedlayoutpapercanvassizeoptions-paperorientation
         */
        readonly paperOrientation?: string;
        /**
         * The paper size that is used to define canvas dimensions.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionbasedlayoutpapercanvassizeoptions.html#cfn-quicksight-dashboard-sectionbasedlayoutpapercanvassizeoptions-papersize
         */
        readonly paperSize?: string;
    }
    /**
     * The configuration of spacing (often a margin or padding).
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-spacing.html
     */
    interface SpacingProperty {
        /**
         * Define the bottom spacing.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-spacing.html#cfn-quicksight-dashboard-spacing-bottom
         */
        readonly bottom?: string;
        /**
         * Define the left spacing.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-spacing.html#cfn-quicksight-dashboard-spacing-left
         */
        readonly left?: string;
        /**
         * Define the right spacing.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-spacing.html#cfn-quicksight-dashboard-spacing-right
         */
        readonly right?: string;
        /**
         * Define the top spacing.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-spacing.html#cfn-quicksight-dashboard-spacing-top
         */
        readonly top?: string;
    }
    /**
     * A sheet is an object that contains a set of visuals that are viewed together on one page in a paginated report.
     *
     * Every analysis and dashboard must contain at least one sheet.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetdefinition.html
     */
    interface SheetDefinitionProperty {
        /**
         * The layout content type of the sheet. Choose one of the following options:.
         *
         * - `PAGINATED` : Creates a sheet for a paginated report.
         * - `INTERACTIVE` : Creates a sheet for an interactive dashboard.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetdefinition.html#cfn-quicksight-dashboard-sheetdefinition-contenttype
         */
        readonly contentType?: string;
        /**
         * A description of the sheet.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetdefinition.html#cfn-quicksight-dashboard-sheetdefinition-description
         */
        readonly description?: string;
        /**
         * The list of filter controls that are on a sheet.
         *
         * For more information, see [Adding filter controls to analysis sheets](https://docs.aws.amazon.com/quicksight/latest/user/filter-controls.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetdefinition.html#cfn-quicksight-dashboard-sheetdefinition-filtercontrols
         */
        readonly filterControls?: Array<CfnDashboard.FilterControlProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * Layouts define how the components of a sheet are arranged.
         *
         * For more information, see [Types of layout](https://docs.aws.amazon.com/quicksight/latest/user/types-of-layout.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetdefinition.html#cfn-quicksight-dashboard-sheetdefinition-layouts
         */
        readonly layouts?: Array<cdk.IResolvable | CfnDashboard.LayoutProperty> | cdk.IResolvable;
        /**
         * The name of the sheet.
         *
         * This name is displayed on the sheet's tab in the Amazon QuickSight console.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetdefinition.html#cfn-quicksight-dashboard-sheetdefinition-name
         */
        readonly name?: string;
        /**
         * The list of parameter controls that are on a sheet.
         *
         * For more information, see [Using a Control with a Parameter in Amazon QuickSight](https://docs.aws.amazon.com/quicksight/latest/user/parameters-controls.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetdefinition.html#cfn-quicksight-dashboard-sheetdefinition-parametercontrols
         */
        readonly parameterControls?: Array<cdk.IResolvable | CfnDashboard.ParameterControlProperty> | cdk.IResolvable;
        /**
         * The control layouts of the sheet.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetdefinition.html#cfn-quicksight-dashboard-sheetdefinition-sheetcontrollayouts
         */
        readonly sheetControlLayouts?: Array<cdk.IResolvable | CfnDashboard.SheetControlLayoutProperty> | cdk.IResolvable;
        /**
         * The unique identifier of a sheet.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetdefinition.html#cfn-quicksight-dashboard-sheetdefinition-sheetid
         */
        readonly sheetId: string;
        /**
         * The text boxes that are on a sheet.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetdefinition.html#cfn-quicksight-dashboard-sheetdefinition-textboxes
         */
        readonly textBoxes?: Array<cdk.IResolvable | CfnDashboard.SheetTextBoxProperty> | cdk.IResolvable;
        /**
         * The title of the sheet.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetdefinition.html#cfn-quicksight-dashboard-sheetdefinition-title
         */
        readonly title?: string;
        /**
         * A list of the visuals that are on a sheet.
         *
         * Visual placement is determined by the layout of the sheet.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetdefinition.html#cfn-quicksight-dashboard-sheetdefinition-visuals
         */
        readonly visuals?: Array<cdk.IResolvable | CfnDashboard.VisualProperty> | cdk.IResolvable;
    }
    /**
     * The control of a parameter that users can interact with in a dashboard or an analysis.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametercontrol.html
     */
    interface ParameterControlProperty {
        /**
         * A control from a date parameter that specifies date and time.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametercontrol.html#cfn-quicksight-dashboard-parametercontrol-datetimepicker
         */
        readonly dateTimePicker?: cdk.IResolvable | CfnDashboard.ParameterDateTimePickerControlProperty;
        /**
         * A control to display a dropdown list with buttons that are used to select a single value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametercontrol.html#cfn-quicksight-dashboard-parametercontrol-dropdown
         */
        readonly dropdown?: cdk.IResolvable | CfnDashboard.ParameterDropDownControlProperty;
        /**
         * A control to display a list with buttons or boxes that are used to select either a single value or multiple values.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametercontrol.html#cfn-quicksight-dashboard-parametercontrol-list
         */
        readonly list?: cdk.IResolvable | CfnDashboard.ParameterListControlProperty;
        /**
         * A control to display a horizontal toggle bar.
         *
         * This is used to change a value by sliding the toggle.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametercontrol.html#cfn-quicksight-dashboard-parametercontrol-slider
         */
        readonly slider?: cdk.IResolvable | CfnDashboard.ParameterSliderControlProperty;
        /**
         * A control to display a text box that is used to enter multiple entries.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametercontrol.html#cfn-quicksight-dashboard-parametercontrol-textarea
         */
        readonly textArea?: cdk.IResolvable | CfnDashboard.ParameterTextAreaControlProperty;
        /**
         * A control to display a text box that is used to enter a single entry.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametercontrol.html#cfn-quicksight-dashboard-parametercontrol-textfield
         */
        readonly textField?: cdk.IResolvable | CfnDashboard.ParameterTextFieldControlProperty;
    }
    /**
     * A control to display a horizontal toggle bar.
     *
     * This is used to change a value by sliding the toggle.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterslidercontrol.html
     */
    interface ParameterSliderControlProperty {
        /**
         * The display options of a control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterslidercontrol.html#cfn-quicksight-dashboard-parameterslidercontrol-displayoptions
         */
        readonly displayOptions?: cdk.IResolvable | CfnDashboard.SliderControlDisplayOptionsProperty;
        /**
         * The smaller value that is displayed at the left of the slider.
         *
         * @default - 0
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterslidercontrol.html#cfn-quicksight-dashboard-parameterslidercontrol-maximumvalue
         */
        readonly maximumValue: number;
        /**
         * The larger value that is displayed at the right of the slider.
         *
         * @default - 0
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterslidercontrol.html#cfn-quicksight-dashboard-parameterslidercontrol-minimumvalue
         */
        readonly minimumValue: number;
        /**
         * The ID of the `ParameterSliderControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterslidercontrol.html#cfn-quicksight-dashboard-parameterslidercontrol-parametercontrolid
         */
        readonly parameterControlId: string;
        /**
         * The source parameter name of the `ParameterSliderControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterslidercontrol.html#cfn-quicksight-dashboard-parameterslidercontrol-sourceparametername
         */
        readonly sourceParameterName: string;
        /**
         * The number of increments that the slider bar is divided into.
         *
         * @default - 0
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterslidercontrol.html#cfn-quicksight-dashboard-parameterslidercontrol-stepsize
         */
        readonly stepSize: number;
        /**
         * The title of the `ParameterSliderControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterslidercontrol.html#cfn-quicksight-dashboard-parameterslidercontrol-title
         */
        readonly title: string;
    }
    /**
     * The display options of a control.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-slidercontroldisplayoptions.html
     */
    interface SliderControlDisplayOptionsProperty {
        /**
         * The configuration of info icon label options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-slidercontroldisplayoptions.html#cfn-quicksight-dashboard-slidercontroldisplayoptions-infoiconlabeloptions
         */
        readonly infoIconLabelOptions?: cdk.IResolvable | CfnDashboard.SheetControlInfoIconLabelOptionsProperty;
        /**
         * The options to configure the title visibility, name, and font size.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-slidercontroldisplayoptions.html#cfn-quicksight-dashboard-slidercontroldisplayoptions-titleoptions
         */
        readonly titleOptions?: cdk.IResolvable | CfnDashboard.LabelOptionsProperty;
    }
    /**
     * The share label options for the labels.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-labeloptions.html
     */
    interface LabelOptionsProperty {
        /**
         * The text for the label.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-labeloptions.html#cfn-quicksight-dashboard-labeloptions-customlabel
         */
        readonly customLabel?: string;
        /**
         * The font configuration of the label.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-labeloptions.html#cfn-quicksight-dashboard-labeloptions-fontconfiguration
         */
        readonly fontConfiguration?: CfnDashboard.FontConfigurationProperty | cdk.IResolvable;
        /**
         * Determines whether or not the label is visible.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-labeloptions.html#cfn-quicksight-dashboard-labeloptions-visibility
         */
        readonly visibility?: string;
    }
    /**
     * Configures the display properties of the given text.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fontconfiguration.html
     */
    interface FontConfigurationProperty {
        /**
         * Determines the color of the text.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fontconfiguration.html#cfn-quicksight-dashboard-fontconfiguration-fontcolor
         */
        readonly fontColor?: string;
        /**
         * Determines the appearance of decorative lines on the text.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fontconfiguration.html#cfn-quicksight-dashboard-fontconfiguration-fontdecoration
         */
        readonly fontDecoration?: string;
        /**
         * The option that determines the text display size.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fontconfiguration.html#cfn-quicksight-dashboard-fontconfiguration-fontsize
         */
        readonly fontSize?: CfnDashboard.FontSizeProperty | cdk.IResolvable;
        /**
         * Determines the text display face that is inherited by the given font family.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fontconfiguration.html#cfn-quicksight-dashboard-fontconfiguration-fontstyle
         */
        readonly fontStyle?: string;
        /**
         * The option that determines the text display weight, or boldness.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fontconfiguration.html#cfn-quicksight-dashboard-fontconfiguration-fontweight
         */
        readonly fontWeight?: CfnDashboard.FontWeightProperty | cdk.IResolvable;
    }
    /**
     * The option that determines the text display size.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fontsize.html
     */
    interface FontSizeProperty {
        /**
         * The lexical name for the text size, proportional to its surrounding context.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fontsize.html#cfn-quicksight-dashboard-fontsize-relative
         */
        readonly relative?: string;
    }
    /**
     * The option that determines the text display weight, or boldness.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fontweight.html
     */
    interface FontWeightProperty {
        /**
         * The lexical name for the level of boldness of the text display.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fontweight.html#cfn-quicksight-dashboard-fontweight-name
         */
        readonly name?: string;
    }
    /**
     * A control to display info icons for filters and parameters.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetcontrolinfoiconlabeloptions.html
     */
    interface SheetControlInfoIconLabelOptionsProperty {
        /**
         * The text content of info icon.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetcontrolinfoiconlabeloptions.html#cfn-quicksight-dashboard-sheetcontrolinfoiconlabeloptions-infoicontext
         */
        readonly infoIconText?: string;
        /**
         * The visibility configuration of info icon label options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetcontrolinfoiconlabeloptions.html#cfn-quicksight-dashboard-sheetcontrolinfoiconlabeloptions-visibility
         */
        readonly visibility?: string;
    }
    /**
     * A control to display a text box that is used to enter multiple entries.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametertextareacontrol.html
     */
    interface ParameterTextAreaControlProperty {
        /**
         * The delimiter that is used to separate the lines in text.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametertextareacontrol.html#cfn-quicksight-dashboard-parametertextareacontrol-delimiter
         */
        readonly delimiter?: string;
        /**
         * The display options of a control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametertextareacontrol.html#cfn-quicksight-dashboard-parametertextareacontrol-displayoptions
         */
        readonly displayOptions?: cdk.IResolvable | CfnDashboard.TextAreaControlDisplayOptionsProperty;
        /**
         * The ID of the `ParameterTextAreaControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametertextareacontrol.html#cfn-quicksight-dashboard-parametertextareacontrol-parametercontrolid
         */
        readonly parameterControlId: string;
        /**
         * The source parameter name of the `ParameterTextAreaControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametertextareacontrol.html#cfn-quicksight-dashboard-parametertextareacontrol-sourceparametername
         */
        readonly sourceParameterName: string;
        /**
         * The title of the `ParameterTextAreaControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametertextareacontrol.html#cfn-quicksight-dashboard-parametertextareacontrol-title
         */
        readonly title: string;
    }
    /**
     * The display options of a control.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-textareacontroldisplayoptions.html
     */
    interface TextAreaControlDisplayOptionsProperty {
        /**
         * The configuration of info icon label options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-textareacontroldisplayoptions.html#cfn-quicksight-dashboard-textareacontroldisplayoptions-infoiconlabeloptions
         */
        readonly infoIconLabelOptions?: cdk.IResolvable | CfnDashboard.SheetControlInfoIconLabelOptionsProperty;
        /**
         * The configuration of the placeholder options in a text area control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-textareacontroldisplayoptions.html#cfn-quicksight-dashboard-textareacontroldisplayoptions-placeholderoptions
         */
        readonly placeholderOptions?: cdk.IResolvable | CfnDashboard.TextControlPlaceholderOptionsProperty;
        /**
         * The options to configure the title visibility, name, and font size.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-textareacontroldisplayoptions.html#cfn-quicksight-dashboard-textareacontroldisplayoptions-titleoptions
         */
        readonly titleOptions?: cdk.IResolvable | CfnDashboard.LabelOptionsProperty;
    }
    /**
     * The configuration of the placeholder options in a text control.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-textcontrolplaceholderoptions.html
     */
    interface TextControlPlaceholderOptionsProperty {
        /**
         * The visibility configuration of the placeholder options in a text control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-textcontrolplaceholderoptions.html#cfn-quicksight-dashboard-textcontrolplaceholderoptions-visibility
         */
        readonly visibility?: string;
    }
    /**
     * A control to display a dropdown list with buttons that are used to select a single value.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdropdowncontrol.html
     */
    interface ParameterDropDownControlProperty {
        /**
         * The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdropdowncontrol.html#cfn-quicksight-dashboard-parameterdropdowncontrol-cascadingcontrolconfiguration
         */
        readonly cascadingControlConfiguration?: CfnDashboard.CascadingControlConfigurationProperty | cdk.IResolvable;
        /**
         * The display options of a control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdropdowncontrol.html#cfn-quicksight-dashboard-parameterdropdowncontrol-displayoptions
         */
        readonly displayOptions?: CfnDashboard.DropDownControlDisplayOptionsProperty | cdk.IResolvable;
        /**
         * The ID of the `ParameterDropDownControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdropdowncontrol.html#cfn-quicksight-dashboard-parameterdropdowncontrol-parametercontrolid
         */
        readonly parameterControlId: string;
        /**
         * A list of selectable values that are used in a control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdropdowncontrol.html#cfn-quicksight-dashboard-parameterdropdowncontrol-selectablevalues
         */
        readonly selectableValues?: cdk.IResolvable | CfnDashboard.ParameterSelectableValuesProperty;
        /**
         * The source parameter name of the `ParameterDropDownControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdropdowncontrol.html#cfn-quicksight-dashboard-parameterdropdowncontrol-sourceparametername
         */
        readonly sourceParameterName: string;
        /**
         * The title of the `ParameterDropDownControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdropdowncontrol.html#cfn-quicksight-dashboard-parameterdropdowncontrol-title
         */
        readonly title: string;
        /**
         * The type parameter name of the `ParameterDropDownControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdropdowncontrol.html#cfn-quicksight-dashboard-parameterdropdowncontrol-type
         */
        readonly type?: string;
    }
    /**
     * The display options of a control.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dropdowncontroldisplayoptions.html
     */
    interface DropDownControlDisplayOptionsProperty {
        /**
         * The configuration of info icon label options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dropdowncontroldisplayoptions.html#cfn-quicksight-dashboard-dropdowncontroldisplayoptions-infoiconlabeloptions
         */
        readonly infoIconLabelOptions?: cdk.IResolvable | CfnDashboard.SheetControlInfoIconLabelOptionsProperty;
        /**
         * The configuration of the `Select all` options in a dropdown control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dropdowncontroldisplayoptions.html#cfn-quicksight-dashboard-dropdowncontroldisplayoptions-selectalloptions
         */
        readonly selectAllOptions?: cdk.IResolvable | CfnDashboard.ListControlSelectAllOptionsProperty;
        /**
         * The options to configure the title visibility, name, and font size.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dropdowncontroldisplayoptions.html#cfn-quicksight-dashboard-dropdowncontroldisplayoptions-titleoptions
         */
        readonly titleOptions?: cdk.IResolvable | CfnDashboard.LabelOptionsProperty;
    }
    /**
     * The configuration of the `Select all` options in a list control.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-listcontrolselectalloptions.html
     */
    interface ListControlSelectAllOptionsProperty {
        /**
         * The visibility configuration of the `Select all` options in a list control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-listcontrolselectalloptions.html#cfn-quicksight-dashboard-listcontrolselectalloptions-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-cascadingcontrolconfiguration.html
     */
    interface CascadingControlConfigurationProperty {
        /**
         * A list of source controls that determine the values that are used in the current control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-cascadingcontrolconfiguration.html#cfn-quicksight-dashboard-cascadingcontrolconfiguration-sourcecontrols
         */
        readonly sourceControls?: Array<CfnDashboard.CascadingControlSourceProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * The source controls that are used in a `CascadingControlConfiguration` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-cascadingcontrolsource.html
     */
    interface CascadingControlSourceProperty {
        /**
         * The column identifier that determines which column to look up for the source sheet control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-cascadingcontrolsource.html#cfn-quicksight-dashboard-cascadingcontrolsource-columntomatch
         */
        readonly columnToMatch?: CfnDashboard.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * The source sheet control ID of a `CascadingControlSource` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-cascadingcontrolsource.html#cfn-quicksight-dashboard-cascadingcontrolsource-sourcesheetcontrolid
         */
        readonly sourceSheetControlId?: string;
    }
    /**
     * A list of selectable values that are used in a control.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterselectablevalues.html
     */
    interface ParameterSelectableValuesProperty {
        /**
         * The column identifier that fetches values from the data set.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterselectablevalues.html#cfn-quicksight-dashboard-parameterselectablevalues-linktodatasetcolumn
         */
        readonly linkToDataSetColumn?: CfnDashboard.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * The values that are used in `ParameterSelectableValues` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterselectablevalues.html#cfn-quicksight-dashboard-parameterselectablevalues-values
         */
        readonly values?: Array<string>;
    }
    /**
     * A control to display a text box that is used to enter a single entry.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametertextfieldcontrol.html
     */
    interface ParameterTextFieldControlProperty {
        /**
         * The display options of a control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametertextfieldcontrol.html#cfn-quicksight-dashboard-parametertextfieldcontrol-displayoptions
         */
        readonly displayOptions?: cdk.IResolvable | CfnDashboard.TextFieldControlDisplayOptionsProperty;
        /**
         * The ID of the `ParameterTextFieldControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametertextfieldcontrol.html#cfn-quicksight-dashboard-parametertextfieldcontrol-parametercontrolid
         */
        readonly parameterControlId: string;
        /**
         * The source parameter name of the `ParameterTextFieldControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametertextfieldcontrol.html#cfn-quicksight-dashboard-parametertextfieldcontrol-sourceparametername
         */
        readonly sourceParameterName: string;
        /**
         * The title of the `ParameterTextFieldControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametertextfieldcontrol.html#cfn-quicksight-dashboard-parametertextfieldcontrol-title
         */
        readonly title: string;
    }
    /**
     * The display options of a control.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-textfieldcontroldisplayoptions.html
     */
    interface TextFieldControlDisplayOptionsProperty {
        /**
         * The configuration of info icon label options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-textfieldcontroldisplayoptions.html#cfn-quicksight-dashboard-textfieldcontroldisplayoptions-infoiconlabeloptions
         */
        readonly infoIconLabelOptions?: cdk.IResolvable | CfnDashboard.SheetControlInfoIconLabelOptionsProperty;
        /**
         * The configuration of the placeholder options in a text field control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-textfieldcontroldisplayoptions.html#cfn-quicksight-dashboard-textfieldcontroldisplayoptions-placeholderoptions
         */
        readonly placeholderOptions?: cdk.IResolvable | CfnDashboard.TextControlPlaceholderOptionsProperty;
        /**
         * The options to configure the title visibility, name, and font size.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-textfieldcontroldisplayoptions.html#cfn-quicksight-dashboard-textfieldcontroldisplayoptions-titleoptions
         */
        readonly titleOptions?: cdk.IResolvable | CfnDashboard.LabelOptionsProperty;
    }
    /**
     * A control to display a list with buttons or boxes that are used to select either a single value or multiple values.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterlistcontrol.html
     */
    interface ParameterListControlProperty {
        /**
         * The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterlistcontrol.html#cfn-quicksight-dashboard-parameterlistcontrol-cascadingcontrolconfiguration
         */
        readonly cascadingControlConfiguration?: CfnDashboard.CascadingControlConfigurationProperty | cdk.IResolvable;
        /**
         * The display options of a control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterlistcontrol.html#cfn-quicksight-dashboard-parameterlistcontrol-displayoptions
         */
        readonly displayOptions?: cdk.IResolvable | CfnDashboard.ListControlDisplayOptionsProperty;
        /**
         * The ID of the `ParameterListControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterlistcontrol.html#cfn-quicksight-dashboard-parameterlistcontrol-parametercontrolid
         */
        readonly parameterControlId: string;
        /**
         * A list of selectable values that are used in a control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterlistcontrol.html#cfn-quicksight-dashboard-parameterlistcontrol-selectablevalues
         */
        readonly selectableValues?: cdk.IResolvable | CfnDashboard.ParameterSelectableValuesProperty;
        /**
         * The source parameter name of the `ParameterListControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterlistcontrol.html#cfn-quicksight-dashboard-parameterlistcontrol-sourceparametername
         */
        readonly sourceParameterName: string;
        /**
         * The title of the `ParameterListControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterlistcontrol.html#cfn-quicksight-dashboard-parameterlistcontrol-title
         */
        readonly title: string;
        /**
         * The type of `ParameterListControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterlistcontrol.html#cfn-quicksight-dashboard-parameterlistcontrol-type
         */
        readonly type?: string;
    }
    /**
     * The display options of a control.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-listcontroldisplayoptions.html
     */
    interface ListControlDisplayOptionsProperty {
        /**
         * The configuration of info icon label options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-listcontroldisplayoptions.html#cfn-quicksight-dashboard-listcontroldisplayoptions-infoiconlabeloptions
         */
        readonly infoIconLabelOptions?: cdk.IResolvable | CfnDashboard.SheetControlInfoIconLabelOptionsProperty;
        /**
         * The configuration of the search options in a list control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-listcontroldisplayoptions.html#cfn-quicksight-dashboard-listcontroldisplayoptions-searchoptions
         */
        readonly searchOptions?: cdk.IResolvable | CfnDashboard.ListControlSearchOptionsProperty;
        /**
         * The configuration of the `Select all` options in a list control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-listcontroldisplayoptions.html#cfn-quicksight-dashboard-listcontroldisplayoptions-selectalloptions
         */
        readonly selectAllOptions?: cdk.IResolvable | CfnDashboard.ListControlSelectAllOptionsProperty;
        /**
         * The options to configure the title visibility, name, and font size.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-listcontroldisplayoptions.html#cfn-quicksight-dashboard-listcontroldisplayoptions-titleoptions
         */
        readonly titleOptions?: cdk.IResolvable | CfnDashboard.LabelOptionsProperty;
    }
    /**
     * The configuration of the search options in a list control.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-listcontrolsearchoptions.html
     */
    interface ListControlSearchOptionsProperty {
        /**
         * The visibility configuration of the search options in a list control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-listcontrolsearchoptions.html#cfn-quicksight-dashboard-listcontrolsearchoptions-visibility
         */
        readonly visibility?: string;
    }
    /**
     * A control from a date parameter that specifies date and time.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdatetimepickercontrol.html
     */
    interface ParameterDateTimePickerControlProperty {
        /**
         * The display options of a control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdatetimepickercontrol.html#cfn-quicksight-dashboard-parameterdatetimepickercontrol-displayoptions
         */
        readonly displayOptions?: CfnDashboard.DateTimePickerControlDisplayOptionsProperty | cdk.IResolvable;
        /**
         * The ID of the `ParameterDateTimePickerControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdatetimepickercontrol.html#cfn-quicksight-dashboard-parameterdatetimepickercontrol-parametercontrolid
         */
        readonly parameterControlId: string;
        /**
         * The name of the `ParameterDateTimePickerControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdatetimepickercontrol.html#cfn-quicksight-dashboard-parameterdatetimepickercontrol-sourceparametername
         */
        readonly sourceParameterName: string;
        /**
         * The title of the `ParameterDateTimePickerControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdatetimepickercontrol.html#cfn-quicksight-dashboard-parameterdatetimepickercontrol-title
         */
        readonly title: string;
    }
    /**
     * The display options of a control.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimepickercontroldisplayoptions.html
     */
    interface DateTimePickerControlDisplayOptionsProperty {
        /**
         * Customize how dates are formatted in controls.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimepickercontroldisplayoptions.html#cfn-quicksight-dashboard-datetimepickercontroldisplayoptions-datetimeformat
         */
        readonly dateTimeFormat?: string;
        /**
         * The configuration of info icon label options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimepickercontroldisplayoptions.html#cfn-quicksight-dashboard-datetimepickercontroldisplayoptions-infoiconlabeloptions
         */
        readonly infoIconLabelOptions?: cdk.IResolvable | CfnDashboard.SheetControlInfoIconLabelOptionsProperty;
        /**
         * The options to configure the title visibility, name, and font size.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimepickercontroldisplayoptions.html#cfn-quicksight-dashboard-datetimepickercontroldisplayoptions-titleoptions
         */
        readonly titleOptions?: cdk.IResolvable | CfnDashboard.LabelOptionsProperty;
    }
    /**
     * A text box.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheettextbox.html
     */
    interface SheetTextBoxProperty {
        /**
         * The content that is displayed in the text box.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheettextbox.html#cfn-quicksight-dashboard-sheettextbox-content
         */
        readonly content?: string;
        /**
         * The unique identifier for a text box.
         *
         * This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have text boxes that share identifiers.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheettextbox.html#cfn-quicksight-dashboard-sheettextbox-sheettextboxid
         */
        readonly sheetTextBoxId: string;
    }
    /**
     * A `Layout` defines the placement of elements within a sheet.
     *
     * For more information, see [Types of layout](https://docs.aws.amazon.com/quicksight/latest/user/types-of-layout.html) in the *Amazon QuickSight User Guide* .
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-layout.html
     */
    interface LayoutProperty {
        /**
         * The configuration that determines what the type of layout for a sheet.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-layout.html#cfn-quicksight-dashboard-layout-configuration
         */
        readonly configuration: cdk.IResolvable | CfnDashboard.LayoutConfigurationProperty;
    }
    /**
     * The configuration that determines what the type of layout will be used on a sheet.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-layoutconfiguration.html
     */
    interface LayoutConfigurationProperty {
        /**
         * A free-form is optimized for a fixed width and has more control over the exact placement of layout elements.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-layoutconfiguration.html#cfn-quicksight-dashboard-layoutconfiguration-freeformlayout
         */
        readonly freeFormLayout?: CfnDashboard.FreeFormLayoutConfigurationProperty | cdk.IResolvable;
        /**
         * A type of layout that can be used on a sheet.
         *
         * In a grid layout, visuals snap to a grid with standard spacing and alignment. Dashboards are displayed as designed, with options to fit to screen or view at actual size. A grid layout can be configured to behave in one of two ways when the viewport is resized: `FIXED` or `RESPONSIVE` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-layoutconfiguration.html#cfn-quicksight-dashboard-layoutconfiguration-gridlayout
         */
        readonly gridLayout?: CfnDashboard.GridLayoutConfigurationProperty | cdk.IResolvable;
        /**
         * A section based layout organizes visuals into multiple sections and has customized header, footer and page break.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-layoutconfiguration.html#cfn-quicksight-dashboard-layoutconfiguration-sectionbasedlayout
         */
        readonly sectionBasedLayout?: cdk.IResolvable | CfnDashboard.SectionBasedLayoutConfigurationProperty;
    }
    /**
     * The configuration for a grid layout. Also called a tiled layout.
     *
     * Visuals snap to a grid with standard spacing and alignment. Dashboards are displayed as designed, with options to fit to screen or view at actual size.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutconfiguration.html
     */
    interface GridLayoutConfigurationProperty {
        /**
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutconfiguration.html#cfn-quicksight-dashboard-gridlayoutconfiguration-canvassizeoptions
         */
        readonly canvasSizeOptions?: CfnDashboard.GridLayoutCanvasSizeOptionsProperty | cdk.IResolvable;
        /**
         * The elements that are included in a grid layout.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutconfiguration.html#cfn-quicksight-dashboard-gridlayoutconfiguration-elements
         */
        readonly elements: Array<CfnDashboard.GridLayoutElementProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * An element within a grid layout.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutelement.html
     */
    interface GridLayoutElementProperty {
        /**
         * The column index for the upper left corner of an element.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutelement.html#cfn-quicksight-dashboard-gridlayoutelement-columnindex
         */
        readonly columnIndex?: number;
        /**
         * The width of a grid element expressed as a number of grid columns.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutelement.html#cfn-quicksight-dashboard-gridlayoutelement-columnspan
         */
        readonly columnSpan: number;
        /**
         * A unique identifier for an element within a grid layout.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutelement.html#cfn-quicksight-dashboard-gridlayoutelement-elementid
         */
        readonly elementId: string;
        /**
         * The type of element.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutelement.html#cfn-quicksight-dashboard-gridlayoutelement-elementtype
         */
        readonly elementType: string;
        /**
         * The row index for the upper left corner of an element.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutelement.html#cfn-quicksight-dashboard-gridlayoutelement-rowindex
         */
        readonly rowIndex?: number;
        /**
         * The height of a grid element expressed as a number of grid rows.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutelement.html#cfn-quicksight-dashboard-gridlayoutelement-rowspan
         */
        readonly rowSpan: number;
    }
    /**
     * The configuration of a free-form layout.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutconfiguration.html
     */
    interface FreeFormLayoutConfigurationProperty {
        /**
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutconfiguration.html#cfn-quicksight-dashboard-freeformlayoutconfiguration-canvassizeoptions
         */
        readonly canvasSizeOptions?: CfnDashboard.FreeFormLayoutCanvasSizeOptionsProperty | cdk.IResolvable;
        /**
         * The elements that are included in a free-form layout.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutconfiguration.html#cfn-quicksight-dashboard-freeformlayoutconfiguration-elements
         */
        readonly elements: Array<CfnDashboard.FreeFormLayoutElementProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * An element within a free-form layout.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelement.html
     */
    interface FreeFormLayoutElementProperty {
        /**
         * The background style configuration of a free-form layout element.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelement.html#cfn-quicksight-dashboard-freeformlayoutelement-backgroundstyle
         */
        readonly backgroundStyle?: CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty | cdk.IResolvable;
        /**
         * The border style configuration of a free-form layout element.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelement.html#cfn-quicksight-dashboard-freeformlayoutelement-borderstyle
         */
        readonly borderStyle?: CfnDashboard.FreeFormLayoutElementBorderStyleProperty | cdk.IResolvable;
        /**
         * A unique identifier for an element within a free-form layout.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelement.html#cfn-quicksight-dashboard-freeformlayoutelement-elementid
         */
        readonly elementId: string;
        /**
         * The type of element.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelement.html#cfn-quicksight-dashboard-freeformlayoutelement-elementtype
         */
        readonly elementType: string;
        /**
         * The height of an element within a free-form layout.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelement.html#cfn-quicksight-dashboard-freeformlayoutelement-height
         */
        readonly height: string;
        /**
         * The loading animation configuration of a free-form layout element.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelement.html#cfn-quicksight-dashboard-freeformlayoutelement-loadinganimation
         */
        readonly loadingAnimation?: cdk.IResolvable | CfnDashboard.LoadingAnimationProperty;
        /**
         * The rendering rules that determine when an element should be displayed within a free-form layout.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelement.html#cfn-quicksight-dashboard-freeformlayoutelement-renderingrules
         */
        readonly renderingRules?: Array<cdk.IResolvable | CfnDashboard.SheetElementRenderingRuleProperty> | cdk.IResolvable;
        /**
         * The border style configuration of a free-form layout element.
         *
         * This border style is used when the element is selected.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelement.html#cfn-quicksight-dashboard-freeformlayoutelement-selectedborderstyle
         */
        readonly selectedBorderStyle?: CfnDashboard.FreeFormLayoutElementBorderStyleProperty | cdk.IResolvable;
        /**
         * The visibility of an element within a free-form layout.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelement.html#cfn-quicksight-dashboard-freeformlayoutelement-visibility
         */
        readonly visibility?: string;
        /**
         * The width of an element within a free-form layout.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelement.html#cfn-quicksight-dashboard-freeformlayoutelement-width
         */
        readonly width: string;
        /**
         * The x-axis coordinate of the element.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelement.html#cfn-quicksight-dashboard-freeformlayoutelement-xaxislocation
         */
        readonly xAxisLocation: string;
        /**
         * The y-axis coordinate of the element.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelement.html#cfn-quicksight-dashboard-freeformlayoutelement-yaxislocation
         */
        readonly yAxisLocation: string;
    }
    /**
     * The background style configuration of a free-form layout element.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelementborderstyle.html
     */
    interface FreeFormLayoutElementBorderStyleProperty {
        /**
         * The border color of a free-form layout element.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelementborderstyle.html#cfn-quicksight-dashboard-freeformlayoutelementborderstyle-color
         */
        readonly color?: string;
        /**
         * The border visibility of a free-form layout element.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelementborderstyle.html#cfn-quicksight-dashboard-freeformlayoutelementborderstyle-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The rendering rules of a sheet that uses a free-form layout.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetelementrenderingrule.html
     */
    interface SheetElementRenderingRuleProperty {
        /**
         * The override configuration of the rendering rules of a sheet.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetelementrenderingrule.html#cfn-quicksight-dashboard-sheetelementrenderingrule-configurationoverrides
         */
        readonly configurationOverrides: cdk.IResolvable | CfnDashboard.SheetElementConfigurationOverridesProperty;
        /**
         * The expression of the rendering rules of a sheet.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetelementrenderingrule.html#cfn-quicksight-dashboard-sheetelementrenderingrule-expression
         */
        readonly expression: string;
    }
    /**
     * The override configuration of the rendering rules of a sheet.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetelementconfigurationoverrides.html
     */
    interface SheetElementConfigurationOverridesProperty {
        /**
         * Determines whether or not the overrides are visible. Choose one of the following options:.
         *
         * - `VISIBLE`
         * - `HIDDEN`
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetelementconfigurationoverrides.html#cfn-quicksight-dashboard-sheetelementconfigurationoverrides-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The configuration of loading animation in free-form layout.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-loadinganimation.html
     */
    interface LoadingAnimationProperty {
        /**
         * The visibility configuration of `LoadingAnimation` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-loadinganimation.html#cfn-quicksight-dashboard-loadinganimation-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The background style configuration of a free-form layout element.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelementbackgroundstyle.html
     */
    interface FreeFormLayoutElementBackgroundStyleProperty {
        /**
         * The background color of a free-form layout element.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelementbackgroundstyle.html#cfn-quicksight-dashboard-freeformlayoutelementbackgroundstyle-color
         */
        readonly color?: string;
        /**
         * The background visibility of a free-form layout element.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelementbackgroundstyle.html#cfn-quicksight-dashboard-freeformlayoutelementbackgroundstyle-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The configuration for a section-based layout.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionbasedlayoutconfiguration.html
     */
    interface SectionBasedLayoutConfigurationProperty {
        /**
         * A list of body section configurations.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionbasedlayoutconfiguration.html#cfn-quicksight-dashboard-sectionbasedlayoutconfiguration-bodysections
         */
        readonly bodySections: Array<CfnDashboard.BodySectionConfigurationProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The options for the canvas of a section-based layout.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionbasedlayoutconfiguration.html#cfn-quicksight-dashboard-sectionbasedlayoutconfiguration-canvassizeoptions
         */
        readonly canvasSizeOptions: cdk.IResolvable | CfnDashboard.SectionBasedLayoutCanvasSizeOptionsProperty;
        /**
         * A list of footer section configurations.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionbasedlayoutconfiguration.html#cfn-quicksight-dashboard-sectionbasedlayoutconfiguration-footersections
         */
        readonly footerSections: Array<CfnDashboard.HeaderFooterSectionConfigurationProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * A list of header section configurations.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionbasedlayoutconfiguration.html#cfn-quicksight-dashboard-sectionbasedlayoutconfiguration-headersections
         */
        readonly headerSections: Array<CfnDashboard.HeaderFooterSectionConfigurationProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * The configuration of a header or footer section.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-headerfootersectionconfiguration.html
     */
    interface HeaderFooterSectionConfigurationProperty {
        /**
         * The layout configuration of the header or footer section.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-headerfootersectionconfiguration.html#cfn-quicksight-dashboard-headerfootersectionconfiguration-layout
         */
        readonly layout: cdk.IResolvable | CfnDashboard.SectionLayoutConfigurationProperty;
        /**
         * The unique identifier of the header or footer section.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-headerfootersectionconfiguration.html#cfn-quicksight-dashboard-headerfootersectionconfiguration-sectionid
         */
        readonly sectionId: string;
        /**
         * The style options of a header or footer section.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-headerfootersectionconfiguration.html#cfn-quicksight-dashboard-headerfootersectionconfiguration-style
         */
        readonly style?: cdk.IResolvable | CfnDashboard.SectionStyleProperty;
    }
    /**
     * The layout configuration of a section.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionlayoutconfiguration.html
     */
    interface SectionLayoutConfigurationProperty {
        /**
         * The free-form layout configuration of a section.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionlayoutconfiguration.html#cfn-quicksight-dashboard-sectionlayoutconfiguration-freeformlayout
         */
        readonly freeFormLayout: CfnDashboard.FreeFormSectionLayoutConfigurationProperty | cdk.IResolvable;
    }
    /**
     * The free-form layout configuration of a section.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformsectionlayoutconfiguration.html
     */
    interface FreeFormSectionLayoutConfigurationProperty {
        /**
         * The elements that are included in the free-form layout.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformsectionlayoutconfiguration.html#cfn-quicksight-dashboard-freeformsectionlayoutconfiguration-elements
         */
        readonly elements: Array<CfnDashboard.FreeFormLayoutElementProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * The options that style a section.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionstyle.html
     */
    interface SectionStyleProperty {
        /**
         * The height of a section.
         *
         * Heights can only be defined for header and footer sections. The default height margin is 0.5 inches.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionstyle.html#cfn-quicksight-dashboard-sectionstyle-height
         */
        readonly height?: string;
        /**
         * The spacing between section content and its top, bottom, left, and right edges.
         *
         * There is no padding by default.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionstyle.html#cfn-quicksight-dashboard-sectionstyle-padding
         */
        readonly padding?: cdk.IResolvable | CfnDashboard.SpacingProperty;
    }
    /**
     * The configuration of a body section.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-bodysectionconfiguration.html
     */
    interface BodySectionConfigurationProperty {
        /**
         * The configuration of content in a body section.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-bodysectionconfiguration.html#cfn-quicksight-dashboard-bodysectionconfiguration-content
         */
        readonly content: CfnDashboard.BodySectionContentProperty | cdk.IResolvable;
        /**
         * The configuration of a page break for a section.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-bodysectionconfiguration.html#cfn-quicksight-dashboard-bodysectionconfiguration-pagebreakconfiguration
         */
        readonly pageBreakConfiguration?: cdk.IResolvable | CfnDashboard.SectionPageBreakConfigurationProperty;
        /**
         * The unique identifier of a body section.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-bodysectionconfiguration.html#cfn-quicksight-dashboard-bodysectionconfiguration-sectionid
         */
        readonly sectionId: string;
        /**
         * The style options of a body section.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-bodysectionconfiguration.html#cfn-quicksight-dashboard-bodysectionconfiguration-style
         */
        readonly style?: cdk.IResolvable | CfnDashboard.SectionStyleProperty;
    }
    /**
     * The configuration of content in a body section.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-bodysectioncontent.html
     */
    interface BodySectionContentProperty {
        /**
         * The layout configuration of a body section.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-bodysectioncontent.html#cfn-quicksight-dashboard-bodysectioncontent-layout
         */
        readonly layout?: cdk.IResolvable | CfnDashboard.SectionLayoutConfigurationProperty;
    }
    /**
     * The configuration of a page break for a section.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionpagebreakconfiguration.html
     */
    interface SectionPageBreakConfigurationProperty {
        /**
         * The configuration of a page break after a section.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionpagebreakconfiguration.html#cfn-quicksight-dashboard-sectionpagebreakconfiguration-after
         */
        readonly after?: cdk.IResolvable | CfnDashboard.SectionAfterPageBreakProperty;
    }
    /**
     * The configuration of a page break after a section.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionafterpagebreak.html
     */
    interface SectionAfterPageBreakProperty {
        /**
         * The option that enables or disables a page break at the end of a section.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionafterpagebreak.html#cfn-quicksight-dashboard-sectionafterpagebreak-status
         */
        readonly status?: string;
    }
    /**
     * The control of a filter that is used to interact with a dashboard or an analysis.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtercontrol.html
     */
    interface FilterControlProperty {
        /**
         * A control from a date filter that is used to specify date and time.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtercontrol.html#cfn-quicksight-dashboard-filtercontrol-datetimepicker
         */
        readonly dateTimePicker?: CfnDashboard.FilterDateTimePickerControlProperty | cdk.IResolvable;
        /**
         * A control to display a dropdown list with buttons that are used to select a single value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtercontrol.html#cfn-quicksight-dashboard-filtercontrol-dropdown
         */
        readonly dropdown?: CfnDashboard.FilterDropDownControlProperty | cdk.IResolvable;
        /**
         * A control to display a list of buttons or boxes.
         *
         * This is used to select either a single value or multiple values.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtercontrol.html#cfn-quicksight-dashboard-filtercontrol-list
         */
        readonly list?: CfnDashboard.FilterListControlProperty | cdk.IResolvable;
        /**
         * A control from a date filter that is used to specify the relative date.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtercontrol.html#cfn-quicksight-dashboard-filtercontrol-relativedatetime
         */
        readonly relativeDateTime?: CfnDashboard.FilterRelativeDateTimeControlProperty | cdk.IResolvable;
        /**
         * A control to display a horizontal toggle bar.
         *
         * This is used to change a value by sliding the toggle.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtercontrol.html#cfn-quicksight-dashboard-filtercontrol-slider
         */
        readonly slider?: CfnDashboard.FilterSliderControlProperty | cdk.IResolvable;
        /**
         * A control to display a text box that is used to enter multiple entries.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtercontrol.html#cfn-quicksight-dashboard-filtercontrol-textarea
         */
        readonly textArea?: CfnDashboard.FilterTextAreaControlProperty | cdk.IResolvable;
        /**
         * A control to display a text box that is used to enter a single entry.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtercontrol.html#cfn-quicksight-dashboard-filtercontrol-textfield
         */
        readonly textField?: CfnDashboard.FilterTextFieldControlProperty | cdk.IResolvable;
    }
    /**
     * A control to display a horizontal toggle bar.
     *
     * This is used to change a value by sliding the toggle.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterslidercontrol.html
     */
    interface FilterSliderControlProperty {
        /**
         * The display options of a control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterslidercontrol.html#cfn-quicksight-dashboard-filterslidercontrol-displayoptions
         */
        readonly displayOptions?: cdk.IResolvable | CfnDashboard.SliderControlDisplayOptionsProperty;
        /**
         * The ID of the `FilterSliderControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterslidercontrol.html#cfn-quicksight-dashboard-filterslidercontrol-filtercontrolid
         */
        readonly filterControlId: string;
        /**
         * The smaller value that is displayed at the left of the slider.
         *
         * @default - 0
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterslidercontrol.html#cfn-quicksight-dashboard-filterslidercontrol-maximumvalue
         */
        readonly maximumValue: number;
        /**
         * The larger value that is displayed at the right of the slider.
         *
         * @default - 0
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterslidercontrol.html#cfn-quicksight-dashboard-filterslidercontrol-minimumvalue
         */
        readonly minimumValue: number;
        /**
         * The source filter ID of the `FilterSliderControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterslidercontrol.html#cfn-quicksight-dashboard-filterslidercontrol-sourcefilterid
         */
        readonly sourceFilterId: string;
        /**
         * The number of increments that the slider bar is divided into.
         *
         * @default - 0
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterslidercontrol.html#cfn-quicksight-dashboard-filterslidercontrol-stepsize
         */
        readonly stepSize: number;
        /**
         * The title of the `FilterSliderControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterslidercontrol.html#cfn-quicksight-dashboard-filterslidercontrol-title
         */
        readonly title: string;
        /**
         * The type of `FilterSliderControl` . Choose one of the following options:.
         *
         * - `SINGLE_POINT` : Filter against(equals) a single data point.
         * - `RANGE` : Filter data that is in a specified range.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterslidercontrol.html#cfn-quicksight-dashboard-filterslidercontrol-type
         */
        readonly type?: string;
    }
    /**
     * A control to display a text box that is used to enter multiple entries.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtertextareacontrol.html
     */
    interface FilterTextAreaControlProperty {
        /**
         * The delimiter that is used to separate the lines in text.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtertextareacontrol.html#cfn-quicksight-dashboard-filtertextareacontrol-delimiter
         */
        readonly delimiter?: string;
        /**
         * The display options of a control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtertextareacontrol.html#cfn-quicksight-dashboard-filtertextareacontrol-displayoptions
         */
        readonly displayOptions?: cdk.IResolvable | CfnDashboard.TextAreaControlDisplayOptionsProperty;
        /**
         * The ID of the `FilterTextAreaControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtertextareacontrol.html#cfn-quicksight-dashboard-filtertextareacontrol-filtercontrolid
         */
        readonly filterControlId: string;
        /**
         * The source filter ID of the `FilterTextAreaControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtertextareacontrol.html#cfn-quicksight-dashboard-filtertextareacontrol-sourcefilterid
         */
        readonly sourceFilterId: string;
        /**
         * The title of the `FilterTextAreaControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtertextareacontrol.html#cfn-quicksight-dashboard-filtertextareacontrol-title
         */
        readonly title: string;
    }
    /**
     * A control to display a dropdown list with buttons that are used to select a single value.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterdropdowncontrol.html
     */
    interface FilterDropDownControlProperty {
        /**
         * The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterdropdowncontrol.html#cfn-quicksight-dashboard-filterdropdowncontrol-cascadingcontrolconfiguration
         */
        readonly cascadingControlConfiguration?: CfnDashboard.CascadingControlConfigurationProperty | cdk.IResolvable;
        /**
         * The display options of the `FilterDropDownControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterdropdowncontrol.html#cfn-quicksight-dashboard-filterdropdowncontrol-displayoptions
         */
        readonly displayOptions?: CfnDashboard.DropDownControlDisplayOptionsProperty | cdk.IResolvable;
        /**
         * The ID of the `FilterDropDownControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterdropdowncontrol.html#cfn-quicksight-dashboard-filterdropdowncontrol-filtercontrolid
         */
        readonly filterControlId: string;
        /**
         * A list of selectable values that are used in a control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterdropdowncontrol.html#cfn-quicksight-dashboard-filterdropdowncontrol-selectablevalues
         */
        readonly selectableValues?: CfnDashboard.FilterSelectableValuesProperty | cdk.IResolvable;
        /**
         * The source filter ID of the `FilterDropDownControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterdropdowncontrol.html#cfn-quicksight-dashboard-filterdropdowncontrol-sourcefilterid
         */
        readonly sourceFilterId: string;
        /**
         * The title of the `FilterDropDownControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterdropdowncontrol.html#cfn-quicksight-dashboard-filterdropdowncontrol-title
         */
        readonly title: string;
        /**
         * The type of the `FilterDropDownControl` . Choose one of the following options:.
         *
         * - `MULTI_SELECT` : The user can select multiple entries from a dropdown menu.
         * - `SINGLE_SELECT` : The user can select a single entry from a dropdown menu.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterdropdowncontrol.html#cfn-quicksight-dashboard-filterdropdowncontrol-type
         */
        readonly type?: string;
    }
    /**
     * A list of selectable values that are used in a control.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterselectablevalues.html
     */
    interface FilterSelectableValuesProperty {
        /**
         * The values that are used in the `FilterSelectableValues` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterselectablevalues.html#cfn-quicksight-dashboard-filterselectablevalues-values
         */
        readonly values?: Array<string>;
    }
    /**
     * A control to display a text box that is used to enter a single entry.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtertextfieldcontrol.html
     */
    interface FilterTextFieldControlProperty {
        /**
         * The display options of a control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtertextfieldcontrol.html#cfn-quicksight-dashboard-filtertextfieldcontrol-displayoptions
         */
        readonly displayOptions?: cdk.IResolvable | CfnDashboard.TextFieldControlDisplayOptionsProperty;
        /**
         * The ID of the `FilterTextFieldControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtertextfieldcontrol.html#cfn-quicksight-dashboard-filtertextfieldcontrol-filtercontrolid
         */
        readonly filterControlId: string;
        /**
         * The source filter ID of the `FilterTextFieldControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtertextfieldcontrol.html#cfn-quicksight-dashboard-filtertextfieldcontrol-sourcefilterid
         */
        readonly sourceFilterId: string;
        /**
         * The title of the `FilterTextFieldControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtertextfieldcontrol.html#cfn-quicksight-dashboard-filtertextfieldcontrol-title
         */
        readonly title: string;
    }
    /**
     * A control to display a list of buttons or boxes.
     *
     * This is used to select either a single value or multiple values.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterlistcontrol.html
     */
    interface FilterListControlProperty {
        /**
         * The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterlistcontrol.html#cfn-quicksight-dashboard-filterlistcontrol-cascadingcontrolconfiguration
         */
        readonly cascadingControlConfiguration?: CfnDashboard.CascadingControlConfigurationProperty | cdk.IResolvable;
        /**
         * The display options of a control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterlistcontrol.html#cfn-quicksight-dashboard-filterlistcontrol-displayoptions
         */
        readonly displayOptions?: cdk.IResolvable | CfnDashboard.ListControlDisplayOptionsProperty;
        /**
         * The ID of the `FilterListControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterlistcontrol.html#cfn-quicksight-dashboard-filterlistcontrol-filtercontrolid
         */
        readonly filterControlId: string;
        /**
         * A list of selectable values that are used in a control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterlistcontrol.html#cfn-quicksight-dashboard-filterlistcontrol-selectablevalues
         */
        readonly selectableValues?: CfnDashboard.FilterSelectableValuesProperty | cdk.IResolvable;
        /**
         * The source filter ID of the `FilterListControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterlistcontrol.html#cfn-quicksight-dashboard-filterlistcontrol-sourcefilterid
         */
        readonly sourceFilterId: string;
        /**
         * The title of the `FilterListControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterlistcontrol.html#cfn-quicksight-dashboard-filterlistcontrol-title
         */
        readonly title: string;
        /**
         * The type of `FilterListControl` . Choose one of the following options:.
         *
         * - `MULTI_SELECT` : The user can select multiple entries from the list.
         * - `SINGLE_SELECT` : The user can select a single entry from the list.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterlistcontrol.html#cfn-quicksight-dashboard-filterlistcontrol-type
         */
        readonly type?: string;
    }
    /**
     * A control from a date filter that is used to specify date and time.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterdatetimepickercontrol.html
     */
    interface FilterDateTimePickerControlProperty {
        /**
         * The display options of a control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterdatetimepickercontrol.html#cfn-quicksight-dashboard-filterdatetimepickercontrol-displayoptions
         */
        readonly displayOptions?: CfnDashboard.DateTimePickerControlDisplayOptionsProperty | cdk.IResolvable;
        /**
         * The ID of the `FilterDateTimePickerControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterdatetimepickercontrol.html#cfn-quicksight-dashboard-filterdatetimepickercontrol-filtercontrolid
         */
        readonly filterControlId: string;
        /**
         * The source filter ID of the `FilterDateTimePickerControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterdatetimepickercontrol.html#cfn-quicksight-dashboard-filterdatetimepickercontrol-sourcefilterid
         */
        readonly sourceFilterId: string;
        /**
         * The title of the `FilterDateTimePickerControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterdatetimepickercontrol.html#cfn-quicksight-dashboard-filterdatetimepickercontrol-title
         */
        readonly title: string;
        /**
         * The date time picker type of a `FilterDateTimePickerControl` . Choose one of the following options:.
         *
         * - `SINGLE_VALUED` : The filter condition is a fixed date.
         * - `DATE_RANGE` : The filter condition is a date time range.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterdatetimepickercontrol.html#cfn-quicksight-dashboard-filterdatetimepickercontrol-type
         */
        readonly type?: string;
    }
    /**
     * A control from a date filter that is used to specify the relative date.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterrelativedatetimecontrol.html
     */
    interface FilterRelativeDateTimeControlProperty {
        /**
         * The display options of a control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterrelativedatetimecontrol.html#cfn-quicksight-dashboard-filterrelativedatetimecontrol-displayoptions
         */
        readonly displayOptions?: cdk.IResolvable | CfnDashboard.RelativeDateTimeControlDisplayOptionsProperty;
        /**
         * The ID of the `FilterTextAreaControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterrelativedatetimecontrol.html#cfn-quicksight-dashboard-filterrelativedatetimecontrol-filtercontrolid
         */
        readonly filterControlId: string;
        /**
         * The source filter ID of the `FilterTextAreaControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterrelativedatetimecontrol.html#cfn-quicksight-dashboard-filterrelativedatetimecontrol-sourcefilterid
         */
        readonly sourceFilterId: string;
        /**
         * The title of the `FilterTextAreaControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterrelativedatetimecontrol.html#cfn-quicksight-dashboard-filterrelativedatetimecontrol-title
         */
        readonly title: string;
    }
    /**
     * The display options of a control.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-relativedatetimecontroldisplayoptions.html
     */
    interface RelativeDateTimeControlDisplayOptionsProperty {
        /**
         * Customize how dates are formatted in controls.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-relativedatetimecontroldisplayoptions.html#cfn-quicksight-dashboard-relativedatetimecontroldisplayoptions-datetimeformat
         */
        readonly dateTimeFormat?: string;
        /**
         * The configuration of info icon label options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-relativedatetimecontroldisplayoptions.html#cfn-quicksight-dashboard-relativedatetimecontroldisplayoptions-infoiconlabeloptions
         */
        readonly infoIconLabelOptions?: cdk.IResolvable | CfnDashboard.SheetControlInfoIconLabelOptionsProperty;
        /**
         * The options to configure the title visibility, name, and font size.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-relativedatetimecontroldisplayoptions.html#cfn-quicksight-dashboard-relativedatetimecontroldisplayoptions-titleoptions
         */
        readonly titleOptions?: cdk.IResolvable | CfnDashboard.LabelOptionsProperty;
    }
    /**
     * A grid layout to define the placement of sheet control.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetcontrollayout.html
     */
    interface SheetControlLayoutProperty {
        /**
         * The configuration that determines the elements and canvas size options of sheet control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetcontrollayout.html#cfn-quicksight-dashboard-sheetcontrollayout-configuration
         */
        readonly configuration: cdk.IResolvable | CfnDashboard.SheetControlLayoutConfigurationProperty;
    }
    /**
     * The configuration that determines the elements and canvas size options of sheet control.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetcontrollayoutconfiguration.html
     */
    interface SheetControlLayoutConfigurationProperty {
        /**
         * The configuration that determines the elements and canvas size options of sheet control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetcontrollayoutconfiguration.html#cfn-quicksight-dashboard-sheetcontrollayoutconfiguration-gridlayout
         */
        readonly gridLayout?: CfnDashboard.GridLayoutConfigurationProperty | cdk.IResolvable;
    }
    /**
     * A visual displayed on a sheet in an analysis, dashboard, or template.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html
     */
    interface VisualProperty {
        /**
         * A bar chart.
         *
         * For more information, see [Using bar charts](https://docs.aws.amazon.com/quicksight/latest/user/bar-charts.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-barchartvisual
         */
        readonly barChartVisual?: CfnDashboard.BarChartVisualProperty | cdk.IResolvable;
        /**
         * A box plot.
         *
         * For more information, see [Using box plots](https://docs.aws.amazon.com/quicksight/latest/user/box-plots.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-boxplotvisual
         */
        readonly boxPlotVisual?: CfnDashboard.BoxPlotVisualProperty | cdk.IResolvable;
        /**
         * A combo chart.
         *
         * For more information, see [Using combo charts](https://docs.aws.amazon.com/quicksight/latest/user/combo-charts.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-combochartvisual
         */
        readonly comboChartVisual?: CfnDashboard.ComboChartVisualProperty | cdk.IResolvable;
        /**
         * A visual that contains custom content.
         *
         * For more information, see [Using custom visual content](https://docs.aws.amazon.com/quicksight/latest/user/custom-visual-content.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-customcontentvisual
         */
        readonly customContentVisual?: CfnDashboard.CustomContentVisualProperty | cdk.IResolvable;
        /**
         * An empty visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-emptyvisual
         */
        readonly emptyVisual?: CfnDashboard.EmptyVisualProperty | cdk.IResolvable;
        /**
         * A filled map.
         *
         * For more information, see [Creating filled maps](https://docs.aws.amazon.com/quicksight/latest/user/filled-maps.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-filledmapvisual
         */
        readonly filledMapVisual?: CfnDashboard.FilledMapVisualProperty | cdk.IResolvable;
        /**
         * A funnel chart.
         *
         * For more information, see [Using funnel charts](https://docs.aws.amazon.com/quicksight/latest/user/funnel-visual-content.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-funnelchartvisual
         */
        readonly funnelChartVisual?: CfnDashboard.FunnelChartVisualProperty | cdk.IResolvable;
        /**
         * A gauge chart.
         *
         * For more information, see [Using gauge charts](https://docs.aws.amazon.com/quicksight/latest/user/gauge-chart.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-gaugechartvisual
         */
        readonly gaugeChartVisual?: CfnDashboard.GaugeChartVisualProperty | cdk.IResolvable;
        /**
         * A geospatial map or a points on map visual.
         *
         * For more information, see [Creating point maps](https://docs.aws.amazon.com/quicksight/latest/user/point-maps.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-geospatialmapvisual
         */
        readonly geospatialMapVisual?: CfnDashboard.GeospatialMapVisualProperty | cdk.IResolvable;
        /**
         * A heat map.
         *
         * For more information, see [Using heat maps](https://docs.aws.amazon.com/quicksight/latest/user/heat-map.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-heatmapvisual
         */
        readonly heatMapVisual?: CfnDashboard.HeatMapVisualProperty | cdk.IResolvable;
        /**
         * A histogram.
         *
         * For more information, see [Using histograms](https://docs.aws.amazon.com/quicksight/latest/user/histogram-charts.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-histogramvisual
         */
        readonly histogramVisual?: CfnDashboard.HistogramVisualProperty | cdk.IResolvable;
        /**
         * An insight visual.
         *
         * For more information, see [Working with insights](https://docs.aws.amazon.com/quicksight/latest/user/computational-insights.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-insightvisual
         */
        readonly insightVisual?: CfnDashboard.InsightVisualProperty | cdk.IResolvable;
        /**
         * A key performance indicator (KPI).
         *
         * For more information, see [Using KPIs](https://docs.aws.amazon.com/quicksight/latest/user/kpi.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-kpivisual
         */
        readonly kpiVisual?: cdk.IResolvable | CfnDashboard.KPIVisualProperty;
        /**
         * A line chart.
         *
         * For more information, see [Using line charts](https://docs.aws.amazon.com/quicksight/latest/user/line-charts.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-linechartvisual
         */
        readonly lineChartVisual?: cdk.IResolvable | CfnDashboard.LineChartVisualProperty;
        /**
         * A pie or donut chart.
         *
         * For more information, see [Using pie charts](https://docs.aws.amazon.com/quicksight/latest/user/pie-chart.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-piechartvisual
         */
        readonly pieChartVisual?: cdk.IResolvable | CfnDashboard.PieChartVisualProperty;
        /**
         * A pivot table.
         *
         * For more information, see [Using pivot tables](https://docs.aws.amazon.com/quicksight/latest/user/pivot-table.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-pivottablevisual
         */
        readonly pivotTableVisual?: cdk.IResolvable | CfnDashboard.PivotTableVisualProperty;
        /**
         * A radar chart visual.
         *
         * For more information, see [Using radar charts](https://docs.aws.amazon.com/quicksight/latest/user/radar-chart.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-radarchartvisual
         */
        readonly radarChartVisual?: cdk.IResolvable | CfnDashboard.RadarChartVisualProperty;
        /**
         * A sankey diagram.
         *
         * For more information, see [Using Sankey diagrams](https://docs.aws.amazon.com/quicksight/latest/user/sankey-diagram.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-sankeydiagramvisual
         */
        readonly sankeyDiagramVisual?: cdk.IResolvable | CfnDashboard.SankeyDiagramVisualProperty;
        /**
         * A scatter plot.
         *
         * For more information, see [Using scatter plots](https://docs.aws.amazon.com/quicksight/latest/user/scatter-plot.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-scatterplotvisual
         */
        readonly scatterPlotVisual?: cdk.IResolvable | CfnDashboard.ScatterPlotVisualProperty;
        /**
         * A table visual.
         *
         * For more information, see [Using tables as visuals](https://docs.aws.amazon.com/quicksight/latest/user/tabular.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-tablevisual
         */
        readonly tableVisual?: cdk.IResolvable | CfnDashboard.TableVisualProperty;
        /**
         * A tree map.
         *
         * For more information, see [Using tree maps](https://docs.aws.amazon.com/quicksight/latest/user/tree-map.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-treemapvisual
         */
        readonly treeMapVisual?: cdk.IResolvable | CfnDashboard.TreeMapVisualProperty;
        /**
         * A waterfall chart.
         *
         * For more information, see [Using waterfall charts](https://docs.aws.amazon.com/quicksight/latest/user/waterfall-chart.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-waterfallvisual
         */
        readonly waterfallVisual?: cdk.IResolvable | CfnDashboard.WaterfallVisualProperty;
        /**
         * A word cloud.
         *
         * For more information, see [Using word clouds](https://docs.aws.amazon.com/quicksight/latest/user/word-cloud.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-wordcloudvisual
         */
        readonly wordCloudVisual?: cdk.IResolvable | CfnDashboard.WordCloudVisualProperty;
    }
    /**
     * A funnel chart.
     *
     * For more information, see [Using funnel charts](https://docs.aws.amazon.com/quicksight/latest/user/funnel-visual-content.html) in the *Amazon QuickSight User Guide* .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartvisual.html
     */
    interface FunnelChartVisualProperty {
        /**
         * The list of custom actions that are configured for a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartvisual.html#cfn-quicksight-dashboard-funnelchartvisual-actions
         */
        readonly actions?: Array<cdk.IResolvable | CfnDashboard.VisualCustomActionProperty> | cdk.IResolvable;
        /**
         * The configuration of a `FunnelChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartvisual.html#cfn-quicksight-dashboard-funnelchartvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnDashboard.FunnelChartConfigurationProperty | cdk.IResolvable;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartvisual.html#cfn-quicksight-dashboard-funnelchartvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnDashboard.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The subtitle that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartvisual.html#cfn-quicksight-dashboard-funnelchartvisual-subtitle
         */
        readonly subtitle?: cdk.IResolvable | CfnDashboard.VisualSubtitleLabelOptionsProperty;
        /**
         * The title that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartvisual.html#cfn-quicksight-dashboard-funnelchartvisual-title
         */
        readonly title?: cdk.IResolvable | CfnDashboard.VisualTitleLabelOptionsProperty;
        /**
         * The unique identifier of a visual.
         *
         * This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartvisual.html#cfn-quicksight-dashboard-funnelchartvisual-visualid
         */
        readonly visualId: string;
    }
    /**
     * The subtitle label options for a visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualsubtitlelabeloptions.html
     */
    interface VisualSubtitleLabelOptionsProperty {
        /**
         * The long text format of the subtitle label, such as plain text or rich text.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualsubtitlelabeloptions.html#cfn-quicksight-dashboard-visualsubtitlelabeloptions-formattext
         */
        readonly formatText?: cdk.IResolvable | CfnDashboard.LongFormatTextProperty;
        /**
         * The visibility of the subtitle label.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualsubtitlelabeloptions.html#cfn-quicksight-dashboard-visualsubtitlelabeloptions-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The text format for a subtitle.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-longformattext.html
     */
    interface LongFormatTextProperty {
        /**
         * Plain text format.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-longformattext.html#cfn-quicksight-dashboard-longformattext-plaintext
         */
        readonly plainText?: string;
        /**
         * Rich text.
         *
         * Examples of rich text include bold, underline, and italics.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-longformattext.html#cfn-quicksight-dashboard-longformattext-richtext
         */
        readonly richText?: string;
    }
    /**
     * The configuration of a `FunnelChartVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartconfiguration.html
     */
    interface FunnelChartConfigurationProperty {
        /**
         * The label options of the categories that are displayed in a `FunnelChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartconfiguration.html#cfn-quicksight-dashboard-funnelchartconfiguration-categorylabeloptions
         */
        readonly categoryLabelOptions?: CfnDashboard.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The options that determine the presentation of the data labels.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartconfiguration.html#cfn-quicksight-dashboard-funnelchartconfiguration-datalabeloptions
         */
        readonly dataLabelOptions?: CfnDashboard.FunnelChartDataLabelOptionsProperty | cdk.IResolvable;
        /**
         * The field well configuration of a `FunnelChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartconfiguration.html#cfn-quicksight-dashboard-funnelchartconfiguration-fieldwells
         */
        readonly fieldWells?: CfnDashboard.FunnelChartFieldWellsProperty | cdk.IResolvable;
        /**
         * The sort configuration of a `FunnelChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartconfiguration.html#cfn-quicksight-dashboard-funnelchartconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: CfnDashboard.FunnelChartSortConfigurationProperty | cdk.IResolvable;
        /**
         * The tooltip configuration of a `FunnelChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartconfiguration.html#cfn-quicksight-dashboard-funnelchartconfiguration-tooltip
         */
        readonly tooltip?: cdk.IResolvable | CfnDashboard.TooltipOptionsProperty;
        /**
         * The label options for the values that are displayed in a `FunnelChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartconfiguration.html#cfn-quicksight-dashboard-funnelchartconfiguration-valuelabeloptions
         */
        readonly valueLabelOptions?: CfnDashboard.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The visual palette configuration of a `FunnelChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartconfiguration.html#cfn-quicksight-dashboard-funnelchartconfiguration-visualpalette
         */
        readonly visualPalette?: cdk.IResolvable | CfnDashboard.VisualPaletteProperty;
    }
    /**
     * The sort configuration of a `FunnelChartVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartsortconfiguration.html
     */
    interface FunnelChartSortConfigurationProperty {
        /**
         * The limit on the number of categories displayed.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartsortconfiguration.html#cfn-quicksight-dashboard-funnelchartsortconfiguration-categoryitemslimit
         */
        readonly categoryItemsLimit?: cdk.IResolvable | CfnDashboard.ItemsLimitConfigurationProperty;
        /**
         * The sort configuration of the category fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartsortconfiguration.html#cfn-quicksight-dashboard-funnelchartsortconfiguration-categorysort
         */
        readonly categorySort?: Array<CfnDashboard.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * The limit configuration of the visual display for an axis.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-itemslimitconfiguration.html
     */
    interface ItemsLimitConfigurationProperty {
        /**
         * The limit on how many items of a field are showed in the chart.
         *
         * For example, the number of slices that are displayed in a pie chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-itemslimitconfiguration.html#cfn-quicksight-dashboard-itemslimitconfiguration-itemslimit
         */
        readonly itemsLimit?: number;
        /**
         * The `Show other` of an axis in the chart. Choose one of the following options:.
         *
         * - `INCLUDE`
         * - `EXCLUDE`
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-itemslimitconfiguration.html#cfn-quicksight-dashboard-itemslimitconfiguration-othercategories
         */
        readonly otherCategories?: string;
    }
    /**
     * The field sort options in a chart configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldsortoptions.html
     */
    interface FieldSortOptionsProperty {
        /**
         * The sort configuration for a column that is not used in a field well.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldsortoptions.html#cfn-quicksight-dashboard-fieldsortoptions-columnsort
         */
        readonly columnSort?: CfnDashboard.ColumnSortProperty | cdk.IResolvable;
        /**
         * The sort configuration for a field in a field well.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldsortoptions.html#cfn-quicksight-dashboard-fieldsortoptions-fieldsort
         */
        readonly fieldSort?: CfnDashboard.FieldSortProperty | cdk.IResolvable;
    }
    /**
     * The sort configuration for a field in a field well.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldsort.html
     */
    interface FieldSortProperty {
        /**
         * The sort direction. Choose one of the following options:.
         *
         * - `ASC` : Ascending
         * - `DESC` : Descending
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldsort.html#cfn-quicksight-dashboard-fieldsort-direction
         */
        readonly direction: string;
        /**
         * The sort configuration target field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldsort.html#cfn-quicksight-dashboard-fieldsort-fieldid
         */
        readonly fieldId: string;
    }
    /**
     * The sort configuration for a column that is not used in a field well.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnsort.html
     */
    interface ColumnSortProperty {
        /**
         * The aggregation function that is defined in the column sort.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnsort.html#cfn-quicksight-dashboard-columnsort-aggregationfunction
         */
        readonly aggregationFunction?: CfnDashboard.AggregationFunctionProperty | cdk.IResolvable;
        /**
         * The sort direction.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnsort.html#cfn-quicksight-dashboard-columnsort-direction
         */
        readonly direction: string;
        /**
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnsort.html#cfn-quicksight-dashboard-columnsort-sortby
         */
        readonly sortBy: CfnDashboard.ColumnIdentifierProperty | cdk.IResolvable;
    }
    /**
     * The options that determine the presentation of the data labels.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartdatalabeloptions.html
     */
    interface FunnelChartDataLabelOptionsProperty {
        /**
         * The visibility of the category labels within the data labels.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartdatalabeloptions.html#cfn-quicksight-dashboard-funnelchartdatalabeloptions-categorylabelvisibility
         */
        readonly categoryLabelVisibility?: string;
        /**
         * The color of the data label text.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartdatalabeloptions.html#cfn-quicksight-dashboard-funnelchartdatalabeloptions-labelcolor
         */
        readonly labelColor?: string;
        /**
         * The font configuration for the data labels.
         *
         * Only the `FontSize` attribute of the font configuration is used for data labels.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartdatalabeloptions.html#cfn-quicksight-dashboard-funnelchartdatalabeloptions-labelfontconfiguration
         */
        readonly labelFontConfiguration?: CfnDashboard.FontConfigurationProperty | cdk.IResolvable;
        /**
         * Determines the style of the metric labels.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartdatalabeloptions.html#cfn-quicksight-dashboard-funnelchartdatalabeloptions-measuredatalabelstyle
         */
        readonly measureDataLabelStyle?: string;
        /**
         * The visibility of the measure labels within the data labels.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartdatalabeloptions.html#cfn-quicksight-dashboard-funnelchartdatalabeloptions-measurelabelvisibility
         */
        readonly measureLabelVisibility?: string;
        /**
         * Determines the positioning of the data label relative to a section of the funnel.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartdatalabeloptions.html#cfn-quicksight-dashboard-funnelchartdatalabeloptions-position
         */
        readonly position?: string;
        /**
         * The visibility option that determines if data labels are displayed.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartdatalabeloptions.html#cfn-quicksight-dashboard-funnelchartdatalabeloptions-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The label options for an axis on a chart.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-chartaxislabeloptions.html
     */
    interface ChartAxisLabelOptionsProperty {
        /**
         * The label options for a chart axis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-chartaxislabeloptions.html#cfn-quicksight-dashboard-chartaxislabeloptions-axislabeloptions
         */
        readonly axisLabelOptions?: Array<CfnDashboard.AxisLabelOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The visibility configuration of the sort icon on a chart's axis label.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-chartaxislabeloptions.html#cfn-quicksight-dashboard-chartaxislabeloptions-sorticonvisibility
         */
        readonly sortIconVisibility?: string;
        /**
         * The visibility of an axis label on a chart. Choose one of the following options:.
         *
         * - `VISIBLE` : Shows the axis.
         * - `HIDDEN` : Hides the axis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-chartaxislabeloptions.html#cfn-quicksight-dashboard-chartaxislabeloptions-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The label options for a chart axis.
     *
     * You must specify the field that the label is targeted to.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axislabeloptions.html
     */
    interface AxisLabelOptionsProperty {
        /**
         * The options that indicate which field the label belongs to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axislabeloptions.html#cfn-quicksight-dashboard-axislabeloptions-applyto
         */
        readonly applyTo?: CfnDashboard.AxisLabelReferenceOptionsProperty | cdk.IResolvable;
        /**
         * The text for the axis label.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axislabeloptions.html#cfn-quicksight-dashboard-axislabeloptions-customlabel
         */
        readonly customLabel?: string;
        /**
         * The font configuration of the axis label.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axislabeloptions.html#cfn-quicksight-dashboard-axislabeloptions-fontconfiguration
         */
        readonly fontConfiguration?: CfnDashboard.FontConfigurationProperty | cdk.IResolvable;
    }
    /**
     * The reference that specifies where the axis label is applied to.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axislabelreferenceoptions.html
     */
    interface AxisLabelReferenceOptionsProperty {
        /**
         * The column that the axis label is targeted to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axislabelreferenceoptions.html#cfn-quicksight-dashboard-axislabelreferenceoptions-column
         */
        readonly column: CfnDashboard.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * The field that the axis label is targeted to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axislabelreferenceoptions.html#cfn-quicksight-dashboard-axislabelreferenceoptions-fieldid
         */
        readonly fieldId: string;
    }
    /**
     * The field well configuration of a `FunnelChartVisual` .
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartfieldwells.html
     */
    interface FunnelChartFieldWellsProperty {
        /**
         * The field well configuration of a `FunnelChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartfieldwells.html#cfn-quicksight-dashboard-funnelchartfieldwells-funnelchartaggregatedfieldwells
         */
        readonly funnelChartAggregatedFieldWells?: CfnDashboard.FunnelChartAggregatedFieldWellsProperty | cdk.IResolvable;
    }
    /**
     * The field well configuration of a `FunnelChartVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartaggregatedfieldwells.html
     */
    interface FunnelChartAggregatedFieldWellsProperty {
        /**
         * The category field wells of a funnel chart.
         *
         * Values are grouped by category fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartaggregatedfieldwells.html#cfn-quicksight-dashboard-funnelchartaggregatedfieldwells-category
         */
        readonly category?: Array<CfnDashboard.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The value field wells of a funnel chart.
         *
         * Values are aggregated based on categories.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartaggregatedfieldwells.html#cfn-quicksight-dashboard-funnelchartaggregatedfieldwells-values
         */
        readonly values?: Array<cdk.IResolvable | CfnDashboard.MeasureFieldProperty> | cdk.IResolvable;
    }
    /**
     * The dimension type field.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dimensionfield.html
     */
    interface DimensionFieldProperty {
        /**
         * The dimension type field with categorical type columns.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dimensionfield.html#cfn-quicksight-dashboard-dimensionfield-categoricaldimensionfield
         */
        readonly categoricalDimensionField?: CfnDashboard.CategoricalDimensionFieldProperty | cdk.IResolvable;
        /**
         * The dimension type field with date type columns.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dimensionfield.html#cfn-quicksight-dashboard-dimensionfield-datedimensionfield
         */
        readonly dateDimensionField?: CfnDashboard.DateDimensionFieldProperty | cdk.IResolvable;
        /**
         * The dimension type field with numerical type columns.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dimensionfield.html#cfn-quicksight-dashboard-dimensionfield-numericaldimensionfield
         */
        readonly numericalDimensionField?: cdk.IResolvable | CfnDashboard.NumericalDimensionFieldProperty;
    }
    /**
     * The dimension type field with date type columns.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datedimensionfield.html
     */
    interface DateDimensionFieldProperty {
        /**
         * The column that is used in the `DateDimensionField` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datedimensionfield.html#cfn-quicksight-dashboard-datedimensionfield-column
         */
        readonly column: CfnDashboard.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * The date granularity of the `DateDimensionField` . Choose one of the following options:.
         *
         * - `YEAR`
         * - `QUARTER`
         * - `MONTH`
         * - `WEEK`
         * - `DAY`
         * - `HOUR`
         * - `MINUTE`
         * - `SECOND`
         * - `MILLISECOND`
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datedimensionfield.html#cfn-quicksight-dashboard-datedimensionfield-dategranularity
         */
        readonly dateGranularity?: string;
        /**
         * The custom field ID.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datedimensionfield.html#cfn-quicksight-dashboard-datedimensionfield-fieldid
         */
        readonly fieldId: string;
        /**
         * The format configuration of the field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datedimensionfield.html#cfn-quicksight-dashboard-datedimensionfield-formatconfiguration
         */
        readonly formatConfiguration?: CfnDashboard.DateTimeFormatConfigurationProperty | cdk.IResolvable;
        /**
         * The custom hierarchy ID.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datedimensionfield.html#cfn-quicksight-dashboard-datedimensionfield-hierarchyid
         */
        readonly hierarchyId?: string;
    }
    /**
     * The dimension type field with numerical type columns.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericaldimensionfield.html
     */
    interface NumericalDimensionFieldProperty {
        /**
         * The column that is used in the `NumericalDimensionField` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericaldimensionfield.html#cfn-quicksight-dashboard-numericaldimensionfield-column
         */
        readonly column: CfnDashboard.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * The custom field ID.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericaldimensionfield.html#cfn-quicksight-dashboard-numericaldimensionfield-fieldid
         */
        readonly fieldId: string;
        /**
         * The format configuration of the field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericaldimensionfield.html#cfn-quicksight-dashboard-numericaldimensionfield-formatconfiguration
         */
        readonly formatConfiguration?: cdk.IResolvable | CfnDashboard.NumberFormatConfigurationProperty;
        /**
         * The custom hierarchy ID.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericaldimensionfield.html#cfn-quicksight-dashboard-numericaldimensionfield-hierarchyid
         */
        readonly hierarchyId?: string;
    }
    /**
     * The dimension type field with categorical type columns..
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoricaldimensionfield.html
     */
    interface CategoricalDimensionFieldProperty {
        /**
         * The column that is used in the `CategoricalDimensionField` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoricaldimensionfield.html#cfn-quicksight-dashboard-categoricaldimensionfield-column
         */
        readonly column: CfnDashboard.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * The custom field ID.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoricaldimensionfield.html#cfn-quicksight-dashboard-categoricaldimensionfield-fieldid
         */
        readonly fieldId: string;
        /**
         * The format configuration of the field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoricaldimensionfield.html#cfn-quicksight-dashboard-categoricaldimensionfield-formatconfiguration
         */
        readonly formatConfiguration?: cdk.IResolvable | CfnDashboard.StringFormatConfigurationProperty;
        /**
         * The custom hierarchy ID.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoricaldimensionfield.html#cfn-quicksight-dashboard-categoricaldimensionfield-hierarchyid
         */
        readonly hierarchyId?: string;
    }
    /**
     * The measure (metric) type field.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-measurefield.html
     */
    interface MeasureFieldProperty {
        /**
         * The calculated measure field only used in pivot tables.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-measurefield.html#cfn-quicksight-dashboard-measurefield-calculatedmeasurefield
         */
        readonly calculatedMeasureField?: CfnDashboard.CalculatedMeasureFieldProperty | cdk.IResolvable;
        /**
         * The measure type field with categorical type columns.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-measurefield.html#cfn-quicksight-dashboard-measurefield-categoricalmeasurefield
         */
        readonly categoricalMeasureField?: CfnDashboard.CategoricalMeasureFieldProperty | cdk.IResolvable;
        /**
         * The measure type field with date type columns.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-measurefield.html#cfn-quicksight-dashboard-measurefield-datemeasurefield
         */
        readonly dateMeasureField?: CfnDashboard.DateMeasureFieldProperty | cdk.IResolvable;
        /**
         * The measure type field with numerical type columns.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-measurefield.html#cfn-quicksight-dashboard-measurefield-numericalmeasurefield
         */
        readonly numericalMeasureField?: cdk.IResolvable | CfnDashboard.NumericalMeasureFieldProperty;
    }
    /**
     * The measure type field with date type columns.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datemeasurefield.html
     */
    interface DateMeasureFieldProperty {
        /**
         * The aggregation function of the measure field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datemeasurefield.html#cfn-quicksight-dashboard-datemeasurefield-aggregationfunction
         */
        readonly aggregationFunction?: string;
        /**
         * The column that is used in the `DateMeasureField` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datemeasurefield.html#cfn-quicksight-dashboard-datemeasurefield-column
         */
        readonly column: CfnDashboard.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * The custom field ID.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datemeasurefield.html#cfn-quicksight-dashboard-datemeasurefield-fieldid
         */
        readonly fieldId: string;
        /**
         * The format configuration of the field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datemeasurefield.html#cfn-quicksight-dashboard-datemeasurefield-formatconfiguration
         */
        readonly formatConfiguration?: CfnDashboard.DateTimeFormatConfigurationProperty | cdk.IResolvable;
    }
    /**
     * The measure type field with numerical type columns.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericalmeasurefield.html
     */
    interface NumericalMeasureFieldProperty {
        /**
         * The aggregation function of the measure field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericalmeasurefield.html#cfn-quicksight-dashboard-numericalmeasurefield-aggregationfunction
         */
        readonly aggregationFunction?: cdk.IResolvable | CfnDashboard.NumericalAggregationFunctionProperty;
        /**
         * The column that is used in the `NumericalMeasureField` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericalmeasurefield.html#cfn-quicksight-dashboard-numericalmeasurefield-column
         */
        readonly column: CfnDashboard.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * The custom field ID.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericalmeasurefield.html#cfn-quicksight-dashboard-numericalmeasurefield-fieldid
         */
        readonly fieldId: string;
        /**
         * The format configuration of the field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericalmeasurefield.html#cfn-quicksight-dashboard-numericalmeasurefield-formatconfiguration
         */
        readonly formatConfiguration?: cdk.IResolvable | CfnDashboard.NumberFormatConfigurationProperty;
    }
    /**
     * The measure type field with categorical type columns.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoricalmeasurefield.html
     */
    interface CategoricalMeasureFieldProperty {
        /**
         * The aggregation function of the measure field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoricalmeasurefield.html#cfn-quicksight-dashboard-categoricalmeasurefield-aggregationfunction
         */
        readonly aggregationFunction?: string;
        /**
         * The column that is used in the `CategoricalMeasureField` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoricalmeasurefield.html#cfn-quicksight-dashboard-categoricalmeasurefield-column
         */
        readonly column: CfnDashboard.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * The custom field ID.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoricalmeasurefield.html#cfn-quicksight-dashboard-categoricalmeasurefield-fieldid
         */
        readonly fieldId: string;
        /**
         * The format configuration of the field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoricalmeasurefield.html#cfn-quicksight-dashboard-categoricalmeasurefield-formatconfiguration
         */
        readonly formatConfiguration?: cdk.IResolvable | CfnDashboard.StringFormatConfigurationProperty;
    }
    /**
     * The table calculation measure field for pivot tables.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-calculatedmeasurefield.html
     */
    interface CalculatedMeasureFieldProperty {
        /**
         * The expression in the table calculation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-calculatedmeasurefield.html#cfn-quicksight-dashboard-calculatedmeasurefield-expression
         */
        readonly expression: string;
        /**
         * The custom field ID.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-calculatedmeasurefield.html#cfn-quicksight-dashboard-calculatedmeasurefield-fieldid
         */
        readonly fieldId: string;
    }
    /**
     * The display options for the visual tooltip.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tooltipoptions.html
     */
    interface TooltipOptionsProperty {
        /**
         * The setup for the detailed tooltip.
         *
         * The tooltip setup is always saved. The display type is decided based on the tooltip type.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tooltipoptions.html#cfn-quicksight-dashboard-tooltipoptions-fieldbasedtooltip
         */
        readonly fieldBasedTooltip?: CfnDashboard.FieldBasedTooltipProperty | cdk.IResolvable;
        /**
         * The selected type for the tooltip. Choose one of the following options:.
         *
         * - `BASIC` : A basic tooltip.
         * - `DETAILED` : A detailed tooltip.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tooltipoptions.html#cfn-quicksight-dashboard-tooltipoptions-selectedtooltiptype
         */
        readonly selectedTooltipType?: string;
        /**
         * Determines whether or not the tooltip is visible.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tooltipoptions.html#cfn-quicksight-dashboard-tooltipoptions-tooltipvisibility
         */
        readonly tooltipVisibility?: string;
    }
    /**
     * The setup for the detailed tooltip.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldbasedtooltip.html
     */
    interface FieldBasedTooltipProperty {
        /**
         * The visibility of `Show aggregations` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldbasedtooltip.html#cfn-quicksight-dashboard-fieldbasedtooltip-aggregationvisibility
         */
        readonly aggregationVisibility?: string;
        /**
         * The fields configuration in the tooltip.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldbasedtooltip.html#cfn-quicksight-dashboard-fieldbasedtooltip-tooltipfields
         */
        readonly tooltipFields?: Array<cdk.IResolvable | CfnDashboard.TooltipItemProperty> | cdk.IResolvable;
        /**
         * The type for the >tooltip title. Choose one of the following options:.
         *
         * - `NONE` : Doesn't use the primary value as the title.
         * - `PRIMARY_VALUE` : Uses primary value as the title.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldbasedtooltip.html#cfn-quicksight-dashboard-fieldbasedtooltip-tooltiptitletype
         */
        readonly tooltipTitleType?: string;
    }
    /**
     * The tooltip.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tooltipitem.html
     */
    interface TooltipItemProperty {
        /**
         * The tooltip item for the columns that are not part of a field well.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tooltipitem.html#cfn-quicksight-dashboard-tooltipitem-columntooltipitem
         */
        readonly columnTooltipItem?: CfnDashboard.ColumnTooltipItemProperty | cdk.IResolvable;
        /**
         * The tooltip item for the fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tooltipitem.html#cfn-quicksight-dashboard-tooltipitem-fieldtooltipitem
         */
        readonly fieldTooltipItem?: CfnDashboard.FieldTooltipItemProperty | cdk.IResolvable;
    }
    /**
     * The tooltip item for the fields.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldtooltipitem.html
     */
    interface FieldTooltipItemProperty {
        /**
         * The unique ID of the field that is targeted by the tooltip.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldtooltipitem.html#cfn-quicksight-dashboard-fieldtooltipitem-fieldid
         */
        readonly fieldId: string;
        /**
         * The label of the tooltip item.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldtooltipitem.html#cfn-quicksight-dashboard-fieldtooltipitem-label
         */
        readonly label?: string;
        /**
         * The visibility of the tooltip item.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldtooltipitem.html#cfn-quicksight-dashboard-fieldtooltipitem-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The tooltip item for the columns that are not part of a field well.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columntooltipitem.html
     */
    interface ColumnTooltipItemProperty {
        /**
         * The aggregation function of the column tooltip item.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columntooltipitem.html#cfn-quicksight-dashboard-columntooltipitem-aggregation
         */
        readonly aggregation?: CfnDashboard.AggregationFunctionProperty | cdk.IResolvable;
        /**
         * The target column of the tooltip item.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columntooltipitem.html#cfn-quicksight-dashboard-columntooltipitem-column
         */
        readonly column: CfnDashboard.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * The label of the tooltip item.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columntooltipitem.html#cfn-quicksight-dashboard-columntooltipitem-label
         */
        readonly label?: string;
        /**
         * The visibility of the tooltip item.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columntooltipitem.html#cfn-quicksight-dashboard-columntooltipitem-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The visual display options for the visual palette.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualpalette.html
     */
    interface VisualPaletteProperty {
        /**
         * The chart color options for the visual palette.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualpalette.html#cfn-quicksight-dashboard-visualpalette-chartcolor
         */
        readonly chartColor?: string;
        /**
         * The color map options for the visual palette.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualpalette.html#cfn-quicksight-dashboard-visualpalette-colormap
         */
        readonly colorMap?: Array<CfnDashboard.DataPathColorProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * The color map that determines the color options for a particular element.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathcolor.html
     */
    interface DataPathColorProperty {
        /**
         * The color that needs to be applied to the element.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathcolor.html#cfn-quicksight-dashboard-datapathcolor-color
         */
        readonly color: string;
        /**
         * The element that the color needs to be applied to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathcolor.html#cfn-quicksight-dashboard-datapathcolor-element
         */
        readonly element: CfnDashboard.DataPathValueProperty | cdk.IResolvable;
        /**
         * The time granularity of the field that the color needs to be applied to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathcolor.html#cfn-quicksight-dashboard-datapathcolor-timegranularity
         */
        readonly timeGranularity?: string;
    }
    /**
     * The data path that needs to be sorted.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathvalue.html
     */
    interface DataPathValueProperty {
        /**
         * The type configuration of the field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathvalue.html#cfn-quicksight-dashboard-datapathvalue-datapathtype
         */
        readonly dataPathType?: CfnDashboard.DataPathTypeProperty | cdk.IResolvable;
        /**
         * The field ID of the field that needs to be sorted.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathvalue.html#cfn-quicksight-dashboard-datapathvalue-fieldid
         */
        readonly fieldId?: string;
        /**
         * The actual value of the field that needs to be sorted.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathvalue.html#cfn-quicksight-dashboard-datapathvalue-fieldvalue
         */
        readonly fieldValue?: string;
    }
    /**
     * The type of the data path value.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathtype.html
     */
    interface DataPathTypeProperty {
        /**
         * The type of data path value utilized in a pivot table. Choose one of the following options:.
         *
         * - `HIERARCHY_ROWS_LAYOUT_COLUMN` - The type of data path for the rows layout column, when `RowsLayout` is set to `HIERARCHY` .
         * - `MULTIPLE_ROW_METRICS_COLUMN` - The type of data path for the metric column when the row is set to Metric Placement.
         * - `EMPTY_COLUMN_HEADER` - The type of data path for the column with empty column header, when there is no field in `ColumnsFieldWell` and the row is set to Metric Placement.
         * - `COUNT_METRIC_COLUMN` - The type of data path for the column with `COUNT` as the metric, when there is no field in the `ValuesFieldWell` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathtype.html#cfn-quicksight-dashboard-datapathtype-pivottabledatapathtype
         */
        readonly pivotTableDataPathType?: string;
    }
    /**
     * A custom action defined on a visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualcustomaction.html
     */
    interface VisualCustomActionProperty {
        /**
         * A list of `VisualCustomActionOperations` .
         *
         * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualcustomaction.html#cfn-quicksight-dashboard-visualcustomaction-actionoperations
         */
        readonly actionOperations: Array<cdk.IResolvable | CfnDashboard.VisualCustomActionOperationProperty> | cdk.IResolvable;
        /**
         * The ID of the `VisualCustomAction` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualcustomaction.html#cfn-quicksight-dashboard-visualcustomaction-customactionid
         */
        readonly customActionId: string;
        /**
         * The name of the `VisualCustomAction` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualcustomaction.html#cfn-quicksight-dashboard-visualcustomaction-name
         */
        readonly name: string;
        /**
         * The status of the `VisualCustomAction` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualcustomaction.html#cfn-quicksight-dashboard-visualcustomaction-status
         */
        readonly status?: string;
        /**
         * The trigger of the `VisualCustomAction` .
         *
         * Valid values are defined as follows:
         *
         * - `DATA_POINT_CLICK` : Initiates a custom action by a left pointer click on a data point.
         * - `DATA_POINT_MENU` : Initiates a custom action by right pointer click from the menu.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualcustomaction.html#cfn-quicksight-dashboard-visualcustomaction-trigger
         */
        readonly trigger: string;
    }
    /**
     * The operation that is defined by the custom action.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualcustomactionoperation.html
     */
    interface VisualCustomActionOperationProperty {
        /**
         * The filter operation that filters data included in a visual or in an entire sheet.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualcustomactionoperation.html#cfn-quicksight-dashboard-visualcustomactionoperation-filteroperation
         */
        readonly filterOperation?: CfnDashboard.CustomActionFilterOperationProperty | cdk.IResolvable;
        /**
         * The navigation operation that navigates between different sheets in the same analysis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualcustomactionoperation.html#cfn-quicksight-dashboard-visualcustomactionoperation-navigationoperation
         */
        readonly navigationOperation?: CfnDashboard.CustomActionNavigationOperationProperty | cdk.IResolvable;
        /**
         * The set parameter operation that sets parameters in custom action.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualcustomactionoperation.html#cfn-quicksight-dashboard-visualcustomactionoperation-setparametersoperation
         */
        readonly setParametersOperation?: CfnDashboard.CustomActionSetParametersOperationProperty | cdk.IResolvable;
        /**
         * The URL operation that opens a link to another webpage.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualcustomactionoperation.html#cfn-quicksight-dashboard-visualcustomactionoperation-urloperation
         */
        readonly urlOperation?: CfnDashboard.CustomActionURLOperationProperty | cdk.IResolvable;
    }
    /**
     * The navigation operation that navigates between different sheets in the same analysis.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customactionnavigationoperation.html
     */
    interface CustomActionNavigationOperationProperty {
        /**
         * The configuration that chooses the navigation target.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customactionnavigationoperation.html#cfn-quicksight-dashboard-customactionnavigationoperation-localnavigationconfiguration
         */
        readonly localNavigationConfiguration?: cdk.IResolvable | CfnDashboard.LocalNavigationConfigurationProperty;
    }
    /**
     * The navigation configuration for `CustomActionNavigationOperation` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-localnavigationconfiguration.html
     */
    interface LocalNavigationConfigurationProperty {
        /**
         * The sheet that is targeted for navigation in the same analysis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-localnavigationconfiguration.html#cfn-quicksight-dashboard-localnavigationconfiguration-targetsheetid
         */
        readonly targetSheetId: string;
    }
    /**
     * The set parameter operation that sets parameters in custom action.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customactionsetparametersoperation.html
     */
    interface CustomActionSetParametersOperationProperty {
        /**
         * The parameter that determines the value configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customactionsetparametersoperation.html#cfn-quicksight-dashboard-customactionsetparametersoperation-parametervalueconfigurations
         */
        readonly parameterValueConfigurations: Array<cdk.IResolvable | CfnDashboard.SetParameterValueConfigurationProperty> | cdk.IResolvable;
    }
    /**
     * The configuration of adding parameters in action.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-setparametervalueconfiguration.html
     */
    interface SetParameterValueConfigurationProperty {
        /**
         * The destination parameter name of the `SetParameterValueConfiguration` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-setparametervalueconfiguration.html#cfn-quicksight-dashboard-setparametervalueconfiguration-destinationparametername
         */
        readonly destinationParameterName: string;
        /**
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-setparametervalueconfiguration.html#cfn-quicksight-dashboard-setparametervalueconfiguration-value
         */
        readonly value: CfnDashboard.DestinationParameterValueConfigurationProperty | cdk.IResolvable;
    }
    /**
     * The configuration of destination parameter values.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-destinationparametervalueconfiguration.html
     */
    interface DestinationParameterValueConfigurationProperty {
        /**
         * The configuration of custom values for destination parameter in `DestinationParameterValueConfiguration` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-destinationparametervalueconfiguration.html#cfn-quicksight-dashboard-destinationparametervalueconfiguration-customvaluesconfiguration
         */
        readonly customValuesConfiguration?: CfnDashboard.CustomValuesConfigurationProperty | cdk.IResolvable;
        /**
         * The configuration that selects all options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-destinationparametervalueconfiguration.html#cfn-quicksight-dashboard-destinationparametervalueconfiguration-selectallvalueoptions
         */
        readonly selectAllValueOptions?: string;
        /**
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-destinationparametervalueconfiguration.html#cfn-quicksight-dashboard-destinationparametervalueconfiguration-sourcecolumn
         */
        readonly sourceColumn?: CfnDashboard.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * The source field ID of the destination parameter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-destinationparametervalueconfiguration.html#cfn-quicksight-dashboard-destinationparametervalueconfiguration-sourcefield
         */
        readonly sourceField?: string;
        /**
         * The source parameter name of the destination parameter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-destinationparametervalueconfiguration.html#cfn-quicksight-dashboard-destinationparametervalueconfiguration-sourceparametername
         */
        readonly sourceParameterName?: string;
    }
    /**
     * The configuration of custom values for the destination parameter in `DestinationParameterValueConfiguration` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customvaluesconfiguration.html
     */
    interface CustomValuesConfigurationProperty {
        /**
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customvaluesconfiguration.html#cfn-quicksight-dashboard-customvaluesconfiguration-customvalues
         */
        readonly customValues: CfnDashboard.CustomParameterValuesProperty | cdk.IResolvable;
        /**
         * Includes the null value in custom action parameter values.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customvaluesconfiguration.html#cfn-quicksight-dashboard-customvaluesconfiguration-includenullvalue
         */
        readonly includeNullValue?: boolean | cdk.IResolvable;
    }
    /**
     * The customized parameter values.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customparametervalues.html
     */
    interface CustomParameterValuesProperty {
        /**
         * A list of datetime-type parameter values.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customparametervalues.html#cfn-quicksight-dashboard-customparametervalues-datetimevalues
         */
        readonly dateTimeValues?: Array<string>;
        /**
         * A list of decimal-type parameter values.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customparametervalues.html#cfn-quicksight-dashboard-customparametervalues-decimalvalues
         */
        readonly decimalValues?: Array<number> | cdk.IResolvable;
        /**
         * A list of integer-type parameter values.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customparametervalues.html#cfn-quicksight-dashboard-customparametervalues-integervalues
         */
        readonly integerValues?: Array<number> | cdk.IResolvable;
        /**
         * A list of string-type parameter values.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customparametervalues.html#cfn-quicksight-dashboard-customparametervalues-stringvalues
         */
        readonly stringValues?: Array<string>;
    }
    /**
     * The filter operation that filters data included in a visual or in an entire sheet.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customactionfilteroperation.html
     */
    interface CustomActionFilterOperationProperty {
        /**
         * The configuration that chooses the fields to be filtered.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customactionfilteroperation.html#cfn-quicksight-dashboard-customactionfilteroperation-selectedfieldsconfiguration
         */
        readonly selectedFieldsConfiguration: CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty | cdk.IResolvable;
        /**
         * The configuration that chooses the target visuals to be filtered.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customactionfilteroperation.html#cfn-quicksight-dashboard-customactionfilteroperation-targetvisualsconfiguration
         */
        readonly targetVisualsConfiguration: CfnDashboard.FilterOperationTargetVisualsConfigurationProperty | cdk.IResolvable;
    }
    /**
     * The configuration of selected fields in the `CustomActionFilterOperation` .
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filteroperationselectedfieldsconfiguration.html
     */
    interface FilterOperationSelectedFieldsConfigurationProperty {
        /**
         * The selected columns of a dataset.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filteroperationselectedfieldsconfiguration.html#cfn-quicksight-dashboard-filteroperationselectedfieldsconfiguration-selectedcolumns
         */
        readonly selectedColumns?: Array<CfnDashboard.ColumnIdentifierProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * A structure that contains the options that choose which fields are filtered in the `CustomActionFilterOperation` .
         *
         * Valid values are defined as follows:
         *
         * - `ALL_FIELDS` : Applies the filter operation to all fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filteroperationselectedfieldsconfiguration.html#cfn-quicksight-dashboard-filteroperationselectedfieldsconfiguration-selectedfieldoptions
         */
        readonly selectedFieldOptions?: string;
        /**
         * Chooses the fields that are filtered in `CustomActionFilterOperation` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filteroperationselectedfieldsconfiguration.html#cfn-quicksight-dashboard-filteroperationselectedfieldsconfiguration-selectedfields
         */
        readonly selectedFields?: Array<string>;
    }
    /**
     * The configuration of target visuals that you want to be filtered.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filteroperationtargetvisualsconfiguration.html
     */
    interface FilterOperationTargetVisualsConfigurationProperty {
        /**
         * The configuration of the same-sheet target visuals that you want to be filtered.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filteroperationtargetvisualsconfiguration.html#cfn-quicksight-dashboard-filteroperationtargetvisualsconfiguration-samesheettargetvisualconfiguration
         */
        readonly sameSheetTargetVisualConfiguration?: cdk.IResolvable | CfnDashboard.SameSheetTargetVisualConfigurationProperty;
    }
    /**
     * The configuration of the same-sheet target visuals that you want to be filtered.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-samesheettargetvisualconfiguration.html
     */
    interface SameSheetTargetVisualConfigurationProperty {
        /**
         * The options that choose the target visual in the same sheet.
         *
         * Valid values are defined as follows:
         *
         * - `ALL_VISUALS` : Applies the filter operation to all visuals in the same sheet.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-samesheettargetvisualconfiguration.html#cfn-quicksight-dashboard-samesheettargetvisualconfiguration-targetvisualoptions
         */
        readonly targetVisualOptions?: string;
        /**
         * A list of the target visual IDs that are located in the same sheet of the analysis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-samesheettargetvisualconfiguration.html#cfn-quicksight-dashboard-samesheettargetvisualconfiguration-targetvisuals
         */
        readonly targetVisuals?: Array<string>;
    }
    /**
     * The URL operation that opens a link to another webpage.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customactionurloperation.html
     */
    interface CustomActionURLOperationProperty {
        /**
         * The target of the `CustomActionURLOperation` .
         *
         * Valid values are defined as follows:
         *
         * - `NEW_TAB` : Opens the target URL in a new browser tab.
         * - `NEW_WINDOW` : Opens the target URL in a new browser window.
         * - `SAME_TAB` : Opens the target URL in the same browser tab.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customactionurloperation.html#cfn-quicksight-dashboard-customactionurloperation-urltarget
         */
        readonly urlTarget: string;
        /**
         * THe URL link of the `CustomActionURLOperation` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customactionurloperation.html#cfn-quicksight-dashboard-customactionurloperation-urltemplate
         */
        readonly urlTemplate: string;
    }
    /**
     * The title label options for a visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualtitlelabeloptions.html
     */
    interface VisualTitleLabelOptionsProperty {
        /**
         * The short text format of the title label, such as plain text or rich text.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualtitlelabeloptions.html#cfn-quicksight-dashboard-visualtitlelabeloptions-formattext
         */
        readonly formatText?: cdk.IResolvable | CfnDashboard.ShortFormatTextProperty;
        /**
         * The visibility of the title label.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualtitlelabeloptions.html#cfn-quicksight-dashboard-visualtitlelabeloptions-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The text format for the title.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-shortformattext.html
     */
    interface ShortFormatTextProperty {
        /**
         * Plain text format.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-shortformattext.html#cfn-quicksight-dashboard-shortformattext-plaintext
         */
        readonly plainText?: string;
        /**
         * Rich text.
         *
         * Examples of rich text include bold, underline, and italics.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-shortformattext.html#cfn-quicksight-dashboard-shortformattext-richtext
         */
        readonly richText?: string;
    }
    /**
     * The option that determines the hierarchy of the fields for a visual element.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnhierarchy.html
     */
    interface ColumnHierarchyProperty {
        /**
         * The option that determines the hierarchy of any `DateTime` fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnhierarchy.html#cfn-quicksight-dashboard-columnhierarchy-datetimehierarchy
         */
        readonly dateTimeHierarchy?: CfnDashboard.DateTimeHierarchyProperty | cdk.IResolvable;
        /**
         * The option that determines the hierarchy of the fields that are built within a visual's field wells.
         *
         * These fields can't be duplicated to other visuals.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnhierarchy.html#cfn-quicksight-dashboard-columnhierarchy-explicithierarchy
         */
        readonly explicitHierarchy?: CfnDashboard.ExplicitHierarchyProperty | cdk.IResolvable;
        /**
         * The option that determines the hierarchy of the fields that are defined during data preparation.
         *
         * These fields are available to use in any analysis that uses the data source.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnhierarchy.html#cfn-quicksight-dashboard-columnhierarchy-predefinedhierarchy
         */
        readonly predefinedHierarchy?: cdk.IResolvable | CfnDashboard.PredefinedHierarchyProperty;
    }
    /**
     * The option that determines the hierarchy of any `DateTime` fields.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimehierarchy.html
     */
    interface DateTimeHierarchyProperty {
        /**
         * The option that determines the drill down filters for the `DateTime` hierarchy.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimehierarchy.html#cfn-quicksight-dashboard-datetimehierarchy-drilldownfilters
         */
        readonly drillDownFilters?: Array<CfnDashboard.DrillDownFilterProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The hierarchy ID of the `DateTime` hierarchy.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimehierarchy.html#cfn-quicksight-dashboard-datetimehierarchy-hierarchyid
         */
        readonly hierarchyId: string;
    }
    /**
     * The drill down filter for the column hierarchies.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-drilldownfilter.html
     */
    interface DrillDownFilterProperty {
        /**
         * The category type drill down filter.
         *
         * This filter is used for string type columns.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-drilldownfilter.html#cfn-quicksight-dashboard-drilldownfilter-categoryfilter
         */
        readonly categoryFilter?: CfnDashboard.CategoryDrillDownFilterProperty | cdk.IResolvable;
        /**
         * The numeric equality type drill down filter.
         *
         * This filter is used for number type columns.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-drilldownfilter.html#cfn-quicksight-dashboard-drilldownfilter-numericequalityfilter
         */
        readonly numericEqualityFilter?: cdk.IResolvable | CfnDashboard.NumericEqualityDrillDownFilterProperty;
        /**
         * The time range drill down filter.
         *
         * This filter is used for date time columns.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-drilldownfilter.html#cfn-quicksight-dashboard-drilldownfilter-timerangefilter
         */
        readonly timeRangeFilter?: cdk.IResolvable | CfnDashboard.TimeRangeDrillDownFilterProperty;
    }
    /**
     * The category drill down filter.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericequalitydrilldownfilter.html
     */
    interface NumericEqualityDrillDownFilterProperty {
        /**
         * The column that the filter is applied to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericequalitydrilldownfilter.html#cfn-quicksight-dashboard-numericequalitydrilldownfilter-column
         */
        readonly column: CfnDashboard.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * The value of the double input numeric drill down filter.
         *
         * @default - 0
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericequalitydrilldownfilter.html#cfn-quicksight-dashboard-numericequalitydrilldownfilter-value
         */
        readonly value: number;
    }
    /**
     * The time range drill down filter.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangedrilldownfilter.html
     */
    interface TimeRangeDrillDownFilterProperty {
        /**
         * The column that the filter is applied to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangedrilldownfilter.html#cfn-quicksight-dashboard-timerangedrilldownfilter-column
         */
        readonly column: CfnDashboard.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * The maximum value for the filter value range.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangedrilldownfilter.html#cfn-quicksight-dashboard-timerangedrilldownfilter-rangemaximum
         */
        readonly rangeMaximum: string;
        /**
         * The minimum value for the filter value range.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangedrilldownfilter.html#cfn-quicksight-dashboard-timerangedrilldownfilter-rangeminimum
         */
        readonly rangeMinimum: string;
        /**
         * The level of time precision that is used to aggregate `DateTime` values.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangedrilldownfilter.html#cfn-quicksight-dashboard-timerangedrilldownfilter-timegranularity
         */
        readonly timeGranularity: string;
    }
    /**
     * The numeric equality type drill down filter.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categorydrilldownfilter.html
     */
    interface CategoryDrillDownFilterProperty {
        /**
         * A list of the string inputs that are the values of the category drill down filter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categorydrilldownfilter.html#cfn-quicksight-dashboard-categorydrilldownfilter-categoryvalues
         */
        readonly categoryValues: Array<string>;
        /**
         * The column that the filter is applied to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categorydrilldownfilter.html#cfn-quicksight-dashboard-categorydrilldownfilter-column
         */
        readonly column: CfnDashboard.ColumnIdentifierProperty | cdk.IResolvable;
    }
    /**
     * The option that determines the hierarchy of the fields that are built within a visual's field wells.
     *
     * These fields can't be duplicated to other visuals.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-explicithierarchy.html
     */
    interface ExplicitHierarchyProperty {
        /**
         * The list of columns that define the explicit hierarchy.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-explicithierarchy.html#cfn-quicksight-dashboard-explicithierarchy-columns
         */
        readonly columns: Array<CfnDashboard.ColumnIdentifierProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The option that determines the drill down filters for the explicit hierarchy.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-explicithierarchy.html#cfn-quicksight-dashboard-explicithierarchy-drilldownfilters
         */
        readonly drillDownFilters?: Array<CfnDashboard.DrillDownFilterProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The hierarchy ID of the explicit hierarchy.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-explicithierarchy.html#cfn-quicksight-dashboard-explicithierarchy-hierarchyid
         */
        readonly hierarchyId: string;
    }
    /**
     * The option that determines the hierarchy of the fields that are defined during data preparation.
     *
     * These fields are available to use in any analysis that uses the data source.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-predefinedhierarchy.html
     */
    interface PredefinedHierarchyProperty {
        /**
         * The list of columns that define the predefined hierarchy.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-predefinedhierarchy.html#cfn-quicksight-dashboard-predefinedhierarchy-columns
         */
        readonly columns: Array<CfnDashboard.ColumnIdentifierProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The option that determines the drill down filters for the predefined hierarchy.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-predefinedhierarchy.html#cfn-quicksight-dashboard-predefinedhierarchy-drilldownfilters
         */
        readonly drillDownFilters?: Array<CfnDashboard.DrillDownFilterProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The hierarchy ID of the predefined hierarchy.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-predefinedhierarchy.html#cfn-quicksight-dashboard-predefinedhierarchy-hierarchyid
         */
        readonly hierarchyId: string;
    }
    /**
     * A filled map.
     *
     * For more information, see [Creating filled maps](https://docs.aws.amazon.com/quicksight/latest/user/filled-maps.html) in the *Amazon QuickSight User Guide* .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapvisual.html
     */
    interface FilledMapVisualProperty {
        /**
         * The list of custom actions that are configured for a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapvisual.html#cfn-quicksight-dashboard-filledmapvisual-actions
         */
        readonly actions?: Array<cdk.IResolvable | CfnDashboard.VisualCustomActionProperty> | cdk.IResolvable;
        /**
         * The configuration settings of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapvisual.html#cfn-quicksight-dashboard-filledmapvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnDashboard.FilledMapConfigurationProperty | cdk.IResolvable;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapvisual.html#cfn-quicksight-dashboard-filledmapvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnDashboard.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The conditional formatting of a `FilledMapVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapvisual.html#cfn-quicksight-dashboard-filledmapvisual-conditionalformatting
         */
        readonly conditionalFormatting?: CfnDashboard.FilledMapConditionalFormattingProperty | cdk.IResolvable;
        /**
         * The subtitle that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapvisual.html#cfn-quicksight-dashboard-filledmapvisual-subtitle
         */
        readonly subtitle?: cdk.IResolvable | CfnDashboard.VisualSubtitleLabelOptionsProperty;
        /**
         * The title that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapvisual.html#cfn-quicksight-dashboard-filledmapvisual-title
         */
        readonly title?: cdk.IResolvable | CfnDashboard.VisualTitleLabelOptionsProperty;
        /**
         * The unique identifier of a visual.
         *
         * This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapvisual.html#cfn-quicksight-dashboard-filledmapvisual-visualid
         */
        readonly visualId: string;
    }
    /**
     * The conditional formatting of a `FilledMapVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapconditionalformatting.html
     */
    interface FilledMapConditionalFormattingProperty {
        /**
         * Conditional formatting options of a `FilledMapVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapconditionalformatting.html#cfn-quicksight-dashboard-filledmapconditionalformatting-conditionalformattingoptions
         */
        readonly conditionalFormattingOptions: Array<CfnDashboard.FilledMapConditionalFormattingOptionProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * Conditional formatting options of a `FilledMapVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapconditionalformattingoption.html
     */
    interface FilledMapConditionalFormattingOptionProperty {
        /**
         * The conditional formatting that determines the shape of the filled map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapconditionalformattingoption.html#cfn-quicksight-dashboard-filledmapconditionalformattingoption-shape
         */
        readonly shape: CfnDashboard.FilledMapShapeConditionalFormattingProperty | cdk.IResolvable;
    }
    /**
     * The conditional formatting that determines the shape of the filled map.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapshapeconditionalformatting.html
     */
    interface FilledMapShapeConditionalFormattingProperty {
        /**
         * The field ID of the filled map shape.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapshapeconditionalformatting.html#cfn-quicksight-dashboard-filledmapshapeconditionalformatting-fieldid
         */
        readonly fieldId: string;
        /**
         * The conditional formatting that determines the background color of a filled map's shape.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapshapeconditionalformatting.html#cfn-quicksight-dashboard-filledmapshapeconditionalformatting-format
         */
        readonly format?: cdk.IResolvable | CfnDashboard.ShapeConditionalFormatProperty;
    }
    /**
     * The shape conditional formatting of a filled map visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-shapeconditionalformat.html
     */
    interface ShapeConditionalFormatProperty {
        /**
         * The conditional formatting for the shape background color of a filled map visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-shapeconditionalformat.html#cfn-quicksight-dashboard-shapeconditionalformat-backgroundcolor
         */
        readonly backgroundColor: CfnDashboard.ConditionalFormattingColorProperty | cdk.IResolvable;
    }
    /**
     * The formatting configuration for the color.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingcolor.html
     */
    interface ConditionalFormattingColorProperty {
        /**
         * Formatting configuration for gradient color.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingcolor.html#cfn-quicksight-dashboard-conditionalformattingcolor-gradient
         */
        readonly gradient?: CfnDashboard.ConditionalFormattingGradientColorProperty | cdk.IResolvable;
        /**
         * Formatting configuration for solid color.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingcolor.html#cfn-quicksight-dashboard-conditionalformattingcolor-solid
         */
        readonly solid?: CfnDashboard.ConditionalFormattingSolidColorProperty | cdk.IResolvable;
    }
    /**
     * Formatting configuration for gradient color.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattinggradientcolor.html
     */
    interface ConditionalFormattingGradientColorProperty {
        /**
         * Determines the color.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattinggradientcolor.html#cfn-quicksight-dashboard-conditionalformattinggradientcolor-color
         */
        readonly color: CfnDashboard.GradientColorProperty | cdk.IResolvable;
        /**
         * The expression that determines the formatting configuration for gradient color.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattinggradientcolor.html#cfn-quicksight-dashboard-conditionalformattinggradientcolor-expression
         */
        readonly expression: string;
    }
    /**
     * Determines the gradient color settings.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gradientcolor.html
     */
    interface GradientColorProperty {
        /**
         * The list of gradient color stops.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gradientcolor.html#cfn-quicksight-dashboard-gradientcolor-stops
         */
        readonly stops?: Array<CfnDashboard.GradientStopProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * Determines the gradient stop configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gradientstop.html
     */
    interface GradientStopProperty {
        /**
         * Determines the color.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gradientstop.html#cfn-quicksight-dashboard-gradientstop-color
         */
        readonly color?: string;
        /**
         * Determines the data value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gradientstop.html#cfn-quicksight-dashboard-gradientstop-datavalue
         */
        readonly dataValue?: number;
        /**
         * Determines gradient offset value.
         *
         * @default - 0
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gradientstop.html#cfn-quicksight-dashboard-gradientstop-gradientoffset
         */
        readonly gradientOffset: number;
    }
    /**
     * Formatting configuration for solid color.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingsolidcolor.html
     */
    interface ConditionalFormattingSolidColorProperty {
        /**
         * Determines the color.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingsolidcolor.html#cfn-quicksight-dashboard-conditionalformattingsolidcolor-color
         */
        readonly color?: string;
        /**
         * The expression that determines the formatting configuration for solid color.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingsolidcolor.html#cfn-quicksight-dashboard-conditionalformattingsolidcolor-expression
         */
        readonly expression: string;
    }
    /**
     * The configuration for a `FilledMapVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapconfiguration.html
     */
    interface FilledMapConfigurationProperty {
        /**
         * The field wells of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapconfiguration.html#cfn-quicksight-dashboard-filledmapconfiguration-fieldwells
         */
        readonly fieldWells?: CfnDashboard.FilledMapFieldWellsProperty | cdk.IResolvable;
        /**
         * The legend display setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapconfiguration.html#cfn-quicksight-dashboard-filledmapconfiguration-legend
         */
        readonly legend?: cdk.IResolvable | CfnDashboard.LegendOptionsProperty;
        /**
         * The map style options of the filled map visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapconfiguration.html#cfn-quicksight-dashboard-filledmapconfiguration-mapstyleoptions
         */
        readonly mapStyleOptions?: CfnDashboard.GeospatialMapStyleOptionsProperty | cdk.IResolvable;
        /**
         * The sort configuration of a `FilledMapVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapconfiguration.html#cfn-quicksight-dashboard-filledmapconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: CfnDashboard.FilledMapSortConfigurationProperty | cdk.IResolvable;
        /**
         * The tooltip display setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapconfiguration.html#cfn-quicksight-dashboard-filledmapconfiguration-tooltip
         */
        readonly tooltip?: cdk.IResolvable | CfnDashboard.TooltipOptionsProperty;
        /**
         * The window options of the filled map visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapconfiguration.html#cfn-quicksight-dashboard-filledmapconfiguration-windowoptions
         */
        readonly windowOptions?: CfnDashboard.GeospatialWindowOptionsProperty | cdk.IResolvable;
    }
    /**
     * The sort configuration of a `FilledMapVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapsortconfiguration.html
     */
    interface FilledMapSortConfigurationProperty {
        /**
         * The sort configuration of the location fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapsortconfiguration.html#cfn-quicksight-dashboard-filledmapsortconfiguration-categorysort
         */
        readonly categorySort?: Array<CfnDashboard.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * The options for the legend setup of a visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-legendoptions.html
     */
    interface LegendOptionsProperty {
        /**
         * The height of the legend.
         *
         * If this value is omitted, a default height is used when rendering.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-legendoptions.html#cfn-quicksight-dashboard-legendoptions-height
         */
        readonly height?: string;
        /**
         * The positions for the legend. Choose one of the following options:.
         *
         * - `AUTO`
         * - `RIGHT`
         * - `BOTTOM`
         * - `LEFT`
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-legendoptions.html#cfn-quicksight-dashboard-legendoptions-position
         */
        readonly position?: string;
        /**
         * The custom title for the legend.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-legendoptions.html#cfn-quicksight-dashboard-legendoptions-title
         */
        readonly title?: cdk.IResolvable | CfnDashboard.LabelOptionsProperty;
        /**
         * Determines whether or not the legend is visible.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-legendoptions.html#cfn-quicksight-dashboard-legendoptions-visibility
         */
        readonly visibility?: string;
        /**
         * The width of the legend.
         *
         * If this value is omitted, a default width is used when rendering.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-legendoptions.html#cfn-quicksight-dashboard-legendoptions-width
         */
        readonly width?: string;
    }
    /**
     * The map style options of the geospatial map.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapstyleoptions.html
     */
    interface GeospatialMapStyleOptionsProperty {
        /**
         * The base map style of the geospatial map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapstyleoptions.html#cfn-quicksight-dashboard-geospatialmapstyleoptions-basemapstyle
         */
        readonly baseMapStyle?: string;
    }
    /**
     * The field wells of a `FilledMapVisual` .
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapfieldwells.html
     */
    interface FilledMapFieldWellsProperty {
        /**
         * The aggregated field well of the filled map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapfieldwells.html#cfn-quicksight-dashboard-filledmapfieldwells-filledmapaggregatedfieldwells
         */
        readonly filledMapAggregatedFieldWells?: CfnDashboard.FilledMapAggregatedFieldWellsProperty | cdk.IResolvable;
    }
    /**
     * The aggregated field well of the filled map.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapaggregatedfieldwells.html
     */
    interface FilledMapAggregatedFieldWellsProperty {
        /**
         * The aggregated location field well of the filled map.
         *
         * Values are grouped by location fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapaggregatedfieldwells.html#cfn-quicksight-dashboard-filledmapaggregatedfieldwells-geospatial
         */
        readonly geospatial?: Array<CfnDashboard.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The aggregated color field well of a filled map.
         *
         * Values are aggregated based on location fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapaggregatedfieldwells.html#cfn-quicksight-dashboard-filledmapaggregatedfieldwells-values
         */
        readonly values?: Array<cdk.IResolvable | CfnDashboard.MeasureFieldProperty> | cdk.IResolvable;
    }
    /**
     * The window options of the geospatial map visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialwindowoptions.html
     */
    interface GeospatialWindowOptionsProperty {
        /**
         * The bounds options (north, south, west, east) of the geospatial window options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialwindowoptions.html#cfn-quicksight-dashboard-geospatialwindowoptions-bounds
         */
        readonly bounds?: CfnDashboard.GeospatialCoordinateBoundsProperty | cdk.IResolvable;
        /**
         * The map zoom modes (manual, auto) of the geospatial window options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialwindowoptions.html#cfn-quicksight-dashboard-geospatialwindowoptions-mapzoommode
         */
        readonly mapZoomMode?: string;
    }
    /**
     * The bound options (north, south, west, east) of the geospatial window options.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialcoordinatebounds.html
     */
    interface GeospatialCoordinateBoundsProperty {
        /**
         * The longitude of the east bound of the geospatial coordinate bounds.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialcoordinatebounds.html#cfn-quicksight-dashboard-geospatialcoordinatebounds-east
         */
        readonly east: number;
        /**
         * The latitude of the north bound of the geospatial coordinate bounds.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialcoordinatebounds.html#cfn-quicksight-dashboard-geospatialcoordinatebounds-north
         */
        readonly north: number;
        /**
         * The latitude of the south bound of the geospatial coordinate bounds.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialcoordinatebounds.html#cfn-quicksight-dashboard-geospatialcoordinatebounds-south
         */
        readonly south: number;
        /**
         * The longitude of the west bound of the geospatial coordinate bounds.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialcoordinatebounds.html#cfn-quicksight-dashboard-geospatialcoordinatebounds-west
         */
        readonly west: number;
    }
    /**
     * A box plot.
     *
     * For more information, see [Using box plots](https://docs.aws.amazon.com/quicksight/latest/user/box-plots.html) in the *Amazon QuickSight User Guide* .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotvisual.html
     */
    interface BoxPlotVisualProperty {
        /**
         * The list of custom actions that are configured for a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotvisual.html#cfn-quicksight-dashboard-boxplotvisual-actions
         */
        readonly actions?: Array<cdk.IResolvable | CfnDashboard.VisualCustomActionProperty> | cdk.IResolvable;
        /**
         * The configuration settings of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotvisual.html#cfn-quicksight-dashboard-boxplotvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnDashboard.BoxPlotChartConfigurationProperty | cdk.IResolvable;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotvisual.html#cfn-quicksight-dashboard-boxplotvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnDashboard.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The subtitle that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotvisual.html#cfn-quicksight-dashboard-boxplotvisual-subtitle
         */
        readonly subtitle?: cdk.IResolvable | CfnDashboard.VisualSubtitleLabelOptionsProperty;
        /**
         * The title that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotvisual.html#cfn-quicksight-dashboard-boxplotvisual-title
         */
        readonly title?: cdk.IResolvable | CfnDashboard.VisualTitleLabelOptionsProperty;
        /**
         * The unique identifier of a visual.
         *
         * This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotvisual.html#cfn-quicksight-dashboard-boxplotvisual-visualid
         */
        readonly visualId: string;
    }
    /**
     * The configuration of a `BoxPlotVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotchartconfiguration.html
     */
    interface BoxPlotChartConfigurationProperty {
        /**
         * The box plot chart options for a box plot visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotchartconfiguration.html#cfn-quicksight-dashboard-boxplotchartconfiguration-boxplotoptions
         */
        readonly boxPlotOptions?: CfnDashboard.BoxPlotOptionsProperty | cdk.IResolvable;
        /**
         * The label display options (grid line, range, scale, axis step) of a box plot category.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotchartconfiguration.html#cfn-quicksight-dashboard-boxplotchartconfiguration-categoryaxis
         */
        readonly categoryAxis?: CfnDashboard.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * The label options (label text, label visibility and sort Icon visibility) of a box plot category.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotchartconfiguration.html#cfn-quicksight-dashboard-boxplotchartconfiguration-categorylabeloptions
         */
        readonly categoryLabelOptions?: CfnDashboard.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The field wells of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotchartconfiguration.html#cfn-quicksight-dashboard-boxplotchartconfiguration-fieldwells
         */
        readonly fieldWells?: CfnDashboard.BoxPlotFieldWellsProperty | cdk.IResolvable;
        /**
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotchartconfiguration.html#cfn-quicksight-dashboard-boxplotchartconfiguration-legend
         */
        readonly legend?: cdk.IResolvable | CfnDashboard.LegendOptionsProperty;
        /**
         * The label display options (grid line, range, scale, axis step) of a box plot category.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotchartconfiguration.html#cfn-quicksight-dashboard-boxplotchartconfiguration-primaryyaxisdisplayoptions
         */
        readonly primaryYAxisDisplayOptions?: CfnDashboard.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * The label options (label text, label visibility and sort icon visibility) of a box plot value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotchartconfiguration.html#cfn-quicksight-dashboard-boxplotchartconfiguration-primaryyaxislabeloptions
         */
        readonly primaryYAxisLabelOptions?: CfnDashboard.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The reference line setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotchartconfiguration.html#cfn-quicksight-dashboard-boxplotchartconfiguration-referencelines
         */
        readonly referenceLines?: Array<cdk.IResolvable | CfnDashboard.ReferenceLineProperty> | cdk.IResolvable;
        /**
         * The sort configuration of a `BoxPlotVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotchartconfiguration.html#cfn-quicksight-dashboard-boxplotchartconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: CfnDashboard.BoxPlotSortConfigurationProperty | cdk.IResolvable;
        /**
         * The tooltip display setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotchartconfiguration.html#cfn-quicksight-dashboard-boxplotchartconfiguration-tooltip
         */
        readonly tooltip?: cdk.IResolvable | CfnDashboard.TooltipOptionsProperty;
        /**
         * The palette (chart color) display setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotchartconfiguration.html#cfn-quicksight-dashboard-boxplotchartconfiguration-visualpalette
         */
        readonly visualPalette?: cdk.IResolvable | CfnDashboard.VisualPaletteProperty;
    }
    /**
     * The sort configuration of a `BoxPlotVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotsortconfiguration.html
     */
    interface BoxPlotSortConfigurationProperty {
        /**
         * The sort configuration of a group by fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotsortconfiguration.html#cfn-quicksight-dashboard-boxplotsortconfiguration-categorysort
         */
        readonly categorySort?: Array<CfnDashboard.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The pagination configuration of a table visual or box plot.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotsortconfiguration.html#cfn-quicksight-dashboard-boxplotsortconfiguration-paginationconfiguration
         */
        readonly paginationConfiguration?: cdk.IResolvable | CfnDashboard.PaginationConfigurationProperty;
    }
    /**
     * The pagination configuration for a table visual or boxplot.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-paginationconfiguration.html
     */
    interface PaginationConfigurationProperty {
        /**
         * Indicates the page number.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-paginationconfiguration.html#cfn-quicksight-dashboard-paginationconfiguration-pagenumber
         */
        readonly pageNumber: number;
        /**
         * Indicates how many items render in one page.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-paginationconfiguration.html#cfn-quicksight-dashboard-paginationconfiguration-pagesize
         */
        readonly pageSize: number;
    }
    /**
     * The reference line visual display options.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referenceline.html
     */
    interface ReferenceLineProperty {
        /**
         * The data configuration of the reference line.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referenceline.html#cfn-quicksight-dashboard-referenceline-dataconfiguration
         */
        readonly dataConfiguration: cdk.IResolvable | CfnDashboard.ReferenceLineDataConfigurationProperty;
        /**
         * The label configuration of the reference line.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referenceline.html#cfn-quicksight-dashboard-referenceline-labelconfiguration
         */
        readonly labelConfiguration?: cdk.IResolvable | CfnDashboard.ReferenceLineLabelConfigurationProperty;
        /**
         * The status of the reference line. Choose one of the following options:.
         *
         * - `ENABLE`
         * - `DISABLE`
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referenceline.html#cfn-quicksight-dashboard-referenceline-status
         */
        readonly status?: string;
        /**
         * The style configuration of the reference line.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referenceline.html#cfn-quicksight-dashboard-referenceline-styleconfiguration
         */
        readonly styleConfiguration?: cdk.IResolvable | CfnDashboard.ReferenceLineStyleConfigurationProperty;
    }
    /**
     * The data configuration of the reference line.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinedataconfiguration.html
     */
    interface ReferenceLineDataConfigurationProperty {
        /**
         * The axis binding type of the reference line. Choose one of the following options:.
         *
         * - `PrimaryY`
         * - `SecondaryY`
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinedataconfiguration.html#cfn-quicksight-dashboard-referencelinedataconfiguration-axisbinding
         */
        readonly axisBinding?: string;
        /**
         * The dynamic configuration of the reference line data configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinedataconfiguration.html#cfn-quicksight-dashboard-referencelinedataconfiguration-dynamicconfiguration
         */
        readonly dynamicConfiguration?: cdk.IResolvable | CfnDashboard.ReferenceLineDynamicDataConfigurationProperty;
        /**
         * The series type of the reference line data configuration. Choose one of the following options:.
         *
         * - `BAR`
         * - `LINE`
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinedataconfiguration.html#cfn-quicksight-dashboard-referencelinedataconfiguration-seriestype
         */
        readonly seriesType?: string;
        /**
         * The static data configuration of the reference line data configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinedataconfiguration.html#cfn-quicksight-dashboard-referencelinedataconfiguration-staticconfiguration
         */
        readonly staticConfiguration?: cdk.IResolvable | CfnDashboard.ReferenceLineStaticDataConfigurationProperty;
    }
    /**
     * The dynamic configuration of the reference line data configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinedynamicdataconfiguration.html
     */
    interface ReferenceLineDynamicDataConfigurationProperty {
        /**
         * The calculation that is used in the dynamic data.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinedynamicdataconfiguration.html#cfn-quicksight-dashboard-referencelinedynamicdataconfiguration-calculation
         */
        readonly calculation: cdk.IResolvable | CfnDashboard.NumericalAggregationFunctionProperty;
        /**
         * The column that the dynamic data targets.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinedynamicdataconfiguration.html#cfn-quicksight-dashboard-referencelinedynamicdataconfiguration-column
         */
        readonly column: CfnDashboard.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * The aggregation function that is used in the dynamic data.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinedynamicdataconfiguration.html#cfn-quicksight-dashboard-referencelinedynamicdataconfiguration-measureaggregationfunction
         */
        readonly measureAggregationFunction?: CfnDashboard.AggregationFunctionProperty | cdk.IResolvable;
    }
    /**
     * The static data configuration of the reference line data configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinestaticdataconfiguration.html
     */
    interface ReferenceLineStaticDataConfigurationProperty {
        /**
         * The double input of the static data.
         *
         * @default - 0
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinestaticdataconfiguration.html#cfn-quicksight-dashboard-referencelinestaticdataconfiguration-value
         */
        readonly value: number;
    }
    /**
     * The label configuration of a reference line.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinelabelconfiguration.html
     */
    interface ReferenceLineLabelConfigurationProperty {
        /**
         * The custom label configuration of the label in a reference line.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinelabelconfiguration.html#cfn-quicksight-dashboard-referencelinelabelconfiguration-customlabelconfiguration
         */
        readonly customLabelConfiguration?: cdk.IResolvable | CfnDashboard.ReferenceLineCustomLabelConfigurationProperty;
        /**
         * The font color configuration of the label in a reference line.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinelabelconfiguration.html#cfn-quicksight-dashboard-referencelinelabelconfiguration-fontcolor
         */
        readonly fontColor?: string;
        /**
         * The font configuration of the label in a reference line.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinelabelconfiguration.html#cfn-quicksight-dashboard-referencelinelabelconfiguration-fontconfiguration
         */
        readonly fontConfiguration?: CfnDashboard.FontConfigurationProperty | cdk.IResolvable;
        /**
         * The horizontal position configuration of the label in a reference line. Choose one of the following options:.
         *
         * - `LEFT`
         * - `CENTER`
         * - `RIGHT`
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinelabelconfiguration.html#cfn-quicksight-dashboard-referencelinelabelconfiguration-horizontalposition
         */
        readonly horizontalPosition?: string;
        /**
         * The value label configuration of the label in a reference line.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinelabelconfiguration.html#cfn-quicksight-dashboard-referencelinelabelconfiguration-valuelabelconfiguration
         */
        readonly valueLabelConfiguration?: cdk.IResolvable | CfnDashboard.ReferenceLineValueLabelConfigurationProperty;
        /**
         * The vertical position configuration of the label in a reference line. Choose one of the following options:.
         *
         * - `ABOVE`
         * - `BELOW`
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinelabelconfiguration.html#cfn-quicksight-dashboard-referencelinelabelconfiguration-verticalposition
         */
        readonly verticalPosition?: string;
    }
    /**
     * The value label configuration of the label in a reference line.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinevaluelabelconfiguration.html
     */
    interface ReferenceLineValueLabelConfigurationProperty {
        /**
         * The format configuration of the value label.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinevaluelabelconfiguration.html#cfn-quicksight-dashboard-referencelinevaluelabelconfiguration-formatconfiguration
         */
        readonly formatConfiguration?: cdk.IResolvable | CfnDashboard.NumericFormatConfigurationProperty;
        /**
         * The relative position of the value label. Choose one of the following options:.
         *
         * - `BEFORE_CUSTOM_LABEL`
         * - `AFTER_CUSTOM_LABEL`
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinevaluelabelconfiguration.html#cfn-quicksight-dashboard-referencelinevaluelabelconfiguration-relativeposition
         */
        readonly relativePosition?: string;
    }
    /**
     * The configuration for a custom label on a `ReferenceLine` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinecustomlabelconfiguration.html
     */
    interface ReferenceLineCustomLabelConfigurationProperty {
        /**
         * The string text of the custom label.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinecustomlabelconfiguration.html#cfn-quicksight-dashboard-referencelinecustomlabelconfiguration-customlabel
         */
        readonly customLabel: string;
    }
    /**
     * The style configuration of the reference line.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinestyleconfiguration.html
     */
    interface ReferenceLineStyleConfigurationProperty {
        /**
         * The hex color of the reference line.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinestyleconfiguration.html#cfn-quicksight-dashboard-referencelinestyleconfiguration-color
         */
        readonly color?: string;
        /**
         * The pattern type of the line style. Choose one of the following options:.
         *
         * - `SOLID`
         * - `DASHED`
         * - `DOTTED`
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinestyleconfiguration.html#cfn-quicksight-dashboard-referencelinestyleconfiguration-pattern
         */
        readonly pattern?: string;
    }
    /**
     * The display options for the axis label.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdisplayoptions.html
     */
    interface AxisDisplayOptionsProperty {
        /**
         * Determines whether or not the axis line is visible.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdisplayoptions.html#cfn-quicksight-dashboard-axisdisplayoptions-axislinevisibility
         */
        readonly axisLineVisibility?: string;
        /**
         * The offset value that determines the starting placement of the axis within a visual's bounds.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdisplayoptions.html#cfn-quicksight-dashboard-axisdisplayoptions-axisoffset
         */
        readonly axisOffset?: string;
        /**
         * The data options for an axis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdisplayoptions.html#cfn-quicksight-dashboard-axisdisplayoptions-dataoptions
         */
        readonly dataOptions?: CfnDashboard.AxisDataOptionsProperty | cdk.IResolvable;
        /**
         * Determines whether or not the grid line is visible.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdisplayoptions.html#cfn-quicksight-dashboard-axisdisplayoptions-gridlinevisibility
         */
        readonly gridLineVisibility?: string;
        /**
         * The scroll bar options for an axis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdisplayoptions.html#cfn-quicksight-dashboard-axisdisplayoptions-scrollbaroptions
         */
        readonly scrollbarOptions?: cdk.IResolvable | CfnDashboard.ScrollBarOptionsProperty;
        /**
         * The tick label options of an axis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdisplayoptions.html#cfn-quicksight-dashboard-axisdisplayoptions-ticklabeloptions
         */
        readonly tickLabelOptions?: CfnDashboard.AxisTickLabelOptionsProperty | cdk.IResolvable;
    }
    /**
     * The data options for an axis.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdataoptions.html
     */
    interface AxisDataOptionsProperty {
        /**
         * The options for an axis with a date field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdataoptions.html#cfn-quicksight-dashboard-axisdataoptions-dateaxisoptions
         */
        readonly dateAxisOptions?: CfnDashboard.DateAxisOptionsProperty | cdk.IResolvable;
        /**
         * The options for an axis with a numeric field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdataoptions.html#cfn-quicksight-dashboard-axisdataoptions-numericaxisoptions
         */
        readonly numericAxisOptions?: cdk.IResolvable | CfnDashboard.NumericAxisOptionsProperty;
    }
    /**
     * The options that determine how a date axis is displayed.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dateaxisoptions.html
     */
    interface DateAxisOptionsProperty {
        /**
         * Determines whether or not missing dates are displayed.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dateaxisoptions.html#cfn-quicksight-dashboard-dateaxisoptions-missingdatevisibility
         */
        readonly missingDateVisibility?: string;
    }
    /**
     * The options for an axis with a numeric field.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericaxisoptions.html
     */
    interface NumericAxisOptionsProperty {
        /**
         * The range setup of a numeric axis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericaxisoptions.html#cfn-quicksight-dashboard-numericaxisoptions-range
         */
        readonly range?: CfnDashboard.AxisDisplayRangeProperty | cdk.IResolvable;
        /**
         * The scale setup of a numeric axis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericaxisoptions.html#cfn-quicksight-dashboard-numericaxisoptions-scale
         */
        readonly scale?: CfnDashboard.AxisScaleProperty | cdk.IResolvable;
    }
    /**
     * The scale setup options for a numeric axis display.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisscale.html
     */
    interface AxisScaleProperty {
        /**
         * The linear axis scale setup.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisscale.html#cfn-quicksight-dashboard-axisscale-linear
         */
        readonly linear?: CfnDashboard.AxisLinearScaleProperty | cdk.IResolvable;
        /**
         * The logarithmic axis scale setup.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisscale.html#cfn-quicksight-dashboard-axisscale-logarithmic
         */
        readonly logarithmic?: CfnDashboard.AxisLogarithmicScaleProperty | cdk.IResolvable;
    }
    /**
     * The logarithmic axis scale setup.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axislogarithmicscale.html
     */
    interface AxisLogarithmicScaleProperty {
        /**
         * The base setup of a logarithmic axis scale.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axislogarithmicscale.html#cfn-quicksight-dashboard-axislogarithmicscale-base
         */
        readonly base?: number;
    }
    /**
     * The liner axis scale setup.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axislinearscale.html
     */
    interface AxisLinearScaleProperty {
        /**
         * The step count setup of a linear axis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axislinearscale.html#cfn-quicksight-dashboard-axislinearscale-stepcount
         */
        readonly stepCount?: number;
        /**
         * The step size setup of a linear axis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axislinearscale.html#cfn-quicksight-dashboard-axislinearscale-stepsize
         */
        readonly stepSize?: number;
    }
    /**
     * The range setup of a numeric axis display range.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdisplayrange.html
     */
    interface AxisDisplayRangeProperty {
        /**
         * The data-driven setup of an axis display range.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdisplayrange.html#cfn-quicksight-dashboard-axisdisplayrange-datadriven
         */
        readonly dataDriven?: any | cdk.IResolvable;
        /**
         * The minimum and maximum setup of an axis display range.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdisplayrange.html#cfn-quicksight-dashboard-axisdisplayrange-minmax
         */
        readonly minMax?: CfnDashboard.AxisDisplayMinMaxRangeProperty | cdk.IResolvable;
    }
    /**
     * The minimum and maximum setup for an axis display range.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdisplayminmaxrange.html
     */
    interface AxisDisplayMinMaxRangeProperty {
        /**
         * The maximum setup for an axis display range.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdisplayminmaxrange.html#cfn-quicksight-dashboard-axisdisplayminmaxrange-maximum
         */
        readonly maximum?: number;
        /**
         * The minimum setup for an axis display range.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdisplayminmaxrange.html#cfn-quicksight-dashboard-axisdisplayminmaxrange-minimum
         */
        readonly minimum?: number;
    }
    /**
     * The tick label options of an axis.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisticklabeloptions.html
     */
    interface AxisTickLabelOptionsProperty {
        /**
         * Determines whether or not the axis ticks are visible.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisticklabeloptions.html#cfn-quicksight-dashboard-axisticklabeloptions-labeloptions
         */
        readonly labelOptions?: cdk.IResolvable | CfnDashboard.LabelOptionsProperty;
        /**
         * The rotation angle of the axis tick labels.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisticklabeloptions.html#cfn-quicksight-dashboard-axisticklabeloptions-rotationangle
         */
        readonly rotationAngle?: number;
    }
    /**
     * The visual display options for a data zoom scroll bar.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scrollbaroptions.html
     */
    interface ScrollBarOptionsProperty {
        /**
         * The visibility of the data zoom scroll bar.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scrollbaroptions.html#cfn-quicksight-dashboard-scrollbaroptions-visibility
         */
        readonly visibility?: string;
        /**
         * The visibility range for the data zoom scroll bar.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scrollbaroptions.html#cfn-quicksight-dashboard-scrollbaroptions-visiblerange
         */
        readonly visibleRange?: cdk.IResolvable | CfnDashboard.VisibleRangeOptionsProperty;
    }
    /**
     * The range options for the data zoom scroll bar.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visiblerangeoptions.html
     */
    interface VisibleRangeOptionsProperty {
        /**
         * The percent range in the visible range.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visiblerangeoptions.html#cfn-quicksight-dashboard-visiblerangeoptions-percentrange
         */
        readonly percentRange?: cdk.IResolvable | CfnDashboard.PercentVisibleRangeProperty;
    }
    /**
     * The percent range in the visible range.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-percentvisiblerange.html
     */
    interface PercentVisibleRangeProperty {
        /**
         * The lower bound of the range.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-percentvisiblerange.html#cfn-quicksight-dashboard-percentvisiblerange-from
         */
        readonly from?: number;
        /**
         * The top bound of the range.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-percentvisiblerange.html#cfn-quicksight-dashboard-percentvisiblerange-to
         */
        readonly to?: number;
    }
    /**
     * The field wells of a `BoxPlotVisual` .
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotfieldwells.html
     */
    interface BoxPlotFieldWellsProperty {
        /**
         * The aggregated field wells of a box plot.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotfieldwells.html#cfn-quicksight-dashboard-boxplotfieldwells-boxplotaggregatedfieldwells
         */
        readonly boxPlotAggregatedFieldWells?: CfnDashboard.BoxPlotAggregatedFieldWellsProperty | cdk.IResolvable;
    }
    /**
     * The aggregated field well for a box plot.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotaggregatedfieldwells.html
     */
    interface BoxPlotAggregatedFieldWellsProperty {
        /**
         * The group by field well of a box plot chart.
         *
         * Values are grouped based on group by fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotaggregatedfieldwells.html#cfn-quicksight-dashboard-boxplotaggregatedfieldwells-groupby
         */
        readonly groupBy?: Array<CfnDashboard.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The value field well of a box plot chart.
         *
         * Values are aggregated based on group by fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotaggregatedfieldwells.html#cfn-quicksight-dashboard-boxplotaggregatedfieldwells-values
         */
        readonly values?: Array<cdk.IResolvable | CfnDashboard.MeasureFieldProperty> | cdk.IResolvable;
    }
    /**
     * The options of a box plot visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotoptions.html
     */
    interface BoxPlotOptionsProperty {
        /**
         * Determines the visibility of all data points of the box plot.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotoptions.html#cfn-quicksight-dashboard-boxplotoptions-alldatapointsvisibility
         */
        readonly allDataPointsVisibility?: string;
        /**
         * Determines the visibility of the outlier in a box plot.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotoptions.html#cfn-quicksight-dashboard-boxplotoptions-outliervisibility
         */
        readonly outlierVisibility?: string;
        /**
         * The style options of the box plot.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotoptions.html#cfn-quicksight-dashboard-boxplotoptions-styleoptions
         */
        readonly styleOptions?: CfnDashboard.BoxPlotStyleOptionsProperty | cdk.IResolvable;
    }
    /**
     * The style options of the box plot.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotstyleoptions.html
     */
    interface BoxPlotStyleOptionsProperty {
        /**
         * The fill styles (solid, transparent) of the box plot.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotstyleoptions.html#cfn-quicksight-dashboard-boxplotstyleoptions-fillstyle
         */
        readonly fillStyle?: string;
    }
    /**
     * A waterfall chart.
     *
     * For more information, see [Using waterfall charts](https://docs.aws.amazon.com/quicksight/latest/user/waterfall-chart.html) in the *Amazon QuickSight User Guide* .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallvisual.html
     */
    interface WaterfallVisualProperty {
        /**
         * The list of custom actions that are configured for a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallvisual.html#cfn-quicksight-dashboard-waterfallvisual-actions
         */
        readonly actions?: Array<cdk.IResolvable | CfnDashboard.VisualCustomActionProperty> | cdk.IResolvable;
        /**
         * The configuration for a waterfall visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallvisual.html#cfn-quicksight-dashboard-waterfallvisual-chartconfiguration
         */
        readonly chartConfiguration?: cdk.IResolvable | CfnDashboard.WaterfallChartConfigurationProperty;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallvisual.html#cfn-quicksight-dashboard-waterfallvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnDashboard.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The subtitle that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallvisual.html#cfn-quicksight-dashboard-waterfallvisual-subtitle
         */
        readonly subtitle?: cdk.IResolvable | CfnDashboard.VisualSubtitleLabelOptionsProperty;
        /**
         * The title that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallvisual.html#cfn-quicksight-dashboard-waterfallvisual-title
         */
        readonly title?: cdk.IResolvable | CfnDashboard.VisualTitleLabelOptionsProperty;
        /**
         * The unique identifier of a visual.
         *
         * This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallvisual.html#cfn-quicksight-dashboard-waterfallvisual-visualid
         */
        readonly visualId: string;
    }
    /**
     * The configuration for a waterfall visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartconfiguration.html
     */
    interface WaterfallChartConfigurationProperty {
        /**
         * The options that determine the presentation of the category axis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartconfiguration.html#cfn-quicksight-dashboard-waterfallchartconfiguration-categoryaxisdisplayoptions
         */
        readonly categoryAxisDisplayOptions?: CfnDashboard.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * The options that determine the presentation of the category axis label.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartconfiguration.html#cfn-quicksight-dashboard-waterfallchartconfiguration-categoryaxislabeloptions
         */
        readonly categoryAxisLabelOptions?: CfnDashboard.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The data label configuration of a waterfall visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartconfiguration.html#cfn-quicksight-dashboard-waterfallchartconfiguration-datalabels
         */
        readonly dataLabels?: CfnDashboard.DataLabelOptionsProperty | cdk.IResolvable;
        /**
         * The field well configuration of a waterfall visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartconfiguration.html#cfn-quicksight-dashboard-waterfallchartconfiguration-fieldwells
         */
        readonly fieldWells?: cdk.IResolvable | CfnDashboard.WaterfallChartFieldWellsProperty;
        /**
         * The legend configuration of a waterfall visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartconfiguration.html#cfn-quicksight-dashboard-waterfallchartconfiguration-legend
         */
        readonly legend?: cdk.IResolvable | CfnDashboard.LegendOptionsProperty;
        /**
         * The options that determine the presentation of the y-axis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartconfiguration.html#cfn-quicksight-dashboard-waterfallchartconfiguration-primaryyaxisdisplayoptions
         */
        readonly primaryYAxisDisplayOptions?: CfnDashboard.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * The options that determine the presentation of the y-axis label.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartconfiguration.html#cfn-quicksight-dashboard-waterfallchartconfiguration-primaryyaxislabeloptions
         */
        readonly primaryYAxisLabelOptions?: CfnDashboard.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The sort configuration of a waterfall visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartconfiguration.html#cfn-quicksight-dashboard-waterfallchartconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: cdk.IResolvable | CfnDashboard.WaterfallChartSortConfigurationProperty;
        /**
         * The visual palette configuration of a waterfall visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartconfiguration.html#cfn-quicksight-dashboard-waterfallchartconfiguration-visualpalette
         */
        readonly visualPalette?: cdk.IResolvable | CfnDashboard.VisualPaletteProperty;
        /**
         * The options that determine the presentation of a waterfall visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartconfiguration.html#cfn-quicksight-dashboard-waterfallchartconfiguration-waterfallchartoptions
         */
        readonly waterfallChartOptions?: cdk.IResolvable | CfnDashboard.WaterfallChartOptionsProperty;
    }
    /**
     * The sort configuration of a waterfall visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartsortconfiguration.html
     */
    interface WaterfallChartSortConfigurationProperty {
        /**
         * The limit on the number of bar groups that are displayed.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartsortconfiguration.html#cfn-quicksight-dashboard-waterfallchartsortconfiguration-breakdownitemslimit
         */
        readonly breakdownItemsLimit?: cdk.IResolvable | CfnDashboard.ItemsLimitConfigurationProperty;
        /**
         * The sort configuration of the category fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartsortconfiguration.html#cfn-quicksight-dashboard-waterfallchartsortconfiguration-categorysort
         */
        readonly categorySort?: Array<CfnDashboard.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * The options that determine the presentation of the data labels.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeloptions.html
     */
    interface DataLabelOptionsProperty {
        /**
         * Determines the visibility of the category field labels.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeloptions.html#cfn-quicksight-dashboard-datalabeloptions-categorylabelvisibility
         */
        readonly categoryLabelVisibility?: string;
        /**
         * The option that determines the data label type.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeloptions.html#cfn-quicksight-dashboard-datalabeloptions-datalabeltypes
         */
        readonly dataLabelTypes?: Array<CfnDashboard.DataLabelTypeProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * Determines the color of the data labels.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeloptions.html#cfn-quicksight-dashboard-datalabeloptions-labelcolor
         */
        readonly labelColor?: string;
        /**
         * Determines the content of the data labels.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeloptions.html#cfn-quicksight-dashboard-datalabeloptions-labelcontent
         */
        readonly labelContent?: string;
        /**
         * Determines the font configuration of the data labels.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeloptions.html#cfn-quicksight-dashboard-datalabeloptions-labelfontconfiguration
         */
        readonly labelFontConfiguration?: CfnDashboard.FontConfigurationProperty | cdk.IResolvable;
        /**
         * Determines the visibility of the measure field labels.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeloptions.html#cfn-quicksight-dashboard-datalabeloptions-measurelabelvisibility
         */
        readonly measureLabelVisibility?: string;
        /**
         * Determines whether overlap is enabled or disabled for the data labels.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeloptions.html#cfn-quicksight-dashboard-datalabeloptions-overlap
         */
        readonly overlap?: string;
        /**
         * Determines the position of the data labels.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeloptions.html#cfn-quicksight-dashboard-datalabeloptions-position
         */
        readonly position?: string;
        /**
         * Determines the visibility of the total.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeloptions.html#cfn-quicksight-dashboard-datalabeloptions-totalsvisibility
         */
        readonly totalsVisibility?: string;
        /**
         * Determines the visibility of the data labels.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeloptions.html#cfn-quicksight-dashboard-datalabeloptions-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The option that determines the data label type.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeltype.html
     */
    interface DataLabelTypeProperty {
        /**
         * The option that specifies individual data values for labels.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeltype.html#cfn-quicksight-dashboard-datalabeltype-datapathlabeltype
         */
        readonly dataPathLabelType?: CfnDashboard.DataPathLabelTypeProperty | cdk.IResolvable;
        /**
         * Determines the label configuration for the entire field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeltype.html#cfn-quicksight-dashboard-datalabeltype-fieldlabeltype
         */
        readonly fieldLabelType?: CfnDashboard.FieldLabelTypeProperty | cdk.IResolvable;
        /**
         * Determines the label configuration for the maximum value in a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeltype.html#cfn-quicksight-dashboard-datalabeltype-maximumlabeltype
         */
        readonly maximumLabelType?: cdk.IResolvable | CfnDashboard.MaximumLabelTypeProperty;
        /**
         * Determines the label configuration for the minimum value in a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeltype.html#cfn-quicksight-dashboard-datalabeltype-minimumlabeltype
         */
        readonly minimumLabelType?: cdk.IResolvable | CfnDashboard.MinimumLabelTypeProperty;
        /**
         * Determines the label configuration for range end value in a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeltype.html#cfn-quicksight-dashboard-datalabeltype-rangeendslabeltype
         */
        readonly rangeEndsLabelType?: cdk.IResolvable | CfnDashboard.RangeEndsLabelTypeProperty;
    }
    /**
     * The maximum label of a data path label.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-maximumlabeltype.html
     */
    interface MaximumLabelTypeProperty {
        /**
         * The visibility of the maximum label.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-maximumlabeltype.html#cfn-quicksight-dashboard-maximumlabeltype-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The option that specifies individual data values for labels.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathlabeltype.html
     */
    interface DataPathLabelTypeProperty {
        /**
         * The field ID of the field that the data label needs to be applied to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathlabeltype.html#cfn-quicksight-dashboard-datapathlabeltype-fieldid
         */
        readonly fieldId?: string;
        /**
         * The actual value of the field that is labeled.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathlabeltype.html#cfn-quicksight-dashboard-datapathlabeltype-fieldvalue
         */
        readonly fieldValue?: string;
        /**
         * The visibility of the data label.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathlabeltype.html#cfn-quicksight-dashboard-datapathlabeltype-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The range ends label type of a data path label.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-rangeendslabeltype.html
     */
    interface RangeEndsLabelTypeProperty {
        /**
         * The visibility of the range ends label.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-rangeendslabeltype.html#cfn-quicksight-dashboard-rangeendslabeltype-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The field label type.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldlabeltype.html
     */
    interface FieldLabelTypeProperty {
        /**
         * Indicates the field that is targeted by the field label.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldlabeltype.html#cfn-quicksight-dashboard-fieldlabeltype-fieldid
         */
        readonly fieldId?: string;
        /**
         * The visibility of the field label.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldlabeltype.html#cfn-quicksight-dashboard-fieldlabeltype-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The minimum label of a data path label.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-minimumlabeltype.html
     */
    interface MinimumLabelTypeProperty {
        /**
         * The visibility of the minimum label.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-minimumlabeltype.html#cfn-quicksight-dashboard-minimumlabeltype-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The field well configuration of a waterfall visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartfieldwells.html
     */
    interface WaterfallChartFieldWellsProperty {
        /**
         * The field well configuration of a waterfall visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartfieldwells.html#cfn-quicksight-dashboard-waterfallchartfieldwells-waterfallchartaggregatedfieldwells
         */
        readonly waterfallChartAggregatedFieldWells?: cdk.IResolvable | CfnDashboard.WaterfallChartAggregatedFieldWellsProperty;
    }
    /**
     * The field well configuration of a waterfall visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartaggregatedfieldwells.html
     */
    interface WaterfallChartAggregatedFieldWellsProperty {
        /**
         * The breakdown field wells of a waterfall visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartaggregatedfieldwells.html#cfn-quicksight-dashboard-waterfallchartaggregatedfieldwells-breakdowns
         */
        readonly breakdowns?: Array<CfnDashboard.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The category field wells of a waterfall visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartaggregatedfieldwells.html#cfn-quicksight-dashboard-waterfallchartaggregatedfieldwells-categories
         */
        readonly categories?: Array<CfnDashboard.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The value field wells of a waterfall visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartaggregatedfieldwells.html#cfn-quicksight-dashboard-waterfallchartaggregatedfieldwells-values
         */
        readonly values?: Array<cdk.IResolvable | CfnDashboard.MeasureFieldProperty> | cdk.IResolvable;
    }
    /**
     * The options that determine the presentation of a waterfall visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartoptions.html
     */
    interface WaterfallChartOptionsProperty {
        /**
         * This option determines the total bar label of a waterfall visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartoptions.html#cfn-quicksight-dashboard-waterfallchartoptions-totalbarlabel
         */
        readonly totalBarLabel?: string;
    }
    /**
     * A visual that contains custom content.
     *
     * For more information, see [Using custom visual content](https://docs.aws.amazon.com/quicksight/latest/user/custom-visual-content.html) in the *Amazon QuickSight User Guide* .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcontentvisual.html
     */
    interface CustomContentVisualProperty {
        /**
         * The list of custom actions that are configured for a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcontentvisual.html#cfn-quicksight-dashboard-customcontentvisual-actions
         */
        readonly actions?: Array<cdk.IResolvable | CfnDashboard.VisualCustomActionProperty> | cdk.IResolvable;
        /**
         * The configuration of a `CustomContentVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcontentvisual.html#cfn-quicksight-dashboard-customcontentvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnDashboard.CustomContentConfigurationProperty | cdk.IResolvable;
        /**
         * The dataset that is used to create the custom content visual.
         *
         * You can't create a visual without a dataset.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcontentvisual.html#cfn-quicksight-dashboard-customcontentvisual-datasetidentifier
         */
        readonly dataSetIdentifier: string;
        /**
         * The subtitle that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcontentvisual.html#cfn-quicksight-dashboard-customcontentvisual-subtitle
         */
        readonly subtitle?: cdk.IResolvable | CfnDashboard.VisualSubtitleLabelOptionsProperty;
        /**
         * The title that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcontentvisual.html#cfn-quicksight-dashboard-customcontentvisual-title
         */
        readonly title?: cdk.IResolvable | CfnDashboard.VisualTitleLabelOptionsProperty;
        /**
         * The unique identifier of a visual.
         *
         * This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcontentvisual.html#cfn-quicksight-dashboard-customcontentvisual-visualid
         */
        readonly visualId: string;
    }
    /**
     * The configuration of a `CustomContentVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcontentconfiguration.html
     */
    interface CustomContentConfigurationProperty {
        /**
         * The content type of the custom content visual.
         *
         * You can use this to have the visual render as an image.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcontentconfiguration.html#cfn-quicksight-dashboard-customcontentconfiguration-contenttype
         */
        readonly contentType?: string;
        /**
         * The input URL that links to the custom content that you want in the custom visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcontentconfiguration.html#cfn-quicksight-dashboard-customcontentconfiguration-contenturl
         */
        readonly contentUrl?: string;
        /**
         * The sizing options for the size of the custom content visual.
         *
         * This structure is required when the `ContentType` of the visual is `'IMAGE'` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcontentconfiguration.html#cfn-quicksight-dashboard-customcontentconfiguration-imagescaling
         */
        readonly imageScaling?: string;
    }
    /**
     * A pie or donut chart.
     *
     * The `PieChartVisual` structure describes a visual that is a member of the pie chart family.
     *
     * The following charts can be described by using this structure:
     *
     * - Pie charts
     * - Donut charts
     *
     * For more information, see [Using pie charts](https://docs.aws.amazon.com/quicksight/latest/user/pie-chart.html) in the *Amazon QuickSight User Guide* .
     *
     * For more information, see [Using donut charts](https://docs.aws.amazon.com/quicksight/latest/user/donut-chart.html) in the *Amazon QuickSight User Guide* .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartvisual.html
     */
    interface PieChartVisualProperty {
        /**
         * The list of custom actions that are configured for a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartvisual.html#cfn-quicksight-dashboard-piechartvisual-actions
         */
        readonly actions?: Array<cdk.IResolvable | CfnDashboard.VisualCustomActionProperty> | cdk.IResolvable;
        /**
         * The configuration of a pie chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartvisual.html#cfn-quicksight-dashboard-piechartvisual-chartconfiguration
         */
        readonly chartConfiguration?: cdk.IResolvable | CfnDashboard.PieChartConfigurationProperty;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartvisual.html#cfn-quicksight-dashboard-piechartvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnDashboard.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The subtitle that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartvisual.html#cfn-quicksight-dashboard-piechartvisual-subtitle
         */
        readonly subtitle?: cdk.IResolvable | CfnDashboard.VisualSubtitleLabelOptionsProperty;
        /**
         * The title that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartvisual.html#cfn-quicksight-dashboard-piechartvisual-title
         */
        readonly title?: cdk.IResolvable | CfnDashboard.VisualTitleLabelOptionsProperty;
        /**
         * The unique identifier of a visual.
         *
         * This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartvisual.html#cfn-quicksight-dashboard-piechartvisual-visualid
         */
        readonly visualId: string;
    }
    /**
     * The configuration of a pie chart.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartconfiguration.html
     */
    interface PieChartConfigurationProperty {
        /**
         * The label options of the group/color that is displayed in a pie chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartconfiguration.html#cfn-quicksight-dashboard-piechartconfiguration-categorylabeloptions
         */
        readonly categoryLabelOptions?: CfnDashboard.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The contribution analysis (anomaly configuration) setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartconfiguration.html#cfn-quicksight-dashboard-piechartconfiguration-contributionanalysisdefaults
         */
        readonly contributionAnalysisDefaults?: Array<CfnDashboard.ContributionAnalysisDefaultProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The options that determine if visual data labels are displayed.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartconfiguration.html#cfn-quicksight-dashboard-piechartconfiguration-datalabels
         */
        readonly dataLabels?: CfnDashboard.DataLabelOptionsProperty | cdk.IResolvable;
        /**
         * The options that determine the shape of the chart.
         *
         * This option determines whether the chart is a pie chart or a donut chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartconfiguration.html#cfn-quicksight-dashboard-piechartconfiguration-donutoptions
         */
        readonly donutOptions?: CfnDashboard.DonutOptionsProperty | cdk.IResolvable;
        /**
         * The field wells of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartconfiguration.html#cfn-quicksight-dashboard-piechartconfiguration-fieldwells
         */
        readonly fieldWells?: cdk.IResolvable | CfnDashboard.PieChartFieldWellsProperty;
        /**
         * The legend display setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartconfiguration.html#cfn-quicksight-dashboard-piechartconfiguration-legend
         */
        readonly legend?: cdk.IResolvable | CfnDashboard.LegendOptionsProperty;
        /**
         * The small multiples setup for the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartconfiguration.html#cfn-quicksight-dashboard-piechartconfiguration-smallmultiplesoptions
         */
        readonly smallMultiplesOptions?: cdk.IResolvable | CfnDashboard.SmallMultiplesOptionsProperty;
        /**
         * The sort configuration of a pie chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartconfiguration.html#cfn-quicksight-dashboard-piechartconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: cdk.IResolvable | CfnDashboard.PieChartSortConfigurationProperty;
        /**
         * The tooltip display setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartconfiguration.html#cfn-quicksight-dashboard-piechartconfiguration-tooltip
         */
        readonly tooltip?: cdk.IResolvable | CfnDashboard.TooltipOptionsProperty;
        /**
         * The label options for the value that is displayed in a pie chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartconfiguration.html#cfn-quicksight-dashboard-piechartconfiguration-valuelabeloptions
         */
        readonly valueLabelOptions?: CfnDashboard.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The palette (chart color) display setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartconfiguration.html#cfn-quicksight-dashboard-piechartconfiguration-visualpalette
         */
        readonly visualPalette?: cdk.IResolvable | CfnDashboard.VisualPaletteProperty;
    }
    /**
     * The sort configuration of a pie chart.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartsortconfiguration.html
     */
    interface PieChartSortConfigurationProperty {
        /**
         * The limit on the number of categories that are displayed in a pie chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartsortconfiguration.html#cfn-quicksight-dashboard-piechartsortconfiguration-categoryitemslimit
         */
        readonly categoryItemsLimit?: cdk.IResolvable | CfnDashboard.ItemsLimitConfigurationProperty;
        /**
         * The sort configuration of the category fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartsortconfiguration.html#cfn-quicksight-dashboard-piechartsortconfiguration-categorysort
         */
        readonly categorySort?: Array<CfnDashboard.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The limit on the number of small multiples panels that are displayed.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartsortconfiguration.html#cfn-quicksight-dashboard-piechartsortconfiguration-smallmultipleslimitconfiguration
         */
        readonly smallMultiplesLimitConfiguration?: cdk.IResolvable | CfnDashboard.ItemsLimitConfigurationProperty;
        /**
         * The sort configuration of the small multiples field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartsortconfiguration.html#cfn-quicksight-dashboard-piechartsortconfiguration-smallmultiplessort
         */
        readonly smallMultiplesSort?: Array<CfnDashboard.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * The contribution analysis visual display for a line, pie, or bar chart.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-contributionanalysisdefault.html
     */
    interface ContributionAnalysisDefaultProperty {
        /**
         * The dimensions columns that are used in the contribution analysis, usually a list of `ColumnIdentifiers` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-contributionanalysisdefault.html#cfn-quicksight-dashboard-contributionanalysisdefault-contributordimensions
         */
        readonly contributorDimensions: Array<CfnDashboard.ColumnIdentifierProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The measure field that is used in the contribution analysis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-contributionanalysisdefault.html#cfn-quicksight-dashboard-contributionanalysisdefault-measurefieldid
         */
        readonly measureFieldId: string;
    }
    /**
     * The field well configuration of a pie chart.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartfieldwells.html
     */
    interface PieChartFieldWellsProperty {
        /**
         * The field well configuration of a pie chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartfieldwells.html#cfn-quicksight-dashboard-piechartfieldwells-piechartaggregatedfieldwells
         */
        readonly pieChartAggregatedFieldWells?: cdk.IResolvable | CfnDashboard.PieChartAggregatedFieldWellsProperty;
    }
    /**
     * The field well configuration of a pie chart.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartaggregatedfieldwells.html
     */
    interface PieChartAggregatedFieldWellsProperty {
        /**
         * The category (group/color) field wells of a pie chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartaggregatedfieldwells.html#cfn-quicksight-dashboard-piechartaggregatedfieldwells-category
         */
        readonly category?: Array<CfnDashboard.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The small multiples field well of a pie chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartaggregatedfieldwells.html#cfn-quicksight-dashboard-piechartaggregatedfieldwells-smallmultiples
         */
        readonly smallMultiples?: Array<CfnDashboard.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The value field wells of a pie chart.
         *
         * Values are aggregated based on categories.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartaggregatedfieldwells.html#cfn-quicksight-dashboard-piechartaggregatedfieldwells-values
         */
        readonly values?: Array<cdk.IResolvable | CfnDashboard.MeasureFieldProperty> | cdk.IResolvable;
    }
    /**
     * The options for configuring a donut chart or pie chart.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-donutoptions.html
     */
    interface DonutOptionsProperty {
        /**
         * The option for define the arc of the chart shape. Valid values are as follows:.
         *
         * - `WHOLE` - A pie chart
         * - `SMALL` - A small-sized donut chart
         * - `MEDIUM` - A medium-sized donut chart
         * - `LARGE` - A large-sized donut chart
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-donutoptions.html#cfn-quicksight-dashboard-donutoptions-arcoptions
         */
        readonly arcOptions?: CfnDashboard.ArcOptionsProperty | cdk.IResolvable;
        /**
         * The label options of the label that is displayed in the center of a donut chart.
         *
         * This option isn't available for pie charts.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-donutoptions.html#cfn-quicksight-dashboard-donutoptions-donutcenteroptions
         */
        readonly donutCenterOptions?: CfnDashboard.DonutCenterOptionsProperty | cdk.IResolvable;
    }
    /**
     * The label options of the label that is displayed in the center of a donut chart.
     *
     * This option isn't available for pie charts.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-donutcenteroptions.html
     */
    interface DonutCenterOptionsProperty {
        /**
         * Determines the visibility of the label in a donut chart.
         *
         * In the Amazon QuickSight console, this option is called `'Show total'` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-donutcenteroptions.html#cfn-quicksight-dashboard-donutcenteroptions-labelvisibility
         */
        readonly labelVisibility?: string;
    }
    /**
     * The options that determine the arc thickness of a `GaugeChartVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-arcoptions.html
     */
    interface ArcOptionsProperty {
        /**
         * The arc thickness of a `GaugeChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-arcoptions.html#cfn-quicksight-dashboard-arcoptions-arcthickness
         */
        readonly arcThickness?: string;
    }
    /**
     * Options that determine the layout and display options of a chart's small multiples.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-smallmultiplesoptions.html
     */
    interface SmallMultiplesOptionsProperty {
        /**
         * Sets the maximum number of visible columns to display in the grid of small multiples panels.
         *
         * The default is `Auto` , which automatically adjusts the columns in the grid to fit the overall layout and size of the given chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-smallmultiplesoptions.html#cfn-quicksight-dashboard-smallmultiplesoptions-maxvisiblecolumns
         */
        readonly maxVisibleColumns?: number;
        /**
         * Sets the maximum number of visible rows to display in the grid of small multiples panels.
         *
         * The default value is `Auto` , which automatically adjusts the rows in the grid to fit the overall layout and size of the given chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-smallmultiplesoptions.html#cfn-quicksight-dashboard-smallmultiplesoptions-maxvisiblerows
         */
        readonly maxVisibleRows?: number;
        /**
         * Configures the display options for each small multiples panel.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-smallmultiplesoptions.html#cfn-quicksight-dashboard-smallmultiplesoptions-panelconfiguration
         */
        readonly panelConfiguration?: cdk.IResolvable | CfnDashboard.PanelConfigurationProperty;
        /**
         * The properties of a small multiples X axis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-smallmultiplesoptions.html#cfn-quicksight-dashboard-smallmultiplesoptions-xaxis
         */
        readonly xAxis?: cdk.IResolvable | CfnDashboard.SmallMultiplesAxisPropertiesProperty;
        /**
         * The properties of a small multiples Y axis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-smallmultiplesoptions.html#cfn-quicksight-dashboard-smallmultiplesoptions-yaxis
         */
        readonly yAxis?: cdk.IResolvable | CfnDashboard.SmallMultiplesAxisPropertiesProperty;
    }
    /**
     * A collection of options that configure how each panel displays in a small multiples chart.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-panelconfiguration.html
     */
    interface PanelConfigurationProperty {
        /**
         * Sets the background color for each panel.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-panelconfiguration.html#cfn-quicksight-dashboard-panelconfiguration-backgroundcolor
         */
        readonly backgroundColor?: string;
        /**
         * Determines whether or not a background for each small multiples panel is rendered.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-panelconfiguration.html#cfn-quicksight-dashboard-panelconfiguration-backgroundvisibility
         */
        readonly backgroundVisibility?: string;
        /**
         * Sets the line color of panel borders.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-panelconfiguration.html#cfn-quicksight-dashboard-panelconfiguration-bordercolor
         */
        readonly borderColor?: string;
        /**
         * Sets the line style of panel borders.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-panelconfiguration.html#cfn-quicksight-dashboard-panelconfiguration-borderstyle
         */
        readonly borderStyle?: string;
        /**
         * Sets the line thickness of panel borders.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-panelconfiguration.html#cfn-quicksight-dashboard-panelconfiguration-borderthickness
         */
        readonly borderThickness?: string;
        /**
         * Determines whether or not each panel displays a border.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-panelconfiguration.html#cfn-quicksight-dashboard-panelconfiguration-bordervisibility
         */
        readonly borderVisibility?: string;
        /**
         * Sets the total amount of negative space to display between sibling panels.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-panelconfiguration.html#cfn-quicksight-dashboard-panelconfiguration-gutterspacing
         */
        readonly gutterSpacing?: string;
        /**
         * Determines whether or not negative space between sibling panels is rendered.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-panelconfiguration.html#cfn-quicksight-dashboard-panelconfiguration-guttervisibility
         */
        readonly gutterVisibility?: string;
        /**
         * Configures the title display within each small multiples panel.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-panelconfiguration.html#cfn-quicksight-dashboard-panelconfiguration-title
         */
        readonly title?: cdk.IResolvable | CfnDashboard.PanelTitleOptionsProperty;
    }
    /**
     * The options that determine the title styles for each small multiples panel.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-paneltitleoptions.html
     */
    interface PanelTitleOptionsProperty {
        /**
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-paneltitleoptions.html#cfn-quicksight-dashboard-paneltitleoptions-fontconfiguration
         */
        readonly fontConfiguration?: CfnDashboard.FontConfigurationProperty | cdk.IResolvable;
        /**
         * Sets the horizontal text alignment of the title within each panel.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-paneltitleoptions.html#cfn-quicksight-dashboard-paneltitleoptions-horizontaltextalignment
         */
        readonly horizontalTextAlignment?: string;
        /**
         * Determines whether or not panel titles are displayed.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-paneltitleoptions.html#cfn-quicksight-dashboard-paneltitleoptions-visibility
         */
        readonly visibility?: string;
    }
    /**
     * Configures the properties of a chart's axes that are used by small multiples panels.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-smallmultiplesaxisproperties.html
     */
    interface SmallMultiplesAxisPropertiesProperty {
        /**
         * Defines the placement of the axis.
         *
         * By default, axes are rendered `OUTSIDE` of the panels. Axes with `INDEPENDENT` scale are rendered `INSIDE` the panels.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-smallmultiplesaxisproperties.html#cfn-quicksight-dashboard-smallmultiplesaxisproperties-placement
         */
        readonly placement?: string;
        /**
         * Determines whether scale of the axes are shared or independent.
         *
         * The default value is `SHARED` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-smallmultiplesaxisproperties.html#cfn-quicksight-dashboard-smallmultiplesaxisproperties-scale
         */
        readonly scale?: string;
    }
    /**
     * A key performance indicator (KPI).
     *
     * For more information, see [Using KPIs](https://docs.aws.amazon.com/quicksight/latest/user/kpi.html) in the *Amazon QuickSight User Guide* .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpivisual.html
     */
    interface KPIVisualProperty {
        /**
         * The list of custom actions that are configured for a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpivisual.html#cfn-quicksight-dashboard-kpivisual-actions
         */
        readonly actions?: Array<cdk.IResolvable | CfnDashboard.VisualCustomActionProperty> | cdk.IResolvable;
        /**
         * The configuration of a KPI visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpivisual.html#cfn-quicksight-dashboard-kpivisual-chartconfiguration
         */
        readonly chartConfiguration?: cdk.IResolvable | CfnDashboard.KPIConfigurationProperty;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpivisual.html#cfn-quicksight-dashboard-kpivisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnDashboard.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The conditional formatting of a KPI visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpivisual.html#cfn-quicksight-dashboard-kpivisual-conditionalformatting
         */
        readonly conditionalFormatting?: cdk.IResolvable | CfnDashboard.KPIConditionalFormattingProperty;
        /**
         * The subtitle that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpivisual.html#cfn-quicksight-dashboard-kpivisual-subtitle
         */
        readonly subtitle?: cdk.IResolvable | CfnDashboard.VisualSubtitleLabelOptionsProperty;
        /**
         * The title that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpivisual.html#cfn-quicksight-dashboard-kpivisual-title
         */
        readonly title?: cdk.IResolvable | CfnDashboard.VisualTitleLabelOptionsProperty;
        /**
         * The unique identifier of a visual.
         *
         * This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpivisual.html#cfn-quicksight-dashboard-kpivisual-visualid
         */
        readonly visualId: string;
    }
    /**
     * The conditional formatting of a KPI visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiconditionalformatting.html
     */
    interface KPIConditionalFormattingProperty {
        /**
         * The conditional formatting options of a KPI visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiconditionalformatting.html#cfn-quicksight-dashboard-kpiconditionalformatting-conditionalformattingoptions
         */
        readonly conditionalFormattingOptions?: Array<cdk.IResolvable | CfnDashboard.KPIConditionalFormattingOptionProperty> | cdk.IResolvable;
    }
    /**
     * The conditional formatting options of a KPI visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiconditionalformattingoption.html
     */
    interface KPIConditionalFormattingOptionProperty {
        /**
         * The conditional formatting for the actual value of a KPI visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiconditionalformattingoption.html#cfn-quicksight-dashboard-kpiconditionalformattingoption-actualvalue
         */
        readonly actualValue?: cdk.IResolvable | CfnDashboard.KPIActualValueConditionalFormattingProperty;
        /**
         * The conditional formatting for the comparison value of a KPI visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiconditionalformattingoption.html#cfn-quicksight-dashboard-kpiconditionalformattingoption-comparisonvalue
         */
        readonly comparisonValue?: cdk.IResolvable | CfnDashboard.KPIComparisonValueConditionalFormattingProperty;
        /**
         * The conditional formatting for the primary value of a KPI visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiconditionalformattingoption.html#cfn-quicksight-dashboard-kpiconditionalformattingoption-primaryvalue
         */
        readonly primaryValue?: cdk.IResolvable | CfnDashboard.KPIPrimaryValueConditionalFormattingProperty;
        /**
         * The conditional formatting for the progress bar of a KPI visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiconditionalformattingoption.html#cfn-quicksight-dashboard-kpiconditionalformattingoption-progressbar
         */
        readonly progressBar?: cdk.IResolvable | CfnDashboard.KPIProgressBarConditionalFormattingProperty;
    }
    /**
     * The conditional formatting for the primary value of a KPI visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiprimaryvalueconditionalformatting.html
     */
    interface KPIPrimaryValueConditionalFormattingProperty {
        /**
         * The conditional formatting of the primary value's icon.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiprimaryvalueconditionalformatting.html#cfn-quicksight-dashboard-kpiprimaryvalueconditionalformatting-icon
         */
        readonly icon?: CfnDashboard.ConditionalFormattingIconProperty | cdk.IResolvable;
        /**
         * The conditional formatting of the primary value's text color.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiprimaryvalueconditionalformatting.html#cfn-quicksight-dashboard-kpiprimaryvalueconditionalformatting-textcolor
         */
        readonly textColor?: CfnDashboard.ConditionalFormattingColorProperty | cdk.IResolvable;
    }
    /**
     * The formatting configuration for the icon.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingicon.html
     */
    interface ConditionalFormattingIconProperty {
        /**
         * Determines the custom condition for an icon set.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingicon.html#cfn-quicksight-dashboard-conditionalformattingicon-customcondition
         */
        readonly customCondition?: CfnDashboard.ConditionalFormattingCustomIconConditionProperty | cdk.IResolvable;
        /**
         * Formatting configuration for icon set.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingicon.html#cfn-quicksight-dashboard-conditionalformattingicon-iconset
         */
        readonly iconSet?: CfnDashboard.ConditionalFormattingIconSetProperty | cdk.IResolvable;
    }
    /**
     * Determines the custom condition for an icon set.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingcustomiconcondition.html
     */
    interface ConditionalFormattingCustomIconConditionProperty {
        /**
         * Determines the color of the icon.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingcustomiconcondition.html#cfn-quicksight-dashboard-conditionalformattingcustomiconcondition-color
         */
        readonly color?: string;
        /**
         * Determines the icon display configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingcustomiconcondition.html#cfn-quicksight-dashboard-conditionalformattingcustomiconcondition-displayconfiguration
         */
        readonly displayConfiguration?: CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty | cdk.IResolvable;
        /**
         * The expression that determines the condition of the icon set.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingcustomiconcondition.html#cfn-quicksight-dashboard-conditionalformattingcustomiconcondition-expression
         */
        readonly expression: string;
        /**
         * Custom icon options for an icon set.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingcustomiconcondition.html#cfn-quicksight-dashboard-conditionalformattingcustomiconcondition-iconoptions
         */
        readonly iconOptions: CfnDashboard.ConditionalFormattingCustomIconOptionsProperty | cdk.IResolvable;
    }
    /**
     * Determines the icon display configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingicondisplayconfiguration.html
     */
    interface ConditionalFormattingIconDisplayConfigurationProperty {
        /**
         * Determines the icon display configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingicondisplayconfiguration.html#cfn-quicksight-dashboard-conditionalformattingicondisplayconfiguration-icondisplayoption
         */
        readonly iconDisplayOption?: string;
    }
    /**
     * Custom icon options for an icon set.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingcustomiconoptions.html
     */
    interface ConditionalFormattingCustomIconOptionsProperty {
        /**
         * Determines the type of icon.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingcustomiconoptions.html#cfn-quicksight-dashboard-conditionalformattingcustomiconoptions-icon
         */
        readonly icon?: string;
        /**
         * Determines the Unicode icon type.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingcustomiconoptions.html#cfn-quicksight-dashboard-conditionalformattingcustomiconoptions-unicodeicon
         */
        readonly unicodeIcon?: string;
    }
    /**
     * Formatting configuration for icon set.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingiconset.html
     */
    interface ConditionalFormattingIconSetProperty {
        /**
         * The expression that determines the formatting configuration for the icon set.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingiconset.html#cfn-quicksight-dashboard-conditionalformattingiconset-expression
         */
        readonly expression: string;
        /**
         * Determines the icon set type.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingiconset.html#cfn-quicksight-dashboard-conditionalformattingiconset-iconsettype
         */
        readonly iconSetType?: string;
    }
    /**
     * The conditional formatting for the actual value of a KPI visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiactualvalueconditionalformatting.html
     */
    interface KPIActualValueConditionalFormattingProperty {
        /**
         * The conditional formatting of the actual value's icon.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiactualvalueconditionalformatting.html#cfn-quicksight-dashboard-kpiactualvalueconditionalformatting-icon
         */
        readonly icon?: CfnDashboard.ConditionalFormattingIconProperty | cdk.IResolvable;
        /**
         * The conditional formatting of the actual value's text color.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiactualvalueconditionalformatting.html#cfn-quicksight-dashboard-kpiactualvalueconditionalformatting-textcolor
         */
        readonly textColor?: CfnDashboard.ConditionalFormattingColorProperty | cdk.IResolvable;
    }
    /**
     * The conditional formatting for the comparison value of a KPI visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpicomparisonvalueconditionalformatting.html
     */
    interface KPIComparisonValueConditionalFormattingProperty {
        /**
         * The conditional formatting of the comparison value's icon.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpicomparisonvalueconditionalformatting.html#cfn-quicksight-dashboard-kpicomparisonvalueconditionalformatting-icon
         */
        readonly icon?: CfnDashboard.ConditionalFormattingIconProperty | cdk.IResolvable;
        /**
         * The conditional formatting of the comparison value's text color.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpicomparisonvalueconditionalformatting.html#cfn-quicksight-dashboard-kpicomparisonvalueconditionalformatting-textcolor
         */
        readonly textColor?: CfnDashboard.ConditionalFormattingColorProperty | cdk.IResolvable;
    }
    /**
     * The conditional formatting for the progress bar of a KPI visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiprogressbarconditionalformatting.html
     */
    interface KPIProgressBarConditionalFormattingProperty {
        /**
         * The conditional formatting of the progress bar's foreground color.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiprogressbarconditionalformatting.html#cfn-quicksight-dashboard-kpiprogressbarconditionalformatting-foregroundcolor
         */
        readonly foregroundColor?: CfnDashboard.ConditionalFormattingColorProperty | cdk.IResolvable;
    }
    /**
     * The configuration of a KPI visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiconfiguration.html
     */
    interface KPIConfigurationProperty {
        /**
         * The field well configuration of a KPI visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiconfiguration.html#cfn-quicksight-dashboard-kpiconfiguration-fieldwells
         */
        readonly fieldWells?: cdk.IResolvable | CfnDashboard.KPIFieldWellsProperty;
        /**
         * The options that determine the presentation of a KPI visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiconfiguration.html#cfn-quicksight-dashboard-kpiconfiguration-kpioptions
         */
        readonly kpiOptions?: cdk.IResolvable | CfnDashboard.KPIOptionsProperty;
        /**
         * The sort configuration of a KPI visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiconfiguration.html#cfn-quicksight-dashboard-kpiconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: cdk.IResolvable | CfnDashboard.KPISortConfigurationProperty;
    }
    /**
     * The sort configuration of a KPI visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpisortconfiguration.html
     */
    interface KPISortConfigurationProperty {
        /**
         * The sort configuration of the trend group fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpisortconfiguration.html#cfn-quicksight-dashboard-kpisortconfiguration-trendgroupsort
         */
        readonly trendGroupSort?: Array<CfnDashboard.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * The options that determine the presentation of a KPI visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpioptions.html
     */
    interface KPIOptionsProperty {
        /**
         * The comparison configuration of a KPI visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpioptions.html#cfn-quicksight-dashboard-kpioptions-comparison
         */
        readonly comparison?: CfnDashboard.ComparisonConfigurationProperty | cdk.IResolvable;
        /**
         * The options that determine the primary value display type.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpioptions.html#cfn-quicksight-dashboard-kpioptions-primaryvaluedisplaytype
         */
        readonly primaryValueDisplayType?: string;
        /**
         * The options that determine the primary value font configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpioptions.html#cfn-quicksight-dashboard-kpioptions-primaryvaluefontconfiguration
         */
        readonly primaryValueFontConfiguration?: CfnDashboard.FontConfigurationProperty | cdk.IResolvable;
        /**
         * The options that determine the presentation of the progress bar of a KPI visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpioptions.html#cfn-quicksight-dashboard-kpioptions-progressbar
         */
        readonly progressBar?: cdk.IResolvable | CfnDashboard.ProgressBarOptionsProperty;
        /**
         * The options that determine the presentation of the secondary value of a KPI visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpioptions.html#cfn-quicksight-dashboard-kpioptions-secondaryvalue
         */
        readonly secondaryValue?: cdk.IResolvable | CfnDashboard.SecondaryValueOptionsProperty;
        /**
         * The options that determine the secondary value font configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpioptions.html#cfn-quicksight-dashboard-kpioptions-secondaryvaluefontconfiguration
         */
        readonly secondaryValueFontConfiguration?: CfnDashboard.FontConfigurationProperty | cdk.IResolvable;
        /**
         * The options that determine the visibility, color, type, and tooltip visibility of the sparkline of a KPI visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpioptions.html#cfn-quicksight-dashboard-kpioptions-sparkline
         */
        readonly sparkline?: cdk.IResolvable | CfnDashboard.KPISparklineOptionsProperty;
        /**
         * The options that determine the presentation of trend arrows in a KPI visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpioptions.html#cfn-quicksight-dashboard-kpioptions-trendarrows
         */
        readonly trendArrows?: cdk.IResolvable | CfnDashboard.TrendArrowOptionsProperty;
        /**
         * The options that determine the layout a KPI visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpioptions.html#cfn-quicksight-dashboard-kpioptions-visuallayoutoptions
         */
        readonly visualLayoutOptions?: cdk.IResolvable | CfnDashboard.KPIVisualLayoutOptionsProperty;
    }
    /**
     * The options that determine the layout a KPI visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpivisuallayoutoptions.html
     */
    interface KPIVisualLayoutOptionsProperty {
        /**
         * The standard layout of the KPI visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpivisuallayoutoptions.html#cfn-quicksight-dashboard-kpivisuallayoutoptions-standardlayout
         */
        readonly standardLayout?: cdk.IResolvable | CfnDashboard.KPIVisualStandardLayoutProperty;
    }
    /**
     * The standard layout of the KPI visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpivisualstandardlayout.html
     */
    interface KPIVisualStandardLayoutProperty {
        /**
         * The standard layout type.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpivisualstandardlayout.html#cfn-quicksight-dashboard-kpivisualstandardlayout-type
         */
        readonly type: string;
    }
    /**
     * The options that determine the presentation of trend arrows in a KPI visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-trendarrowoptions.html
     */
    interface TrendArrowOptionsProperty {
        /**
         * The visibility of the trend arrows.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-trendarrowoptions.html#cfn-quicksight-dashboard-trendarrowoptions-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The options that determine the presentation of the secondary value of a KPI visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-secondaryvalueoptions.html
     */
    interface SecondaryValueOptionsProperty {
        /**
         * Determines the visibility of the secondary value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-secondaryvalueoptions.html#cfn-quicksight-dashboard-secondaryvalueoptions-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The comparison display configuration of a KPI or gauge chart.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-comparisonconfiguration.html
     */
    interface ComparisonConfigurationProperty {
        /**
         * The format of the comparison.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-comparisonconfiguration.html#cfn-quicksight-dashboard-comparisonconfiguration-comparisonformat
         */
        readonly comparisonFormat?: CfnDashboard.ComparisonFormatConfigurationProperty | cdk.IResolvable;
        /**
         * The method of the comparison. Choose from the following options:.
         *
         * - `DIFFERENCE`
         * - `PERCENT_DIFFERENCE`
         * - `PERCENT`
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-comparisonconfiguration.html#cfn-quicksight-dashboard-comparisonconfiguration-comparisonmethod
         */
        readonly comparisonMethod?: string;
    }
    /**
     * The format of the comparison.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-comparisonformatconfiguration.html
     */
    interface ComparisonFormatConfigurationProperty {
        /**
         * The number display format.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-comparisonformatconfiguration.html#cfn-quicksight-dashboard-comparisonformatconfiguration-numberdisplayformatconfiguration
         */
        readonly numberDisplayFormatConfiguration?: cdk.IResolvable | CfnDashboard.NumberDisplayFormatConfigurationProperty;
        /**
         * The percentage display format.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-comparisonformatconfiguration.html#cfn-quicksight-dashboard-comparisonformatconfiguration-percentagedisplayformatconfiguration
         */
        readonly percentageDisplayFormatConfiguration?: cdk.IResolvable | CfnDashboard.PercentageDisplayFormatConfigurationProperty;
    }
    /**
     * The options that determine the presentation of the progress bar of a KPI visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-progressbaroptions.html
     */
    interface ProgressBarOptionsProperty {
        /**
         * The visibility of the progress bar.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-progressbaroptions.html#cfn-quicksight-dashboard-progressbaroptions-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The options that determine the visibility, color, type, and tooltip visibility of the sparkline of a KPI visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpisparklineoptions.html
     */
    interface KPISparklineOptionsProperty {
        /**
         * The color of the sparkline.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpisparklineoptions.html#cfn-quicksight-dashboard-kpisparklineoptions-color
         */
        readonly color?: string;
        /**
         * The tooltip visibility of the sparkline.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpisparklineoptions.html#cfn-quicksight-dashboard-kpisparklineoptions-tooltipvisibility
         */
        readonly tooltipVisibility?: string;
        /**
         * The type of the sparkline.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpisparklineoptions.html#cfn-quicksight-dashboard-kpisparklineoptions-type
         */
        readonly type: string;
        /**
         * The visibility of the sparkline.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpisparklineoptions.html#cfn-quicksight-dashboard-kpisparklineoptions-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The field well configuration of a KPI visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpifieldwells.html
     */
    interface KPIFieldWellsProperty {
        /**
         * The target value field wells of a KPI visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpifieldwells.html#cfn-quicksight-dashboard-kpifieldwells-targetvalues
         */
        readonly targetValues?: Array<cdk.IResolvable | CfnDashboard.MeasureFieldProperty> | cdk.IResolvable;
        /**
         * The trend group field wells of a KPI visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpifieldwells.html#cfn-quicksight-dashboard-kpifieldwells-trendgroups
         */
        readonly trendGroups?: Array<CfnDashboard.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The value field wells of a KPI visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpifieldwells.html#cfn-quicksight-dashboard-kpifieldwells-values
         */
        readonly values?: Array<cdk.IResolvable | CfnDashboard.MeasureFieldProperty> | cdk.IResolvable;
    }
    /**
     * A histogram.
     *
     * For more information, see [Using histograms](https://docs.aws.amazon.com/quicksight/latest/user/histogram-charts.html) in the *Amazon QuickSight User Guide* .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramvisual.html
     */
    interface HistogramVisualProperty {
        /**
         * The list of custom actions that are configured for a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramvisual.html#cfn-quicksight-dashboard-histogramvisual-actions
         */
        readonly actions?: Array<cdk.IResolvable | CfnDashboard.VisualCustomActionProperty> | cdk.IResolvable;
        /**
         * The configuration for a `HistogramVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramvisual.html#cfn-quicksight-dashboard-histogramvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnDashboard.HistogramConfigurationProperty | cdk.IResolvable;
        /**
         * The subtitle that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramvisual.html#cfn-quicksight-dashboard-histogramvisual-subtitle
         */
        readonly subtitle?: cdk.IResolvable | CfnDashboard.VisualSubtitleLabelOptionsProperty;
        /**
         * The title that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramvisual.html#cfn-quicksight-dashboard-histogramvisual-title
         */
        readonly title?: cdk.IResolvable | CfnDashboard.VisualTitleLabelOptionsProperty;
        /**
         * The unique identifier of a visual.
         *
         * This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramvisual.html#cfn-quicksight-dashboard-histogramvisual-visualid
         */
        readonly visualId: string;
    }
    /**
     * The configuration for a `HistogramVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramconfiguration.html
     */
    interface HistogramConfigurationProperty {
        /**
         * The options that determine the presentation of histogram bins.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramconfiguration.html#cfn-quicksight-dashboard-histogramconfiguration-binoptions
         */
        readonly binOptions?: CfnDashboard.HistogramBinOptionsProperty | cdk.IResolvable;
        /**
         * The data label configuration of a histogram.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramconfiguration.html#cfn-quicksight-dashboard-histogramconfiguration-datalabels
         */
        readonly dataLabels?: CfnDashboard.DataLabelOptionsProperty | cdk.IResolvable;
        /**
         * The field well configuration of a histogram.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramconfiguration.html#cfn-quicksight-dashboard-histogramconfiguration-fieldwells
         */
        readonly fieldWells?: CfnDashboard.HistogramFieldWellsProperty | cdk.IResolvable;
        /**
         * The tooltip configuration of a histogram.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramconfiguration.html#cfn-quicksight-dashboard-histogramconfiguration-tooltip
         */
        readonly tooltip?: cdk.IResolvable | CfnDashboard.TooltipOptionsProperty;
        /**
         * The visual palette configuration of a histogram.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramconfiguration.html#cfn-quicksight-dashboard-histogramconfiguration-visualpalette
         */
        readonly visualPalette?: cdk.IResolvable | CfnDashboard.VisualPaletteProperty;
        /**
         * The options that determine the presentation of the x-axis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramconfiguration.html#cfn-quicksight-dashboard-histogramconfiguration-xaxisdisplayoptions
         */
        readonly xAxisDisplayOptions?: CfnDashboard.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * The options that determine the presentation of the x-axis label.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramconfiguration.html#cfn-quicksight-dashboard-histogramconfiguration-xaxislabeloptions
         */
        readonly xAxisLabelOptions?: CfnDashboard.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The options that determine the presentation of the y-axis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramconfiguration.html#cfn-quicksight-dashboard-histogramconfiguration-yaxisdisplayoptions
         */
        readonly yAxisDisplayOptions?: CfnDashboard.AxisDisplayOptionsProperty | cdk.IResolvable;
    }
    /**
     * The options that determine the presentation of histogram bins.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogrambinoptions.html
     */
    interface HistogramBinOptionsProperty {
        /**
         * The options that determine the bin count of a histogram.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogrambinoptions.html#cfn-quicksight-dashboard-histogrambinoptions-bincount
         */
        readonly binCount?: CfnDashboard.BinCountOptionsProperty | cdk.IResolvable;
        /**
         * The options that determine the bin width of a histogram.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogrambinoptions.html#cfn-quicksight-dashboard-histogrambinoptions-binwidth
         */
        readonly binWidth?: CfnDashboard.BinWidthOptionsProperty | cdk.IResolvable;
        /**
         * The options that determine the selected bin type.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogrambinoptions.html#cfn-quicksight-dashboard-histogrambinoptions-selectedbintype
         */
        readonly selectedBinType?: string;
        /**
         * The options that determine the bin start value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogrambinoptions.html#cfn-quicksight-dashboard-histogrambinoptions-startvalue
         */
        readonly startValue?: number;
    }
    /**
     * The options that determine the bin width of a histogram.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-binwidthoptions.html
     */
    interface BinWidthOptionsProperty {
        /**
         * The options that determine the bin count limit.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-binwidthoptions.html#cfn-quicksight-dashboard-binwidthoptions-bincountlimit
         */
        readonly binCountLimit?: number;
        /**
         * The options that determine the bin width value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-binwidthoptions.html#cfn-quicksight-dashboard-binwidthoptions-value
         */
        readonly value?: number;
    }
    /**
     * The options that determine the bin count of a histogram.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-bincountoptions.html
     */
    interface BinCountOptionsProperty {
        /**
         * The options that determine the bin count value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-bincountoptions.html#cfn-quicksight-dashboard-bincountoptions-value
         */
        readonly value?: number;
    }
    /**
     * The field well configuration of a histogram.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramfieldwells.html
     */
    interface HistogramFieldWellsProperty {
        /**
         * The field well configuration of a histogram.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramfieldwells.html#cfn-quicksight-dashboard-histogramfieldwells-histogramaggregatedfieldwells
         */
        readonly histogramAggregatedFieldWells?: CfnDashboard.HistogramAggregatedFieldWellsProperty | cdk.IResolvable;
    }
    /**
     * The field well configuration of a histogram.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramaggregatedfieldwells.html
     */
    interface HistogramAggregatedFieldWellsProperty {
        /**
         * The value field wells of a histogram.
         *
         * Values are aggregated by `COUNT` or `DISTINCT_COUNT` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramaggregatedfieldwells.html#cfn-quicksight-dashboard-histogramaggregatedfieldwells-values
         */
        readonly values?: Array<cdk.IResolvable | CfnDashboard.MeasureFieldProperty> | cdk.IResolvable;
    }
    /**
     * A table visual.
     *
     * For more information, see [Using tables as visuals](https://docs.aws.amazon.com/quicksight/latest/user/tabular.html) in the *Amazon QuickSight User Guide* .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablevisual.html
     */
    interface TableVisualProperty {
        /**
         * The list of custom actions that are configured for a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablevisual.html#cfn-quicksight-dashboard-tablevisual-actions
         */
        readonly actions?: Array<cdk.IResolvable | CfnDashboard.VisualCustomActionProperty> | cdk.IResolvable;
        /**
         * The configuration settings of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablevisual.html#cfn-quicksight-dashboard-tablevisual-chartconfiguration
         */
        readonly chartConfiguration?: cdk.IResolvable | CfnDashboard.TableConfigurationProperty;
        /**
         * The conditional formatting for a `PivotTableVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablevisual.html#cfn-quicksight-dashboard-tablevisual-conditionalformatting
         */
        readonly conditionalFormatting?: cdk.IResolvable | CfnDashboard.TableConditionalFormattingProperty;
        /**
         * The subtitle that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablevisual.html#cfn-quicksight-dashboard-tablevisual-subtitle
         */
        readonly subtitle?: cdk.IResolvable | CfnDashboard.VisualSubtitleLabelOptionsProperty;
        /**
         * The title that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablevisual.html#cfn-quicksight-dashboard-tablevisual-title
         */
        readonly title?: cdk.IResolvable | CfnDashboard.VisualTitleLabelOptionsProperty;
        /**
         * The unique identifier of a visual.
         *
         * This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablevisual.html#cfn-quicksight-dashboard-tablevisual-visualid
         */
        readonly visualId: string;
    }
    /**
     * The conditional formatting for a `PivotTableVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableconditionalformatting.html
     */
    interface TableConditionalFormattingProperty {
        /**
         * Conditional formatting options for a `PivotTableVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableconditionalformatting.html#cfn-quicksight-dashboard-tableconditionalformatting-conditionalformattingoptions
         */
        readonly conditionalFormattingOptions?: Array<cdk.IResolvable | CfnDashboard.TableConditionalFormattingOptionProperty> | cdk.IResolvable;
    }
    /**
     * Conditional formatting options for a `PivotTableVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableconditionalformattingoption.html
     */
    interface TableConditionalFormattingOptionProperty {
        /**
         * The cell conditional formatting option for a table.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableconditionalformattingoption.html#cfn-quicksight-dashboard-tableconditionalformattingoption-cell
         */
        readonly cell?: cdk.IResolvable | CfnDashboard.TableCellConditionalFormattingProperty;
        /**
         * The row conditional formatting option for a table.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableconditionalformattingoption.html#cfn-quicksight-dashboard-tableconditionalformattingoption-row
         */
        readonly row?: cdk.IResolvable | CfnDashboard.TableRowConditionalFormattingProperty;
    }
    /**
     * The conditional formatting of a table row.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablerowconditionalformatting.html
     */
    interface TableRowConditionalFormattingProperty {
        /**
         * The conditional formatting color (solid, gradient) of the background for a table row.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablerowconditionalformatting.html#cfn-quicksight-dashboard-tablerowconditionalformatting-backgroundcolor
         */
        readonly backgroundColor?: CfnDashboard.ConditionalFormattingColorProperty | cdk.IResolvable;
        /**
         * The conditional formatting color (solid, gradient) of the text for a table row.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablerowconditionalformatting.html#cfn-quicksight-dashboard-tablerowconditionalformatting-textcolor
         */
        readonly textColor?: CfnDashboard.ConditionalFormattingColorProperty | cdk.IResolvable;
    }
    /**
     * The cell conditional formatting option for a table.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablecellconditionalformatting.html
     */
    interface TableCellConditionalFormattingProperty {
        /**
         * The field ID of the cell for conditional formatting.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablecellconditionalformatting.html#cfn-quicksight-dashboard-tablecellconditionalformatting-fieldid
         */
        readonly fieldId: string;
        /**
         * The text format of the cell for conditional formatting.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablecellconditionalformatting.html#cfn-quicksight-dashboard-tablecellconditionalformatting-textformat
         */
        readonly textFormat?: cdk.IResolvable | CfnDashboard.TextConditionalFormatProperty;
    }
    /**
     * The conditional formatting for the text.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-textconditionalformat.html
     */
    interface TextConditionalFormatProperty {
        /**
         * The conditional formatting for the text background color.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-textconditionalformat.html#cfn-quicksight-dashboard-textconditionalformat-backgroundcolor
         */
        readonly backgroundColor?: CfnDashboard.ConditionalFormattingColorProperty | cdk.IResolvable;
        /**
         * The conditional formatting for the icon.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-textconditionalformat.html#cfn-quicksight-dashboard-textconditionalformat-icon
         */
        readonly icon?: CfnDashboard.ConditionalFormattingIconProperty | cdk.IResolvable;
        /**
         * The conditional formatting for the text color.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-textconditionalformat.html#cfn-quicksight-dashboard-textconditionalformat-textcolor
         */
        readonly textColor?: CfnDashboard.ConditionalFormattingColorProperty | cdk.IResolvable;
    }
    /**
     * The configuration for a `TableVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableconfiguration.html
     */
    interface TableConfigurationProperty {
        /**
         * The field options for a table visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableconfiguration.html#cfn-quicksight-dashboard-tableconfiguration-fieldoptions
         */
        readonly fieldOptions?: cdk.IResolvable | CfnDashboard.TableFieldOptionsProperty;
        /**
         * The field wells of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableconfiguration.html#cfn-quicksight-dashboard-tableconfiguration-fieldwells
         */
        readonly fieldWells?: cdk.IResolvable | CfnDashboard.TableFieldWellsProperty;
        /**
         * The paginated report options for a table visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableconfiguration.html#cfn-quicksight-dashboard-tableconfiguration-paginatedreportoptions
         */
        readonly paginatedReportOptions?: cdk.IResolvable | CfnDashboard.TablePaginatedReportOptionsProperty;
        /**
         * The sort configuration for a `TableVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableconfiguration.html#cfn-quicksight-dashboard-tableconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: cdk.IResolvable | CfnDashboard.TableSortConfigurationProperty;
        /**
         * A collection of inline visualizations to display within a chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableconfiguration.html#cfn-quicksight-dashboard-tableconfiguration-tableinlinevisualizations
         */
        readonly tableInlineVisualizations?: Array<cdk.IResolvable | CfnDashboard.TableInlineVisualizationProperty> | cdk.IResolvable;
        /**
         * The table options for a table visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableconfiguration.html#cfn-quicksight-dashboard-tableconfiguration-tableoptions
         */
        readonly tableOptions?: cdk.IResolvable | CfnDashboard.TableOptionsProperty;
        /**
         * The total options for a table visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableconfiguration.html#cfn-quicksight-dashboard-tableconfiguration-totaloptions
         */
        readonly totalOptions?: cdk.IResolvable | CfnDashboard.TotalOptionsProperty;
    }
    /**
     * The sort configuration for a `TableVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablesortconfiguration.html
     */
    interface TableSortConfigurationProperty {
        /**
         * The pagination configuration (page size, page number) for the table.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablesortconfiguration.html#cfn-quicksight-dashboard-tablesortconfiguration-paginationconfiguration
         */
        readonly paginationConfiguration?: cdk.IResolvable | CfnDashboard.PaginationConfigurationProperty;
        /**
         * The field sort options for rows in the table.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablesortconfiguration.html#cfn-quicksight-dashboard-tablesortconfiguration-rowsort
         */
        readonly rowSort?: Array<CfnDashboard.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * The paginated report options for a table visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablepaginatedreportoptions.html
     */
    interface TablePaginatedReportOptionsProperty {
        /**
         * The visibility of repeating header rows on each page.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablepaginatedreportoptions.html#cfn-quicksight-dashboard-tablepaginatedreportoptions-overflowcolumnheadervisibility
         */
        readonly overflowColumnHeaderVisibility?: string;
        /**
         * The visibility of printing table overflow across pages.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablepaginatedreportoptions.html#cfn-quicksight-dashboard-tablepaginatedreportoptions-verticaloverflowvisibility
         */
        readonly verticalOverflowVisibility?: string;
    }
    /**
     * The table options for a table visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableoptions.html
     */
    interface TableOptionsProperty {
        /**
         * The table cell style of table cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableoptions.html#cfn-quicksight-dashboard-tableoptions-cellstyle
         */
        readonly cellStyle?: cdk.IResolvable | CfnDashboard.TableCellStyleProperty;
        /**
         * The table cell style of a table header.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableoptions.html#cfn-quicksight-dashboard-tableoptions-headerstyle
         */
        readonly headerStyle?: cdk.IResolvable | CfnDashboard.TableCellStyleProperty;
        /**
         * The orientation (vertical, horizontal) for a table.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableoptions.html#cfn-quicksight-dashboard-tableoptions-orientation
         */
        readonly orientation?: string;
        /**
         * The row alternate color options (widget status, row alternate colors) for a table.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableoptions.html#cfn-quicksight-dashboard-tableoptions-rowalternatecoloroptions
         */
        readonly rowAlternateColorOptions?: cdk.IResolvable | CfnDashboard.RowAlternateColorOptionsProperty;
    }
    /**
     * The table cell style for a cell in pivot table or table visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablecellstyle.html
     */
    interface TableCellStyleProperty {
        /**
         * The background color for the table cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablecellstyle.html#cfn-quicksight-dashboard-tablecellstyle-backgroundcolor
         */
        readonly backgroundColor?: string;
        /**
         * The borders for the table cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablecellstyle.html#cfn-quicksight-dashboard-tablecellstyle-border
         */
        readonly border?: CfnDashboard.GlobalTableBorderOptionsProperty | cdk.IResolvable;
        /**
         * The font configuration of the table cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablecellstyle.html#cfn-quicksight-dashboard-tablecellstyle-fontconfiguration
         */
        readonly fontConfiguration?: CfnDashboard.FontConfigurationProperty | cdk.IResolvable;
        /**
         * The height color for the table cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablecellstyle.html#cfn-quicksight-dashboard-tablecellstyle-height
         */
        readonly height?: number;
        /**
         * The horizontal text alignment (left, center, right, auto) for the table cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablecellstyle.html#cfn-quicksight-dashboard-tablecellstyle-horizontaltextalignment
         */
        readonly horizontalTextAlignment?: string;
        /**
         * The text wrap (none, wrap) for the table cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablecellstyle.html#cfn-quicksight-dashboard-tablecellstyle-textwrap
         */
        readonly textWrap?: string;
        /**
         * The vertical text alignment (top, middle, bottom) for the table cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablecellstyle.html#cfn-quicksight-dashboard-tablecellstyle-verticaltextalignment
         */
        readonly verticalTextAlignment?: string;
        /**
         * The visibility of the table cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablecellstyle.html#cfn-quicksight-dashboard-tablecellstyle-visibility
         */
        readonly visibility?: string;
    }
    /**
     * Determines the border options for a table visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-globaltableborderoptions.html
     */
    interface GlobalTableBorderOptionsProperty {
        /**
         * Determines the options for side specific border.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-globaltableborderoptions.html#cfn-quicksight-dashboard-globaltableborderoptions-sidespecificborder
         */
        readonly sideSpecificBorder?: cdk.IResolvable | CfnDashboard.TableSideBorderOptionsProperty;
        /**
         * Determines the options for uniform border.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-globaltableborderoptions.html#cfn-quicksight-dashboard-globaltableborderoptions-uniformborder
         */
        readonly uniformBorder?: cdk.IResolvable | CfnDashboard.TableBorderOptionsProperty;
    }
    /**
     * The border options for a table border.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableborderoptions.html
     */
    interface TableBorderOptionsProperty {
        /**
         * The color of a table border.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableborderoptions.html#cfn-quicksight-dashboard-tableborderoptions-color
         */
        readonly color?: string;
        /**
         * The style (none, solid) of a table border.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableborderoptions.html#cfn-quicksight-dashboard-tableborderoptions-style
         */
        readonly style?: string;
        /**
         * The thickness of a table border.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableborderoptions.html#cfn-quicksight-dashboard-tableborderoptions-thickness
         */
        readonly thickness?: number;
    }
    /**
     * The side border options for a table.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablesideborderoptions.html
     */
    interface TableSideBorderOptionsProperty {
        /**
         * The table border options of the bottom border.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablesideborderoptions.html#cfn-quicksight-dashboard-tablesideborderoptions-bottom
         */
        readonly bottom?: cdk.IResolvable | CfnDashboard.TableBorderOptionsProperty;
        /**
         * The table border options of the inner horizontal border.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablesideborderoptions.html#cfn-quicksight-dashboard-tablesideborderoptions-innerhorizontal
         */
        readonly innerHorizontal?: cdk.IResolvable | CfnDashboard.TableBorderOptionsProperty;
        /**
         * The table border options of the inner vertical border.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablesideborderoptions.html#cfn-quicksight-dashboard-tablesideborderoptions-innervertical
         */
        readonly innerVertical?: cdk.IResolvable | CfnDashboard.TableBorderOptionsProperty;
        /**
         * The table border options of the left border.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablesideborderoptions.html#cfn-quicksight-dashboard-tablesideborderoptions-left
         */
        readonly left?: cdk.IResolvable | CfnDashboard.TableBorderOptionsProperty;
        /**
         * The table border options of the right border.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablesideborderoptions.html#cfn-quicksight-dashboard-tablesideborderoptions-right
         */
        readonly right?: cdk.IResolvable | CfnDashboard.TableBorderOptionsProperty;
        /**
         * The table border options of the top border.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablesideborderoptions.html#cfn-quicksight-dashboard-tablesideborderoptions-top
         */
        readonly top?: cdk.IResolvable | CfnDashboard.TableBorderOptionsProperty;
    }
    /**
     * Determines the row alternate color options.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-rowalternatecoloroptions.html
     */
    interface RowAlternateColorOptionsProperty {
        /**
         * Determines the list of row alternate colors.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-rowalternatecoloroptions.html#cfn-quicksight-dashboard-rowalternatecoloroptions-rowalternatecolors
         */
        readonly rowAlternateColors?: Array<string>;
        /**
         * Determines the widget status.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-rowalternatecoloroptions.html#cfn-quicksight-dashboard-rowalternatecoloroptions-status
         */
        readonly status?: string;
        /**
         * The primary background color options for alternate rows.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-rowalternatecoloroptions.html#cfn-quicksight-dashboard-rowalternatecoloroptions-useprimarybackgroundcolor
         */
        readonly usePrimaryBackgroundColor?: string;
    }
    /**
     * The inline visualization of a specific type to display within a chart.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableinlinevisualization.html
     */
    interface TableInlineVisualizationProperty {
        /**
         * The configuration of the inline visualization of the data bars within a chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableinlinevisualization.html#cfn-quicksight-dashboard-tableinlinevisualization-databars
         */
        readonly dataBars?: CfnDashboard.DataBarsOptionsProperty | cdk.IResolvable;
    }
    /**
     * The options for data bars.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-databarsoptions.html
     */
    interface DataBarsOptionsProperty {
        /**
         * The field ID for the data bars options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-databarsoptions.html#cfn-quicksight-dashboard-databarsoptions-fieldid
         */
        readonly fieldId: string;
        /**
         * The color of the negative data bar.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-databarsoptions.html#cfn-quicksight-dashboard-databarsoptions-negativecolor
         */
        readonly negativeColor?: string;
        /**
         * The color of the positive data bar.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-databarsoptions.html#cfn-quicksight-dashboard-databarsoptions-positivecolor
         */
        readonly positiveColor?: string;
    }
    /**
     * The field wells for a table visual.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldwells.html
     */
    interface TableFieldWellsProperty {
        /**
         * The aggregated field well for the table.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldwells.html#cfn-quicksight-dashboard-tablefieldwells-tableaggregatedfieldwells
         */
        readonly tableAggregatedFieldWells?: cdk.IResolvable | CfnDashboard.TableAggregatedFieldWellsProperty;
        /**
         * The unaggregated field well for the table.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldwells.html#cfn-quicksight-dashboard-tablefieldwells-tableunaggregatedfieldwells
         */
        readonly tableUnaggregatedFieldWells?: cdk.IResolvable | CfnDashboard.TableUnaggregatedFieldWellsProperty;
    }
    /**
     * The unaggregated field well for the table.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableunaggregatedfieldwells.html
     */
    interface TableUnaggregatedFieldWellsProperty {
        /**
         * The values field well for a pivot table.
         *
         * Values are unaggregated for an unaggregated table.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableunaggregatedfieldwells.html#cfn-quicksight-dashboard-tableunaggregatedfieldwells-values
         */
        readonly values?: Array<cdk.IResolvable | CfnDashboard.UnaggregatedFieldProperty> | cdk.IResolvable;
    }
    /**
     * The unaggregated field for a table.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-unaggregatedfield.html
     */
    interface UnaggregatedFieldProperty {
        /**
         * The column that is used in the `UnaggregatedField` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-unaggregatedfield.html#cfn-quicksight-dashboard-unaggregatedfield-column
         */
        readonly column: CfnDashboard.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * The custom field ID.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-unaggregatedfield.html#cfn-quicksight-dashboard-unaggregatedfield-fieldid
         */
        readonly fieldId: string;
        /**
         * The format configuration of the field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-unaggregatedfield.html#cfn-quicksight-dashboard-unaggregatedfield-formatconfiguration
         */
        readonly formatConfiguration?: CfnDashboard.FormatConfigurationProperty | cdk.IResolvable;
    }
    /**
     * The aggregated field well for the table.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableaggregatedfieldwells.html
     */
    interface TableAggregatedFieldWellsProperty {
        /**
         * The group by field well for a pivot table.
         *
         * Values are grouped by group by fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableaggregatedfieldwells.html#cfn-quicksight-dashboard-tableaggregatedfieldwells-groupby
         */
        readonly groupBy?: Array<CfnDashboard.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The values field well for a pivot table.
         *
         * Values are aggregated based on group by fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableaggregatedfieldwells.html#cfn-quicksight-dashboard-tableaggregatedfieldwells-values
         */
        readonly values?: Array<cdk.IResolvable | CfnDashboard.MeasureFieldProperty> | cdk.IResolvable;
    }
    /**
     * The field options of a table visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldoptions.html
     */
    interface TableFieldOptionsProperty {
        /**
         * The order of the field IDs that are configured as field options for a table visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldoptions.html#cfn-quicksight-dashboard-tablefieldoptions-order
         */
        readonly order?: Array<string>;
        /**
         * The settings for the pinned columns of a table visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldoptions.html#cfn-quicksight-dashboard-tablefieldoptions-pinnedfieldoptions
         */
        readonly pinnedFieldOptions?: cdk.IResolvable | CfnDashboard.TablePinnedFieldOptionsProperty;
        /**
         * The field options to be configured to a table.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldoptions.html#cfn-quicksight-dashboard-tablefieldoptions-selectedfieldoptions
         */
        readonly selectedFieldOptions?: Array<cdk.IResolvable | CfnDashboard.TableFieldOptionProperty> | cdk.IResolvable;
    }
    /**
     * The settings for the pinned columns of a table visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablepinnedfieldoptions.html
     */
    interface TablePinnedFieldOptionsProperty {
        /**
         * A list of columns to be pinned to the left of a table visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablepinnedfieldoptions.html#cfn-quicksight-dashboard-tablepinnedfieldoptions-pinnedleftfields
         */
        readonly pinnedLeftFields?: Array<string>;
    }
    /**
     * The options for a table field.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldoption.html
     */
    interface TableFieldOptionProperty {
        /**
         * The custom label for a table field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldoption.html#cfn-quicksight-dashboard-tablefieldoption-customlabel
         */
        readonly customLabel?: string;
        /**
         * The field ID for a table field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldoption.html#cfn-quicksight-dashboard-tablefieldoption-fieldid
         */
        readonly fieldId: string;
        /**
         * The URL configuration for a table field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldoption.html#cfn-quicksight-dashboard-tablefieldoption-urlstyling
         */
        readonly urlStyling?: cdk.IResolvable | CfnDashboard.TableFieldURLConfigurationProperty;
        /**
         * The visibility of a table field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldoption.html#cfn-quicksight-dashboard-tablefieldoption-visibility
         */
        readonly visibility?: string;
        /**
         * The width for a table field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldoption.html#cfn-quicksight-dashboard-tablefieldoption-width
         */
        readonly width?: string;
    }
    /**
     * The URL configuration for a table field.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldurlconfiguration.html
     */
    interface TableFieldURLConfigurationProperty {
        /**
         * The image configuration of a table field URL.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldurlconfiguration.html#cfn-quicksight-dashboard-tablefieldurlconfiguration-imageconfiguration
         */
        readonly imageConfiguration?: cdk.IResolvable | CfnDashboard.TableFieldImageConfigurationProperty;
        /**
         * The link configuration of a table field URL.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldurlconfiguration.html#cfn-quicksight-dashboard-tablefieldurlconfiguration-linkconfiguration
         */
        readonly linkConfiguration?: cdk.IResolvable | CfnDashboard.TableFieldLinkConfigurationProperty;
    }
    /**
     * The link configuration of a table field URL.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldlinkconfiguration.html
     */
    interface TableFieldLinkConfigurationProperty {
        /**
         * The URL content (text, icon) for the table link configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldlinkconfiguration.html#cfn-quicksight-dashboard-tablefieldlinkconfiguration-content
         */
        readonly content: cdk.IResolvable | CfnDashboard.TableFieldLinkContentConfigurationProperty;
        /**
         * The URL target (new tab, new window, same tab) for the table link configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldlinkconfiguration.html#cfn-quicksight-dashboard-tablefieldlinkconfiguration-target
         */
        readonly target: string;
    }
    /**
     * The URL content (text, icon) for the table link configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldlinkcontentconfiguration.html
     */
    interface TableFieldLinkContentConfigurationProperty {
        /**
         * The custom icon content for the table link content configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldlinkcontentconfiguration.html#cfn-quicksight-dashboard-tablefieldlinkcontentconfiguration-customiconcontent
         */
        readonly customIconContent?: cdk.IResolvable | CfnDashboard.TableFieldCustomIconContentProperty;
        /**
         * The custom text content (value, font configuration) for the table link content configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldlinkcontentconfiguration.html#cfn-quicksight-dashboard-tablefieldlinkcontentconfiguration-customtextcontent
         */
        readonly customTextContent?: cdk.IResolvable | CfnDashboard.TableFieldCustomTextContentProperty;
    }
    /**
     * The custom icon content for the table link content configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldcustomiconcontent.html
     */
    interface TableFieldCustomIconContentProperty {
        /**
         * The icon set type (link) of the custom icon content for table URL link content.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldcustomiconcontent.html#cfn-quicksight-dashboard-tablefieldcustomiconcontent-icon
         */
        readonly icon?: string;
    }
    /**
     * The custom text content (value, font configuration) for the table link content configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldcustomtextcontent.html
     */
    interface TableFieldCustomTextContentProperty {
        /**
         * The font configuration of the custom text content for the table URL link content.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldcustomtextcontent.html#cfn-quicksight-dashboard-tablefieldcustomtextcontent-fontconfiguration
         */
        readonly fontConfiguration: CfnDashboard.FontConfigurationProperty | cdk.IResolvable;
        /**
         * The string value of the custom text content for the table URL link content.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldcustomtextcontent.html#cfn-quicksight-dashboard-tablefieldcustomtextcontent-value
         */
        readonly value?: string;
    }
    /**
     * The image configuration of a table field URL.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldimageconfiguration.html
     */
    interface TableFieldImageConfigurationProperty {
        /**
         * The sizing options for the table image configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldimageconfiguration.html#cfn-quicksight-dashboard-tablefieldimageconfiguration-sizingoptions
         */
        readonly sizingOptions?: cdk.IResolvable | CfnDashboard.TableCellImageSizingConfigurationProperty;
    }
    /**
     * The sizing options for the table image configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablecellimagesizingconfiguration.html
     */
    interface TableCellImageSizingConfigurationProperty {
        /**
         * The cell scaling configuration of the sizing options for the table image configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablecellimagesizingconfiguration.html#cfn-quicksight-dashboard-tablecellimagesizingconfiguration-tablecellimagescalingconfiguration
         */
        readonly tableCellImageScalingConfiguration?: string;
    }
    /**
     * The total options for a table visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-totaloptions.html
     */
    interface TotalOptionsProperty {
        /**
         * The custom label string for the total cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-totaloptions.html#cfn-quicksight-dashboard-totaloptions-customlabel
         */
        readonly customLabel?: string;
        /**
         * The placement (start, end) for the total cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-totaloptions.html#cfn-quicksight-dashboard-totaloptions-placement
         */
        readonly placement?: string;
        /**
         * The scroll status (pinned, scrolled) for the total cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-totaloptions.html#cfn-quicksight-dashboard-totaloptions-scrollstatus
         */
        readonly scrollStatus?: string;
        /**
         * The total aggregation settings for each value field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-totaloptions.html#cfn-quicksight-dashboard-totaloptions-totalaggregationoptions
         */
        readonly totalAggregationOptions?: Array<cdk.IResolvable | CfnDashboard.TotalAggregationOptionProperty> | cdk.IResolvable;
        /**
         * Cell styling options for the total cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-totaloptions.html#cfn-quicksight-dashboard-totaloptions-totalcellstyle
         */
        readonly totalCellStyle?: cdk.IResolvable | CfnDashboard.TableCellStyleProperty;
        /**
         * The visibility configuration for the total cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-totaloptions.html#cfn-quicksight-dashboard-totaloptions-totalsvisibility
         */
        readonly totalsVisibility?: string;
    }
    /**
     * The total aggregation settings map of a field id.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-totalaggregationoption.html
     */
    interface TotalAggregationOptionProperty {
        /**
         * The field id that's associated with the total aggregation option.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-totalaggregationoption.html#cfn-quicksight-dashboard-totalaggregationoption-fieldid
         */
        readonly fieldId: string;
        /**
         * The total aggregation function that you want to set for a specified field id.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-totalaggregationoption.html#cfn-quicksight-dashboard-totalaggregationoption-totalaggregationfunction
         */
        readonly totalAggregationFunction: cdk.IResolvable | CfnDashboard.TotalAggregationFunctionProperty;
    }
    /**
     * An aggregation function that aggregates the total values of a measure.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-totalaggregationfunction.html
     */
    interface TotalAggregationFunctionProperty {
        /**
         * A built in aggregation function for total values.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-totalaggregationfunction.html#cfn-quicksight-dashboard-totalaggregationfunction-simpletotalaggregationfunction
         */
        readonly simpleTotalAggregationFunction?: string;
    }
    /**
     * A pivot table.
     *
     * For more information, see [Using pivot tables](https://docs.aws.amazon.com/quicksight/latest/user/pivot-table.html) in the *Amazon QuickSight User Guide* .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablevisual.html
     */
    interface PivotTableVisualProperty {
        /**
         * The list of custom actions that are configured for a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablevisual.html#cfn-quicksight-dashboard-pivottablevisual-actions
         */
        readonly actions?: Array<cdk.IResolvable | CfnDashboard.VisualCustomActionProperty> | cdk.IResolvable;
        /**
         * The configuration settings of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablevisual.html#cfn-quicksight-dashboard-pivottablevisual-chartconfiguration
         */
        readonly chartConfiguration?: cdk.IResolvable | CfnDashboard.PivotTableConfigurationProperty;
        /**
         * The conditional formatting for a `PivotTableVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablevisual.html#cfn-quicksight-dashboard-pivottablevisual-conditionalformatting
         */
        readonly conditionalFormatting?: cdk.IResolvable | CfnDashboard.PivotTableConditionalFormattingProperty;
        /**
         * The subtitle that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablevisual.html#cfn-quicksight-dashboard-pivottablevisual-subtitle
         */
        readonly subtitle?: cdk.IResolvable | CfnDashboard.VisualSubtitleLabelOptionsProperty;
        /**
         * The title that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablevisual.html#cfn-quicksight-dashboard-pivottablevisual-title
         */
        readonly title?: cdk.IResolvable | CfnDashboard.VisualTitleLabelOptionsProperty;
        /**
         * The unique identifier of a visual.
         *
         * This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablevisual.html#cfn-quicksight-dashboard-pivottablevisual-visualid
         */
        readonly visualId: string;
    }
    /**
     * The conditional formatting for a `PivotTableVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableconditionalformatting.html
     */
    interface PivotTableConditionalFormattingProperty {
        /**
         * Conditional formatting options for a `PivotTableVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableconditionalformatting.html#cfn-quicksight-dashboard-pivottableconditionalformatting-conditionalformattingoptions
         */
        readonly conditionalFormattingOptions?: Array<cdk.IResolvable | CfnDashboard.PivotTableConditionalFormattingOptionProperty> | cdk.IResolvable;
    }
    /**
     * Conditional formatting options for a `PivotTableVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableconditionalformattingoption.html
     */
    interface PivotTableConditionalFormattingOptionProperty {
        /**
         * The cell conditional formatting option for a pivot table.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableconditionalformattingoption.html#cfn-quicksight-dashboard-pivottableconditionalformattingoption-cell
         */
        readonly cell?: cdk.IResolvable | CfnDashboard.PivotTableCellConditionalFormattingProperty;
    }
    /**
     * The cell conditional formatting option for a pivot table.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablecellconditionalformatting.html
     */
    interface PivotTableCellConditionalFormattingProperty {
        /**
         * The field ID of the cell for conditional formatting.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablecellconditionalformatting.html#cfn-quicksight-dashboard-pivottablecellconditionalformatting-fieldid
         */
        readonly fieldId: string;
        /**
         * The scope of the cell for conditional formatting.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablecellconditionalformatting.html#cfn-quicksight-dashboard-pivottablecellconditionalformatting-scope
         */
        readonly scope?: cdk.IResolvable | CfnDashboard.PivotTableConditionalFormattingScopeProperty;
        /**
         * A list of cell scopes for conditional formatting.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablecellconditionalformatting.html#cfn-quicksight-dashboard-pivottablecellconditionalformatting-scopes
         */
        readonly scopes?: Array<cdk.IResolvable | CfnDashboard.PivotTableConditionalFormattingScopeProperty> | cdk.IResolvable;
        /**
         * The text format of the cell for conditional formatting.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablecellconditionalformatting.html#cfn-quicksight-dashboard-pivottablecellconditionalformatting-textformat
         */
        readonly textFormat?: cdk.IResolvable | CfnDashboard.TextConditionalFormatProperty;
    }
    /**
     * The scope of the cell for conditional formatting.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableconditionalformattingscope.html
     */
    interface PivotTableConditionalFormattingScopeProperty {
        /**
         * The role (field, field total, grand total) of the cell for conditional formatting.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableconditionalformattingscope.html#cfn-quicksight-dashboard-pivottableconditionalformattingscope-role
         */
        readonly role?: string;
    }
    /**
     * The configuration for a `PivotTableVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableconfiguration.html
     */
    interface PivotTableConfigurationProperty {
        /**
         * The field options for a pivot table visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableconfiguration.html#cfn-quicksight-dashboard-pivottableconfiguration-fieldoptions
         */
        readonly fieldOptions?: cdk.IResolvable | CfnDashboard.PivotTableFieldOptionsProperty;
        /**
         * The field wells of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableconfiguration.html#cfn-quicksight-dashboard-pivottableconfiguration-fieldwells
         */
        readonly fieldWells?: cdk.IResolvable | CfnDashboard.PivotTableFieldWellsProperty;
        /**
         * The paginated report options for a pivot table visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableconfiguration.html#cfn-quicksight-dashboard-pivottableconfiguration-paginatedreportoptions
         */
        readonly paginatedReportOptions?: cdk.IResolvable | CfnDashboard.PivotTablePaginatedReportOptionsProperty;
        /**
         * The sort configuration for a `PivotTableVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableconfiguration.html#cfn-quicksight-dashboard-pivottableconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: cdk.IResolvable | CfnDashboard.PivotTableSortConfigurationProperty;
        /**
         * The table options for a pivot table visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableconfiguration.html#cfn-quicksight-dashboard-pivottableconfiguration-tableoptions
         */
        readonly tableOptions?: cdk.IResolvable | CfnDashboard.PivotTableOptionsProperty;
        /**
         * The total options for a pivot table visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableconfiguration.html#cfn-quicksight-dashboard-pivottableconfiguration-totaloptions
         */
        readonly totalOptions?: cdk.IResolvable | CfnDashboard.PivotTableTotalOptionsProperty;
    }
    /**
     * The sort configuration for a `PivotTableVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablesortconfiguration.html
     */
    interface PivotTableSortConfigurationProperty {
        /**
         * The field sort options for a pivot table sort configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablesortconfiguration.html#cfn-quicksight-dashboard-pivottablesortconfiguration-fieldsortoptions
         */
        readonly fieldSortOptions?: Array<cdk.IResolvable | CfnDashboard.PivotFieldSortOptionsProperty> | cdk.IResolvable;
    }
    /**
     * The field sort options for a pivot table sort configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivotfieldsortoptions.html
     */
    interface PivotFieldSortOptionsProperty {
        /**
         * The field ID for the field sort options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivotfieldsortoptions.html#cfn-quicksight-dashboard-pivotfieldsortoptions-fieldid
         */
        readonly fieldId: string;
        /**
         * The sort by field for the field sort options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivotfieldsortoptions.html#cfn-quicksight-dashboard-pivotfieldsortoptions-sortby
         */
        readonly sortBy: cdk.IResolvable | CfnDashboard.PivotTableSortByProperty;
    }
    /**
     * The sort by field for the field sort options.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablesortby.html
     */
    interface PivotTableSortByProperty {
        /**
         * The column sort (field id, direction) for the pivot table sort by options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablesortby.html#cfn-quicksight-dashboard-pivottablesortby-column
         */
        readonly column?: CfnDashboard.ColumnSortProperty | cdk.IResolvable;
        /**
         * The data path sort (data path value, direction) for the pivot table sort by options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablesortby.html#cfn-quicksight-dashboard-pivottablesortby-datapath
         */
        readonly dataPath?: CfnDashboard.DataPathSortProperty | cdk.IResolvable;
        /**
         * The field sort (field id, direction) for the pivot table sort by options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablesortby.html#cfn-quicksight-dashboard-pivottablesortby-field
         */
        readonly field?: CfnDashboard.FieldSortProperty | cdk.IResolvable;
    }
    /**
     * Allows data paths to be sorted by a specific data value.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathsort.html
     */
    interface DataPathSortProperty {
        /**
         * Determines the sort direction.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathsort.html#cfn-quicksight-dashboard-datapathsort-direction
         */
        readonly direction: string;
        /**
         * The list of data paths that need to be sorted.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathsort.html#cfn-quicksight-dashboard-datapathsort-sortpaths
         */
        readonly sortPaths: Array<CfnDashboard.DataPathValueProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * The paginated report options for a pivot table visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablepaginatedreportoptions.html
     */
    interface PivotTablePaginatedReportOptionsProperty {
        /**
         * The visibility of the repeating header rows on each page.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablepaginatedreportoptions.html#cfn-quicksight-dashboard-pivottablepaginatedreportoptions-overflowcolumnheadervisibility
         */
        readonly overflowColumnHeaderVisibility?: string;
        /**
         * The visibility of the printing table overflow across pages.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablepaginatedreportoptions.html#cfn-quicksight-dashboard-pivottablepaginatedreportoptions-verticaloverflowvisibility
         */
        readonly verticalOverflowVisibility?: string;
    }
    /**
     * The table options for a pivot table visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableoptions.html
     */
    interface PivotTableOptionsProperty {
        /**
         * The table cell style of cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableoptions.html#cfn-quicksight-dashboard-pivottableoptions-cellstyle
         */
        readonly cellStyle?: cdk.IResolvable | CfnDashboard.TableCellStyleProperty;
        /**
         * The visibility setting of a pivot table's collapsed row dimension fields.
         *
         * If the value of this structure is `HIDDEN` , all collapsed columns in a pivot table are automatically hidden. The default value is `VISIBLE` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableoptions.html#cfn-quicksight-dashboard-pivottableoptions-collapsedrowdimensionsvisibility
         */
        readonly collapsedRowDimensionsVisibility?: string;
        /**
         * The table cell style of the column header.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableoptions.html#cfn-quicksight-dashboard-pivottableoptions-columnheaderstyle
         */
        readonly columnHeaderStyle?: cdk.IResolvable | CfnDashboard.TableCellStyleProperty;
        /**
         * The visibility of the column names.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableoptions.html#cfn-quicksight-dashboard-pivottableoptions-columnnamesvisibility
         */
        readonly columnNamesVisibility?: string;
        /**
         * The default cell width of the pivot table.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableoptions.html#cfn-quicksight-dashboard-pivottableoptions-defaultcellwidth
         */
        readonly defaultCellWidth?: string;
        /**
         * The metric placement (row, column) options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableoptions.html#cfn-quicksight-dashboard-pivottableoptions-metricplacement
         */
        readonly metricPlacement?: string;
        /**
         * The row alternate color options (widget status, row alternate colors).
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableoptions.html#cfn-quicksight-dashboard-pivottableoptions-rowalternatecoloroptions
         */
        readonly rowAlternateColorOptions?: cdk.IResolvable | CfnDashboard.RowAlternateColorOptionsProperty;
        /**
         * The table cell style of row field names.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableoptions.html#cfn-quicksight-dashboard-pivottableoptions-rowfieldnamesstyle
         */
        readonly rowFieldNamesStyle?: cdk.IResolvable | CfnDashboard.TableCellStyleProperty;
        /**
         * The table cell style of the row headers.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableoptions.html#cfn-quicksight-dashboard-pivottableoptions-rowheaderstyle
         */
        readonly rowHeaderStyle?: cdk.IResolvable | CfnDashboard.TableCellStyleProperty;
        /**
         * The options for the label that is located above the row headers.
         *
         * This option is only applicable when `RowsLayout` is set to `HIERARCHY` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableoptions.html#cfn-quicksight-dashboard-pivottableoptions-rowslabeloptions
         */
        readonly rowsLabelOptions?: cdk.IResolvable | CfnDashboard.PivotTableRowsLabelOptionsProperty;
        /**
         * The layout for the row dimension headers of a pivot table. Choose one of the following options.
         *
         * - `TABULAR` : (Default) Each row field is displayed in a separate column.
         * - `HIERARCHY` : All row fields are displayed in a single column. Indentation is used to differentiate row headers of different fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableoptions.html#cfn-quicksight-dashboard-pivottableoptions-rowslayout
         */
        readonly rowsLayout?: string;
        /**
         * The visibility of the single metric options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableoptions.html#cfn-quicksight-dashboard-pivottableoptions-singlemetricvisibility
         */
        readonly singleMetricVisibility?: string;
        /**
         * Determines the visibility of the pivot table.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableoptions.html#cfn-quicksight-dashboard-pivottableoptions-togglebuttonsvisibility
         */
        readonly toggleButtonsVisibility?: string;
    }
    /**
     * The options for the label thta is located above the row headers.
     *
     * This option is only applicable when `RowsLayout` is set to `HIERARCHY` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablerowslabeloptions.html
     */
    interface PivotTableRowsLabelOptionsProperty {
        /**
         * The custom label string for the rows label.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablerowslabeloptions.html#cfn-quicksight-dashboard-pivottablerowslabeloptions-customlabel
         */
        readonly customLabel?: string;
        /**
         * The visibility of the rows label.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablerowslabeloptions.html#cfn-quicksight-dashboard-pivottablerowslabeloptions-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The field wells for a pivot table visual.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablefieldwells.html
     */
    interface PivotTableFieldWellsProperty {
        /**
         * The aggregated field well for the pivot table.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablefieldwells.html#cfn-quicksight-dashboard-pivottablefieldwells-pivottableaggregatedfieldwells
         */
        readonly pivotTableAggregatedFieldWells?: cdk.IResolvable | CfnDashboard.PivotTableAggregatedFieldWellsProperty;
    }
    /**
     * The aggregated field well for the pivot table.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableaggregatedfieldwells.html
     */
    interface PivotTableAggregatedFieldWellsProperty {
        /**
         * The columns field well for a pivot table.
         *
         * Values are grouped by columns fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableaggregatedfieldwells.html#cfn-quicksight-dashboard-pivottableaggregatedfieldwells-columns
         */
        readonly columns?: Array<CfnDashboard.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The rows field well for a pivot table.
         *
         * Values are grouped by rows fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableaggregatedfieldwells.html#cfn-quicksight-dashboard-pivottableaggregatedfieldwells-rows
         */
        readonly rows?: Array<CfnDashboard.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The values field well for a pivot table.
         *
         * Values are aggregated based on rows and columns fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableaggregatedfieldwells.html#cfn-quicksight-dashboard-pivottableaggregatedfieldwells-values
         */
        readonly values?: Array<cdk.IResolvable | CfnDashboard.MeasureFieldProperty> | cdk.IResolvable;
    }
    /**
     * The field options for a pivot table visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablefieldoptions.html
     */
    interface PivotTableFieldOptionsProperty {
        /**
         * The collapse state options for the pivot table field options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablefieldoptions.html#cfn-quicksight-dashboard-pivottablefieldoptions-collapsestateoptions
         */
        readonly collapseStateOptions?: Array<cdk.IResolvable | CfnDashboard.PivotTableFieldCollapseStateOptionProperty> | cdk.IResolvable;
        /**
         * The data path options for the pivot table field options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablefieldoptions.html#cfn-quicksight-dashboard-pivottablefieldoptions-datapathoptions
         */
        readonly dataPathOptions?: Array<cdk.IResolvable | CfnDashboard.PivotTableDataPathOptionProperty> | cdk.IResolvable;
        /**
         * The selected field options for the pivot table field options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablefieldoptions.html#cfn-quicksight-dashboard-pivottablefieldoptions-selectedfieldoptions
         */
        readonly selectedFieldOptions?: Array<cdk.IResolvable | CfnDashboard.PivotTableFieldOptionProperty> | cdk.IResolvable;
    }
    /**
     * The collapse state options for the pivot table field options.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablefieldcollapsestateoption.html
     */
    interface PivotTableFieldCollapseStateOptionProperty {
        /**
         * The state of the field target of a pivot table. Choose one of the following options:.
         *
         * - `COLLAPSED`
         * - `EXPANDED`
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablefieldcollapsestateoption.html#cfn-quicksight-dashboard-pivottablefieldcollapsestateoption-state
         */
        readonly state?: string;
        /**
         * A tagged-union object that sets the collapse state.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablefieldcollapsestateoption.html#cfn-quicksight-dashboard-pivottablefieldcollapsestateoption-target
         */
        readonly target: cdk.IResolvable | CfnDashboard.PivotTableFieldCollapseStateTargetProperty;
    }
    /**
     * The target of a pivot table field collapse state.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablefieldcollapsestatetarget.html
     */
    interface PivotTableFieldCollapseStateTargetProperty {
        /**
         * The data path of the pivot table's header.
         *
         * Used to set the collapse state.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablefieldcollapsestatetarget.html#cfn-quicksight-dashboard-pivottablefieldcollapsestatetarget-fielddatapathvalues
         */
        readonly fieldDataPathValues?: Array<CfnDashboard.DataPathValueProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The field ID of the pivot table that the collapse state needs to be set to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablefieldcollapsestatetarget.html#cfn-quicksight-dashboard-pivottablefieldcollapsestatetarget-fieldid
         */
        readonly fieldId?: string;
    }
    /**
     * The data path options for the pivot table field options.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottabledatapathoption.html
     */
    interface PivotTableDataPathOptionProperty {
        /**
         * The list of data path values for the data path options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottabledatapathoption.html#cfn-quicksight-dashboard-pivottabledatapathoption-datapathlist
         */
        readonly dataPathList: Array<CfnDashboard.DataPathValueProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The width of the data path option.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottabledatapathoption.html#cfn-quicksight-dashboard-pivottabledatapathoption-width
         */
        readonly width?: string;
    }
    /**
     * The selected field options for the pivot table field options.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablefieldoption.html
     */
    interface PivotTableFieldOptionProperty {
        /**
         * The custom label of the pivot table field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablefieldoption.html#cfn-quicksight-dashboard-pivottablefieldoption-customlabel
         */
        readonly customLabel?: string;
        /**
         * The field ID of the pivot table field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablefieldoption.html#cfn-quicksight-dashboard-pivottablefieldoption-fieldid
         */
        readonly fieldId: string;
        /**
         * The visibility of the pivot table field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablefieldoption.html#cfn-quicksight-dashboard-pivottablefieldoption-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The total options for a pivot table visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottabletotaloptions.html
     */
    interface PivotTableTotalOptionsProperty {
        /**
         * The column subtotal options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottabletotaloptions.html#cfn-quicksight-dashboard-pivottabletotaloptions-columnsubtotaloptions
         */
        readonly columnSubtotalOptions?: cdk.IResolvable | CfnDashboard.SubtotalOptionsProperty;
        /**
         * The column total options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottabletotaloptions.html#cfn-quicksight-dashboard-pivottabletotaloptions-columntotaloptions
         */
        readonly columnTotalOptions?: cdk.IResolvable | CfnDashboard.PivotTotalOptionsProperty;
        /**
         * The row subtotal options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottabletotaloptions.html#cfn-quicksight-dashboard-pivottabletotaloptions-rowsubtotaloptions
         */
        readonly rowSubtotalOptions?: cdk.IResolvable | CfnDashboard.SubtotalOptionsProperty;
        /**
         * The row total options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottabletotaloptions.html#cfn-quicksight-dashboard-pivottabletotaloptions-rowtotaloptions
         */
        readonly rowTotalOptions?: cdk.IResolvable | CfnDashboard.PivotTotalOptionsProperty;
    }
    /**
     * The subtotal options.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-subtotaloptions.html
     */
    interface SubtotalOptionsProperty {
        /**
         * The custom label string for the subtotal cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-subtotaloptions.html#cfn-quicksight-dashboard-subtotaloptions-customlabel
         */
        readonly customLabel?: string;
        /**
         * The field level (all, custom, last) for the subtotal cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-subtotaloptions.html#cfn-quicksight-dashboard-subtotaloptions-fieldlevel
         */
        readonly fieldLevel?: string;
        /**
         * The optional configuration of subtotal cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-subtotaloptions.html#cfn-quicksight-dashboard-subtotaloptions-fieldleveloptions
         */
        readonly fieldLevelOptions?: Array<cdk.IResolvable | CfnDashboard.PivotTableFieldSubtotalOptionsProperty> | cdk.IResolvable;
        /**
         * The cell styling options for the subtotals of header cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-subtotaloptions.html#cfn-quicksight-dashboard-subtotaloptions-metricheadercellstyle
         */
        readonly metricHeaderCellStyle?: cdk.IResolvable | CfnDashboard.TableCellStyleProperty;
        /**
         * The style targets options for subtotals.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-subtotaloptions.html#cfn-quicksight-dashboard-subtotaloptions-styletargets
         */
        readonly styleTargets?: Array<cdk.IResolvable | CfnDashboard.TableStyleTargetProperty> | cdk.IResolvable;
        /**
         * The cell styling options for the subtotal cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-subtotaloptions.html#cfn-quicksight-dashboard-subtotaloptions-totalcellstyle
         */
        readonly totalCellStyle?: cdk.IResolvable | CfnDashboard.TableCellStyleProperty;
        /**
         * The visibility configuration for the subtotal cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-subtotaloptions.html#cfn-quicksight-dashboard-subtotaloptions-totalsvisibility
         */
        readonly totalsVisibility?: string;
        /**
         * The cell styling options for the subtotals of value cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-subtotaloptions.html#cfn-quicksight-dashboard-subtotaloptions-valuecellstyle
         */
        readonly valueCellStyle?: cdk.IResolvable | CfnDashboard.TableCellStyleProperty;
    }
    /**
     * The optional configuration of subtotals cells.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablefieldsubtotaloptions.html
     */
    interface PivotTableFieldSubtotalOptionsProperty {
        /**
         * The field ID of the subtotal options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablefieldsubtotaloptions.html#cfn-quicksight-dashboard-pivottablefieldsubtotaloptions-fieldid
         */
        readonly fieldId?: string;
    }
    /**
     * The table style target.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablestyletarget.html
     */
    interface TableStyleTargetProperty {
        /**
         * The cell type of the table style target.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablestyletarget.html#cfn-quicksight-dashboard-tablestyletarget-celltype
         */
        readonly cellType: string;
    }
    /**
     * The optional configuration of totals cells in a `PivotTableVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottotaloptions.html
     */
    interface PivotTotalOptionsProperty {
        /**
         * The custom label string for the total cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottotaloptions.html#cfn-quicksight-dashboard-pivottotaloptions-customlabel
         */
        readonly customLabel?: string;
        /**
         * The cell styling options for the total of header cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottotaloptions.html#cfn-quicksight-dashboard-pivottotaloptions-metricheadercellstyle
         */
        readonly metricHeaderCellStyle?: cdk.IResolvable | CfnDashboard.TableCellStyleProperty;
        /**
         * The placement (start, end) for the total cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottotaloptions.html#cfn-quicksight-dashboard-pivottotaloptions-placement
         */
        readonly placement?: string;
        /**
         * The scroll status (pinned, scrolled) for the total cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottotaloptions.html#cfn-quicksight-dashboard-pivottotaloptions-scrollstatus
         */
        readonly scrollStatus?: string;
        /**
         * The total aggregation options for each value field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottotaloptions.html#cfn-quicksight-dashboard-pivottotaloptions-totalaggregationoptions
         */
        readonly totalAggregationOptions?: Array<cdk.IResolvable | CfnDashboard.TotalAggregationOptionProperty> | cdk.IResolvable;
        /**
         * The cell styling options for the total cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottotaloptions.html#cfn-quicksight-dashboard-pivottotaloptions-totalcellstyle
         */
        readonly totalCellStyle?: cdk.IResolvable | CfnDashboard.TableCellStyleProperty;
        /**
         * The visibility configuration for the total cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottotaloptions.html#cfn-quicksight-dashboard-pivottotaloptions-totalsvisibility
         */
        readonly totalsVisibility?: string;
        /**
         * The cell styling options for the totals of value cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottotaloptions.html#cfn-quicksight-dashboard-pivottotaloptions-valuecellstyle
         */
        readonly valueCellStyle?: cdk.IResolvable | CfnDashboard.TableCellStyleProperty;
    }
    /**
     * A geospatial map or a points on map visual.
     *
     * For more information, see [Creating point maps](https://docs.aws.amazon.com/quicksight/latest/user/point-maps.html) in the *Amazon QuickSight User Guide* .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapvisual.html
     */
    interface GeospatialMapVisualProperty {
        /**
         * The list of custom actions that are configured for a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapvisual.html#cfn-quicksight-dashboard-geospatialmapvisual-actions
         */
        readonly actions?: Array<cdk.IResolvable | CfnDashboard.VisualCustomActionProperty> | cdk.IResolvable;
        /**
         * The configuration settings of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapvisual.html#cfn-quicksight-dashboard-geospatialmapvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnDashboard.GeospatialMapConfigurationProperty | cdk.IResolvable;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapvisual.html#cfn-quicksight-dashboard-geospatialmapvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnDashboard.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The subtitle that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapvisual.html#cfn-quicksight-dashboard-geospatialmapvisual-subtitle
         */
        readonly subtitle?: cdk.IResolvable | CfnDashboard.VisualSubtitleLabelOptionsProperty;
        /**
         * The title that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapvisual.html#cfn-quicksight-dashboard-geospatialmapvisual-title
         */
        readonly title?: cdk.IResolvable | CfnDashboard.VisualTitleLabelOptionsProperty;
        /**
         * The unique identifier of a visual.
         *
         * This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapvisual.html#cfn-quicksight-dashboard-geospatialmapvisual-visualid
         */
        readonly visualId: string;
    }
    /**
     * The configuration of a `GeospatialMapVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapconfiguration.html
     */
    interface GeospatialMapConfigurationProperty {
        /**
         * The field wells of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapconfiguration.html#cfn-quicksight-dashboard-geospatialmapconfiguration-fieldwells
         */
        readonly fieldWells?: CfnDashboard.GeospatialMapFieldWellsProperty | cdk.IResolvable;
        /**
         * The legend display setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapconfiguration.html#cfn-quicksight-dashboard-geospatialmapconfiguration-legend
         */
        readonly legend?: cdk.IResolvable | CfnDashboard.LegendOptionsProperty;
        /**
         * The map style options of the geospatial map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapconfiguration.html#cfn-quicksight-dashboard-geospatialmapconfiguration-mapstyleoptions
         */
        readonly mapStyleOptions?: CfnDashboard.GeospatialMapStyleOptionsProperty | cdk.IResolvable;
        /**
         * The point style options of the geospatial map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapconfiguration.html#cfn-quicksight-dashboard-geospatialmapconfiguration-pointstyleoptions
         */
        readonly pointStyleOptions?: CfnDashboard.GeospatialPointStyleOptionsProperty | cdk.IResolvable;
        /**
         * The tooltip display setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapconfiguration.html#cfn-quicksight-dashboard-geospatialmapconfiguration-tooltip
         */
        readonly tooltip?: cdk.IResolvable | CfnDashboard.TooltipOptionsProperty;
        /**
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapconfiguration.html#cfn-quicksight-dashboard-geospatialmapconfiguration-visualpalette
         */
        readonly visualPalette?: cdk.IResolvable | CfnDashboard.VisualPaletteProperty;
        /**
         * The window options of the geospatial map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapconfiguration.html#cfn-quicksight-dashboard-geospatialmapconfiguration-windowoptions
         */
        readonly windowOptions?: CfnDashboard.GeospatialWindowOptionsProperty | cdk.IResolvable;
    }
    /**
     * The field wells of a `GeospatialMapVisual` .
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapfieldwells.html
     */
    interface GeospatialMapFieldWellsProperty {
        /**
         * The aggregated field well for a geospatial map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapfieldwells.html#cfn-quicksight-dashboard-geospatialmapfieldwells-geospatialmapaggregatedfieldwells
         */
        readonly geospatialMapAggregatedFieldWells?: CfnDashboard.GeospatialMapAggregatedFieldWellsProperty | cdk.IResolvable;
    }
    /**
     * The aggregated field wells for a geospatial map.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapaggregatedfieldwells.html
     */
    interface GeospatialMapAggregatedFieldWellsProperty {
        /**
         * The color field wells of a geospatial map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapaggregatedfieldwells.html#cfn-quicksight-dashboard-geospatialmapaggregatedfieldwells-colors
         */
        readonly colors?: Array<CfnDashboard.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The geospatial field wells of a geospatial map.
         *
         * Values are grouped by geospatial fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapaggregatedfieldwells.html#cfn-quicksight-dashboard-geospatialmapaggregatedfieldwells-geospatial
         */
        readonly geospatial?: Array<CfnDashboard.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The size field wells of a geospatial map.
         *
         * Values are aggregated based on geospatial fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapaggregatedfieldwells.html#cfn-quicksight-dashboard-geospatialmapaggregatedfieldwells-values
         */
        readonly values?: Array<cdk.IResolvable | CfnDashboard.MeasureFieldProperty> | cdk.IResolvable;
    }
    /**
     * The point style of the geospatial map.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialpointstyleoptions.html
     */
    interface GeospatialPointStyleOptionsProperty {
        /**
         * The cluster marker configuration of the geospatial point style.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialpointstyleoptions.html#cfn-quicksight-dashboard-geospatialpointstyleoptions-clustermarkerconfiguration
         */
        readonly clusterMarkerConfiguration?: CfnDashboard.ClusterMarkerConfigurationProperty | cdk.IResolvable;
        /**
         * The heatmap configuration of the geospatial point style.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialpointstyleoptions.html#cfn-quicksight-dashboard-geospatialpointstyleoptions-heatmapconfiguration
         */
        readonly heatmapConfiguration?: CfnDashboard.GeospatialHeatmapConfigurationProperty | cdk.IResolvable;
        /**
         * The selected point styles (point, cluster) of the geospatial map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialpointstyleoptions.html#cfn-quicksight-dashboard-geospatialpointstyleoptions-selectedpointstyle
         */
        readonly selectedPointStyle?: string;
    }
    /**
     * The cluster marker configuration of the geospatial map selected point style.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-clustermarkerconfiguration.html
     */
    interface ClusterMarkerConfigurationProperty {
        /**
         * The cluster marker that is a part of the cluster marker configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-clustermarkerconfiguration.html#cfn-quicksight-dashboard-clustermarkerconfiguration-clustermarker
         */
        readonly clusterMarker?: CfnDashboard.ClusterMarkerProperty | cdk.IResolvable;
    }
    /**
     * The cluster marker that is a part of the cluster marker configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-clustermarker.html
     */
    interface ClusterMarkerProperty {
        /**
         * The simple cluster marker of the cluster marker.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-clustermarker.html#cfn-quicksight-dashboard-clustermarker-simpleclustermarker
         */
        readonly simpleClusterMarker?: cdk.IResolvable | CfnDashboard.SimpleClusterMarkerProperty;
    }
    /**
     * The simple cluster marker of the cluster marker.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-simpleclustermarker.html
     */
    interface SimpleClusterMarkerProperty {
        /**
         * The color of the simple cluster marker.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-simpleclustermarker.html#cfn-quicksight-dashboard-simpleclustermarker-color
         */
        readonly color?: string;
    }
    /**
     * The heatmap configuration of the geospatial point style.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialheatmapconfiguration.html
     */
    interface GeospatialHeatmapConfigurationProperty {
        /**
         * The color scale specification for the heatmap point style.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialheatmapconfiguration.html#cfn-quicksight-dashboard-geospatialheatmapconfiguration-heatmapcolor
         */
        readonly heatmapColor?: CfnDashboard.GeospatialHeatmapColorScaleProperty | cdk.IResolvable;
    }
    /**
     * The color scale specification for the heatmap point style.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialheatmapcolorscale.html
     */
    interface GeospatialHeatmapColorScaleProperty {
        /**
         * The list of colors to be used in heatmap point style.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialheatmapcolorscale.html#cfn-quicksight-dashboard-geospatialheatmapcolorscale-colors
         */
        readonly colors?: Array<CfnDashboard.GeospatialHeatmapDataColorProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * The color to be used in the heatmap point style.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialheatmapdatacolor.html
     */
    interface GeospatialHeatmapDataColorProperty {
        /**
         * The hex color to be used in the heatmap point style.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialheatmapdatacolor.html#cfn-quicksight-dashboard-geospatialheatmapdatacolor-color
         */
        readonly color: string;
    }
    /**
     * A bar chart.
     *
     * The `BarChartVisual` structure describes a visual that is a member of the bar chart family. The following charts can be described using this structure:
     *
     * - Horizontal bar chart
     * - Vertical bar chart
     * - Horizontal stacked bar chart
     * - Vertical stacked bar chart
     * - Horizontal stacked 100% bar chart
     * - Vertical stacked 100% bar chart
     *
     * For more information, see [Using bar charts](https://docs.aws.amazon.com/quicksight/latest/user/bar-charts.html) in the *Amazon QuickSight User Guide* .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartvisual.html
     */
    interface BarChartVisualProperty {
        /**
         * The list of custom actions that are configured for a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartvisual.html#cfn-quicksight-dashboard-barchartvisual-actions
         */
        readonly actions?: Array<cdk.IResolvable | CfnDashboard.VisualCustomActionProperty> | cdk.IResolvable;
        /**
         * The configuration settings of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartvisual.html#cfn-quicksight-dashboard-barchartvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnDashboard.BarChartConfigurationProperty | cdk.IResolvable;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartvisual.html#cfn-quicksight-dashboard-barchartvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnDashboard.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The subtitle that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartvisual.html#cfn-quicksight-dashboard-barchartvisual-subtitle
         */
        readonly subtitle?: cdk.IResolvable | CfnDashboard.VisualSubtitleLabelOptionsProperty;
        /**
         * The title that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartvisual.html#cfn-quicksight-dashboard-barchartvisual-title
         */
        readonly title?: cdk.IResolvable | CfnDashboard.VisualTitleLabelOptionsProperty;
        /**
         * The unique identifier of a visual.
         *
         * This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartvisual.html#cfn-quicksight-dashboard-barchartvisual-visualid
         */
        readonly visualId: string;
    }
    /**
     * The configuration of a `BarChartVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html
     */
    interface BarChartConfigurationProperty {
        /**
         * Determines the arrangement of the bars.
         *
         * The orientation and arrangement of bars determine the type of bar that is used in the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-barsarrangement
         */
        readonly barsArrangement?: string;
        /**
         * The label display options (grid line, range, scale, axis step) for bar chart category.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-categoryaxis
         */
        readonly categoryAxis?: CfnDashboard.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * The label options (label text, label visibility and sort icon visibility) for a bar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-categorylabeloptions
         */
        readonly categoryLabelOptions?: CfnDashboard.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The label options (label text, label visibility and sort icon visibility) for a color that is used in a bar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-colorlabeloptions
         */
        readonly colorLabelOptions?: CfnDashboard.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The contribution analysis (anomaly configuration) setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-contributionanalysisdefaults
         */
        readonly contributionAnalysisDefaults?: Array<CfnDashboard.ContributionAnalysisDefaultProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The options that determine if visual data labels are displayed.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-datalabels
         */
        readonly dataLabels?: CfnDashboard.DataLabelOptionsProperty | cdk.IResolvable;
        /**
         * The field wells of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-fieldwells
         */
        readonly fieldWells?: CfnDashboard.BarChartFieldWellsProperty | cdk.IResolvable;
        /**
         * The legend display setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-legend
         */
        readonly legend?: cdk.IResolvable | CfnDashboard.LegendOptionsProperty;
        /**
         * The orientation of the bars in a bar chart visual. There are two valid values in this structure:.
         *
         * - `HORIZONTAL` : Used for charts that have horizontal bars. Visuals that use this value are horizontal bar charts, horizontal stacked bar charts, and horizontal stacked 100% bar charts.
         * - `VERTICAL` : Used for charts that have vertical bars. Visuals that use this value are vertical bar charts, vertical stacked bar charts, and vertical stacked 100% bar charts.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-orientation
         */
        readonly orientation?: string;
        /**
         * The reference line setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-referencelines
         */
        readonly referenceLines?: Array<cdk.IResolvable | CfnDashboard.ReferenceLineProperty> | cdk.IResolvable;
        /**
         * The small multiples setup for the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-smallmultiplesoptions
         */
        readonly smallMultiplesOptions?: cdk.IResolvable | CfnDashboard.SmallMultiplesOptionsProperty;
        /**
         * The sort configuration of a `BarChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: CfnDashboard.BarChartSortConfigurationProperty | cdk.IResolvable;
        /**
         * The tooltip display setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-tooltip
         */
        readonly tooltip?: cdk.IResolvable | CfnDashboard.TooltipOptionsProperty;
        /**
         * The label display options (grid line, range, scale, axis step) for a bar chart value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-valueaxis
         */
        readonly valueAxis?: CfnDashboard.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * The label options (label text, label visibility and sort icon visibility) for a bar chart value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-valuelabeloptions
         */
        readonly valueLabelOptions?: CfnDashboard.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The palette (chart color) display setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-visualpalette
         */
        readonly visualPalette?: cdk.IResolvable | CfnDashboard.VisualPaletteProperty;
    }
    /**
     * sort-configuration-description.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartsortconfiguration.html
     */
    interface BarChartSortConfigurationProperty {
        /**
         * The limit on the number of categories displayed in a bar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartsortconfiguration.html#cfn-quicksight-dashboard-barchartsortconfiguration-categoryitemslimit
         */
        readonly categoryItemsLimit?: cdk.IResolvable | CfnDashboard.ItemsLimitConfigurationProperty;
        /**
         * The sort configuration of category fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartsortconfiguration.html#cfn-quicksight-dashboard-barchartsortconfiguration-categorysort
         */
        readonly categorySort?: Array<CfnDashboard.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The limit on the number of values displayed in a bar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartsortconfiguration.html#cfn-quicksight-dashboard-barchartsortconfiguration-coloritemslimit
         */
        readonly colorItemsLimit?: cdk.IResolvable | CfnDashboard.ItemsLimitConfigurationProperty;
        /**
         * The sort configuration of color fields in a bar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartsortconfiguration.html#cfn-quicksight-dashboard-barchartsortconfiguration-colorsort
         */
        readonly colorSort?: Array<CfnDashboard.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The limit on the number of small multiples panels that are displayed.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartsortconfiguration.html#cfn-quicksight-dashboard-barchartsortconfiguration-smallmultipleslimitconfiguration
         */
        readonly smallMultiplesLimitConfiguration?: cdk.IResolvable | CfnDashboard.ItemsLimitConfigurationProperty;
        /**
         * The sort configuration of the small multiples field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartsortconfiguration.html#cfn-quicksight-dashboard-barchartsortconfiguration-smallmultiplessort
         */
        readonly smallMultiplesSort?: Array<CfnDashboard.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * The field wells of a `BarChartVisual` .
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartfieldwells.html
     */
    interface BarChartFieldWellsProperty {
        /**
         * The aggregated field wells of a bar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartfieldwells.html#cfn-quicksight-dashboard-barchartfieldwells-barchartaggregatedfieldwells
         */
        readonly barChartAggregatedFieldWells?: CfnDashboard.BarChartAggregatedFieldWellsProperty | cdk.IResolvable;
    }
    /**
     * The aggregated field wells of a bar chart.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartaggregatedfieldwells.html
     */
    interface BarChartAggregatedFieldWellsProperty {
        /**
         * The category (y-axis) field well of a bar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartaggregatedfieldwells.html#cfn-quicksight-dashboard-barchartaggregatedfieldwells-category
         */
        readonly category?: Array<CfnDashboard.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The color (group/color) field well of a bar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartaggregatedfieldwells.html#cfn-quicksight-dashboard-barchartaggregatedfieldwells-colors
         */
        readonly colors?: Array<CfnDashboard.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The small multiples field well of a bar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartaggregatedfieldwells.html#cfn-quicksight-dashboard-barchartaggregatedfieldwells-smallmultiples
         */
        readonly smallMultiples?: Array<CfnDashboard.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The value field wells of a bar chart.
         *
         * Values are aggregated by category.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartaggregatedfieldwells.html#cfn-quicksight-dashboard-barchartaggregatedfieldwells-values
         */
        readonly values?: Array<cdk.IResolvable | CfnDashboard.MeasureFieldProperty> | cdk.IResolvable;
    }
    /**
     * A scatter plot.
     *
     * For more information, see [Using scatter plots](https://docs.aws.amazon.com/quicksight/latest/user/scatter-plot.html) in the *Amazon QuickSight User Guide* .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotvisual.html
     */
    interface ScatterPlotVisualProperty {
        /**
         * The list of custom actions that are configured for a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotvisual.html#cfn-quicksight-dashboard-scatterplotvisual-actions
         */
        readonly actions?: Array<cdk.IResolvable | CfnDashboard.VisualCustomActionProperty> | cdk.IResolvable;
        /**
         * The configuration settings of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotvisual.html#cfn-quicksight-dashboard-scatterplotvisual-chartconfiguration
         */
        readonly chartConfiguration?: cdk.IResolvable | CfnDashboard.ScatterPlotConfigurationProperty;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotvisual.html#cfn-quicksight-dashboard-scatterplotvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnDashboard.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The subtitle that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotvisual.html#cfn-quicksight-dashboard-scatterplotvisual-subtitle
         */
        readonly subtitle?: cdk.IResolvable | CfnDashboard.VisualSubtitleLabelOptionsProperty;
        /**
         * The title that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotvisual.html#cfn-quicksight-dashboard-scatterplotvisual-title
         */
        readonly title?: cdk.IResolvable | CfnDashboard.VisualTitleLabelOptionsProperty;
        /**
         * The unique identifier of a visual.
         *
         * This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotvisual.html#cfn-quicksight-dashboard-scatterplotvisual-visualid
         */
        readonly visualId: string;
    }
    /**
     * The configuration of a scatter plot.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotconfiguration.html
     */
    interface ScatterPlotConfigurationProperty {
        /**
         * The options that determine if visual data labels are displayed.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotconfiguration.html#cfn-quicksight-dashboard-scatterplotconfiguration-datalabels
         */
        readonly dataLabels?: CfnDashboard.DataLabelOptionsProperty | cdk.IResolvable;
        /**
         * The field wells of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotconfiguration.html#cfn-quicksight-dashboard-scatterplotconfiguration-fieldwells
         */
        readonly fieldWells?: cdk.IResolvable | CfnDashboard.ScatterPlotFieldWellsProperty;
        /**
         * The legend display setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotconfiguration.html#cfn-quicksight-dashboard-scatterplotconfiguration-legend
         */
        readonly legend?: cdk.IResolvable | CfnDashboard.LegendOptionsProperty;
        /**
         * The legend display setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotconfiguration.html#cfn-quicksight-dashboard-scatterplotconfiguration-tooltip
         */
        readonly tooltip?: cdk.IResolvable | CfnDashboard.TooltipOptionsProperty;
        /**
         * The palette (chart color) display setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotconfiguration.html#cfn-quicksight-dashboard-scatterplotconfiguration-visualpalette
         */
        readonly visualPalette?: cdk.IResolvable | CfnDashboard.VisualPaletteProperty;
        /**
         * The label display options (grid line, range, scale, and axis step) of the scatter plot's x-axis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotconfiguration.html#cfn-quicksight-dashboard-scatterplotconfiguration-xaxisdisplayoptions
         */
        readonly xAxisDisplayOptions?: CfnDashboard.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * The label options (label text, label visibility, and sort icon visibility) of the scatter plot's x-axis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotconfiguration.html#cfn-quicksight-dashboard-scatterplotconfiguration-xaxislabeloptions
         */
        readonly xAxisLabelOptions?: CfnDashboard.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The label display options (grid line, range, scale, and axis step) of the scatter plot's y-axis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotconfiguration.html#cfn-quicksight-dashboard-scatterplotconfiguration-yaxisdisplayoptions
         */
        readonly yAxisDisplayOptions?: CfnDashboard.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * The label options (label text, label visibility, and sort icon visibility) of the scatter plot's y-axis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotconfiguration.html#cfn-quicksight-dashboard-scatterplotconfiguration-yaxislabeloptions
         */
        readonly yAxisLabelOptions?: CfnDashboard.ChartAxisLabelOptionsProperty | cdk.IResolvable;
    }
    /**
     * The field well configuration of a scatter plot.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotfieldwells.html
     */
    interface ScatterPlotFieldWellsProperty {
        /**
         * The aggregated field wells of a scatter plot.
         *
         * The x and y-axes of scatter plots with aggregated field wells are aggregated by category, label, or both.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotfieldwells.html#cfn-quicksight-dashboard-scatterplotfieldwells-scatterplotcategoricallyaggregatedfieldwells
         */
        readonly scatterPlotCategoricallyAggregatedFieldWells?: cdk.IResolvable | CfnDashboard.ScatterPlotCategoricallyAggregatedFieldWellsProperty;
        /**
         * The unaggregated field wells of a scatter plot.
         *
         * The x and y-axes of these scatter plots are unaggregated.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotfieldwells.html#cfn-quicksight-dashboard-scatterplotfieldwells-scatterplotunaggregatedfieldwells
         */
        readonly scatterPlotUnaggregatedFieldWells?: cdk.IResolvable | CfnDashboard.ScatterPlotUnaggregatedFieldWellsProperty;
    }
    /**
     * The unaggregated field wells of a scatter plot.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotunaggregatedfieldwells.html
     */
    interface ScatterPlotUnaggregatedFieldWellsProperty {
        /**
         * The category field well of a scatter plot.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotunaggregatedfieldwells.html#cfn-quicksight-dashboard-scatterplotunaggregatedfieldwells-category
         */
        readonly category?: Array<CfnDashboard.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The label field well of a scatter plot.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotunaggregatedfieldwells.html#cfn-quicksight-dashboard-scatterplotunaggregatedfieldwells-label
         */
        readonly label?: Array<CfnDashboard.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The size field well of a scatter plot.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotunaggregatedfieldwells.html#cfn-quicksight-dashboard-scatterplotunaggregatedfieldwells-size
         */
        readonly size?: Array<cdk.IResolvable | CfnDashboard.MeasureFieldProperty> | cdk.IResolvable;
        /**
         * The x-axis field well of a scatter plot.
         *
         * The x-axis is a dimension field and cannot be aggregated.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotunaggregatedfieldwells.html#cfn-quicksight-dashboard-scatterplotunaggregatedfieldwells-xaxis
         */
        readonly xAxis?: Array<CfnDashboard.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The y-axis field well of a scatter plot.
         *
         * The y-axis is a dimension field and cannot be aggregated.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotunaggregatedfieldwells.html#cfn-quicksight-dashboard-scatterplotunaggregatedfieldwells-yaxis
         */
        readonly yAxis?: Array<CfnDashboard.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * The aggregated field well of a scatter plot.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotcategoricallyaggregatedfieldwells.html
     */
    interface ScatterPlotCategoricallyAggregatedFieldWellsProperty {
        /**
         * The category field well of a scatter plot.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotcategoricallyaggregatedfieldwells.html#cfn-quicksight-dashboard-scatterplotcategoricallyaggregatedfieldwells-category
         */
        readonly category?: Array<CfnDashboard.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The label field well of a scatter plot.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotcategoricallyaggregatedfieldwells.html#cfn-quicksight-dashboard-scatterplotcategoricallyaggregatedfieldwells-label
         */
        readonly label?: Array<CfnDashboard.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The size field well of a scatter plot.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotcategoricallyaggregatedfieldwells.html#cfn-quicksight-dashboard-scatterplotcategoricallyaggregatedfieldwells-size
         */
        readonly size?: Array<cdk.IResolvable | CfnDashboard.MeasureFieldProperty> | cdk.IResolvable;
        /**
         * The x-axis field well of a scatter plot.
         *
         * The x-axis is aggregated by category.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotcategoricallyaggregatedfieldwells.html#cfn-quicksight-dashboard-scatterplotcategoricallyaggregatedfieldwells-xaxis
         */
        readonly xAxis?: Array<cdk.IResolvable | CfnDashboard.MeasureFieldProperty> | cdk.IResolvable;
        /**
         * The y-axis field well of a scatter plot.
         *
         * The y-axis is aggregated by category.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotcategoricallyaggregatedfieldwells.html#cfn-quicksight-dashboard-scatterplotcategoricallyaggregatedfieldwells-yaxis
         */
        readonly yAxis?: Array<cdk.IResolvable | CfnDashboard.MeasureFieldProperty> | cdk.IResolvable;
    }
    /**
     * A radar chart visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartvisual.html
     */
    interface RadarChartVisualProperty {
        /**
         * The list of custom actions that are configured for a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartvisual.html#cfn-quicksight-dashboard-radarchartvisual-actions
         */
        readonly actions?: Array<cdk.IResolvable | CfnDashboard.VisualCustomActionProperty> | cdk.IResolvable;
        /**
         * The configuration settings of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartvisual.html#cfn-quicksight-dashboard-radarchartvisual-chartconfiguration
         */
        readonly chartConfiguration?: cdk.IResolvable | CfnDashboard.RadarChartConfigurationProperty;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartvisual.html#cfn-quicksight-dashboard-radarchartvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnDashboard.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The subtitle that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartvisual.html#cfn-quicksight-dashboard-radarchartvisual-subtitle
         */
        readonly subtitle?: cdk.IResolvable | CfnDashboard.VisualSubtitleLabelOptionsProperty;
        /**
         * The title that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartvisual.html#cfn-quicksight-dashboard-radarchartvisual-title
         */
        readonly title?: cdk.IResolvable | CfnDashboard.VisualTitleLabelOptionsProperty;
        /**
         * The unique identifier of a visual.
         *
         * This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartvisual.html#cfn-quicksight-dashboard-radarchartvisual-visualid
         */
        readonly visualId: string;
    }
    /**
     * The configuration of a `RadarChartVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html
     */
    interface RadarChartConfigurationProperty {
        /**
         * Determines the visibility of the colors of alternatign bands in a radar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html#cfn-quicksight-dashboard-radarchartconfiguration-alternatebandcolorsvisibility
         */
        readonly alternateBandColorsVisibility?: string;
        /**
         * The color of the even-numbered alternate bands of a radar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html#cfn-quicksight-dashboard-radarchartconfiguration-alternatebandevencolor
         */
        readonly alternateBandEvenColor?: string;
        /**
         * The color of the odd-numbered alternate bands of a radar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html#cfn-quicksight-dashboard-radarchartconfiguration-alternatebandoddcolor
         */
        readonly alternateBandOddColor?: string;
        /**
         * The axis behavior options of a radar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html#cfn-quicksight-dashboard-radarchartconfiguration-axesrangescale
         */
        readonly axesRangeScale?: string;
        /**
         * The base sreies settings of a radar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html#cfn-quicksight-dashboard-radarchartconfiguration-baseseriessettings
         */
        readonly baseSeriesSettings?: cdk.IResolvable | CfnDashboard.RadarChartSeriesSettingsProperty;
        /**
         * The category axis of a radar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html#cfn-quicksight-dashboard-radarchartconfiguration-categoryaxis
         */
        readonly categoryAxis?: CfnDashboard.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * The category label options of a radar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html#cfn-quicksight-dashboard-radarchartconfiguration-categorylabeloptions
         */
        readonly categoryLabelOptions?: CfnDashboard.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The color axis of a radar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html#cfn-quicksight-dashboard-radarchartconfiguration-coloraxis
         */
        readonly colorAxis?: CfnDashboard.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * The color label options of a radar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html#cfn-quicksight-dashboard-radarchartconfiguration-colorlabeloptions
         */
        readonly colorLabelOptions?: CfnDashboard.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The field well configuration of a `RadarChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html#cfn-quicksight-dashboard-radarchartconfiguration-fieldwells
         */
        readonly fieldWells?: cdk.IResolvable | CfnDashboard.RadarChartFieldWellsProperty;
        /**
         * The legend display setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html#cfn-quicksight-dashboard-radarchartconfiguration-legend
         */
        readonly legend?: cdk.IResolvable | CfnDashboard.LegendOptionsProperty;
        /**
         * The shape of the radar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html#cfn-quicksight-dashboard-radarchartconfiguration-shape
         */
        readonly shape?: string;
        /**
         * The sort configuration of a `RadarChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html#cfn-quicksight-dashboard-radarchartconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: cdk.IResolvable | CfnDashboard.RadarChartSortConfigurationProperty;
        /**
         * The start angle of a radar chart's axis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html#cfn-quicksight-dashboard-radarchartconfiguration-startangle
         */
        readonly startAngle?: number;
        /**
         * The palette (chart color) display setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html#cfn-quicksight-dashboard-radarchartconfiguration-visualpalette
         */
        readonly visualPalette?: cdk.IResolvable | CfnDashboard.VisualPaletteProperty;
    }
    /**
     * The sort configuration of a `RadarChartVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartsortconfiguration.html
     */
    interface RadarChartSortConfigurationProperty {
        /**
         * The category items limit for a radar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartsortconfiguration.html#cfn-quicksight-dashboard-radarchartsortconfiguration-categoryitemslimit
         */
        readonly categoryItemsLimit?: cdk.IResolvable | CfnDashboard.ItemsLimitConfigurationProperty;
        /**
         * The category sort options of a radar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartsortconfiguration.html#cfn-quicksight-dashboard-radarchartsortconfiguration-categorysort
         */
        readonly categorySort?: Array<CfnDashboard.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The color items limit of a radar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartsortconfiguration.html#cfn-quicksight-dashboard-radarchartsortconfiguration-coloritemslimit
         */
        readonly colorItemsLimit?: cdk.IResolvable | CfnDashboard.ItemsLimitConfigurationProperty;
        /**
         * The color sort configuration of a radar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartsortconfiguration.html#cfn-quicksight-dashboard-radarchartsortconfiguration-colorsort
         */
        readonly colorSort?: Array<CfnDashboard.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * The series settings of a radar chart.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartseriessettings.html
     */
    interface RadarChartSeriesSettingsProperty {
        /**
         * The area style settings of a radar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartseriessettings.html#cfn-quicksight-dashboard-radarchartseriessettings-areastylesettings
         */
        readonly areaStyleSettings?: cdk.IResolvable | CfnDashboard.RadarChartAreaStyleSettingsProperty;
    }
    /**
     * The configured style settings of a radar chart.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartareastylesettings.html
     */
    interface RadarChartAreaStyleSettingsProperty {
        /**
         * The visibility settings of a radar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartareastylesettings.html#cfn-quicksight-dashboard-radarchartareastylesettings-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The field wells of a radar chart visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartfieldwells.html
     */
    interface RadarChartFieldWellsProperty {
        /**
         * The aggregated field wells of a radar chart visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartfieldwells.html#cfn-quicksight-dashboard-radarchartfieldwells-radarchartaggregatedfieldwells
         */
        readonly radarChartAggregatedFieldWells?: cdk.IResolvable | CfnDashboard.RadarChartAggregatedFieldWellsProperty;
    }
    /**
     * The aggregated field well configuration of a `RadarChartVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartaggregatedfieldwells.html
     */
    interface RadarChartAggregatedFieldWellsProperty {
        /**
         * The aggregated field well categories of a radar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartaggregatedfieldwells.html#cfn-quicksight-dashboard-radarchartaggregatedfieldwells-category
         */
        readonly category?: Array<CfnDashboard.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The color that are assigned to the aggregated field wells of a radar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartaggregatedfieldwells.html#cfn-quicksight-dashboard-radarchartaggregatedfieldwells-color
         */
        readonly color?: Array<CfnDashboard.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The values that are assigned to the aggregated field wells of a radar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartaggregatedfieldwells.html#cfn-quicksight-dashboard-radarchartaggregatedfieldwells-values
         */
        readonly values?: Array<cdk.IResolvable | CfnDashboard.MeasureFieldProperty> | cdk.IResolvable;
    }
    /**
     * A heat map.
     *
     * For more information, see [Using heat maps](https://docs.aws.amazon.com/quicksight/latest/user/heat-map.html) in the *Amazon QuickSight User Guide* .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapvisual.html
     */
    interface HeatMapVisualProperty {
        /**
         * The list of custom actions that are configured for a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapvisual.html#cfn-quicksight-dashboard-heatmapvisual-actions
         */
        readonly actions?: Array<cdk.IResolvable | CfnDashboard.VisualCustomActionProperty> | cdk.IResolvable;
        /**
         * The configuration of a heat map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapvisual.html#cfn-quicksight-dashboard-heatmapvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnDashboard.HeatMapConfigurationProperty | cdk.IResolvable;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapvisual.html#cfn-quicksight-dashboard-heatmapvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnDashboard.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The subtitle that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapvisual.html#cfn-quicksight-dashboard-heatmapvisual-subtitle
         */
        readonly subtitle?: cdk.IResolvable | CfnDashboard.VisualSubtitleLabelOptionsProperty;
        /**
         * The title that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapvisual.html#cfn-quicksight-dashboard-heatmapvisual-title
         */
        readonly title?: cdk.IResolvable | CfnDashboard.VisualTitleLabelOptionsProperty;
        /**
         * The unique identifier of a visual.
         *
         * This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapvisual.html#cfn-quicksight-dashboard-heatmapvisual-visualid
         */
        readonly visualId: string;
    }
    /**
     * The configuration of a heat map.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapconfiguration.html
     */
    interface HeatMapConfigurationProperty {
        /**
         * The color options (gradient color, point of divergence) in a heat map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapconfiguration.html#cfn-quicksight-dashboard-heatmapconfiguration-colorscale
         */
        readonly colorScale?: CfnDashboard.ColorScaleProperty | cdk.IResolvable;
        /**
         * The label options of the column that is displayed in a heat map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapconfiguration.html#cfn-quicksight-dashboard-heatmapconfiguration-columnlabeloptions
         */
        readonly columnLabelOptions?: CfnDashboard.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The options that determine if visual data labels are displayed.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapconfiguration.html#cfn-quicksight-dashboard-heatmapconfiguration-datalabels
         */
        readonly dataLabels?: CfnDashboard.DataLabelOptionsProperty | cdk.IResolvable;
        /**
         * The field wells of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapconfiguration.html#cfn-quicksight-dashboard-heatmapconfiguration-fieldwells
         */
        readonly fieldWells?: CfnDashboard.HeatMapFieldWellsProperty | cdk.IResolvable;
        /**
         * The legend display setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapconfiguration.html#cfn-quicksight-dashboard-heatmapconfiguration-legend
         */
        readonly legend?: cdk.IResolvable | CfnDashboard.LegendOptionsProperty;
        /**
         * The label options of the row that is displayed in a `heat map` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapconfiguration.html#cfn-quicksight-dashboard-heatmapconfiguration-rowlabeloptions
         */
        readonly rowLabelOptions?: CfnDashboard.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The sort configuration of a heat map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapconfiguration.html#cfn-quicksight-dashboard-heatmapconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: CfnDashboard.HeatMapSortConfigurationProperty | cdk.IResolvable;
        /**
         * The tooltip display setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapconfiguration.html#cfn-quicksight-dashboard-heatmapconfiguration-tooltip
         */
        readonly tooltip?: cdk.IResolvable | CfnDashboard.TooltipOptionsProperty;
    }
    /**
     * The sort configuration of a heat map.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapsortconfiguration.html
     */
    interface HeatMapSortConfigurationProperty {
        /**
         * The limit on the number of columns that are displayed in a heat map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapsortconfiguration.html#cfn-quicksight-dashboard-heatmapsortconfiguration-heatmapcolumnitemslimitconfiguration
         */
        readonly heatMapColumnItemsLimitConfiguration?: cdk.IResolvable | CfnDashboard.ItemsLimitConfigurationProperty;
        /**
         * The column sort configuration for heat map for columns that aren't a part of a field well.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapsortconfiguration.html#cfn-quicksight-dashboard-heatmapsortconfiguration-heatmapcolumnsort
         */
        readonly heatMapColumnSort?: Array<CfnDashboard.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The limit on the number of rows that are displayed in a heat map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapsortconfiguration.html#cfn-quicksight-dashboard-heatmapsortconfiguration-heatmaprowitemslimitconfiguration
         */
        readonly heatMapRowItemsLimitConfiguration?: cdk.IResolvable | CfnDashboard.ItemsLimitConfigurationProperty;
        /**
         * The field sort configuration of the rows fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapsortconfiguration.html#cfn-quicksight-dashboard-heatmapsortconfiguration-heatmaprowsort
         */
        readonly heatMapRowSort?: Array<CfnDashboard.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * The field well configuration of a heat map.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapfieldwells.html
     */
    interface HeatMapFieldWellsProperty {
        /**
         * The aggregated field wells of a heat map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapfieldwells.html#cfn-quicksight-dashboard-heatmapfieldwells-heatmapaggregatedfieldwells
         */
        readonly heatMapAggregatedFieldWells?: CfnDashboard.HeatMapAggregatedFieldWellsProperty | cdk.IResolvable;
    }
    /**
     * The aggregated field wells of a heat map.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapaggregatedfieldwells.html
     */
    interface HeatMapAggregatedFieldWellsProperty {
        /**
         * The columns field well of a heat map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapaggregatedfieldwells.html#cfn-quicksight-dashboard-heatmapaggregatedfieldwells-columns
         */
        readonly columns?: Array<CfnDashboard.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The rows field well of a heat map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapaggregatedfieldwells.html#cfn-quicksight-dashboard-heatmapaggregatedfieldwells-rows
         */
        readonly rows?: Array<CfnDashboard.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The values field well of a heat map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapaggregatedfieldwells.html#cfn-quicksight-dashboard-heatmapaggregatedfieldwells-values
         */
        readonly values?: Array<cdk.IResolvable | CfnDashboard.MeasureFieldProperty> | cdk.IResolvable;
    }
    /**
     * Determines the color scale that is applied to the visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-colorscale.html
     */
    interface ColorScaleProperty {
        /**
         * Determines the color fill type.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-colorscale.html#cfn-quicksight-dashboard-colorscale-colorfilltype
         */
        readonly colorFillType: string;
        /**
         * Determines the list of colors that are applied to the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-colorscale.html#cfn-quicksight-dashboard-colorscale-colors
         */
        readonly colors: Array<CfnDashboard.DataColorProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * Determines the color that is applied to null values.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-colorscale.html#cfn-quicksight-dashboard-colorscale-nullvaluecolor
         */
        readonly nullValueColor?: CfnDashboard.DataColorProperty | cdk.IResolvable;
    }
    /**
     * Determines the color that is applied to a particular data value.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datacolor.html
     */
    interface DataColorProperty {
        /**
         * The color that is applied to the data value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datacolor.html#cfn-quicksight-dashboard-datacolor-color
         */
        readonly color?: string;
        /**
         * The data value that the color is applied to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datacolor.html#cfn-quicksight-dashboard-datacolor-datavalue
         */
        readonly dataValue?: number;
    }
    /**
     * A tree map.
     *
     * For more information, see [Using tree maps](https://docs.aws.amazon.com/quicksight/latest/user/tree-map.html) in the *Amazon QuickSight User Guide* .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapvisual.html
     */
    interface TreeMapVisualProperty {
        /**
         * The list of custom actions that are configured for a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapvisual.html#cfn-quicksight-dashboard-treemapvisual-actions
         */
        readonly actions?: Array<cdk.IResolvable | CfnDashboard.VisualCustomActionProperty> | cdk.IResolvable;
        /**
         * The configuration settings of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapvisual.html#cfn-quicksight-dashboard-treemapvisual-chartconfiguration
         */
        readonly chartConfiguration?: cdk.IResolvable | CfnDashboard.TreeMapConfigurationProperty;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapvisual.html#cfn-quicksight-dashboard-treemapvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnDashboard.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The subtitle that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapvisual.html#cfn-quicksight-dashboard-treemapvisual-subtitle
         */
        readonly subtitle?: cdk.IResolvable | CfnDashboard.VisualSubtitleLabelOptionsProperty;
        /**
         * The title that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapvisual.html#cfn-quicksight-dashboard-treemapvisual-title
         */
        readonly title?: cdk.IResolvable | CfnDashboard.VisualTitleLabelOptionsProperty;
        /**
         * The unique identifier of a visual.
         *
         * This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapvisual.html#cfn-quicksight-dashboard-treemapvisual-visualid
         */
        readonly visualId: string;
    }
    /**
     * The configuration of a tree map.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapconfiguration.html
     */
    interface TreeMapConfigurationProperty {
        /**
         * The label options (label text, label visibility) for the colors displayed in a tree map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapconfiguration.html#cfn-quicksight-dashboard-treemapconfiguration-colorlabeloptions
         */
        readonly colorLabelOptions?: CfnDashboard.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The color options (gradient color, point of divergence) of a tree map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapconfiguration.html#cfn-quicksight-dashboard-treemapconfiguration-colorscale
         */
        readonly colorScale?: CfnDashboard.ColorScaleProperty | cdk.IResolvable;
        /**
         * The options that determine if visual data labels are displayed.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapconfiguration.html#cfn-quicksight-dashboard-treemapconfiguration-datalabels
         */
        readonly dataLabels?: CfnDashboard.DataLabelOptionsProperty | cdk.IResolvable;
        /**
         * The field wells of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapconfiguration.html#cfn-quicksight-dashboard-treemapconfiguration-fieldwells
         */
        readonly fieldWells?: cdk.IResolvable | CfnDashboard.TreeMapFieldWellsProperty;
        /**
         * The label options (label text, label visibility) of the groups that are displayed in a tree map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapconfiguration.html#cfn-quicksight-dashboard-treemapconfiguration-grouplabeloptions
         */
        readonly groupLabelOptions?: CfnDashboard.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The legend display setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapconfiguration.html#cfn-quicksight-dashboard-treemapconfiguration-legend
         */
        readonly legend?: cdk.IResolvable | CfnDashboard.LegendOptionsProperty;
        /**
         * The label options (label text, label visibility) of the sizes that are displayed in a tree map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapconfiguration.html#cfn-quicksight-dashboard-treemapconfiguration-sizelabeloptions
         */
        readonly sizeLabelOptions?: CfnDashboard.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The sort configuration of a tree map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapconfiguration.html#cfn-quicksight-dashboard-treemapconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: cdk.IResolvable | CfnDashboard.TreeMapSortConfigurationProperty;
        /**
         * The tooltip display setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapconfiguration.html#cfn-quicksight-dashboard-treemapconfiguration-tooltip
         */
        readonly tooltip?: cdk.IResolvable | CfnDashboard.TooltipOptionsProperty;
    }
    /**
     * The sort configuration of a tree map.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapsortconfiguration.html
     */
    interface TreeMapSortConfigurationProperty {
        /**
         * The limit on the number of groups that are displayed.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapsortconfiguration.html#cfn-quicksight-dashboard-treemapsortconfiguration-treemapgroupitemslimitconfiguration
         */
        readonly treeMapGroupItemsLimitConfiguration?: cdk.IResolvable | CfnDashboard.ItemsLimitConfigurationProperty;
        /**
         * The sort configuration of group by fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapsortconfiguration.html#cfn-quicksight-dashboard-treemapsortconfiguration-treemapsort
         */
        readonly treeMapSort?: Array<CfnDashboard.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * The field wells of a tree map.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapfieldwells.html
     */
    interface TreeMapFieldWellsProperty {
        /**
         * The aggregated field wells of a tree map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapfieldwells.html#cfn-quicksight-dashboard-treemapfieldwells-treemapaggregatedfieldwells
         */
        readonly treeMapAggregatedFieldWells?: cdk.IResolvable | CfnDashboard.TreeMapAggregatedFieldWellsProperty;
    }
    /**
     * Aggregated field wells of a tree map.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapaggregatedfieldwells.html
     */
    interface TreeMapAggregatedFieldWellsProperty {
        /**
         * The color field well of a tree map.
         *
         * Values are grouped by aggregations based on group by fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapaggregatedfieldwells.html#cfn-quicksight-dashboard-treemapaggregatedfieldwells-colors
         */
        readonly colors?: Array<cdk.IResolvable | CfnDashboard.MeasureFieldProperty> | cdk.IResolvable;
        /**
         * The group by field well of a tree map.
         *
         * Values are grouped based on group by fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapaggregatedfieldwells.html#cfn-quicksight-dashboard-treemapaggregatedfieldwells-groups
         */
        readonly groups?: Array<CfnDashboard.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The size field well of a tree map.
         *
         * Values are aggregated based on group by fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapaggregatedfieldwells.html#cfn-quicksight-dashboard-treemapaggregatedfieldwells-sizes
         */
        readonly sizes?: Array<cdk.IResolvable | CfnDashboard.MeasureFieldProperty> | cdk.IResolvable;
    }
    /**
     * A combo chart.
     *
     * The `ComboChartVisual` includes stacked bar combo charts and clustered bar combo charts
     *
     * For more information, see [Using combo charts](https://docs.aws.amazon.com/quicksight/latest/user/combo-charts.html) in the *Amazon QuickSight User Guide* .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartvisual.html
     */
    interface ComboChartVisualProperty {
        /**
         * The list of custom actions that are configured for a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartvisual.html#cfn-quicksight-dashboard-combochartvisual-actions
         */
        readonly actions?: Array<cdk.IResolvable | CfnDashboard.VisualCustomActionProperty> | cdk.IResolvable;
        /**
         * The configuration settings of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartvisual.html#cfn-quicksight-dashboard-combochartvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnDashboard.ComboChartConfigurationProperty | cdk.IResolvable;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartvisual.html#cfn-quicksight-dashboard-combochartvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnDashboard.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The subtitle that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartvisual.html#cfn-quicksight-dashboard-combochartvisual-subtitle
         */
        readonly subtitle?: cdk.IResolvable | CfnDashboard.VisualSubtitleLabelOptionsProperty;
        /**
         * The title that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartvisual.html#cfn-quicksight-dashboard-combochartvisual-title
         */
        readonly title?: cdk.IResolvable | CfnDashboard.VisualTitleLabelOptionsProperty;
        /**
         * The unique identifier of a visual.
         *
         * This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartvisual.html#cfn-quicksight-dashboard-combochartvisual-visualid
         */
        readonly visualId: string;
    }
    /**
     * The configuration of a `ComboChartVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html
     */
    interface ComboChartConfigurationProperty {
        /**
         * The options that determine if visual data labels are displayed.
         *
         * The data label options for a bar in a combo chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-bardatalabels
         */
        readonly barDataLabels?: CfnDashboard.DataLabelOptionsProperty | cdk.IResolvable;
        /**
         * Determines the bar arrangement in a combo chart. The following are valid values in this structure:.
         *
         * - `CLUSTERED` : For clustered bar combo charts.
         * - `STACKED` : For stacked bar combo charts.
         * - `STACKED_PERCENT` : Do not use. If you use this value, the operation returns a validation error.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-barsarrangement
         */
        readonly barsArrangement?: string;
        /**
         * The category axis of a combo chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-categoryaxis
         */
        readonly categoryAxis?: CfnDashboard.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * The label options (label text, label visibility, and sort icon visibility) of a combo chart category (group/color) field well.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-categorylabeloptions
         */
        readonly categoryLabelOptions?: CfnDashboard.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The label options (label text, label visibility, and sort icon visibility) of a combo chart's color field well.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-colorlabeloptions
         */
        readonly colorLabelOptions?: CfnDashboard.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The field wells of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-fieldwells
         */
        readonly fieldWells?: CfnDashboard.ComboChartFieldWellsProperty | cdk.IResolvable;
        /**
         * The legend display setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-legend
         */
        readonly legend?: cdk.IResolvable | CfnDashboard.LegendOptionsProperty;
        /**
         * The options that determine if visual data labels are displayed.
         *
         * The data label options for a line in a combo chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-linedatalabels
         */
        readonly lineDataLabels?: CfnDashboard.DataLabelOptionsProperty | cdk.IResolvable;
        /**
         * The label display options (grid line, range, scale, and axis step) of a combo chart's primary y-axis (bar) field well.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-primaryyaxisdisplayoptions
         */
        readonly primaryYAxisDisplayOptions?: CfnDashboard.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * The label options (label text, label visibility, and sort icon visibility) of a combo chart's primary y-axis (bar) field well.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-primaryyaxislabeloptions
         */
        readonly primaryYAxisLabelOptions?: CfnDashboard.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The reference line setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-referencelines
         */
        readonly referenceLines?: Array<cdk.IResolvable | CfnDashboard.ReferenceLineProperty> | cdk.IResolvable;
        /**
         * The label display options (grid line, range, scale, axis step) of a combo chart's secondary y-axis (line) field well.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-secondaryyaxisdisplayoptions
         */
        readonly secondaryYAxisDisplayOptions?: CfnDashboard.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * The label options (label text, label visibility, and sort icon visibility) of a combo chart's secondary y-axis(line) field well.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-secondaryyaxislabeloptions
         */
        readonly secondaryYAxisLabelOptions?: CfnDashboard.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The sort configuration of a `ComboChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: CfnDashboard.ComboChartSortConfigurationProperty | cdk.IResolvable;
        /**
         * The legend display setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-tooltip
         */
        readonly tooltip?: cdk.IResolvable | CfnDashboard.TooltipOptionsProperty;
        /**
         * The palette (chart color) display setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-visualpalette
         */
        readonly visualPalette?: cdk.IResolvable | CfnDashboard.VisualPaletteProperty;
    }
    /**
     * The sort configuration of a `ComboChartVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartsortconfiguration.html
     */
    interface ComboChartSortConfigurationProperty {
        /**
         * The item limit configuration for the category field well of a combo chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartsortconfiguration.html#cfn-quicksight-dashboard-combochartsortconfiguration-categoryitemslimit
         */
        readonly categoryItemsLimit?: cdk.IResolvable | CfnDashboard.ItemsLimitConfigurationProperty;
        /**
         * The sort configuration of the category field well in a combo chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartsortconfiguration.html#cfn-quicksight-dashboard-combochartsortconfiguration-categorysort
         */
        readonly categorySort?: Array<CfnDashboard.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The item limit configuration of the color field well in a combo chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartsortconfiguration.html#cfn-quicksight-dashboard-combochartsortconfiguration-coloritemslimit
         */
        readonly colorItemsLimit?: cdk.IResolvable | CfnDashboard.ItemsLimitConfigurationProperty;
        /**
         * The sort configuration of the color field well in a combo chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartsortconfiguration.html#cfn-quicksight-dashboard-combochartsortconfiguration-colorsort
         */
        readonly colorSort?: Array<CfnDashboard.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * The field wells of the visual.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartfieldwells.html
     */
    interface ComboChartFieldWellsProperty {
        /**
         * The aggregated field wells of a combo chart.
         *
         * Combo charts only have aggregated field wells. Columns in a combo chart are aggregated by category.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartfieldwells.html#cfn-quicksight-dashboard-combochartfieldwells-combochartaggregatedfieldwells
         */
        readonly comboChartAggregatedFieldWells?: CfnDashboard.ComboChartAggregatedFieldWellsProperty | cdk.IResolvable;
    }
    /**
     * The aggregated field wells of a combo chart.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartaggregatedfieldwells.html
     */
    interface ComboChartAggregatedFieldWellsProperty {
        /**
         * The aggregated `BarValues` field well of a combo chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartaggregatedfieldwells.html#cfn-quicksight-dashboard-combochartaggregatedfieldwells-barvalues
         */
        readonly barValues?: Array<cdk.IResolvable | CfnDashboard.MeasureFieldProperty> | cdk.IResolvable;
        /**
         * The aggregated category field wells of a combo chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartaggregatedfieldwells.html#cfn-quicksight-dashboard-combochartaggregatedfieldwells-category
         */
        readonly category?: Array<CfnDashboard.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The aggregated colors field well of a combo chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartaggregatedfieldwells.html#cfn-quicksight-dashboard-combochartaggregatedfieldwells-colors
         */
        readonly colors?: Array<CfnDashboard.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The aggregated `LineValues` field well of a combo chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartaggregatedfieldwells.html#cfn-quicksight-dashboard-combochartaggregatedfieldwells-linevalues
         */
        readonly lineValues?: Array<cdk.IResolvable | CfnDashboard.MeasureFieldProperty> | cdk.IResolvable;
    }
    /**
     * A word cloud.
     *
     * For more information, see [Using word clouds](https://docs.aws.amazon.com/quicksight/latest/user/word-cloud.html) in the *Amazon QuickSight User Guide* .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudvisual.html
     */
    interface WordCloudVisualProperty {
        /**
         * The list of custom actions that are configured for a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudvisual.html#cfn-quicksight-dashboard-wordcloudvisual-actions
         */
        readonly actions?: Array<cdk.IResolvable | CfnDashboard.VisualCustomActionProperty> | cdk.IResolvable;
        /**
         * The configuration settings of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudvisual.html#cfn-quicksight-dashboard-wordcloudvisual-chartconfiguration
         */
        readonly chartConfiguration?: cdk.IResolvable | CfnDashboard.WordCloudChartConfigurationProperty;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudvisual.html#cfn-quicksight-dashboard-wordcloudvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnDashboard.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The subtitle that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudvisual.html#cfn-quicksight-dashboard-wordcloudvisual-subtitle
         */
        readonly subtitle?: cdk.IResolvable | CfnDashboard.VisualSubtitleLabelOptionsProperty;
        /**
         * The title that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudvisual.html#cfn-quicksight-dashboard-wordcloudvisual-title
         */
        readonly title?: cdk.IResolvable | CfnDashboard.VisualTitleLabelOptionsProperty;
        /**
         * The unique identifier of a visual.
         *
         * This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudvisual.html#cfn-quicksight-dashboard-wordcloudvisual-visualid
         */
        readonly visualId: string;
    }
    /**
     * The configuration of a word cloud visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudchartconfiguration.html
     */
    interface WordCloudChartConfigurationProperty {
        /**
         * The label options (label text, label visibility, and sort icon visibility) for the word cloud category.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudchartconfiguration.html#cfn-quicksight-dashboard-wordcloudchartconfiguration-categorylabeloptions
         */
        readonly categoryLabelOptions?: CfnDashboard.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The field wells of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudchartconfiguration.html#cfn-quicksight-dashboard-wordcloudchartconfiguration-fieldwells
         */
        readonly fieldWells?: cdk.IResolvable | CfnDashboard.WordCloudFieldWellsProperty;
        /**
         * The sort configuration of a word cloud visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudchartconfiguration.html#cfn-quicksight-dashboard-wordcloudchartconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: cdk.IResolvable | CfnDashboard.WordCloudSortConfigurationProperty;
        /**
         * The options for a word cloud visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudchartconfiguration.html#cfn-quicksight-dashboard-wordcloudchartconfiguration-wordcloudoptions
         */
        readonly wordCloudOptions?: cdk.IResolvable | CfnDashboard.WordCloudOptionsProperty;
    }
    /**
     * The sort configuration of a word cloud visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudsortconfiguration.html
     */
    interface WordCloudSortConfigurationProperty {
        /**
         * The limit on the number of groups that are displayed in a word cloud.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudsortconfiguration.html#cfn-quicksight-dashboard-wordcloudsortconfiguration-categoryitemslimit
         */
        readonly categoryItemsLimit?: cdk.IResolvable | CfnDashboard.ItemsLimitConfigurationProperty;
        /**
         * The sort configuration of group by fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudsortconfiguration.html#cfn-quicksight-dashboard-wordcloudsortconfiguration-categorysort
         */
        readonly categorySort?: Array<CfnDashboard.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * The field wells of a word cloud visual.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudfieldwells.html
     */
    interface WordCloudFieldWellsProperty {
        /**
         * The aggregated field wells of a word cloud.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudfieldwells.html#cfn-quicksight-dashboard-wordcloudfieldwells-wordcloudaggregatedfieldwells
         */
        readonly wordCloudAggregatedFieldWells?: cdk.IResolvable | CfnDashboard.WordCloudAggregatedFieldWellsProperty;
    }
    /**
     * The aggregated field wells of a word cloud.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudaggregatedfieldwells.html
     */
    interface WordCloudAggregatedFieldWellsProperty {
        /**
         * The group by field well of a word cloud.
         *
         * Values are grouped by group by fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudaggregatedfieldwells.html#cfn-quicksight-dashboard-wordcloudaggregatedfieldwells-groupby
         */
        readonly groupBy?: Array<CfnDashboard.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The size field well of a word cloud.
         *
         * Values are aggregated based on group by fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudaggregatedfieldwells.html#cfn-quicksight-dashboard-wordcloudaggregatedfieldwells-size
         */
        readonly size?: Array<cdk.IResolvable | CfnDashboard.MeasureFieldProperty> | cdk.IResolvable;
    }
    /**
     * The word cloud options for a word cloud visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudoptions.html
     */
    interface WordCloudOptionsProperty {
        /**
         * The cloud layout options (fluid, normal) of a word cloud.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudoptions.html#cfn-quicksight-dashboard-wordcloudoptions-cloudlayout
         */
        readonly cloudLayout?: string;
        /**
         * The length limit of each word from 1-100.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudoptions.html#cfn-quicksight-dashboard-wordcloudoptions-maximumstringlength
         */
        readonly maximumStringLength?: number;
        /**
         * The word casing options (lower_case, existing_case) for the words in a word cloud.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudoptions.html#cfn-quicksight-dashboard-wordcloudoptions-wordcasing
         */
        readonly wordCasing?: string;
        /**
         * The word orientation options (horizontal, horizontal_and_vertical) for the words in a word cloud.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudoptions.html#cfn-quicksight-dashboard-wordcloudoptions-wordorientation
         */
        readonly wordOrientation?: string;
        /**
         * The word padding options (none, small, medium, large) for the words in a word cloud.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudoptions.html#cfn-quicksight-dashboard-wordcloudoptions-wordpadding
         */
        readonly wordPadding?: string;
        /**
         * The word scaling options (emphasize, normal) for the words in a word cloud.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudoptions.html#cfn-quicksight-dashboard-wordcloudoptions-wordscaling
         */
        readonly wordScaling?: string;
    }
    /**
     * An insight visual.
     *
     * For more information, see [Working with insights](https://docs.aws.amazon.com/quicksight/latest/user/computational-insights.html) in the *Amazon QuickSight User Guide* .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-insightvisual.html
     */
    interface InsightVisualProperty {
        /**
         * The list of custom actions that are configured for a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-insightvisual.html#cfn-quicksight-dashboard-insightvisual-actions
         */
        readonly actions?: Array<cdk.IResolvable | CfnDashboard.VisualCustomActionProperty> | cdk.IResolvable;
        /**
         * The dataset that is used in the insight visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-insightvisual.html#cfn-quicksight-dashboard-insightvisual-datasetidentifier
         */
        readonly dataSetIdentifier: string;
        /**
         * The configuration of an insight visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-insightvisual.html#cfn-quicksight-dashboard-insightvisual-insightconfiguration
         */
        readonly insightConfiguration?: CfnDashboard.InsightConfigurationProperty | cdk.IResolvable;
        /**
         * The subtitle that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-insightvisual.html#cfn-quicksight-dashboard-insightvisual-subtitle
         */
        readonly subtitle?: cdk.IResolvable | CfnDashboard.VisualSubtitleLabelOptionsProperty;
        /**
         * The title that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-insightvisual.html#cfn-quicksight-dashboard-insightvisual-title
         */
        readonly title?: cdk.IResolvable | CfnDashboard.VisualTitleLabelOptionsProperty;
        /**
         * The unique identifier of a visual.
         *
         * This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-insightvisual.html#cfn-quicksight-dashboard-insightvisual-visualid
         */
        readonly visualId: string;
    }
    /**
     * The configuration of an insight visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-insightconfiguration.html
     */
    interface InsightConfigurationProperty {
        /**
         * The computations configurations of the insight visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-insightconfiguration.html#cfn-quicksight-dashboard-insightconfiguration-computations
         */
        readonly computations?: Array<CfnDashboard.ComputationProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The custom narrative of the insight visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-insightconfiguration.html#cfn-quicksight-dashboard-insightconfiguration-customnarrative
         */
        readonly customNarrative?: CfnDashboard.CustomNarrativeOptionsProperty | cdk.IResolvable;
    }
    /**
     * The computation union that is used in an insight visual.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-computation.html
     */
    interface ComputationProperty {
        /**
         * The forecast computation configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-computation.html#cfn-quicksight-dashboard-computation-forecast
         */
        readonly forecast?: CfnDashboard.ForecastComputationProperty | cdk.IResolvable;
        /**
         * The growth rate computation configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-computation.html#cfn-quicksight-dashboard-computation-growthrate
         */
        readonly growthRate?: CfnDashboard.GrowthRateComputationProperty | cdk.IResolvable;
        /**
         * The maximum and minimum computation configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-computation.html#cfn-quicksight-dashboard-computation-maximumminimum
         */
        readonly maximumMinimum?: cdk.IResolvable | CfnDashboard.MaximumMinimumComputationProperty;
        /**
         * The metric comparison computation configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-computation.html#cfn-quicksight-dashboard-computation-metriccomparison
         */
        readonly metricComparison?: cdk.IResolvable | CfnDashboard.MetricComparisonComputationProperty;
        /**
         * The period over period computation configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-computation.html#cfn-quicksight-dashboard-computation-periodoverperiod
         */
        readonly periodOverPeriod?: cdk.IResolvable | CfnDashboard.PeriodOverPeriodComputationProperty;
        /**
         * The period to `DataSetIdentifier` computation configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-computation.html#cfn-quicksight-dashboard-computation-periodtodate
         */
        readonly periodToDate?: cdk.IResolvable | CfnDashboard.PeriodToDateComputationProperty;
        /**
         * The top movers and bottom movers computation configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-computation.html#cfn-quicksight-dashboard-computation-topbottommovers
         */
        readonly topBottomMovers?: cdk.IResolvable | CfnDashboard.TopBottomMoversComputationProperty;
        /**
         * The top ranked and bottom ranked computation configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-computation.html#cfn-quicksight-dashboard-computation-topbottomranked
         */
        readonly topBottomRanked?: cdk.IResolvable | CfnDashboard.TopBottomRankedComputationProperty;
        /**
         * The total aggregation computation configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-computation.html#cfn-quicksight-dashboard-computation-totalaggregation
         */
        readonly totalAggregation?: cdk.IResolvable | CfnDashboard.TotalAggregationComputationProperty;
        /**
         * The unique values computation configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-computation.html#cfn-quicksight-dashboard-computation-uniquevalues
         */
        readonly uniqueValues?: cdk.IResolvable | CfnDashboard.UniqueValuesComputationProperty;
    }
    /**
     * The period to date computation configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-periodtodatecomputation.html
     */
    interface PeriodToDateComputationProperty {
        /**
         * The ID for a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-periodtodatecomputation.html#cfn-quicksight-dashboard-periodtodatecomputation-computationid
         */
        readonly computationId: string;
        /**
         * The name of a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-periodtodatecomputation.html#cfn-quicksight-dashboard-periodtodatecomputation-name
         */
        readonly name?: string;
        /**
         * The time granularity setup of period to date computation. Choose from the following options:.
         *
         * - YEAR: Year to date.
         * - MONTH: Month to date.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-periodtodatecomputation.html#cfn-quicksight-dashboard-periodtodatecomputation-periodtimegranularity
         */
        readonly periodTimeGranularity?: string;
        /**
         * The time field that is used in a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-periodtodatecomputation.html#cfn-quicksight-dashboard-periodtodatecomputation-time
         */
        readonly time?: CfnDashboard.DimensionFieldProperty | cdk.IResolvable;
        /**
         * The value field that is used in a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-periodtodatecomputation.html#cfn-quicksight-dashboard-periodtodatecomputation-value
         */
        readonly value?: cdk.IResolvable | CfnDashboard.MeasureFieldProperty;
    }
    /**
     * The growth rate computation configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-growthratecomputation.html
     */
    interface GrowthRateComputationProperty {
        /**
         * The ID for a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-growthratecomputation.html#cfn-quicksight-dashboard-growthratecomputation-computationid
         */
        readonly computationId: string;
        /**
         * The name of a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-growthratecomputation.html#cfn-quicksight-dashboard-growthratecomputation-name
         */
        readonly name?: string;
        /**
         * The period size setup of a growth rate computation.
         *
         * @default - 0
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-growthratecomputation.html#cfn-quicksight-dashboard-growthratecomputation-periodsize
         */
        readonly periodSize?: number;
        /**
         * The time field that is used in a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-growthratecomputation.html#cfn-quicksight-dashboard-growthratecomputation-time
         */
        readonly time?: CfnDashboard.DimensionFieldProperty | cdk.IResolvable;
        /**
         * The value field that is used in a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-growthratecomputation.html#cfn-quicksight-dashboard-growthratecomputation-value
         */
        readonly value?: cdk.IResolvable | CfnDashboard.MeasureFieldProperty;
    }
    /**
     * The top ranked and bottom ranked computation configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottomrankedcomputation.html
     */
    interface TopBottomRankedComputationProperty {
        /**
         * The category field that is used in a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottomrankedcomputation.html#cfn-quicksight-dashboard-topbottomrankedcomputation-category
         */
        readonly category?: CfnDashboard.DimensionFieldProperty | cdk.IResolvable;
        /**
         * The ID for a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottomrankedcomputation.html#cfn-quicksight-dashboard-topbottomrankedcomputation-computationid
         */
        readonly computationId: string;
        /**
         * The name of a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottomrankedcomputation.html#cfn-quicksight-dashboard-topbottomrankedcomputation-name
         */
        readonly name?: string;
        /**
         * The result size of a top and bottom ranked computation.
         *
         * @default - 0
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottomrankedcomputation.html#cfn-quicksight-dashboard-topbottomrankedcomputation-resultsize
         */
        readonly resultSize?: number;
        /**
         * The computation type. Choose one of the following options:.
         *
         * - TOP: A top ranked computation.
         * - BOTTOM: A bottom ranked computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottomrankedcomputation.html#cfn-quicksight-dashboard-topbottomrankedcomputation-type
         */
        readonly type: string;
        /**
         * The value field that is used in a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottomrankedcomputation.html#cfn-quicksight-dashboard-topbottomrankedcomputation-value
         */
        readonly value?: cdk.IResolvable | CfnDashboard.MeasureFieldProperty;
    }
    /**
     * The total aggregation computation configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-totalaggregationcomputation.html
     */
    interface TotalAggregationComputationProperty {
        /**
         * The ID for a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-totalaggregationcomputation.html#cfn-quicksight-dashboard-totalaggregationcomputation-computationid
         */
        readonly computationId: string;
        /**
         * The name of a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-totalaggregationcomputation.html#cfn-quicksight-dashboard-totalaggregationcomputation-name
         */
        readonly name?: string;
        /**
         * The value field that is used in a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-totalaggregationcomputation.html#cfn-quicksight-dashboard-totalaggregationcomputation-value
         */
        readonly value?: cdk.IResolvable | CfnDashboard.MeasureFieldProperty;
    }
    /**
     * The forecast computation configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastcomputation.html
     */
    interface ForecastComputationProperty {
        /**
         * The ID for a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastcomputation.html#cfn-quicksight-dashboard-forecastcomputation-computationid
         */
        readonly computationId: string;
        /**
         * The custom seasonality value setup of a forecast computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastcomputation.html#cfn-quicksight-dashboard-forecastcomputation-customseasonalityvalue
         */
        readonly customSeasonalityValue?: number;
        /**
         * The lower boundary setup of a forecast computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastcomputation.html#cfn-quicksight-dashboard-forecastcomputation-lowerboundary
         */
        readonly lowerBoundary?: number;
        /**
         * The name of a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastcomputation.html#cfn-quicksight-dashboard-forecastcomputation-name
         */
        readonly name?: string;
        /**
         * The periods backward setup of a forecast computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastcomputation.html#cfn-quicksight-dashboard-forecastcomputation-periodsbackward
         */
        readonly periodsBackward?: number;
        /**
         * The periods forward setup of a forecast computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastcomputation.html#cfn-quicksight-dashboard-forecastcomputation-periodsforward
         */
        readonly periodsForward?: number;
        /**
         * The prediction interval setup of a forecast computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastcomputation.html#cfn-quicksight-dashboard-forecastcomputation-predictioninterval
         */
        readonly predictionInterval?: number;
        /**
         * The seasonality setup of a forecast computation. Choose one of the following options:.
         *
         * - `AUTOMATIC`
         * - `CUSTOM` : Checks the custom seasonality value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastcomputation.html#cfn-quicksight-dashboard-forecastcomputation-seasonality
         */
        readonly seasonality?: string;
        /**
         * The time field that is used in a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastcomputation.html#cfn-quicksight-dashboard-forecastcomputation-time
         */
        readonly time?: CfnDashboard.DimensionFieldProperty | cdk.IResolvable;
        /**
         * The upper boundary setup of a forecast computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastcomputation.html#cfn-quicksight-dashboard-forecastcomputation-upperboundary
         */
        readonly upperBoundary?: number;
        /**
         * The value field that is used in a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastcomputation.html#cfn-quicksight-dashboard-forecastcomputation-value
         */
        readonly value?: cdk.IResolvable | CfnDashboard.MeasureFieldProperty;
    }
    /**
     * The maximum and minimum computation configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-maximumminimumcomputation.html
     */
    interface MaximumMinimumComputationProperty {
        /**
         * The ID for a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-maximumminimumcomputation.html#cfn-quicksight-dashboard-maximumminimumcomputation-computationid
         */
        readonly computationId: string;
        /**
         * The name of a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-maximumminimumcomputation.html#cfn-quicksight-dashboard-maximumminimumcomputation-name
         */
        readonly name?: string;
        /**
         * The time field that is used in a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-maximumminimumcomputation.html#cfn-quicksight-dashboard-maximumminimumcomputation-time
         */
        readonly time?: CfnDashboard.DimensionFieldProperty | cdk.IResolvable;
        /**
         * The type of computation. Choose one of the following options:.
         *
         * - MAXIMUM: A maximum computation.
         * - MINIMUM: A minimum computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-maximumminimumcomputation.html#cfn-quicksight-dashboard-maximumminimumcomputation-type
         */
        readonly type: string;
        /**
         * The value field that is used in a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-maximumminimumcomputation.html#cfn-quicksight-dashboard-maximumminimumcomputation-value
         */
        readonly value?: cdk.IResolvable | CfnDashboard.MeasureFieldProperty;
    }
    /**
     * The period over period computation configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-periodoverperiodcomputation.html
     */
    interface PeriodOverPeriodComputationProperty {
        /**
         * The ID for a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-periodoverperiodcomputation.html#cfn-quicksight-dashboard-periodoverperiodcomputation-computationid
         */
        readonly computationId: string;
        /**
         * The name of a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-periodoverperiodcomputation.html#cfn-quicksight-dashboard-periodoverperiodcomputation-name
         */
        readonly name?: string;
        /**
         * The time field that is used in a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-periodoverperiodcomputation.html#cfn-quicksight-dashboard-periodoverperiodcomputation-time
         */
        readonly time?: CfnDashboard.DimensionFieldProperty | cdk.IResolvable;
        /**
         * The value field that is used in a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-periodoverperiodcomputation.html#cfn-quicksight-dashboard-periodoverperiodcomputation-value
         */
        readonly value?: cdk.IResolvable | CfnDashboard.MeasureFieldProperty;
    }
    /**
     * The metric comparison computation configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-metriccomparisoncomputation.html
     */
    interface MetricComparisonComputationProperty {
        /**
         * The ID for a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-metriccomparisoncomputation.html#cfn-quicksight-dashboard-metriccomparisoncomputation-computationid
         */
        readonly computationId: string;
        /**
         * The field that is used in a metric comparison from value setup.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-metriccomparisoncomputation.html#cfn-quicksight-dashboard-metriccomparisoncomputation-fromvalue
         */
        readonly fromValue?: cdk.IResolvable | CfnDashboard.MeasureFieldProperty;
        /**
         * The name of a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-metriccomparisoncomputation.html#cfn-quicksight-dashboard-metriccomparisoncomputation-name
         */
        readonly name?: string;
        /**
         * The field that is used in a metric comparison to value setup.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-metriccomparisoncomputation.html#cfn-quicksight-dashboard-metriccomparisoncomputation-targetvalue
         */
        readonly targetValue?: cdk.IResolvable | CfnDashboard.MeasureFieldProperty;
        /**
         * The time field that is used in a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-metriccomparisoncomputation.html#cfn-quicksight-dashboard-metriccomparisoncomputation-time
         */
        readonly time?: CfnDashboard.DimensionFieldProperty | cdk.IResolvable;
    }
    /**
     * The top movers and bottom movers computation setup.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottommoverscomputation.html
     */
    interface TopBottomMoversComputationProperty {
        /**
         * The category field that is used in a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottommoverscomputation.html#cfn-quicksight-dashboard-topbottommoverscomputation-category
         */
        readonly category?: CfnDashboard.DimensionFieldProperty | cdk.IResolvable;
        /**
         * The ID for a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottommoverscomputation.html#cfn-quicksight-dashboard-topbottommoverscomputation-computationid
         */
        readonly computationId: string;
        /**
         * The mover size setup of the top and bottom movers computation.
         *
         * @default - 0
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottommoverscomputation.html#cfn-quicksight-dashboard-topbottommoverscomputation-moversize
         */
        readonly moverSize?: number;
        /**
         * The name of a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottommoverscomputation.html#cfn-quicksight-dashboard-topbottommoverscomputation-name
         */
        readonly name?: string;
        /**
         * The sort order setup of the top and bottom movers computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottommoverscomputation.html#cfn-quicksight-dashboard-topbottommoverscomputation-sortorder
         */
        readonly sortOrder?: string;
        /**
         * The time field that is used in a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottommoverscomputation.html#cfn-quicksight-dashboard-topbottommoverscomputation-time
         */
        readonly time?: CfnDashboard.DimensionFieldProperty | cdk.IResolvable;
        /**
         * The computation type. Choose from the following options:.
         *
         * - TOP: Top movers computation.
         * - BOTTOM: Bottom movers computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottommoverscomputation.html#cfn-quicksight-dashboard-topbottommoverscomputation-type
         */
        readonly type: string;
        /**
         * The value field that is used in a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottommoverscomputation.html#cfn-quicksight-dashboard-topbottommoverscomputation-value
         */
        readonly value?: cdk.IResolvable | CfnDashboard.MeasureFieldProperty;
    }
    /**
     * The unique values computation configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-uniquevaluescomputation.html
     */
    interface UniqueValuesComputationProperty {
        /**
         * The category field that is used in a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-uniquevaluescomputation.html#cfn-quicksight-dashboard-uniquevaluescomputation-category
         */
        readonly category?: CfnDashboard.DimensionFieldProperty | cdk.IResolvable;
        /**
         * The ID for a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-uniquevaluescomputation.html#cfn-quicksight-dashboard-uniquevaluescomputation-computationid
         */
        readonly computationId: string;
        /**
         * The name of a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-uniquevaluescomputation.html#cfn-quicksight-dashboard-uniquevaluescomputation-name
         */
        readonly name?: string;
    }
    /**
     * The custom narrative options.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customnarrativeoptions.html
     */
    interface CustomNarrativeOptionsProperty {
        /**
         * The string input of custom narrative.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customnarrativeoptions.html#cfn-quicksight-dashboard-customnarrativeoptions-narrative
         */
        readonly narrative: string;
    }
    /**
     * A sankey diagram.
     *
     * For more information, see [Using Sankey diagrams](https://docs.aws.amazon.com/quicksight/latest/user/sankey-diagram.html) in the *Amazon QuickSight User Guide* .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramvisual.html
     */
    interface SankeyDiagramVisualProperty {
        /**
         * The list of custom actions that are configured for a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramvisual.html#cfn-quicksight-dashboard-sankeydiagramvisual-actions
         */
        readonly actions?: Array<cdk.IResolvable | CfnDashboard.VisualCustomActionProperty> | cdk.IResolvable;
        /**
         * The configuration of a sankey diagram.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramvisual.html#cfn-quicksight-dashboard-sankeydiagramvisual-chartconfiguration
         */
        readonly chartConfiguration?: cdk.IResolvable | CfnDashboard.SankeyDiagramChartConfigurationProperty;
        /**
         * The subtitle that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramvisual.html#cfn-quicksight-dashboard-sankeydiagramvisual-subtitle
         */
        readonly subtitle?: cdk.IResolvable | CfnDashboard.VisualSubtitleLabelOptionsProperty;
        /**
         * The title that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramvisual.html#cfn-quicksight-dashboard-sankeydiagramvisual-title
         */
        readonly title?: cdk.IResolvable | CfnDashboard.VisualTitleLabelOptionsProperty;
        /**
         * The unique identifier of a visual.
         *
         * This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramvisual.html#cfn-quicksight-dashboard-sankeydiagramvisual-visualid
         */
        readonly visualId: string;
    }
    /**
     * The configuration of a sankey diagram.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramchartconfiguration.html
     */
    interface SankeyDiagramChartConfigurationProperty {
        /**
         * The data label configuration of a sankey diagram.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramchartconfiguration.html#cfn-quicksight-dashboard-sankeydiagramchartconfiguration-datalabels
         */
        readonly dataLabels?: CfnDashboard.DataLabelOptionsProperty | cdk.IResolvable;
        /**
         * The field well configuration of a sankey diagram.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramchartconfiguration.html#cfn-quicksight-dashboard-sankeydiagramchartconfiguration-fieldwells
         */
        readonly fieldWells?: cdk.IResolvable | CfnDashboard.SankeyDiagramFieldWellsProperty;
        /**
         * The sort configuration of a sankey diagram.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramchartconfiguration.html#cfn-quicksight-dashboard-sankeydiagramchartconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: cdk.IResolvable | CfnDashboard.SankeyDiagramSortConfigurationProperty;
    }
    /**
     * The sort configuration of a sankey diagram.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramsortconfiguration.html
     */
    interface SankeyDiagramSortConfigurationProperty {
        /**
         * The limit on the number of destination nodes that are displayed in a sankey diagram.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramsortconfiguration.html#cfn-quicksight-dashboard-sankeydiagramsortconfiguration-destinationitemslimit
         */
        readonly destinationItemsLimit?: cdk.IResolvable | CfnDashboard.ItemsLimitConfigurationProperty;
        /**
         * The limit on the number of source nodes that are displayed in a sankey diagram.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramsortconfiguration.html#cfn-quicksight-dashboard-sankeydiagramsortconfiguration-sourceitemslimit
         */
        readonly sourceItemsLimit?: cdk.IResolvable | CfnDashboard.ItemsLimitConfigurationProperty;
        /**
         * The sort configuration of the weight fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramsortconfiguration.html#cfn-quicksight-dashboard-sankeydiagramsortconfiguration-weightsort
         */
        readonly weightSort?: Array<CfnDashboard.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * The field well configuration of a sankey diagram.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramfieldwells.html
     */
    interface SankeyDiagramFieldWellsProperty {
        /**
         * The field well configuration of a sankey diagram.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramfieldwells.html#cfn-quicksight-dashboard-sankeydiagramfieldwells-sankeydiagramaggregatedfieldwells
         */
        readonly sankeyDiagramAggregatedFieldWells?: cdk.IResolvable | CfnDashboard.SankeyDiagramAggregatedFieldWellsProperty;
    }
    /**
     * The field well configuration of a sankey diagram.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramaggregatedfieldwells.html
     */
    interface SankeyDiagramAggregatedFieldWellsProperty {
        /**
         * The destination field wells of a sankey diagram.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramaggregatedfieldwells.html#cfn-quicksight-dashboard-sankeydiagramaggregatedfieldwells-destination
         */
        readonly destination?: Array<CfnDashboard.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The source field wells of a sankey diagram.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramaggregatedfieldwells.html#cfn-quicksight-dashboard-sankeydiagramaggregatedfieldwells-source
         */
        readonly source?: Array<CfnDashboard.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The weight field wells of a sankey diagram.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramaggregatedfieldwells.html#cfn-quicksight-dashboard-sankeydiagramaggregatedfieldwells-weight
         */
        readonly weight?: Array<cdk.IResolvable | CfnDashboard.MeasureFieldProperty> | cdk.IResolvable;
    }
    /**
     * A gauge chart.
     *
     * For more information, see [Using gauge charts](https://docs.aws.amazon.com/quicksight/latest/user/gauge-chart.html) in the *Amazon QuickSight User Guide* .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartvisual.html
     */
    interface GaugeChartVisualProperty {
        /**
         * The list of custom actions that are configured for a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartvisual.html#cfn-quicksight-dashboard-gaugechartvisual-actions
         */
        readonly actions?: Array<cdk.IResolvable | CfnDashboard.VisualCustomActionProperty> | cdk.IResolvable;
        /**
         * The configuration of a `GaugeChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartvisual.html#cfn-quicksight-dashboard-gaugechartvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnDashboard.GaugeChartConfigurationProperty | cdk.IResolvable;
        /**
         * The conditional formatting of a `GaugeChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartvisual.html#cfn-quicksight-dashboard-gaugechartvisual-conditionalformatting
         */
        readonly conditionalFormatting?: CfnDashboard.GaugeChartConditionalFormattingProperty | cdk.IResolvable;
        /**
         * The subtitle that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartvisual.html#cfn-quicksight-dashboard-gaugechartvisual-subtitle
         */
        readonly subtitle?: cdk.IResolvable | CfnDashboard.VisualSubtitleLabelOptionsProperty;
        /**
         * The title that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartvisual.html#cfn-quicksight-dashboard-gaugechartvisual-title
         */
        readonly title?: cdk.IResolvable | CfnDashboard.VisualTitleLabelOptionsProperty;
        /**
         * The unique identifier of a visual.
         *
         * This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartvisual.html#cfn-quicksight-dashboard-gaugechartvisual-visualid
         */
        readonly visualId: string;
    }
    /**
     * The conditional formatting of a `GaugeChartVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartconditionalformatting.html
     */
    interface GaugeChartConditionalFormattingProperty {
        /**
         * Conditional formatting options of a `GaugeChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartconditionalformatting.html#cfn-quicksight-dashboard-gaugechartconditionalformatting-conditionalformattingoptions
         */
        readonly conditionalFormattingOptions?: Array<CfnDashboard.GaugeChartConditionalFormattingOptionProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * Conditional formatting options of a `GaugeChartVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartconditionalformattingoption.html
     */
    interface GaugeChartConditionalFormattingOptionProperty {
        /**
         * The options that determine the presentation of the arc of a `GaugeChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartconditionalformattingoption.html#cfn-quicksight-dashboard-gaugechartconditionalformattingoption-arc
         */
        readonly arc?: CfnDashboard.GaugeChartArcConditionalFormattingProperty | cdk.IResolvable;
        /**
         * The conditional formatting for the primary value of a `GaugeChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartconditionalformattingoption.html#cfn-quicksight-dashboard-gaugechartconditionalformattingoption-primaryvalue
         */
        readonly primaryValue?: CfnDashboard.GaugeChartPrimaryValueConditionalFormattingProperty | cdk.IResolvable;
    }
    /**
     * The options that determine the presentation of the arc of a `GaugeChartVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartarcconditionalformatting.html
     */
    interface GaugeChartArcConditionalFormattingProperty {
        /**
         * The conditional formatting of the arc foreground color.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartarcconditionalformatting.html#cfn-quicksight-dashboard-gaugechartarcconditionalformatting-foregroundcolor
         */
        readonly foregroundColor?: CfnDashboard.ConditionalFormattingColorProperty | cdk.IResolvable;
    }
    /**
     * The conditional formatting for the primary value of a `GaugeChartVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartprimaryvalueconditionalformatting.html
     */
    interface GaugeChartPrimaryValueConditionalFormattingProperty {
        /**
         * The conditional formatting of the primary value icon.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartprimaryvalueconditionalformatting.html#cfn-quicksight-dashboard-gaugechartprimaryvalueconditionalformatting-icon
         */
        readonly icon?: CfnDashboard.ConditionalFormattingIconProperty | cdk.IResolvable;
        /**
         * The conditional formatting of the primary value text color.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartprimaryvalueconditionalformatting.html#cfn-quicksight-dashboard-gaugechartprimaryvalueconditionalformatting-textcolor
         */
        readonly textColor?: CfnDashboard.ConditionalFormattingColorProperty | cdk.IResolvable;
    }
    /**
     * The configuration of a `GaugeChartVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartconfiguration.html
     */
    interface GaugeChartConfigurationProperty {
        /**
         * The data label configuration of a `GaugeChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartconfiguration.html#cfn-quicksight-dashboard-gaugechartconfiguration-datalabels
         */
        readonly dataLabels?: CfnDashboard.DataLabelOptionsProperty | cdk.IResolvable;
        /**
         * The field well configuration of a `GaugeChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartconfiguration.html#cfn-quicksight-dashboard-gaugechartconfiguration-fieldwells
         */
        readonly fieldWells?: CfnDashboard.GaugeChartFieldWellsProperty | cdk.IResolvable;
        /**
         * The options that determine the presentation of the `GaugeChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartconfiguration.html#cfn-quicksight-dashboard-gaugechartconfiguration-gaugechartoptions
         */
        readonly gaugeChartOptions?: CfnDashboard.GaugeChartOptionsProperty | cdk.IResolvable;
        /**
         * The tooltip configuration of a `GaugeChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartconfiguration.html#cfn-quicksight-dashboard-gaugechartconfiguration-tooltipoptions
         */
        readonly tooltipOptions?: cdk.IResolvable | CfnDashboard.TooltipOptionsProperty;
        /**
         * The visual palette configuration of a `GaugeChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartconfiguration.html#cfn-quicksight-dashboard-gaugechartconfiguration-visualpalette
         */
        readonly visualPalette?: cdk.IResolvable | CfnDashboard.VisualPaletteProperty;
    }
    /**
     * The field well configuration of a `GaugeChartVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartfieldwells.html
     */
    interface GaugeChartFieldWellsProperty {
        /**
         * The target value field wells of a `GaugeChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartfieldwells.html#cfn-quicksight-dashboard-gaugechartfieldwells-targetvalues
         */
        readonly targetValues?: Array<cdk.IResolvable | CfnDashboard.MeasureFieldProperty> | cdk.IResolvable;
        /**
         * The value field wells of a `GaugeChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartfieldwells.html#cfn-quicksight-dashboard-gaugechartfieldwells-values
         */
        readonly values?: Array<cdk.IResolvable | CfnDashboard.MeasureFieldProperty> | cdk.IResolvable;
    }
    /**
     * The options that determine the presentation of the `GaugeChartVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartoptions.html
     */
    interface GaugeChartOptionsProperty {
        /**
         * The arc configuration of a `GaugeChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartoptions.html#cfn-quicksight-dashboard-gaugechartoptions-arc
         */
        readonly arc?: CfnDashboard.ArcConfigurationProperty | cdk.IResolvable;
        /**
         * The arc axis configuration of a `GaugeChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartoptions.html#cfn-quicksight-dashboard-gaugechartoptions-arcaxis
         */
        readonly arcAxis?: CfnDashboard.ArcAxisConfigurationProperty | cdk.IResolvable;
        /**
         * The comparison configuration of a `GaugeChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartoptions.html#cfn-quicksight-dashboard-gaugechartoptions-comparison
         */
        readonly comparison?: CfnDashboard.ComparisonConfigurationProperty | cdk.IResolvable;
        /**
         * The options that determine the primary value display type.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartoptions.html#cfn-quicksight-dashboard-gaugechartoptions-primaryvaluedisplaytype
         */
        readonly primaryValueDisplayType?: string;
        /**
         * The options that determine the primary value font configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartoptions.html#cfn-quicksight-dashboard-gaugechartoptions-primaryvaluefontconfiguration
         */
        readonly primaryValueFontConfiguration?: CfnDashboard.FontConfigurationProperty | cdk.IResolvable;
    }
    /**
     * The arc configuration of a `GaugeChartVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-arcconfiguration.html
     */
    interface ArcConfigurationProperty {
        /**
         * The option that determines the arc angle of a `GaugeChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-arcconfiguration.html#cfn-quicksight-dashboard-arcconfiguration-arcangle
         */
        readonly arcAngle?: number;
        /**
         * The options that determine the arc thickness of a `GaugeChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-arcconfiguration.html#cfn-quicksight-dashboard-arcconfiguration-arcthickness
         */
        readonly arcThickness?: string;
    }
    /**
     * The arc axis configuration of a `GaugeChartVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-arcaxisconfiguration.html
     */
    interface ArcAxisConfigurationProperty {
        /**
         * The arc axis range of a `GaugeChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-arcaxisconfiguration.html#cfn-quicksight-dashboard-arcaxisconfiguration-range
         */
        readonly range?: CfnDashboard.ArcAxisDisplayRangeProperty | cdk.IResolvable;
        /**
         * The reserved range of the arc axis.
         *
         * @default - 0
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-arcaxisconfiguration.html#cfn-quicksight-dashboard-arcaxisconfiguration-reserverange
         */
        readonly reserveRange?: number;
    }
    /**
     * The arc axis range of a `GaugeChartVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-arcaxisdisplayrange.html
     */
    interface ArcAxisDisplayRangeProperty {
        /**
         * The maximum value of the arc axis range.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-arcaxisdisplayrange.html#cfn-quicksight-dashboard-arcaxisdisplayrange-max
         */
        readonly max?: number;
        /**
         * The minimum value of the arc axis range.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-arcaxisdisplayrange.html#cfn-quicksight-dashboard-arcaxisdisplayrange-min
         */
        readonly min?: number;
    }
    /**
     * A line chart.
     *
     * For more information, see [Using line charts](https://docs.aws.amazon.com/quicksight/latest/user/line-charts.html) in the *Amazon QuickSight User Guide* .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartvisual.html
     */
    interface LineChartVisualProperty {
        /**
         * The list of custom actions that are configured for a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartvisual.html#cfn-quicksight-dashboard-linechartvisual-actions
         */
        readonly actions?: Array<cdk.IResolvable | CfnDashboard.VisualCustomActionProperty> | cdk.IResolvable;
        /**
         * The configuration of a line chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartvisual.html#cfn-quicksight-dashboard-linechartvisual-chartconfiguration
         */
        readonly chartConfiguration?: cdk.IResolvable | CfnDashboard.LineChartConfigurationProperty;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartvisual.html#cfn-quicksight-dashboard-linechartvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnDashboard.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The subtitle that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartvisual.html#cfn-quicksight-dashboard-linechartvisual-subtitle
         */
        readonly subtitle?: cdk.IResolvable | CfnDashboard.VisualSubtitleLabelOptionsProperty;
        /**
         * The title that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartvisual.html#cfn-quicksight-dashboard-linechartvisual-title
         */
        readonly title?: cdk.IResolvable | CfnDashboard.VisualTitleLabelOptionsProperty;
        /**
         * The unique identifier of a visual.
         *
         * This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartvisual.html#cfn-quicksight-dashboard-linechartvisual-visualid
         */
        readonly visualId: string;
    }
    /**
     * The configuration of a line chart.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html
     */
    interface LineChartConfigurationProperty {
        /**
         * The default configuration of a line chart's contribution analysis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-contributionanalysisdefaults
         */
        readonly contributionAnalysisDefaults?: Array<CfnDashboard.ContributionAnalysisDefaultProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The data label configuration of a line chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-datalabels
         */
        readonly dataLabels?: CfnDashboard.DataLabelOptionsProperty | cdk.IResolvable;
        /**
         * The options that determine the default presentation of all line series in `LineChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-defaultseriessettings
         */
        readonly defaultSeriesSettings?: cdk.IResolvable | CfnDashboard.LineChartDefaultSeriesSettingsProperty;
        /**
         * The field well configuration of a line chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-fieldwells
         */
        readonly fieldWells?: cdk.IResolvable | CfnDashboard.LineChartFieldWellsProperty;
        /**
         * The forecast configuration of a line chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-forecastconfigurations
         */
        readonly forecastConfigurations?: Array<CfnDashboard.ForecastConfigurationProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The legend configuration of a line chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-legend
         */
        readonly legend?: cdk.IResolvable | CfnDashboard.LegendOptionsProperty;
        /**
         * The series axis configuration of a line chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-primaryyaxisdisplayoptions
         */
        readonly primaryYAxisDisplayOptions?: cdk.IResolvable | CfnDashboard.LineSeriesAxisDisplayOptionsProperty;
        /**
         * The options that determine the presentation of the y-axis label.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-primaryyaxislabeloptions
         */
        readonly primaryYAxisLabelOptions?: CfnDashboard.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The reference lines configuration of a line chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-referencelines
         */
        readonly referenceLines?: Array<cdk.IResolvable | CfnDashboard.ReferenceLineProperty> | cdk.IResolvable;
        /**
         * The series axis configuration of a line chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-secondaryyaxisdisplayoptions
         */
        readonly secondaryYAxisDisplayOptions?: cdk.IResolvable | CfnDashboard.LineSeriesAxisDisplayOptionsProperty;
        /**
         * The options that determine the presentation of the secondary y-axis label.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-secondaryyaxislabeloptions
         */
        readonly secondaryYAxisLabelOptions?: CfnDashboard.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The series item configuration of a line chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-series
         */
        readonly series?: Array<cdk.IResolvable | CfnDashboard.SeriesItemProperty> | cdk.IResolvable;
        /**
         * The small multiples setup for the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-smallmultiplesoptions
         */
        readonly smallMultiplesOptions?: cdk.IResolvable | CfnDashboard.SmallMultiplesOptionsProperty;
        /**
         * The sort configuration of a line chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: cdk.IResolvable | CfnDashboard.LineChartSortConfigurationProperty;
        /**
         * The tooltip configuration of a line chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-tooltip
         */
        readonly tooltip?: cdk.IResolvable | CfnDashboard.TooltipOptionsProperty;
        /**
         * Determines the type of the line chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-type
         */
        readonly type?: string;
        /**
         * The visual palette configuration of a line chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-visualpalette
         */
        readonly visualPalette?: cdk.IResolvable | CfnDashboard.VisualPaletteProperty;
        /**
         * The options that determine the presentation of the x-axis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-xaxisdisplayoptions
         */
        readonly xAxisDisplayOptions?: CfnDashboard.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * The options that determine the presentation of the x-axis label.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-xaxislabeloptions
         */
        readonly xAxisLabelOptions?: CfnDashboard.ChartAxisLabelOptionsProperty | cdk.IResolvable;
    }
    /**
     * The sort configuration of a line chart.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartsortconfiguration.html
     */
    interface LineChartSortConfigurationProperty {
        /**
         * The limit on the number of categories that are displayed in a line chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartsortconfiguration.html#cfn-quicksight-dashboard-linechartsortconfiguration-categoryitemslimitconfiguration
         */
        readonly categoryItemsLimitConfiguration?: cdk.IResolvable | CfnDashboard.ItemsLimitConfigurationProperty;
        /**
         * The sort configuration of the category fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartsortconfiguration.html#cfn-quicksight-dashboard-linechartsortconfiguration-categorysort
         */
        readonly categorySort?: Array<CfnDashboard.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The limit on the number of lines that are displayed in a line chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartsortconfiguration.html#cfn-quicksight-dashboard-linechartsortconfiguration-coloritemslimitconfiguration
         */
        readonly colorItemsLimitConfiguration?: cdk.IResolvable | CfnDashboard.ItemsLimitConfigurationProperty;
        /**
         * The limit on the number of small multiples panels that are displayed.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartsortconfiguration.html#cfn-quicksight-dashboard-linechartsortconfiguration-smallmultipleslimitconfiguration
         */
        readonly smallMultiplesLimitConfiguration?: cdk.IResolvable | CfnDashboard.ItemsLimitConfigurationProperty;
        /**
         * The sort configuration of the small multiples field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartsortconfiguration.html#cfn-quicksight-dashboard-linechartsortconfiguration-smallmultiplessort
         */
        readonly smallMultiplesSort?: Array<CfnDashboard.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * The series axis configuration of a line chart.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-lineseriesaxisdisplayoptions.html
     */
    interface LineSeriesAxisDisplayOptionsProperty {
        /**
         * The options that determine the presentation of the line series axis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-lineseriesaxisdisplayoptions.html#cfn-quicksight-dashboard-lineseriesaxisdisplayoptions-axisoptions
         */
        readonly axisOptions?: CfnDashboard.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * The configuration options that determine how missing data is treated during the rendering of a line chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-lineseriesaxisdisplayoptions.html#cfn-quicksight-dashboard-lineseriesaxisdisplayoptions-missingdataconfigurations
         */
        readonly missingDataConfigurations?: Array<cdk.IResolvable | CfnDashboard.MissingDataConfigurationProperty> | cdk.IResolvable;
    }
    /**
     * The configuration options that determine how missing data is treated during the rendering of a line chart.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-missingdataconfiguration.html
     */
    interface MissingDataConfigurationProperty {
        /**
         * The treatment option that determines how missing data should be rendered. Choose from the following options:.
         *
         * - `INTERPOLATE` : Interpolate missing values between the prior and the next known value.
         * - `SHOW_AS_ZERO` : Show missing values as the value `0` .
         * - `SHOW_AS_BLANK` : Display a blank space when rendering missing data.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-missingdataconfiguration.html#cfn-quicksight-dashboard-missingdataconfiguration-treatmentoption
         */
        readonly treatmentOption?: string;
    }
    /**
     * The options that determine the default presentation of all line series in `LineChartVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartdefaultseriessettings.html
     */
    interface LineChartDefaultSeriesSettingsProperty {
        /**
         * The axis to which you are binding all line series to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartdefaultseriessettings.html#cfn-quicksight-dashboard-linechartdefaultseriessettings-axisbinding
         */
        readonly axisBinding?: string;
        /**
         * Line styles options for all line series in the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartdefaultseriessettings.html#cfn-quicksight-dashboard-linechartdefaultseriessettings-linestylesettings
         */
        readonly lineStyleSettings?: cdk.IResolvable | CfnDashboard.LineChartLineStyleSettingsProperty;
        /**
         * Marker styles options for all line series in the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartdefaultseriessettings.html#cfn-quicksight-dashboard-linechartdefaultseriessettings-markerstylesettings
         */
        readonly markerStyleSettings?: cdk.IResolvable | CfnDashboard.LineChartMarkerStyleSettingsProperty;
    }
    /**
     * Line styles options for a line series in `LineChartVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartlinestylesettings.html
     */
    interface LineChartLineStyleSettingsProperty {
        /**
         * Interpolation style for line series.
         *
         * - `LINEAR` : Show as default, linear style.
         * - `SMOOTH` : Show as a smooth curve.
         * - `STEPPED` : Show steps in line.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartlinestylesettings.html#cfn-quicksight-dashboard-linechartlinestylesettings-lineinterpolation
         */
        readonly lineInterpolation?: string;
        /**
         * Line style for line series.
         *
         * - `SOLID` : Show as a solid line.
         * - `DOTTED` : Show as a dotted line.
         * - `DASHED` : Show as a dashed line.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartlinestylesettings.html#cfn-quicksight-dashboard-linechartlinestylesettings-linestyle
         */
        readonly lineStyle?: string;
        /**
         * Configuration option that determines whether to show the line for the series.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartlinestylesettings.html#cfn-quicksight-dashboard-linechartlinestylesettings-linevisibility
         */
        readonly lineVisibility?: string;
        /**
         * Width that determines the line thickness.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartlinestylesettings.html#cfn-quicksight-dashboard-linechartlinestylesettings-linewidth
         */
        readonly lineWidth?: string;
    }
    /**
     * Marker styles options for a line series in `LineChartVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartmarkerstylesettings.html
     */
    interface LineChartMarkerStyleSettingsProperty {
        /**
         * Color of marker in the series.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartmarkerstylesettings.html#cfn-quicksight-dashboard-linechartmarkerstylesettings-markercolor
         */
        readonly markerColor?: string;
        /**
         * Shape option for markers in the series.
         *
         * - `CIRCLE` : Show marker as a circle.
         * - `TRIANGLE` : Show marker as a triangle.
         * - `SQUARE` : Show marker as a square.
         * - `DIAMOND` : Show marker as a diamond.
         * - `ROUNDED_SQUARE` : Show marker as a rounded square.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartmarkerstylesettings.html#cfn-quicksight-dashboard-linechartmarkerstylesettings-markershape
         */
        readonly markerShape?: string;
        /**
         * Size of marker in the series.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartmarkerstylesettings.html#cfn-quicksight-dashboard-linechartmarkerstylesettings-markersize
         */
        readonly markerSize?: string;
        /**
         * Configuration option that determines whether to show the markers in the series.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartmarkerstylesettings.html#cfn-quicksight-dashboard-linechartmarkerstylesettings-markervisibility
         */
        readonly markerVisibility?: string;
    }
    /**
     * The forecast configuration that is used in a line chart's display properties.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastconfiguration.html
     */
    interface ForecastConfigurationProperty {
        /**
         * The forecast properties setup of a forecast in the line chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastconfiguration.html#cfn-quicksight-dashboard-forecastconfiguration-forecastproperties
         */
        readonly forecastProperties?: cdk.IResolvable | CfnDashboard.TimeBasedForecastPropertiesProperty;
        /**
         * The forecast scenario of a forecast in the line chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastconfiguration.html#cfn-quicksight-dashboard-forecastconfiguration-scenario
         */
        readonly scenario?: CfnDashboard.ForecastScenarioProperty | cdk.IResolvable;
    }
    /**
     * The forecast properties setup of a forecast in the line chart.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timebasedforecastproperties.html
     */
    interface TimeBasedForecastPropertiesProperty {
        /**
         * The lower boundary setup of a forecast computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timebasedforecastproperties.html#cfn-quicksight-dashboard-timebasedforecastproperties-lowerboundary
         */
        readonly lowerBoundary?: number;
        /**
         * The periods backward setup of a forecast computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timebasedforecastproperties.html#cfn-quicksight-dashboard-timebasedforecastproperties-periodsbackward
         */
        readonly periodsBackward?: number;
        /**
         * The periods forward setup of a forecast computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timebasedforecastproperties.html#cfn-quicksight-dashboard-timebasedforecastproperties-periodsforward
         */
        readonly periodsForward?: number;
        /**
         * The prediction interval setup of a forecast computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timebasedforecastproperties.html#cfn-quicksight-dashboard-timebasedforecastproperties-predictioninterval
         */
        readonly predictionInterval?: number;
        /**
         * The seasonality setup of a forecast computation. Choose one of the following options:.
         *
         * - `NULL` : The input is set to `NULL` .
         * - `NON_NULL` : The input is set to a custom value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timebasedforecastproperties.html#cfn-quicksight-dashboard-timebasedforecastproperties-seasonality
         */
        readonly seasonality?: number;
        /**
         * The upper boundary setup of a forecast computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timebasedforecastproperties.html#cfn-quicksight-dashboard-timebasedforecastproperties-upperboundary
         */
        readonly upperBoundary?: number;
    }
    /**
     * The forecast scenario of a forecast in the line chart.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastscenario.html
     */
    interface ForecastScenarioProperty {
        /**
         * The what-if analysis forecast setup with the target date.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastscenario.html#cfn-quicksight-dashboard-forecastscenario-whatifpointscenario
         */
        readonly whatIfPointScenario?: cdk.IResolvable | CfnDashboard.WhatIfPointScenarioProperty;
        /**
         * The what-if analysis forecast setup with the date range.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastscenario.html#cfn-quicksight-dashboard-forecastscenario-whatifrangescenario
         */
        readonly whatIfRangeScenario?: cdk.IResolvable | CfnDashboard.WhatIfRangeScenarioProperty;
    }
    /**
     * Provides the forecast to meet the target for a particular date range.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-whatifrangescenario.html
     */
    interface WhatIfRangeScenarioProperty {
        /**
         * The end date in the date range that you need the forecast results for.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-whatifrangescenario.html#cfn-quicksight-dashboard-whatifrangescenario-enddate
         */
        readonly endDate: string;
        /**
         * The start date in the date range that you need the forecast results for.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-whatifrangescenario.html#cfn-quicksight-dashboard-whatifrangescenario-startdate
         */
        readonly startDate: string;
        /**
         * The target value that you want to meet for the provided date range.
         *
         * @default - 0
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-whatifrangescenario.html#cfn-quicksight-dashboard-whatifrangescenario-value
         */
        readonly value: number;
    }
    /**
     * Provides the forecast to meet the target for a particular date.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-whatifpointscenario.html
     */
    interface WhatIfPointScenarioProperty {
        /**
         * The date that you need the forecast results for.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-whatifpointscenario.html#cfn-quicksight-dashboard-whatifpointscenario-date
         */
        readonly date: string;
        /**
         * The target value that you want to meet for the provided date.
         *
         * @default - 0
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-whatifpointscenario.html#cfn-quicksight-dashboard-whatifpointscenario-value
         */
        readonly value: number;
    }
    /**
     * The series item configuration of a line chart.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-seriesitem.html
     */
    interface SeriesItemProperty {
        /**
         * The data field series item configuration of a line chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-seriesitem.html#cfn-quicksight-dashboard-seriesitem-datafieldseriesitem
         */
        readonly dataFieldSeriesItem?: CfnDashboard.DataFieldSeriesItemProperty | cdk.IResolvable;
        /**
         * The field series item configuration of a line chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-seriesitem.html#cfn-quicksight-dashboard-seriesitem-fieldseriesitem
         */
        readonly fieldSeriesItem?: CfnDashboard.FieldSeriesItemProperty | cdk.IResolvable;
    }
    /**
     * The field series item configuration of a line chart.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldseriesitem.html
     */
    interface FieldSeriesItemProperty {
        /**
         * The axis that you are binding the field to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldseriesitem.html#cfn-quicksight-dashboard-fieldseriesitem-axisbinding
         */
        readonly axisBinding: string;
        /**
         * The field ID of the field for which you are setting the axis binding.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldseriesitem.html#cfn-quicksight-dashboard-fieldseriesitem-fieldid
         */
        readonly fieldId: string;
        /**
         * The options that determine the presentation of line series associated to the field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldseriesitem.html#cfn-quicksight-dashboard-fieldseriesitem-settings
         */
        readonly settings?: cdk.IResolvable | CfnDashboard.LineChartSeriesSettingsProperty;
    }
    /**
     * The options that determine the presentation of a line series in the visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartseriessettings.html
     */
    interface LineChartSeriesSettingsProperty {
        /**
         * Line styles options for a line series in `LineChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartseriessettings.html#cfn-quicksight-dashboard-linechartseriessettings-linestylesettings
         */
        readonly lineStyleSettings?: cdk.IResolvable | CfnDashboard.LineChartLineStyleSettingsProperty;
        /**
         * Marker styles options for a line series in `LineChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartseriessettings.html#cfn-quicksight-dashboard-linechartseriessettings-markerstylesettings
         */
        readonly markerStyleSettings?: cdk.IResolvable | CfnDashboard.LineChartMarkerStyleSettingsProperty;
    }
    /**
     * The data field series item configuration of a line chart.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datafieldseriesitem.html
     */
    interface DataFieldSeriesItemProperty {
        /**
         * The axis that you are binding the field to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datafieldseriesitem.html#cfn-quicksight-dashboard-datafieldseriesitem-axisbinding
         */
        readonly axisBinding: string;
        /**
         * The field ID of the field that you are setting the axis binding to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datafieldseriesitem.html#cfn-quicksight-dashboard-datafieldseriesitem-fieldid
         */
        readonly fieldId: string;
        /**
         * The field value of the field that you are setting the axis binding to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datafieldseriesitem.html#cfn-quicksight-dashboard-datafieldseriesitem-fieldvalue
         */
        readonly fieldValue?: string;
        /**
         * The options that determine the presentation of line series associated to the field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datafieldseriesitem.html#cfn-quicksight-dashboard-datafieldseriesitem-settings
         */
        readonly settings?: cdk.IResolvable | CfnDashboard.LineChartSeriesSettingsProperty;
    }
    /**
     * The field well configuration of a line chart.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartfieldwells.html
     */
    interface LineChartFieldWellsProperty {
        /**
         * The field well configuration of a line chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartfieldwells.html#cfn-quicksight-dashboard-linechartfieldwells-linechartaggregatedfieldwells
         */
        readonly lineChartAggregatedFieldWells?: cdk.IResolvable | CfnDashboard.LineChartAggregatedFieldWellsProperty;
    }
    /**
     * The field well configuration of a line chart.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartaggregatedfieldwells.html
     */
    interface LineChartAggregatedFieldWellsProperty {
        /**
         * The category field wells of a line chart.
         *
         * Values are grouped by category fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartaggregatedfieldwells.html#cfn-quicksight-dashboard-linechartaggregatedfieldwells-category
         */
        readonly category?: Array<CfnDashboard.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The color field wells of a line chart.
         *
         * Values are grouped by category fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartaggregatedfieldwells.html#cfn-quicksight-dashboard-linechartaggregatedfieldwells-colors
         */
        readonly colors?: Array<CfnDashboard.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The small multiples field well of a line chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartaggregatedfieldwells.html#cfn-quicksight-dashboard-linechartaggregatedfieldwells-smallmultiples
         */
        readonly smallMultiples?: Array<CfnDashboard.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The value field wells of a line chart.
         *
         * Values are aggregated based on categories.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartaggregatedfieldwells.html#cfn-quicksight-dashboard-linechartaggregatedfieldwells-values
         */
        readonly values?: Array<cdk.IResolvable | CfnDashboard.MeasureFieldProperty> | cdk.IResolvable;
    }
    /**
     * An empty visual.
     *
     * Empty visuals are used in layouts but have not been configured to show any data. A new visual created in the Amazon QuickSight console is considered an `EmptyVisual` until a visual type is selected.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-emptyvisual.html
     */
    interface EmptyVisualProperty {
        /**
         * The list of custom actions that are configured for a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-emptyvisual.html#cfn-quicksight-dashboard-emptyvisual-actions
         */
        readonly actions?: Array<cdk.IResolvable | CfnDashboard.VisualCustomActionProperty> | cdk.IResolvable;
        /**
         * The data set that is used in the empty visual.
         *
         * Every visual requires a dataset to render.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-emptyvisual.html#cfn-quicksight-dashboard-emptyvisual-datasetidentifier
         */
        readonly dataSetIdentifier: string;
        /**
         * The unique identifier of a visual.
         *
         * This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-emptyvisual.html#cfn-quicksight-dashboard-emptyvisual-visualid
         */
        readonly visualId: string;
    }
    /**
     * The declaration definition of a parameter.
     *
     * For more information, see [Parameters in Amazon QuickSight](https://docs.aws.amazon.com/quicksight/latest/user/parameters-in-quicksight.html) in the *Amazon QuickSight User Guide* .
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdeclaration.html
     */
    interface ParameterDeclarationProperty {
        /**
         * A parameter declaration for the `DateTime` data type.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdeclaration.html#cfn-quicksight-dashboard-parameterdeclaration-datetimeparameterdeclaration
         */
        readonly dateTimeParameterDeclaration?: CfnDashboard.DateTimeParameterDeclarationProperty | cdk.IResolvable;
        /**
         * A parameter declaration for the `Decimal` data type.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdeclaration.html#cfn-quicksight-dashboard-parameterdeclaration-decimalparameterdeclaration
         */
        readonly decimalParameterDeclaration?: CfnDashboard.DecimalParameterDeclarationProperty | cdk.IResolvable;
        /**
         * A parameter declaration for the `Integer` data type.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdeclaration.html#cfn-quicksight-dashboard-parameterdeclaration-integerparameterdeclaration
         */
        readonly integerParameterDeclaration?: CfnDashboard.IntegerParameterDeclarationProperty | cdk.IResolvable;
        /**
         * A parameter declaration for the `String` data type.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdeclaration.html#cfn-quicksight-dashboard-parameterdeclaration-stringparameterdeclaration
         */
        readonly stringParameterDeclaration?: cdk.IResolvable | CfnDashboard.StringParameterDeclarationProperty;
    }
    /**
     * A parameter declaration for the `String` data type.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringparameterdeclaration.html
     */
    interface StringParameterDeclarationProperty {
        /**
         * The default values of a parameter.
         *
         * If the parameter is a single-value parameter, a maximum of one default value can be provided.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringparameterdeclaration.html#cfn-quicksight-dashboard-stringparameterdeclaration-defaultvalues
         */
        readonly defaultValues?: cdk.IResolvable | CfnDashboard.StringDefaultValuesProperty;
        /**
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringparameterdeclaration.html#cfn-quicksight-dashboard-stringparameterdeclaration-mappeddatasetparameters
         */
        readonly mappedDataSetParameters?: Array<cdk.IResolvable | CfnDashboard.MappedDataSetParameterProperty> | cdk.IResolvable;
        /**
         * The name of the parameter that is being declared.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringparameterdeclaration.html#cfn-quicksight-dashboard-stringparameterdeclaration-name
         */
        readonly name: string;
        /**
         * The value type determines whether the parameter is a single-value or multi-value parameter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringparameterdeclaration.html#cfn-quicksight-dashboard-stringparameterdeclaration-parametervaluetype
         */
        readonly parameterValueType: string;
        /**
         * The configuration that defines the default value of a `String` parameter when a value has not been set.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringparameterdeclaration.html#cfn-quicksight-dashboard-stringparameterdeclaration-valuewhenunset
         */
        readonly valueWhenUnset?: cdk.IResolvable | CfnDashboard.StringValueWhenUnsetConfigurationProperty;
    }
    /**
     * A dataset parameter that is mapped to an analysis parameter.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-mappeddatasetparameter.html
     */
    interface MappedDataSetParameterProperty {
        /**
         * A unique name that identifies a dataset within the analysis or dashboard.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-mappeddatasetparameter.html#cfn-quicksight-dashboard-mappeddatasetparameter-datasetidentifier
         */
        readonly dataSetIdentifier: string;
        /**
         * The name of the dataset parameter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-mappeddatasetparameter.html#cfn-quicksight-dashboard-mappeddatasetparameter-datasetparametername
         */
        readonly dataSetParameterName: string;
    }
    /**
     * The default values of the `StringParameterDeclaration` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringdefaultvalues.html
     */
    interface StringDefaultValuesProperty {
        /**
         * The dynamic value of the `StringDefaultValues` .
         *
         * Different defaults displayed according to users, groups, and values mapping.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringdefaultvalues.html#cfn-quicksight-dashboard-stringdefaultvalues-dynamicvalue
         */
        readonly dynamicValue?: CfnDashboard.DynamicDefaultValueProperty | cdk.IResolvable;
        /**
         * The static values of the `DecimalDefaultValues` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringdefaultvalues.html#cfn-quicksight-dashboard-stringdefaultvalues-staticvalues
         */
        readonly staticValues?: Array<string>;
    }
    /**
     * Defines different defaults to the users or groups based on mapping.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dynamicdefaultvalue.html
     */
    interface DynamicDefaultValueProperty {
        /**
         * The column that contains the default value of each user or group.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dynamicdefaultvalue.html#cfn-quicksight-dashboard-dynamicdefaultvalue-defaultvaluecolumn
         */
        readonly defaultValueColumn: CfnDashboard.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * The column that contains the group name.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dynamicdefaultvalue.html#cfn-quicksight-dashboard-dynamicdefaultvalue-groupnamecolumn
         */
        readonly groupNameColumn?: CfnDashboard.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * The column that contains the username.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dynamicdefaultvalue.html#cfn-quicksight-dashboard-dynamicdefaultvalue-usernamecolumn
         */
        readonly userNameColumn?: CfnDashboard.ColumnIdentifierProperty | cdk.IResolvable;
    }
    /**
     * The configuration that defines the default value of a `String` parameter when a value has not been set.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringvaluewhenunsetconfiguration.html
     */
    interface StringValueWhenUnsetConfigurationProperty {
        /**
         * A custom value that's used when the value of a parameter isn't set.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringvaluewhenunsetconfiguration.html#cfn-quicksight-dashboard-stringvaluewhenunsetconfiguration-customvalue
         */
        readonly customValue?: string;
        /**
         * The built-in options for default values. The value can be one of the following:.
         *
         * - `RECOMMENDED` : The recommended value.
         * - `NULL` : The `NULL` value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringvaluewhenunsetconfiguration.html#cfn-quicksight-dashboard-stringvaluewhenunsetconfiguration-valuewhenunsetoption
         */
        readonly valueWhenUnsetOption?: string;
    }
    /**
     * A parameter declaration for the `DateTime` data type.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimeparameterdeclaration.html
     */
    interface DateTimeParameterDeclarationProperty {
        /**
         * The default values of a parameter.
         *
         * If the parameter is a single-value parameter, a maximum of one default value can be provided.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimeparameterdeclaration.html#cfn-quicksight-dashboard-datetimeparameterdeclaration-defaultvalues
         */
        readonly defaultValues?: CfnDashboard.DateTimeDefaultValuesProperty | cdk.IResolvable;
        /**
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimeparameterdeclaration.html#cfn-quicksight-dashboard-datetimeparameterdeclaration-mappeddatasetparameters
         */
        readonly mappedDataSetParameters?: Array<cdk.IResolvable | CfnDashboard.MappedDataSetParameterProperty> | cdk.IResolvable;
        /**
         * The name of the parameter that is being declared.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimeparameterdeclaration.html#cfn-quicksight-dashboard-datetimeparameterdeclaration-name
         */
        readonly name: string;
        /**
         * The level of time precision that is used to aggregate `DateTime` values.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimeparameterdeclaration.html#cfn-quicksight-dashboard-datetimeparameterdeclaration-timegranularity
         */
        readonly timeGranularity?: string;
        /**
         * The configuration that defines the default value of a `DateTime` parameter when a value has not been set.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimeparameterdeclaration.html#cfn-quicksight-dashboard-datetimeparameterdeclaration-valuewhenunset
         */
        readonly valueWhenUnset?: CfnDashboard.DateTimeValueWhenUnsetConfigurationProperty | cdk.IResolvable;
    }
    /**
     * The default values of the `DateTimeParameterDeclaration` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimedefaultvalues.html
     */
    interface DateTimeDefaultValuesProperty {
        /**
         * The dynamic value of the `DataTimeDefaultValues` .
         *
         * Different defaults are displayed according to users, groups, and values mapping.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimedefaultvalues.html#cfn-quicksight-dashboard-datetimedefaultvalues-dynamicvalue
         */
        readonly dynamicValue?: CfnDashboard.DynamicDefaultValueProperty | cdk.IResolvable;
        /**
         * The rolling date of the `DataTimeDefaultValues` .
         *
         * The date is determined from the dataset based on input expression.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimedefaultvalues.html#cfn-quicksight-dashboard-datetimedefaultvalues-rollingdate
         */
        readonly rollingDate?: cdk.IResolvable | CfnDashboard.RollingDateConfigurationProperty;
        /**
         * The static values of the `DataTimeDefaultValues` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimedefaultvalues.html#cfn-quicksight-dashboard-datetimedefaultvalues-staticvalues
         */
        readonly staticValues?: Array<string>;
    }
    /**
     * The configuration that defines the default value of a `DateTime` parameter when a value has not been set.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimevaluewhenunsetconfiguration.html
     */
    interface DateTimeValueWhenUnsetConfigurationProperty {
        /**
         * A custom value that's used when the value of a parameter isn't set.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimevaluewhenunsetconfiguration.html#cfn-quicksight-dashboard-datetimevaluewhenunsetconfiguration-customvalue
         */
        readonly customValue?: string;
        /**
         * The built-in options for default values. The value can be one of the following:.
         *
         * - `RECOMMENDED` : The recommended value.
         * - `NULL` : The `NULL` value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimevaluewhenunsetconfiguration.html#cfn-quicksight-dashboard-datetimevaluewhenunsetconfiguration-valuewhenunsetoption
         */
        readonly valueWhenUnsetOption?: string;
    }
    /**
     * A parameter declaration for the `Decimal` data type.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimalparameterdeclaration.html
     */
    interface DecimalParameterDeclarationProperty {
        /**
         * The default values of a parameter.
         *
         * If the parameter is a single-value parameter, a maximum of one default value can be provided.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimalparameterdeclaration.html#cfn-quicksight-dashboard-decimalparameterdeclaration-defaultvalues
         */
        readonly defaultValues?: CfnDashboard.DecimalDefaultValuesProperty | cdk.IResolvable;
        /**
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimalparameterdeclaration.html#cfn-quicksight-dashboard-decimalparameterdeclaration-mappeddatasetparameters
         */
        readonly mappedDataSetParameters?: Array<cdk.IResolvable | CfnDashboard.MappedDataSetParameterProperty> | cdk.IResolvable;
        /**
         * The name of the parameter that is being declared.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimalparameterdeclaration.html#cfn-quicksight-dashboard-decimalparameterdeclaration-name
         */
        readonly name: string;
        /**
         * The value type determines whether the parameter is a single-value or multi-value parameter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimalparameterdeclaration.html#cfn-quicksight-dashboard-decimalparameterdeclaration-parametervaluetype
         */
        readonly parameterValueType: string;
        /**
         * The configuration that defines the default value of a `Decimal` parameter when a value has not been set.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimalparameterdeclaration.html#cfn-quicksight-dashboard-decimalparameterdeclaration-valuewhenunset
         */
        readonly valueWhenUnset?: CfnDashboard.DecimalValueWhenUnsetConfigurationProperty | cdk.IResolvable;
    }
    /**
     * The default values of the `DecimalParameterDeclaration` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimaldefaultvalues.html
     */
    interface DecimalDefaultValuesProperty {
        /**
         * The dynamic value of the `DecimalDefaultValues` .
         *
         * Different defaults are displayed according to users, groups, and values mapping.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimaldefaultvalues.html#cfn-quicksight-dashboard-decimaldefaultvalues-dynamicvalue
         */
        readonly dynamicValue?: CfnDashboard.DynamicDefaultValueProperty | cdk.IResolvable;
        /**
         * The static values of the `DecimalDefaultValues` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimaldefaultvalues.html#cfn-quicksight-dashboard-decimaldefaultvalues-staticvalues
         */
        readonly staticValues?: Array<number> | cdk.IResolvable;
    }
    /**
     * The configuration that defines the default value of a `Decimal` parameter when a value has not been set.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimalvaluewhenunsetconfiguration.html
     */
    interface DecimalValueWhenUnsetConfigurationProperty {
        /**
         * A custom value that's used when the value of a parameter isn't set.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimalvaluewhenunsetconfiguration.html#cfn-quicksight-dashboard-decimalvaluewhenunsetconfiguration-customvalue
         */
        readonly customValue?: number;
        /**
         * The built-in options for default values. The value can be one of the following:.
         *
         * - `RECOMMENDED` : The recommended value.
         * - `NULL` : The `NULL` value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimalvaluewhenunsetconfiguration.html#cfn-quicksight-dashboard-decimalvaluewhenunsetconfiguration-valuewhenunsetoption
         */
        readonly valueWhenUnsetOption?: string;
    }
    /**
     * A parameter declaration for the `Integer` data type.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integerparameterdeclaration.html
     */
    interface IntegerParameterDeclarationProperty {
        /**
         * The default values of a parameter.
         *
         * If the parameter is a single-value parameter, a maximum of one default value can be provided.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integerparameterdeclaration.html#cfn-quicksight-dashboard-integerparameterdeclaration-defaultvalues
         */
        readonly defaultValues?: CfnDashboard.IntegerDefaultValuesProperty | cdk.IResolvable;
        /**
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integerparameterdeclaration.html#cfn-quicksight-dashboard-integerparameterdeclaration-mappeddatasetparameters
         */
        readonly mappedDataSetParameters?: Array<cdk.IResolvable | CfnDashboard.MappedDataSetParameterProperty> | cdk.IResolvable;
        /**
         * The name of the parameter that is being declared.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integerparameterdeclaration.html#cfn-quicksight-dashboard-integerparameterdeclaration-name
         */
        readonly name: string;
        /**
         * The value type determines whether the parameter is a single-value or multi-value parameter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integerparameterdeclaration.html#cfn-quicksight-dashboard-integerparameterdeclaration-parametervaluetype
         */
        readonly parameterValueType: string;
        /**
         * A parameter declaration for the `Integer` data type.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integerparameterdeclaration.html#cfn-quicksight-dashboard-integerparameterdeclaration-valuewhenunset
         */
        readonly valueWhenUnset?: CfnDashboard.IntegerValueWhenUnsetConfigurationProperty | cdk.IResolvable;
    }
    /**
     * The default values of the `IntegerParameterDeclaration` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integerdefaultvalues.html
     */
    interface IntegerDefaultValuesProperty {
        /**
         * The dynamic value of the `IntegerDefaultValues` .
         *
         * Different defaults are displayed according to users, groups, and values mapping.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integerdefaultvalues.html#cfn-quicksight-dashboard-integerdefaultvalues-dynamicvalue
         */
        readonly dynamicValue?: CfnDashboard.DynamicDefaultValueProperty | cdk.IResolvable;
        /**
         * The static values of the `IntegerDefaultValues` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integerdefaultvalues.html#cfn-quicksight-dashboard-integerdefaultvalues-staticvalues
         */
        readonly staticValues?: Array<number> | cdk.IResolvable;
    }
    /**
     * A parameter declaration for the `Integer` data type.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integervaluewhenunsetconfiguration.html
     */
    interface IntegerValueWhenUnsetConfigurationProperty {
        /**
         * A custom value that's used when the value of a parameter isn't set.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integervaluewhenunsetconfiguration.html#cfn-quicksight-dashboard-integervaluewhenunsetconfiguration-customvalue
         */
        readonly customValue?: number;
        /**
         * The built-in options for default values. The value can be one of the following:.
         *
         * - `RECOMMENDED` : The recommended value.
         * - `NULL` : The `NULL` value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integervaluewhenunsetconfiguration.html#cfn-quicksight-dashboard-integervaluewhenunsetconfiguration-valuewhenunsetoption
         */
        readonly valueWhenUnsetOption?: string;
    }
    /**
     * An array of analysis level configurations.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-assetoptions.html
     */
    interface AssetOptionsProperty {
        /**
         * Determines the timezone for the analysis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-assetoptions.html#cfn-quicksight-dashboard-assetoptions-timezone
         */
        readonly timezone?: string;
        /**
         * Determines the week start day for an analysis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-assetoptions.html#cfn-quicksight-dashboard-assetoptions-weekstart
         */
        readonly weekStart?: string;
    }
    /**
     * Permission for the resource.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-resourcepermission.html
     */
    interface ResourcePermissionProperty {
        /**
         * The IAM action to grant or revoke permissions on.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-resourcepermission.html#cfn-quicksight-dashboard-resourcepermission-actions
         */
        readonly actions: Array<string>;
        /**
         * The Amazon Resource Name (ARN) of the principal. This can be one of the following:.
         *
         * - The ARN of an Amazon QuickSight user or group associated with a data source or dataset. (This is common.)
         * - The ARN of an Amazon QuickSight user, group, or namespace associated with an analysis, dashboard, template, or theme. (This is common.)
         * - The ARN of an AWS account root: This is an IAM ARN rather than a Amazon QuickSight ARN. Use this option only to share resources (templates) across AWS accounts . (This is less common.)
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-resourcepermission.html#cfn-quicksight-dashboard-resourcepermission-principal
         */
        readonly principal: string;
        /**
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-resourcepermission.html#cfn-quicksight-dashboard-resourcepermission-resource
         */
        readonly resource?: string;
    }
    /**
     * A structure that contains the configuration of a shareable link to the dashboard.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linksharingconfiguration.html
     */
    interface LinkSharingConfigurationProperty {
        /**
         * A structure that contains the permissions of a shareable link.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linksharingconfiguration.html#cfn-quicksight-dashboard-linksharingconfiguration-permissions
         */
        readonly permissions?: Array<cdk.IResolvable | CfnDashboard.ResourcePermissionProperty> | cdk.IResolvable;
    }
    /**
     * The option to relax the validation that is required to create and update analyses, dashboards, and templates with definition objects.
     *
     * When you set this value to `LENIENT` , validation is skipped for specific errors.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-validationstrategy.html
     */
    interface ValidationStrategyProperty {
        /**
         * The mode of validation for the asset to be created or updated.
         *
         * When you set this value to `STRICT` , strict validation for every error is enforced. When you set this value to `LENIENT` , validation is skipped for specific UI errors.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-validationstrategy.html#cfn-quicksight-dashboard-validationstrategy-mode
         */
        readonly mode: string;
    }
    /**
     * A *sheet* , which is an object that contains a set of visuals that are viewed together on one page in Amazon QuickSight.
     *
     * Every analysis and dashboard contains at least one sheet. Each sheet contains at least one visualization widget, for example a chart, pivot table, or narrative insight. Sheets can be associated with other components, such as controls, filters, and so on.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheet.html
     */
    interface SheetProperty {
        /**
         * The name of a sheet.
         *
         * This name is displayed on the sheet's tab in the Amazon QuickSight console.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheet.html#cfn-quicksight-dashboard-sheet-name
         */
        readonly name?: string;
        /**
         * The unique identifier associated with a sheet.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheet.html#cfn-quicksight-dashboard-sheet-sheetid
         */
        readonly sheetId?: string;
    }
    /**
     * Dashboard error.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboarderror.html
     */
    interface DashboardErrorProperty {
        /**
         * Message.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboarderror.html#cfn-quicksight-dashboard-dashboarderror-message
         */
        readonly message?: string;
        /**
         * Type.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboarderror.html#cfn-quicksight-dashboard-dashboarderror-type
         */
        readonly type?: string;
        /**
         * Lists the violated entities that caused the dashboard error.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboarderror.html#cfn-quicksight-dashboard-dashboarderror-violatedentities
         */
        readonly violatedEntities?: Array<CfnDashboard.EntityProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * An object, structure, or sub-structure of an analysis, template, or dashboard.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-entity.html
     */
    interface EntityProperty {
        /**
         * The hierarchical path of the entity within the analysis, template, or dashboard definition tree.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-entity.html#cfn-quicksight-dashboard-entity-path
         */
        readonly path?: string;
    }
    /**
     * Dashboard version.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversion.html
     */
    interface DashboardVersionProperty {
        /**
         * The Amazon Resource Name (ARN) of the resource.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversion.html#cfn-quicksight-dashboard-dashboardversion-arn
         */
        readonly arn?: string;
        /**
         * The time that this dashboard version was created.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversion.html#cfn-quicksight-dashboard-dashboardversion-createdtime
         */
        readonly createdTime?: string;
        /**
         * The Amazon Resource Numbers (ARNs) for the datasets that are associated with this version of the dashboard.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversion.html#cfn-quicksight-dashboard-dashboardversion-datasetarns
         */
        readonly dataSetArns?: Array<string>;
        /**
         * Description.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversion.html#cfn-quicksight-dashboard-dashboardversion-description
         */
        readonly description?: string;
        /**
         * Errors associated with this dashboard version.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversion.html#cfn-quicksight-dashboard-dashboardversion-errors
         */
        readonly errors?: Array<CfnDashboard.DashboardErrorProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * A list of the associated sheets with the unique identifier and name of each sheet.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversion.html#cfn-quicksight-dashboard-dashboardversion-sheets
         */
        readonly sheets?: Array<cdk.IResolvable | CfnDashboard.SheetProperty> | cdk.IResolvable;
        /**
         * Source entity ARN.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversion.html#cfn-quicksight-dashboard-dashboardversion-sourceentityarn
         */
        readonly sourceEntityArn?: string;
        /**
         * The HTTP status of the request.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversion.html#cfn-quicksight-dashboard-dashboardversion-status
         */
        readonly status?: string;
        /**
         * The ARN of the theme associated with a version of the dashboard.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversion.html#cfn-quicksight-dashboard-dashboardversion-themearn
         */
        readonly themeArn?: string;
        /**
         * Version number for this version of the dashboard.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversion.html#cfn-quicksight-dashboard-dashboardversion-versionnumber
         */
        readonly versionNumber?: number;
    }
}
/**
 * Properties for defining a `CfnDashboard`
 *
 * @struct
 * @stability external
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html
 */
export interface CfnDashboardProps {
    /**
     * The ID of the AWS account where you want to create the dashboard.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-awsaccountid
     */
    readonly awsAccountId: string;
    /**
     * The ID for the dashboard, also added to the IAM policy.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-dashboardid
     */
    readonly dashboardId: string;
    /**
     * Options for publishing the dashboard when you create it:.
     *
     * - `AvailabilityStatus` for `AdHocFilteringOption` - This status can be either `ENABLED` or `DISABLED` . When this is set to `DISABLED` , Amazon QuickSight disables the left filter pane on the published dashboard, which can be used for ad hoc (one-time) filtering. This option is `ENABLED` by default.
     * - `AvailabilityStatus` for `ExportToCSVOption` - This status can be either `ENABLED` or `DISABLED` . The visual option to export data to .CSV format isn't enabled when this is set to `DISABLED` . This option is `ENABLED` by default.
     * - `VisibilityState` for `SheetControlsOption` - This visibility state can be either `COLLAPSED` or `EXPANDED` . This option is `COLLAPSED` by default.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-dashboardpublishoptions
     */
    readonly dashboardPublishOptions?: CfnDashboard.DashboardPublishOptionsProperty | cdk.IResolvable;
    /**
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-definition
     */
    readonly definition?: CfnDashboard.DashboardVersionDefinitionProperty | cdk.IResolvable;
    /**
     * A structure that contains the link sharing configurations that you want to apply overrides to.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-linksharingconfiguration
     */
    readonly linkSharingConfiguration?: cdk.IResolvable | CfnDashboard.LinkSharingConfigurationProperty;
    /**
     * The display name of the dashboard.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-name
     */
    readonly name: string;
    /**
     * The parameters for the creation of the dashboard, which you want to use to override the default settings.
     *
     * A dashboard can have any type of parameters, and some parameters might accept multiple values.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-parameters
     */
    readonly parameters?: cdk.IResolvable | CfnDashboard.ParametersProperty;
    /**
     * A structure that contains the permissions of the dashboard.
     *
     * You can use this structure for granting permissions by providing a list of IAM action information for each principal ARN.
     *
     * To specify no permissions, omit the permissions list.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-permissions
     */
    readonly permissions?: Array<cdk.IResolvable | CfnDashboard.ResourcePermissionProperty> | cdk.IResolvable;
    /**
     * The entity that you are using as a source when you create the dashboard.
     *
     * In `SourceEntity` , you specify the type of object that you want to use. You can only create a dashboard from a template, so you use a `SourceTemplate` entity. If you need to create a dashboard from an analysis, first convert the analysis to a template by using the `CreateTemplate` API operation. For `SourceTemplate` , specify the Amazon Resource Name (ARN) of the source template. The `SourceTemplate` ARN can contain any AWS account; and any QuickSight-supported AWS Region .
     *
     * Use the `DataSetReferences` entity within `SourceTemplate` to list the replacement datasets for the placeholders listed in the original. The schema in each dataset must match its placeholder.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-sourceentity
     */
    readonly sourceEntity?: CfnDashboard.DashboardSourceEntityProperty | cdk.IResolvable;
    /**
     * Contains a map of the key-value pairs for the resource tag or tags assigned to the dashboard.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-tags
     */
    readonly tags?: Array<cdk.CfnTag>;
    /**
     * The Amazon Resource Name (ARN) of the theme that is being used for this dashboard.
     *
     * If you add a value for this field, it overrides the value that is used in the source entity. The theme ARN must exist in the same AWS account where you create the dashboard.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-themearn
     */
    readonly themeArn?: string;
    /**
     * The option to relax the validation that is required to create and update analyses, dashboards, and templates with definition objects.
     *
     * When you set this value to `LENIENT` , validation is skipped for specific errors.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-validationstrategy
     */
    readonly validationStrategy?: cdk.IResolvable | CfnDashboard.ValidationStrategyProperty;
    /**
     * A description for the first version of the dashboard being created.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-versiondescription
     */
    readonly versionDescription?: string;
}
/**
 * Creates a dataset.
 *
 * This operation doesn't support datasets that include uploaded files as a source.
 *
 * @cloudformationResource AWS::QuickSight::DataSet
 * @stability external
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html
 */
export declare class CfnDataSet extends cdk.CfnResource implements cdk.IInspectable, cdk.ITaggable {
    /**
     * The CloudFormation resource type name for this resource class.
     */
    static readonly CFN_RESOURCE_TYPE_NAME: string;
    /**
     * Build a CfnDataSet from CloudFormation properties
     *
     * A factory method that creates a new instance of this class from an object
     * containing the CloudFormation properties of this resource.
     * Used in the @aws-cdk/cloudformation-include module.
     *
     * @internal
     */
    static _fromCloudFormation(scope: constructs.Construct, id: string, resourceAttributes: any, options: cfn_parse.FromCloudFormationOptions): CfnDataSet;
    /**
     * The Amazon Resource Name (ARN) of the dataset.
     *
     * @cloudformationAttribute Arn
     */
    readonly attrArn: string;
    /**
     * <p>The amount of SPICE capacity used by this dataset. This is 0 if the dataset isn't
     *             imported into SPICE.</p>
     *
     * @cloudformationAttribute ConsumedSpiceCapacityInBytes
     */
    readonly attrConsumedSpiceCapacityInBytes: cdk.IResolvable;
    /**
     * The time this dataset version was created.
     *
     * @cloudformationAttribute CreatedTime
     */
    readonly attrCreatedTime: string;
    /**
     * The time this dataset version was last updated.
     *
     * @cloudformationAttribute LastUpdatedTime
     */
    readonly attrLastUpdatedTime: string;
    /**
     * <p>The list of columns after all transforms. These columns are available in templates,
     *             analyses, and dashboards.</p>
     *
     * @cloudformationAttribute OutputColumns
     */
    readonly attrOutputColumns: cdk.IResolvable;
    /**
     * The AWS account ID.
     */
    awsAccountId?: string;
    /**
     * Groupings of columns that work together in certain Amazon QuickSight features.
     */
    columnGroups?: Array<CfnDataSet.ColumnGroupProperty | cdk.IResolvable> | cdk.IResolvable;
    /**
     * A set of one or more definitions of a `ColumnLevelPermissionRule` .
     */
    columnLevelPermissionRules?: Array<CfnDataSet.ColumnLevelPermissionRuleProperty | cdk.IResolvable> | cdk.IResolvable;
    /**
     * An ID for the dataset that you want to create.
     */
    dataSetId?: string;
    /**
     * The parameters that are declared in a dataset.
     */
    datasetParameters?: Array<CfnDataSet.DatasetParameterProperty | cdk.IResolvable> | cdk.IResolvable;
    /**
     * The refresh properties of a dataset.
     */
    dataSetRefreshProperties?: CfnDataSet.DataSetRefreshPropertiesProperty | cdk.IResolvable;
    /**
     * The usage configuration to apply to child datasets that reference this dataset as a source.
     */
    dataSetUsageConfiguration?: CfnDataSet.DataSetUsageConfigurationProperty | cdk.IResolvable;
    /**
     * The folder that contains fields and nested subfolders for your dataset.
     */
    fieldFolders?: cdk.IResolvable | Record<string, CfnDataSet.FieldFolderProperty | cdk.IResolvable>;
    /**
     * Indicates whether you want to import the data into SPICE.
     */
    importMode?: string;
    /**
     * The wait policy to use when creating or updating a Dataset.
     */
    ingestionWaitPolicy?: CfnDataSet.IngestionWaitPolicyProperty | cdk.IResolvable;
    /**
     * Configures the combination and transformation of the data from the physical tables.
     */
    logicalTableMap?: cdk.IResolvable | Record<string, cdk.IResolvable | CfnDataSet.LogicalTableProperty>;
    /**
     * The display name for the dataset.
     */
    name?: string;
    /**
     * A list of resource permissions on the dataset.
     */
    permissions?: Array<cdk.IResolvable | CfnDataSet.ResourcePermissionProperty> | cdk.IResolvable;
    /**
     * Declares the physical tables that are available in the underlying data sources.
     */
    physicalTableMap?: cdk.IResolvable | Record<string, cdk.IResolvable | CfnDataSet.PhysicalTableProperty>;
    /**
     * The row-level security configuration for the data that you want to create.
     */
    rowLevelPermissionDataSet?: cdk.IResolvable | CfnDataSet.RowLevelPermissionDataSetProperty;
    /**
     * The element you can use to define tags for row-level security.
     */
    rowLevelPermissionTagConfiguration?: cdk.IResolvable | CfnDataSet.RowLevelPermissionTagConfigurationProperty;
    /**
     * Tag Manager which manages the tags for this resource
     */
    readonly tags: cdk.TagManager;
    /**
     * Contains a map of the key-value pairs for the resource tag or tags assigned to the dataset.
     */
    tagsRaw?: Array<cdk.CfnTag>;
    /**
     * @param scope Scope in which this resource is defined
     * @param id Construct identifier for this resource (unique in its scope)
     * @param props Resource properties
     */
    constructor(scope: constructs.Construct, id: string, props?: CfnDataSetProps);
    protected get cfnProperties(): Record<string, any>;
    /**
     * Examines the CloudFormation resource and discloses attributes
     *
     * @param inspector tree inspector to collect and process attributes
     */
    inspect(inspector: cdk.TreeInspector): void;
    protected renderProperties(props: Record<string, any>): Record<string, any>;
}
export declare namespace CfnDataSet {
    /**
     * A view of a data source that contains information about the shape of the data in the underlying source.
     *
     * This is a variant type structure. For this structure to be valid, only one of the attributes can be non-null.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-physicaltable.html
     */
    interface PhysicalTableProperty {
        /**
         * A physical table type built from the results of the custom SQL query.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-physicaltable.html#cfn-quicksight-dataset-physicaltable-customsql
         */
        readonly customSql?: CfnDataSet.CustomSqlProperty | cdk.IResolvable;
        /**
         * A physical table type for relational data sources.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-physicaltable.html#cfn-quicksight-dataset-physicaltable-relationaltable
         */
        readonly relationalTable?: cdk.IResolvable | CfnDataSet.RelationalTableProperty;
        /**
         * A physical table type for as S3 data source.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-physicaltable.html#cfn-quicksight-dataset-physicaltable-s3source
         */
        readonly s3Source?: cdk.IResolvable | CfnDataSet.S3SourceProperty;
    }
    /**
     * A physical table type for relational data sources.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-relationaltable.html
     */
    interface RelationalTableProperty {
        /**
         * The catalog associated with a table.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-relationaltable.html#cfn-quicksight-dataset-relationaltable-catalog
         */
        readonly catalog?: string;
        /**
         * The Amazon Resource Name (ARN) for the data source.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-relationaltable.html#cfn-quicksight-dataset-relationaltable-datasourcearn
         */
        readonly dataSourceArn: string;
        /**
         * The column schema of the table.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-relationaltable.html#cfn-quicksight-dataset-relationaltable-inputcolumns
         */
        readonly inputColumns: Array<CfnDataSet.InputColumnProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The name of the relational table.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-relationaltable.html#cfn-quicksight-dataset-relationaltable-name
         */
        readonly name: string;
        /**
         * The schema name.
         *
         * This name applies to certain relational database engines.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-relationaltable.html#cfn-quicksight-dataset-relationaltable-schema
         */
        readonly schema?: string;
    }
    /**
     * Metadata for a column that is used as the input of a transform operation.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-inputcolumn.html
     */
    interface InputColumnProperty {
        /**
         * The name of this column in the underlying data source.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-inputcolumn.html#cfn-quicksight-dataset-inputcolumn-name
         */
        readonly name: string;
        /**
         * The sub data type of the column.
         *
         * Sub types are only available for decimal columns that are part of a SPICE dataset.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-inputcolumn.html#cfn-quicksight-dataset-inputcolumn-subtype
         */
        readonly subType?: string;
        /**
         * The data type of the column.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-inputcolumn.html#cfn-quicksight-dataset-inputcolumn-type
         */
        readonly type: string;
    }
    /**
     * A physical table type built from the results of the custom SQL query.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-customsql.html
     */
    interface CustomSqlProperty {
        /**
         * The column schema from the SQL query result set.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-customsql.html#cfn-quicksight-dataset-customsql-columns
         */
        readonly columns: Array<CfnDataSet.InputColumnProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The Amazon Resource Name (ARN) of the data source.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-customsql.html#cfn-quicksight-dataset-customsql-datasourcearn
         */
        readonly dataSourceArn: string;
        /**
         * A display name for the SQL query result.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-customsql.html#cfn-quicksight-dataset-customsql-name
         */
        readonly name: string;
        /**
         * The SQL query.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-customsql.html#cfn-quicksight-dataset-customsql-sqlquery
         */
        readonly sqlQuery: string;
    }
    /**
     * A physical table type for an S3 data source.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-s3source.html
     */
    interface S3SourceProperty {
        /**
         * The Amazon Resource Name (ARN) for the data source.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-s3source.html#cfn-quicksight-dataset-s3source-datasourcearn
         */
        readonly dataSourceArn: string;
        /**
         * A physical table type for an S3 data source.
         *
         * > For files that aren't JSON, only `STRING` data types are supported in input columns.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-s3source.html#cfn-quicksight-dataset-s3source-inputcolumns
         */
        readonly inputColumns: Array<CfnDataSet.InputColumnProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * Information about the format for the S3 source file or files.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-s3source.html#cfn-quicksight-dataset-s3source-uploadsettings
         */
        readonly uploadSettings?: cdk.IResolvable | CfnDataSet.UploadSettingsProperty;
    }
    /**
     * Information about the format for a source file or files.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-uploadsettings.html
     */
    interface UploadSettingsProperty {
        /**
         * Whether the file has a header row, or the files each have a header row.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-uploadsettings.html#cfn-quicksight-dataset-uploadsettings-containsheader
         */
        readonly containsHeader?: boolean | cdk.IResolvable;
        /**
         * The delimiter between values in the file.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-uploadsettings.html#cfn-quicksight-dataset-uploadsettings-delimiter
         */
        readonly delimiter?: string;
        /**
         * File format.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-uploadsettings.html#cfn-quicksight-dataset-uploadsettings-format
         */
        readonly format?: string;
        /**
         * A row number to start reading data from.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-uploadsettings.html#cfn-quicksight-dataset-uploadsettings-startfromrow
         */
        readonly startFromRow?: number;
        /**
         * Text qualifier.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-uploadsettings.html#cfn-quicksight-dataset-uploadsettings-textqualifier
         */
        readonly textQualifier?: string;
    }
    /**
     * A FieldFolder element is a folder that contains fields and nested subfolders.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-fieldfolder.html
     */
    interface FieldFolderProperty {
        /**
         * A folder has a list of columns.
         *
         * A column can only be in one folder.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-fieldfolder.html#cfn-quicksight-dataset-fieldfolder-columns
         */
        readonly columns?: Array<string>;
        /**
         * The description for a field folder.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-fieldfolder.html#cfn-quicksight-dataset-fieldfolder-description
         */
        readonly description?: string;
    }
    /**
     * Information about a dataset that contains permissions for row-level security (RLS).
     *
     * The permissions dataset maps fields to users or groups. For more information, see [Using Row-Level Security (RLS) to Restrict Access to a Dataset](https://docs.aws.amazon.com/quicksight/latest/user/restrict-access-to-a-data-set-using-row-level-security.html) in the *Amazon QuickSight User Guide* .
     *
     * The option to deny permissions by setting `PermissionPolicy` to `DENY_ACCESS` is not supported for new RLS datasets.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-rowlevelpermissiondataset.html
     */
    interface RowLevelPermissionDataSetProperty {
        /**
         * The Amazon Resource Name (ARN) of the dataset that contains permissions for RLS.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-rowlevelpermissiondataset.html#cfn-quicksight-dataset-rowlevelpermissiondataset-arn
         */
        readonly arn: string;
        /**
         * The user or group rules associated with the dataset that contains permissions for RLS.
         *
         * By default, `FormatVersion` is `VERSION_1` . When `FormatVersion` is `VERSION_1` , `UserName` and `GroupName` are required. When `FormatVersion` is `VERSION_2` , `UserARN` and `GroupARN` are required, and `Namespace` must not exist.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-rowlevelpermissiondataset.html#cfn-quicksight-dataset-rowlevelpermissiondataset-formatversion
         */
        readonly formatVersion?: string;
        /**
         * The namespace associated with the dataset that contains permissions for RLS.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-rowlevelpermissiondataset.html#cfn-quicksight-dataset-rowlevelpermissiondataset-namespace
         */
        readonly namespace?: string;
        /**
         * The type of permissions to use when interpreting the permissions for RLS.
         *
         * `DENY_ACCESS` is included for backward compatibility only.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-rowlevelpermissiondataset.html#cfn-quicksight-dataset-rowlevelpermissiondataset-permissionpolicy
         */
        readonly permissionPolicy: string;
        /**
         * The status of the row-level security permission dataset.
         *
         * If enabled, the status is `ENABLED` . If disabled, the status is `DISABLED` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-rowlevelpermissiondataset.html#cfn-quicksight-dataset-rowlevelpermissiondataset-status
         */
        readonly status?: string;
    }
    /**
     * The element you can use to define tags for row-level security.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-rowlevelpermissiontagconfiguration.html
     */
    interface RowLevelPermissionTagConfigurationProperty {
        /**
         * The status of row-level security tags.
         *
         * If enabled, the status is `ENABLED` . If disabled, the status is `DISABLED` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-rowlevelpermissiontagconfiguration.html#cfn-quicksight-dataset-rowlevelpermissiontagconfiguration-status
         */
        readonly status?: string;
        /**
         * The configuration of tags on a dataset to set row-level security.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-rowlevelpermissiontagconfiguration.html#cfn-quicksight-dataset-rowlevelpermissiontagconfiguration-tagruleconfigurations
         */
        readonly tagRuleConfigurations?: any | cdk.IResolvable;
        /**
         * A set of rules associated with row-level security, such as the tag names and columns that they are assigned to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-rowlevelpermissiontagconfiguration.html#cfn-quicksight-dataset-rowlevelpermissiontagconfiguration-tagrules
         */
        readonly tagRules: Array<cdk.IResolvable | CfnDataSet.RowLevelPermissionTagRuleProperty> | cdk.IResolvable;
    }
    /**
     * A set of rules associated with a tag.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-rowlevelpermissiontagrule.html
     */
    interface RowLevelPermissionTagRuleProperty {
        /**
         * The column name that a tag key is assigned to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-rowlevelpermissiontagrule.html#cfn-quicksight-dataset-rowlevelpermissiontagrule-columnname
         */
        readonly columnName: string;
        /**
         * A string that you want to use to filter by all the values in a column in the dataset and don’t want to list the values one by one.
         *
         * For example, you can use an asterisk as your match all value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-rowlevelpermissiontagrule.html#cfn-quicksight-dataset-rowlevelpermissiontagrule-matchallvalue
         */
        readonly matchAllValue?: string;
        /**
         * The unique key for a tag.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-rowlevelpermissiontagrule.html#cfn-quicksight-dataset-rowlevelpermissiontagrule-tagkey
         */
        readonly tagKey: string;
        /**
         * A string that you want to use to delimit the values when you pass the values at run time.
         *
         * For example, you can delimit the values with a comma.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-rowlevelpermissiontagrule.html#cfn-quicksight-dataset-rowlevelpermissiontagrule-tagmultivaluedelimiter
         */
        readonly tagMultiValueDelimiter?: string;
    }
    /**
     * The wait policy to use when creating or updating a Dataset.
     *
     * The default is to wait for SPICE ingestion to finish with timeout of 36 hours.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-ingestionwaitpolicy.html
     */
    interface IngestionWaitPolicyProperty {
        /**
         * The maximum time (in hours) to wait for Ingestion to complete.
         *
         * Default timeout is 36 hours. Applicable only when `DataSetImportMode` mode is set to SPICE and `WaitForSpiceIngestion` is set to true.
         *
         * @default - 36
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-ingestionwaitpolicy.html#cfn-quicksight-dataset-ingestionwaitpolicy-ingestionwaittimeinhours
         */
        readonly ingestionWaitTimeInHours?: number;
        /**
         * Wait for SPICE ingestion to finish to mark dataset creation or update as successful.
         *
         * Default (true). Applicable only when `DataSetImportMode` mode is set to SPICE.
         *
         * @default - true
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-ingestionwaitpolicy.html#cfn-quicksight-dataset-ingestionwaitpolicy-waitforspiceingestion
         */
        readonly waitForSpiceIngestion?: boolean | cdk.IResolvable;
    }
    /**
     * The refresh properties of a dataset.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-datasetrefreshproperties.html
     */
    interface DataSetRefreshPropertiesProperty {
        /**
         * The refresh configuration for a dataset.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-datasetrefreshproperties.html#cfn-quicksight-dataset-datasetrefreshproperties-refreshconfiguration
         */
        readonly refreshConfiguration?: cdk.IResolvable | CfnDataSet.RefreshConfigurationProperty;
    }
    /**
     * The refresh configuration of a dataset.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-refreshconfiguration.html
     */
    interface RefreshConfigurationProperty {
        /**
         * The incremental refresh for the dataset.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-refreshconfiguration.html#cfn-quicksight-dataset-refreshconfiguration-incrementalrefresh
         */
        readonly incrementalRefresh?: CfnDataSet.IncrementalRefreshProperty | cdk.IResolvable;
    }
    /**
     * The incremental refresh configuration for a dataset.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-incrementalrefresh.html
     */
    interface IncrementalRefreshProperty {
        /**
         * The lookback window setup for an incremental refresh configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-incrementalrefresh.html#cfn-quicksight-dataset-incrementalrefresh-lookbackwindow
         */
        readonly lookbackWindow?: cdk.IResolvable | CfnDataSet.LookbackWindowProperty;
    }
    /**
     * The lookback window setup of an incremental refresh configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-lookbackwindow.html
     */
    interface LookbackWindowProperty {
        /**
         * The name of the lookback window column.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-lookbackwindow.html#cfn-quicksight-dataset-lookbackwindow-columnname
         */
        readonly columnName?: string;
        /**
         * The lookback window column size.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-lookbackwindow.html#cfn-quicksight-dataset-lookbackwindow-size
         */
        readonly size?: number;
        /**
         * The size unit that is used for the lookback window column.
         *
         * Valid values for this structure are `HOUR` , `DAY` , and `WEEK` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-lookbackwindow.html#cfn-quicksight-dataset-lookbackwindow-sizeunit
         */
        readonly sizeUnit?: string;
    }
    /**
     * A rule defined to grant access on one or more restricted columns.
     *
     * Each dataset can have multiple rules. To create a restricted column, you add it to one or more rules. Each rule must contain at least one column and at least one user or group. To be able to see a restricted column, a user or group needs to be added to a rule for that column.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-columnlevelpermissionrule.html
     */
    interface ColumnLevelPermissionRuleProperty {
        /**
         * An array of column names.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-columnlevelpermissionrule.html#cfn-quicksight-dataset-columnlevelpermissionrule-columnnames
         */
        readonly columnNames?: Array<string>;
        /**
         * An array of Amazon Resource Names (ARNs) for Amazon QuickSight users or groups.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-columnlevelpermissionrule.html#cfn-quicksight-dataset-columnlevelpermissionrule-principals
         */
        readonly principals?: Array<string>;
    }
    /**
     * Groupings of columns that work together in certain Amazon QuickSight features.
     *
     * This is a variant type structure. For this structure to be valid, only one of the attributes can be non-null.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-columngroup.html
     */
    interface ColumnGroupProperty {
        /**
         * Geospatial column group that denotes a hierarchy.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-columngroup.html#cfn-quicksight-dataset-columngroup-geospatialcolumngroup
         */
        readonly geoSpatialColumnGroup?: CfnDataSet.GeoSpatialColumnGroupProperty | cdk.IResolvable;
    }
    /**
     * Geospatial column group that denotes a hierarchy.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-geospatialcolumngroup.html
     */
    interface GeoSpatialColumnGroupProperty {
        /**
         * Columns in this hierarchy.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-geospatialcolumngroup.html#cfn-quicksight-dataset-geospatialcolumngroup-columns
         */
        readonly columns: Array<string>;
        /**
         * Country code.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-geospatialcolumngroup.html#cfn-quicksight-dataset-geospatialcolumngroup-countrycode
         */
        readonly countryCode?: string;
        /**
         * A display name for the hierarchy.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-geospatialcolumngroup.html#cfn-quicksight-dataset-geospatialcolumngroup-name
         */
        readonly name: string;
    }
    /**
     * The parameter declarations of the dataset.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-datasetparameter.html
     */
    interface DatasetParameterProperty {
        /**
         * A date time parameter that is created in the dataset.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-datasetparameter.html#cfn-quicksight-dataset-datasetparameter-datetimedatasetparameter
         */
        readonly dateTimeDatasetParameter?: CfnDataSet.DateTimeDatasetParameterProperty | cdk.IResolvable;
        /**
         * A decimal parameter that is created in the dataset.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-datasetparameter.html#cfn-quicksight-dataset-datasetparameter-decimaldatasetparameter
         */
        readonly decimalDatasetParameter?: CfnDataSet.DecimalDatasetParameterProperty | cdk.IResolvable;
        /**
         * An integer parameter that is created in the dataset.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-datasetparameter.html#cfn-quicksight-dataset-datasetparameter-integerdatasetparameter
         */
        readonly integerDatasetParameter?: CfnDataSet.IntegerDatasetParameterProperty | cdk.IResolvable;
        /**
         * A string parameter that is created in the dataset.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-datasetparameter.html#cfn-quicksight-dataset-datasetparameter-stringdatasetparameter
         */
        readonly stringDatasetParameter?: cdk.IResolvable | CfnDataSet.StringDatasetParameterProperty;
    }
    /**
     * An integer parameter that is created in the dataset.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-integerdatasetparameter.html
     */
    interface IntegerDatasetParameterProperty {
        /**
         * A list of default values for a given integer parameter.
         *
         * This structure only accepts static values.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-integerdatasetparameter.html#cfn-quicksight-dataset-integerdatasetparameter-defaultvalues
         */
        readonly defaultValues?: CfnDataSet.IntegerDatasetParameterDefaultValuesProperty | cdk.IResolvable;
        /**
         * An identifier for the integer parameter created in the dataset.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-integerdatasetparameter.html#cfn-quicksight-dataset-integerdatasetparameter-id
         */
        readonly id: string;
        /**
         * The name of the integer parameter that is created in the dataset.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-integerdatasetparameter.html#cfn-quicksight-dataset-integerdatasetparameter-name
         */
        readonly name: string;
        /**
         * The value type of the dataset parameter.
         *
         * Valid values are `single value` or `multi value` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-integerdatasetparameter.html#cfn-quicksight-dataset-integerdatasetparameter-valuetype
         */
        readonly valueType: string;
    }
    /**
     * A list of default values for a given integer parameter.
     *
     * This structure only accepts static values.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-integerdatasetparameterdefaultvalues.html
     */
    interface IntegerDatasetParameterDefaultValuesProperty {
        /**
         * A list of static default values for a given integer parameter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-integerdatasetparameterdefaultvalues.html#cfn-quicksight-dataset-integerdatasetparameterdefaultvalues-staticvalues
         */
        readonly staticValues?: Array<number> | cdk.IResolvable;
    }
    /**
     * A date time parameter that is created in the dataset.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-datetimedatasetparameter.html
     */
    interface DateTimeDatasetParameterProperty {
        /**
         * A list of default values for a given date time parameter.
         *
         * This structure only accepts static values.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-datetimedatasetparameter.html#cfn-quicksight-dataset-datetimedatasetparameter-defaultvalues
         */
        readonly defaultValues?: CfnDataSet.DateTimeDatasetParameterDefaultValuesProperty | cdk.IResolvable;
        /**
         * An identifier for the parameter that is created in the dataset.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-datetimedatasetparameter.html#cfn-quicksight-dataset-datetimedatasetparameter-id
         */
        readonly id: string;
        /**
         * The name of the date time parameter that is created in the dataset.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-datetimedatasetparameter.html#cfn-quicksight-dataset-datetimedatasetparameter-name
         */
        readonly name: string;
        /**
         * The time granularity of the date time parameter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-datetimedatasetparameter.html#cfn-quicksight-dataset-datetimedatasetparameter-timegranularity
         */
        readonly timeGranularity?: string;
        /**
         * The value type of the dataset parameter.
         *
         * Valid values are `single value` or `multi value` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-datetimedatasetparameter.html#cfn-quicksight-dataset-datetimedatasetparameter-valuetype
         */
        readonly valueType: string;
    }
    /**
     * <p>List of default values defined for a given string date time parameter type.
     *
     * Currently only static values are supported.</p>
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-datetimedatasetparameterdefaultvalues.html
     */
    interface DateTimeDatasetParameterDefaultValuesProperty {
        /**
         * A list of static default values for a given date time parameter.
         *
         * The valid format for this property is `yyyy-MM-dd’T’HH:mm:ss’Z’` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-datetimedatasetparameterdefaultvalues.html#cfn-quicksight-dataset-datetimedatasetparameterdefaultvalues-staticvalues
         */
        readonly staticValues?: Array<string>;
    }
    /**
     * A decimal parameter that is created in the dataset.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-decimaldatasetparameter.html
     */
    interface DecimalDatasetParameterProperty {
        /**
         * A list of default values for a given decimal parameter.
         *
         * This structure only accepts static values.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-decimaldatasetparameter.html#cfn-quicksight-dataset-decimaldatasetparameter-defaultvalues
         */
        readonly defaultValues?: CfnDataSet.DecimalDatasetParameterDefaultValuesProperty | cdk.IResolvable;
        /**
         * An identifier for the decimal parameter created in the dataset.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-decimaldatasetparameter.html#cfn-quicksight-dataset-decimaldatasetparameter-id
         */
        readonly id: string;
        /**
         * The name of the decimal parameter that is created in the dataset.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-decimaldatasetparameter.html#cfn-quicksight-dataset-decimaldatasetparameter-name
         */
        readonly name: string;
        /**
         * The value type of the dataset parameter.
         *
         * Valid values are `single value` or `multi value` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-decimaldatasetparameter.html#cfn-quicksight-dataset-decimaldatasetparameter-valuetype
         */
        readonly valueType: string;
    }
    /**
     * A list of default values for a given decimal parameter.
     *
     * This structure only accepts static values.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-decimaldatasetparameterdefaultvalues.html
     */
    interface DecimalDatasetParameterDefaultValuesProperty {
        /**
         * A list of static default values for a given decimal parameter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-decimaldatasetparameterdefaultvalues.html#cfn-quicksight-dataset-decimaldatasetparameterdefaultvalues-staticvalues
         */
        readonly staticValues?: Array<number> | cdk.IResolvable;
    }
    /**
     * A string parameter that is created in the dataset.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-stringdatasetparameter.html
     */
    interface StringDatasetParameterProperty {
        /**
         * A list of default values for a given string dataset parameter type.
         *
         * This structure only accepts static values.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-stringdatasetparameter.html#cfn-quicksight-dataset-stringdatasetparameter-defaultvalues
         */
        readonly defaultValues?: cdk.IResolvable | CfnDataSet.StringDatasetParameterDefaultValuesProperty;
        /**
         * An identifier for the string parameter that is created in the dataset.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-stringdatasetparameter.html#cfn-quicksight-dataset-stringdatasetparameter-id
         */
        readonly id: string;
        /**
         * The name of the string parameter that is created in the dataset.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-stringdatasetparameter.html#cfn-quicksight-dataset-stringdatasetparameter-name
         */
        readonly name: string;
        /**
         * The value type of the dataset parameter.
         *
         * Valid values are `single value` or `multi value` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-stringdatasetparameter.html#cfn-quicksight-dataset-stringdatasetparameter-valuetype
         */
        readonly valueType: string;
    }
    /**
     * A list of default values for a given string dataset parameter type.
     *
     * This structure only accepts static values.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-stringdatasetparameterdefaultvalues.html
     */
    interface StringDatasetParameterDefaultValuesProperty {
        /**
         * A list of static default values for a given string parameter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-stringdatasetparameterdefaultvalues.html#cfn-quicksight-dataset-stringdatasetparameterdefaultvalues-staticvalues
         */
        readonly staticValues?: Array<string>;
    }
    /**
     * A *logical table* is a unit that joins and that data transformations operate on.
     *
     * A logical table has a source, which can be either a physical table or result of a join. When a logical table points to a physical table, the logical table acts as a mutable copy of that physical table through transform operations.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-logicaltable.html
     */
    interface LogicalTableProperty {
        /**
         * A display name for the logical table.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-logicaltable.html#cfn-quicksight-dataset-logicaltable-alias
         */
        readonly alias: string;
        /**
         * Transform operations that act on this logical table.
         *
         * For this structure to be valid, only one of the attributes can be non-null.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-logicaltable.html#cfn-quicksight-dataset-logicaltable-datatransforms
         */
        readonly dataTransforms?: Array<cdk.IResolvable | CfnDataSet.TransformOperationProperty> | cdk.IResolvable;
        /**
         * Source of this logical table.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-logicaltable.html#cfn-quicksight-dataset-logicaltable-source
         */
        readonly source: cdk.IResolvable | CfnDataSet.LogicalTableSourceProperty;
    }
    /**
     * A data transformation on a logical table.
     *
     * This is a variant type structure. For this structure to be valid, only one of the attributes can be non-null.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-transformoperation.html
     */
    interface TransformOperationProperty {
        /**
         * A transform operation that casts a column to a different type.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-transformoperation.html#cfn-quicksight-dataset-transformoperation-castcolumntypeoperation
         */
        readonly castColumnTypeOperation?: CfnDataSet.CastColumnTypeOperationProperty | cdk.IResolvable;
        /**
         * An operation that creates calculated columns.
         *
         * Columns created in one such operation form a lexical closure.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-transformoperation.html#cfn-quicksight-dataset-transformoperation-createcolumnsoperation
         */
        readonly createColumnsOperation?: CfnDataSet.CreateColumnsOperationProperty | cdk.IResolvable;
        /**
         * An operation that filters rows based on some condition.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-transformoperation.html#cfn-quicksight-dataset-transformoperation-filteroperation
         */
        readonly filterOperation?: CfnDataSet.FilterOperationProperty | cdk.IResolvable;
        /**
         * <p>A transform operation that overrides the dataset parameter values defined in another dataset.</p>.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-transformoperation.html#cfn-quicksight-dataset-transformoperation-overridedatasetparameteroperation
         */
        readonly overrideDatasetParameterOperation?: cdk.IResolvable | CfnDataSet.OverrideDatasetParameterOperationProperty;
        /**
         * An operation that projects columns.
         *
         * Operations that come after a projection can only refer to projected columns.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-transformoperation.html#cfn-quicksight-dataset-transformoperation-projectoperation
         */
        readonly projectOperation?: cdk.IResolvable | CfnDataSet.ProjectOperationProperty;
        /**
         * An operation that renames a column.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-transformoperation.html#cfn-quicksight-dataset-transformoperation-renamecolumnoperation
         */
        readonly renameColumnOperation?: cdk.IResolvable | CfnDataSet.RenameColumnOperationProperty;
        /**
         * An operation that tags a column with additional information.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-transformoperation.html#cfn-quicksight-dataset-transformoperation-tagcolumnoperation
         */
        readonly tagColumnOperation?: cdk.IResolvable | CfnDataSet.TagColumnOperationProperty;
    }
    /**
     * A transform operation that tags a column with additional information.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-tagcolumnoperation.html
     */
    interface TagColumnOperationProperty {
        /**
         * The column that this operation acts on.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-tagcolumnoperation.html#cfn-quicksight-dataset-tagcolumnoperation-columnname
         */
        readonly columnName: string;
        /**
         * The dataset column tag, currently only used for geospatial type tagging.
         *
         * > This is not tags for the AWS tagging feature.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-tagcolumnoperation.html#cfn-quicksight-dataset-tagcolumnoperation-tags
         */
        readonly tags: Array<CfnDataSet.ColumnTagProperty>;
    }
    /**
     * A tag for a column in a `[TagColumnOperation](https://docs.aws.amazon.com/quicksight/latest/APIReference/API_TagColumnOperation.html)` structure. This is a variant type structure. For this structure to be valid, only one of the attributes can be non-null.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-columntag.html
     */
    interface ColumnTagProperty {
        /**
         * A description for a column.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-columntag.html#cfn-quicksight-dataset-columntag-columndescription
         */
        readonly columnDescription?: CfnDataSet.ColumnDescriptionProperty | cdk.IResolvable;
        /**
         * A geospatial role for a column.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-columntag.html#cfn-quicksight-dataset-columntag-columngeographicrole
         */
        readonly columnGeographicRole?: string;
    }
    /**
     * Metadata that contains a description for a column.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-columndescription.html
     */
    interface ColumnDescriptionProperty {
        /**
         * The text of a description for a column.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-columndescription.html#cfn-quicksight-dataset-columndescription-text
         */
        readonly text?: string;
    }
    /**
     * A transform operation that overrides the dataset parameter values that are defined in another dataset.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-overridedatasetparameteroperation.html
     */
    interface OverrideDatasetParameterOperationProperty {
        /**
         * The new default values for the parameter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-overridedatasetparameteroperation.html#cfn-quicksight-dataset-overridedatasetparameteroperation-newdefaultvalues
         */
        readonly newDefaultValues?: cdk.IResolvable | CfnDataSet.NewDefaultValuesProperty;
        /**
         * The new name for the parameter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-overridedatasetparameteroperation.html#cfn-quicksight-dataset-overridedatasetparameteroperation-newparametername
         */
        readonly newParameterName?: string;
        /**
         * The name of the parameter to be overridden with different values.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-overridedatasetparameteroperation.html#cfn-quicksight-dataset-overridedatasetparameteroperation-parametername
         */
        readonly parameterName: string;
    }
    /**
     * The new default values for the parameter.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-newdefaultvalues.html
     */
    interface NewDefaultValuesProperty {
        /**
         * A list of static default values for a given date time parameter.
         *
         * The valid format for this property is `yyyy-MM-dd’T’HH:mm:ss’Z’` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-newdefaultvalues.html#cfn-quicksight-dataset-newdefaultvalues-datetimestaticvalues
         */
        readonly dateTimeStaticValues?: Array<string>;
        /**
         * A list of static default values for a given decimal parameter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-newdefaultvalues.html#cfn-quicksight-dataset-newdefaultvalues-decimalstaticvalues
         */
        readonly decimalStaticValues?: Array<number> | cdk.IResolvable;
        /**
         * A list of static default values for a given integer parameter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-newdefaultvalues.html#cfn-quicksight-dataset-newdefaultvalues-integerstaticvalues
         */
        readonly integerStaticValues?: Array<number> | cdk.IResolvable;
        /**
         * A list of static default values for a given string parameter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-newdefaultvalues.html#cfn-quicksight-dataset-newdefaultvalues-stringstaticvalues
         */
        readonly stringStaticValues?: Array<string>;
    }
    /**
     * A transform operation that filters rows based on a condition.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-filteroperation.html
     */
    interface FilterOperationProperty {
        /**
         * An expression that must evaluate to a Boolean value.
         *
         * Rows for which the expression evaluates to true are kept in the dataset.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-filteroperation.html#cfn-quicksight-dataset-filteroperation-conditionexpression
         */
        readonly conditionExpression: string;
    }
    /**
     * A transform operation that casts a column to a different type.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-castcolumntypeoperation.html
     */
    interface CastColumnTypeOperationProperty {
        /**
         * Column name.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-castcolumntypeoperation.html#cfn-quicksight-dataset-castcolumntypeoperation-columnname
         */
        readonly columnName: string;
        /**
         * When casting a column from string to datetime type, you can supply a string in a format supported by Amazon QuickSight to denote the source data format.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-castcolumntypeoperation.html#cfn-quicksight-dataset-castcolumntypeoperation-format
         */
        readonly format?: string;
        /**
         * New column data type.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-castcolumntypeoperation.html#cfn-quicksight-dataset-castcolumntypeoperation-newcolumntype
         */
        readonly newColumnType: string;
        /**
         * The sub data type of the new column.
         *
         * Sub types are only available for decimal columns that are part of a SPICE dataset.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-castcolumntypeoperation.html#cfn-quicksight-dataset-castcolumntypeoperation-subtype
         */
        readonly subType?: string;
    }
    /**
     * A transform operation that creates calculated columns.
     *
     * Columns created in one such operation form a lexical closure.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-createcolumnsoperation.html
     */
    interface CreateColumnsOperationProperty {
        /**
         * Calculated columns to create.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-createcolumnsoperation.html#cfn-quicksight-dataset-createcolumnsoperation-columns
         */
        readonly columns: Array<CfnDataSet.CalculatedColumnProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * A calculated column for a dataset.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-calculatedcolumn.html
     */
    interface CalculatedColumnProperty {
        /**
         * A unique ID to identify a calculated column.
         *
         * During a dataset update, if the column ID of a calculated column matches that of an existing calculated column, Amazon QuickSight preserves the existing calculated column.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-calculatedcolumn.html#cfn-quicksight-dataset-calculatedcolumn-columnid
         */
        readonly columnId: string;
        /**
         * Column name.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-calculatedcolumn.html#cfn-quicksight-dataset-calculatedcolumn-columnname
         */
        readonly columnName: string;
        /**
         * An expression that defines the calculated column.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-calculatedcolumn.html#cfn-quicksight-dataset-calculatedcolumn-expression
         */
        readonly expression: string;
    }
    /**
     * A transform operation that renames a column.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-renamecolumnoperation.html
     */
    interface RenameColumnOperationProperty {
        /**
         * The name of the column to be renamed.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-renamecolumnoperation.html#cfn-quicksight-dataset-renamecolumnoperation-columnname
         */
        readonly columnName: string;
        /**
         * The new name for the column.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-renamecolumnoperation.html#cfn-quicksight-dataset-renamecolumnoperation-newcolumnname
         */
        readonly newColumnName: string;
    }
    /**
     * A transform operation that projects columns.
     *
     * Operations that come after a projection can only refer to projected columns.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-projectoperation.html
     */
    interface ProjectOperationProperty {
        /**
         * Projected columns.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-projectoperation.html#cfn-quicksight-dataset-projectoperation-projectedcolumns
         */
        readonly projectedColumns: Array<string>;
    }
    /**
     * Information about the source of a logical table.
     *
     * This is a variant type structure. For this structure to be valid, only one of the attributes can be non-null.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-logicaltablesource.html
     */
    interface LogicalTableSourceProperty {
        /**
         * The Amazon Resource Number (ARN) of the parent dataset.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-logicaltablesource.html#cfn-quicksight-dataset-logicaltablesource-datasetarn
         */
        readonly dataSetArn?: string;
        /**
         * Specifies the result of a join of two logical tables.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-logicaltablesource.html#cfn-quicksight-dataset-logicaltablesource-joininstruction
         */
        readonly joinInstruction?: cdk.IResolvable | CfnDataSet.JoinInstructionProperty;
        /**
         * Physical table ID.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-logicaltablesource.html#cfn-quicksight-dataset-logicaltablesource-physicaltableid
         */
        readonly physicalTableId?: string;
    }
    /**
     * The instructions associated with a join.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-joininstruction.html
     */
    interface JoinInstructionProperty {
        /**
         * Join key properties of the left operand.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-joininstruction.html#cfn-quicksight-dataset-joininstruction-leftjoinkeyproperties
         */
        readonly leftJoinKeyProperties?: cdk.IResolvable | CfnDataSet.JoinKeyPropertiesProperty;
        /**
         * The operand on the left side of a join.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-joininstruction.html#cfn-quicksight-dataset-joininstruction-leftoperand
         */
        readonly leftOperand: string;
        /**
         * The join instructions provided in the `ON` clause of a join.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-joininstruction.html#cfn-quicksight-dataset-joininstruction-onclause
         */
        readonly onClause: string;
        /**
         * Join key properties of the right operand.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-joininstruction.html#cfn-quicksight-dataset-joininstruction-rightjoinkeyproperties
         */
        readonly rightJoinKeyProperties?: cdk.IResolvable | CfnDataSet.JoinKeyPropertiesProperty;
        /**
         * The operand on the right side of a join.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-joininstruction.html#cfn-quicksight-dataset-joininstruction-rightoperand
         */
        readonly rightOperand: string;
        /**
         * The type of join that it is.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-joininstruction.html#cfn-quicksight-dataset-joininstruction-type
         */
        readonly type: string;
    }
    /**
     * Properties associated with the columns participating in a join.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-joinkeyproperties.html
     */
    interface JoinKeyPropertiesProperty {
        /**
         * A value that indicates that a row in a table is uniquely identified by the columns in a join key.
         *
         * This is used by Amazon QuickSight to optimize query performance.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-joinkeyproperties.html#cfn-quicksight-dataset-joinkeyproperties-uniquekey
         */
        readonly uniqueKey?: boolean | cdk.IResolvable;
    }
    /**
     * Permission for the resource.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-resourcepermission.html
     */
    interface ResourcePermissionProperty {
        /**
         * The IAM action to grant or revoke permisions on.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-resourcepermission.html#cfn-quicksight-dataset-resourcepermission-actions
         */
        readonly actions: Array<string>;
        /**
         * The Amazon Resource Name (ARN) of the principal. This can be one of the following:.
         *
         * - The ARN of an Amazon QuickSight user or group associated with a data source or dataset. (This is common.)
         * - The ARN of an Amazon QuickSight user, group, or namespace associated with an analysis, dashboard, template, or theme. (This is common.)
         * - The ARN of an AWS account root: This is an IAM ARN rather than a Amazon QuickSight ARN. Use this option only to share resources (templates) across AWS accounts . (This is less common.)
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-resourcepermission.html#cfn-quicksight-dataset-resourcepermission-principal
         */
        readonly principal: string;
    }
    /**
     * The usage configuration to apply to child datasets that reference this dataset as a source.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-datasetusageconfiguration.html
     */
    interface DataSetUsageConfigurationProperty {
        /**
         * An option that controls whether a child dataset of a direct query can use this dataset as a source.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-datasetusageconfiguration.html#cfn-quicksight-dataset-datasetusageconfiguration-disableuseasdirectquerysource
         */
        readonly disableUseAsDirectQuerySource?: boolean | cdk.IResolvable;
        /**
         * An option that controls whether a child dataset that's stored in QuickSight can use this dataset as a source.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-datasetusageconfiguration.html#cfn-quicksight-dataset-datasetusageconfiguration-disableuseasimportedsource
         */
        readonly disableUseAsImportedSource?: boolean | cdk.IResolvable;
    }
    /**
     * Output column.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-outputcolumn.html
     */
    interface OutputColumnProperty {
        /**
         * A description for a column.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-outputcolumn.html#cfn-quicksight-dataset-outputcolumn-description
         */
        readonly description?: string;
        /**
         * The display name of the column..
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-outputcolumn.html#cfn-quicksight-dataset-outputcolumn-name
         */
        readonly name?: string;
        /**
         * The sub data type of the column.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-outputcolumn.html#cfn-quicksight-dataset-outputcolumn-subtype
         */
        readonly subType?: string;
        /**
         * The data type of the column.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-outputcolumn.html#cfn-quicksight-dataset-outputcolumn-type
         */
        readonly type?: string;
    }
}
/**
 * Properties for defining a `CfnDataSet`
 *
 * @struct
 * @stability external
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html
 */
export interface CfnDataSetProps {
    /**
     * The AWS account ID.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-awsaccountid
     */
    readonly awsAccountId?: string;
    /**
     * Groupings of columns that work together in certain Amazon QuickSight features.
     *
     * Currently, only geospatial hierarchy is supported.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-columngroups
     */
    readonly columnGroups?: Array<CfnDataSet.ColumnGroupProperty | cdk.IResolvable> | cdk.IResolvable;
    /**
     * A set of one or more definitions of a `ColumnLevelPermissionRule` .
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-columnlevelpermissionrules
     */
    readonly columnLevelPermissionRules?: Array<CfnDataSet.ColumnLevelPermissionRuleProperty | cdk.IResolvable> | cdk.IResolvable;
    /**
     * An ID for the dataset that you want to create.
     *
     * This ID is unique per AWS Region for each AWS account.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-datasetid
     */
    readonly dataSetId?: string;
    /**
     * The parameters that are declared in a dataset.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-datasetparameters
     */
    readonly datasetParameters?: Array<CfnDataSet.DatasetParameterProperty | cdk.IResolvable> | cdk.IResolvable;
    /**
     * The refresh properties of a dataset.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-datasetrefreshproperties
     */
    readonly dataSetRefreshProperties?: CfnDataSet.DataSetRefreshPropertiesProperty | cdk.IResolvable;
    /**
     * The usage configuration to apply to child datasets that reference this dataset as a source.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-datasetusageconfiguration
     */
    readonly dataSetUsageConfiguration?: CfnDataSet.DataSetUsageConfigurationProperty | cdk.IResolvable;
    /**
     * The folder that contains fields and nested subfolders for your dataset.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-fieldfolders
     */
    readonly fieldFolders?: cdk.IResolvable | Record<string, CfnDataSet.FieldFolderProperty | cdk.IResolvable>;
    /**
     * Indicates whether you want to import the data into SPICE.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-importmode
     */
    readonly importMode?: string;
    /**
     * The wait policy to use when creating or updating a Dataset.
     *
     * The default is to wait for SPICE ingestion to finish with timeout of 36 hours.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-ingestionwaitpolicy
     */
    readonly ingestionWaitPolicy?: CfnDataSet.IngestionWaitPolicyProperty | cdk.IResolvable;
    /**
     * Configures the combination and transformation of the data from the physical tables.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-logicaltablemap
     */
    readonly logicalTableMap?: cdk.IResolvable | Record<string, cdk.IResolvable | CfnDataSet.LogicalTableProperty>;
    /**
     * The display name for the dataset.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-name
     */
    readonly name?: string;
    /**
     * A list of resource permissions on the dataset.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-permissions
     */
    readonly permissions?: Array<cdk.IResolvable | CfnDataSet.ResourcePermissionProperty> | cdk.IResolvable;
    /**
     * Declares the physical tables that are available in the underlying data sources.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-physicaltablemap
     */
    readonly physicalTableMap?: cdk.IResolvable | Record<string, cdk.IResolvable | CfnDataSet.PhysicalTableProperty>;
    /**
     * The row-level security configuration for the data that you want to create.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-rowlevelpermissiondataset
     */
    readonly rowLevelPermissionDataSet?: cdk.IResolvable | CfnDataSet.RowLevelPermissionDataSetProperty;
    /**
     * The element you can use to define tags for row-level security.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-rowlevelpermissiontagconfiguration
     */
    readonly rowLevelPermissionTagConfiguration?: cdk.IResolvable | CfnDataSet.RowLevelPermissionTagConfigurationProperty;
    /**
     * Contains a map of the key-value pairs for the resource tag or tags assigned to the dataset.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-tags
     */
    readonly tags?: Array<cdk.CfnTag>;
}
/**
 * Creates a data source.
 *
 * @cloudformationResource AWS::QuickSight::DataSource
 * @stability external
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html
 */
export declare class CfnDataSource extends cdk.CfnResource implements cdk.IInspectable, cdk.ITaggable {
    /**
     * The CloudFormation resource type name for this resource class.
     */
    static readonly CFN_RESOURCE_TYPE_NAME: string;
    /**
     * Build a CfnDataSource from CloudFormation properties
     *
     * A factory method that creates a new instance of this class from an object
     * containing the CloudFormation properties of this resource.
     * Used in the @aws-cdk/cloudformation-include module.
     *
     * @internal
     */
    static _fromCloudFormation(scope: constructs.Construct, id: string, resourceAttributes: any, options: cfn_parse.FromCloudFormationOptions): CfnDataSource;
    /**
     * The Amazon Resource Name (ARN) of the dataset.
     *
     * @cloudformationAttribute Arn
     */
    readonly attrArn: string;
    /**
     * The time that this data source was created.
     *
     * @cloudformationAttribute CreatedTime
     */
    readonly attrCreatedTime: string;
    /**
     * The last time that this data source was updated.
     *
     * @cloudformationAttribute LastUpdatedTime
     */
    readonly attrLastUpdatedTime: string;
    /**
     * The HTTP status of the request.
     *
     * @cloudformationAttribute Status
     */
    readonly attrStatus: string;
    /**
     * A set of alternate data source parameters that you want to share for the credentials stored with this data source.
     */
    alternateDataSourceParameters?: Array<CfnDataSource.DataSourceParametersProperty | cdk.IResolvable> | cdk.IResolvable;
    /**
     * The AWS account ID.
     */
    awsAccountId?: string;
    /**
     * The credentials Amazon QuickSight that uses to connect to your underlying source.
     */
    credentials?: CfnDataSource.DataSourceCredentialsProperty | cdk.IResolvable;
    /**
     * An ID for the data source.
     */
    dataSourceId?: string;
    /**
     * The parameters that Amazon QuickSight uses to connect to your underlying source.
     */
    dataSourceParameters?: CfnDataSource.DataSourceParametersProperty | cdk.IResolvable;
    /**
     * Error information from the last update or the creation of the data source.
     */
    errorInfo?: CfnDataSource.DataSourceErrorInfoProperty | cdk.IResolvable;
    /**
     * A display name for the data source.
     */
    name?: string;
    /**
     * A list of resource permissions on the data source.
     */
    permissions?: Array<cdk.IResolvable | CfnDataSource.ResourcePermissionProperty> | cdk.IResolvable;
    /**
     * Secure Socket Layer (SSL) properties that apply when Amazon QuickSight connects to your underlying source.
     */
    sslProperties?: cdk.IResolvable | CfnDataSource.SslPropertiesProperty;
    /**
     * Tag Manager which manages the tags for this resource
     */
    readonly tags: cdk.TagManager;
    /**
     * Contains a map of the key-value pairs for the resource tag or tags assigned to the data source.
     */
    tagsRaw?: Array<cdk.CfnTag>;
    /**
     * The type of the data source. To return a list of all data sources, use `ListDataSources` .
     */
    type?: string;
    /**
     * Use this parameter only when you want Amazon QuickSight to use a VPC connection when connecting to your underlying source.
     */
    vpcConnectionProperties?: cdk.IResolvable | CfnDataSource.VpcConnectionPropertiesProperty;
    /**
     * @param scope Scope in which this resource is defined
     * @param id Construct identifier for this resource (unique in its scope)
     * @param props Resource properties
     */
    constructor(scope: constructs.Construct, id: string, props?: CfnDataSourceProps);
    protected get cfnProperties(): Record<string, any>;
    /**
     * Examines the CloudFormation resource and discloses attributes
     *
     * @param inspector tree inspector to collect and process attributes
     */
    inspect(inspector: cdk.TreeInspector): void;
    protected renderProperties(props: Record<string, any>): Record<string, any>;
}
export declare namespace CfnDataSource {
    /**
     * The parameters that Amazon QuickSight uses to connect to your underlying data source.
     *
     * This is a variant type structure. For this structure to be valid, only one of the attributes can be non-null.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html
     */
    interface DataSourceParametersProperty {
        /**
         * The parameters for OpenSearch.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-amazonelasticsearchparameters
         */
        readonly amazonElasticsearchParameters?: CfnDataSource.AmazonElasticsearchParametersProperty | cdk.IResolvable;
        /**
         * The parameters for OpenSearch.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-amazonopensearchparameters
         */
        readonly amazonOpenSearchParameters?: CfnDataSource.AmazonOpenSearchParametersProperty | cdk.IResolvable;
        /**
         * The parameters for Amazon Athena.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-athenaparameters
         */
        readonly athenaParameters?: CfnDataSource.AthenaParametersProperty | cdk.IResolvable;
        /**
         * The parameters for Amazon Aurora MySQL.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-auroraparameters
         */
        readonly auroraParameters?: CfnDataSource.AuroraParametersProperty | cdk.IResolvable;
        /**
         * The parameters for Amazon Aurora.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-aurorapostgresqlparameters
         */
        readonly auroraPostgreSqlParameters?: CfnDataSource.AuroraPostgreSqlParametersProperty | cdk.IResolvable;
        /**
         * The required parameters that are needed to connect to a Databricks data source.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-databricksparameters
         */
        readonly databricksParameters?: CfnDataSource.DatabricksParametersProperty | cdk.IResolvable;
        /**
         * The parameters for MariaDB.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-mariadbparameters
         */
        readonly mariaDbParameters?: cdk.IResolvable | CfnDataSource.MariaDbParametersProperty;
        /**
         * The parameters for MySQL.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-mysqlparameters
         */
        readonly mySqlParameters?: cdk.IResolvable | CfnDataSource.MySqlParametersProperty;
        /**
         * Oracle parameters.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-oracleparameters
         */
        readonly oracleParameters?: cdk.IResolvable | CfnDataSource.OracleParametersProperty;
        /**
         * The parameters for PostgreSQL.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-postgresqlparameters
         */
        readonly postgreSqlParameters?: cdk.IResolvable | CfnDataSource.PostgreSqlParametersProperty;
        /**
         * The parameters for Presto.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-prestoparameters
         */
        readonly prestoParameters?: cdk.IResolvable | CfnDataSource.PrestoParametersProperty;
        /**
         * The parameters for Amazon RDS.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-rdsparameters
         */
        readonly rdsParameters?: cdk.IResolvable | CfnDataSource.RdsParametersProperty;
        /**
         * The parameters for Amazon Redshift.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-redshiftparameters
         */
        readonly redshiftParameters?: cdk.IResolvable | CfnDataSource.RedshiftParametersProperty;
        /**
         * The parameters for S3.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-s3parameters
         */
        readonly s3Parameters?: cdk.IResolvable | CfnDataSource.S3ParametersProperty;
        /**
         * The parameters for Snowflake.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-snowflakeparameters
         */
        readonly snowflakeParameters?: cdk.IResolvable | CfnDataSource.SnowflakeParametersProperty;
        /**
         * The parameters for Spark.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-sparkparameters
         */
        readonly sparkParameters?: cdk.IResolvable | CfnDataSource.SparkParametersProperty;
        /**
         * The parameters for SQL Server.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-sqlserverparameters
         */
        readonly sqlServerParameters?: cdk.IResolvable | CfnDataSource.SqlServerParametersProperty;
        /**
         * The parameters that are required to connect to a Starburst data source.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-starburstparameters
         */
        readonly starburstParameters?: cdk.IResolvable | CfnDataSource.StarburstParametersProperty;
        /**
         * The parameters for Teradata.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-teradataparameters
         */
        readonly teradataParameters?: cdk.IResolvable | CfnDataSource.TeradataParametersProperty;
        /**
         * The parameters that are required to connect to a Trino data source.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-trinoparameters
         */
        readonly trinoParameters?: cdk.IResolvable | CfnDataSource.TrinoParametersProperty;
    }
    /**
     * Parameters for Amazon Aurora PostgreSQL-Compatible Edition.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-aurorapostgresqlparameters.html
     */
    interface AuroraPostgreSqlParametersProperty {
        /**
         * The Amazon Aurora PostgreSQL database to connect to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-aurorapostgresqlparameters.html#cfn-quicksight-datasource-aurorapostgresqlparameters-database
         */
        readonly database: string;
        /**
         * The Amazon Aurora PostgreSQL-Compatible host to connect to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-aurorapostgresqlparameters.html#cfn-quicksight-datasource-aurorapostgresqlparameters-host
         */
        readonly host: string;
        /**
         * The port that Amazon Aurora PostgreSQL is listening on.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-aurorapostgresqlparameters.html#cfn-quicksight-datasource-aurorapostgresqlparameters-port
         */
        readonly port: number;
    }
    /**
     * The parameters for Teradata.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-teradataparameters.html
     */
    interface TeradataParametersProperty {
        /**
         * Database.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-teradataparameters.html#cfn-quicksight-datasource-teradataparameters-database
         */
        readonly database: string;
        /**
         * Host.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-teradataparameters.html#cfn-quicksight-datasource-teradataparameters-host
         */
        readonly host: string;
        /**
         * Port.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-teradataparameters.html#cfn-quicksight-datasource-teradataparameters-port
         */
        readonly port: number;
    }
    /**
     * The parameters for Amazon RDS.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-rdsparameters.html
     */
    interface RdsParametersProperty {
        /**
         * Database.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-rdsparameters.html#cfn-quicksight-datasource-rdsparameters-database
         */
        readonly database: string;
        /**
         * Instance ID.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-rdsparameters.html#cfn-quicksight-datasource-rdsparameters-instanceid
         */
        readonly instanceId: string;
    }
    /**
     * Parameters for Amazon Athena.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-athenaparameters.html
     */
    interface AthenaParametersProperty {
        /**
         * Use the `RoleArn` structure to override an account-wide role for a specific Athena data source.
         *
         * For example, say an account administrator has turned off all Athena access with an account-wide role. The administrator can then use `RoleArn` to bypass the account-wide role and allow Athena access for the single Athena data source that is specified in the structure, even if the account-wide role forbidding Athena access is still active.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-athenaparameters.html#cfn-quicksight-datasource-athenaparameters-rolearn
         */
        readonly roleArn?: string;
        /**
         * The workgroup that Amazon Athena uses.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-athenaparameters.html#cfn-quicksight-datasource-athenaparameters-workgroup
         */
        readonly workGroup?: string;
    }
    /**
     * The parameters for Spark.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-sparkparameters.html
     */
    interface SparkParametersProperty {
        /**
         * Host.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-sparkparameters.html#cfn-quicksight-datasource-sparkparameters-host
         */
        readonly host: string;
        /**
         * Port.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-sparkparameters.html#cfn-quicksight-datasource-sparkparameters-port
         */
        readonly port: number;
    }
    /**
     * The parameters for MariaDB.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-mariadbparameters.html
     */
    interface MariaDbParametersProperty {
        /**
         * Database.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-mariadbparameters.html#cfn-quicksight-datasource-mariadbparameters-database
         */
        readonly database: string;
        /**
         * Host.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-mariadbparameters.html#cfn-quicksight-datasource-mariadbparameters-host
         */
        readonly host: string;
        /**
         * Port.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-mariadbparameters.html#cfn-quicksight-datasource-mariadbparameters-port
         */
        readonly port: number;
    }
    /**
     * Oracle parameters.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-oracleparameters.html
     */
    interface OracleParametersProperty {
        /**
         * Database.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-oracleparameters.html#cfn-quicksight-datasource-oracleparameters-database
         */
        readonly database: string;
        /**
         * Host.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-oracleparameters.html#cfn-quicksight-datasource-oracleparameters-host
         */
        readonly host: string;
        /**
         * Port.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-oracleparameters.html#cfn-quicksight-datasource-oracleparameters-port
         */
        readonly port: number;
    }
    /**
     * The parameters for Presto.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-prestoparameters.html
     */
    interface PrestoParametersProperty {
        /**
         * Catalog.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-prestoparameters.html#cfn-quicksight-datasource-prestoparameters-catalog
         */
        readonly catalog: string;
        /**
         * Host.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-prestoparameters.html#cfn-quicksight-datasource-prestoparameters-host
         */
        readonly host: string;
        /**
         * Port.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-prestoparameters.html#cfn-quicksight-datasource-prestoparameters-port
         */
        readonly port: number;
    }
    /**
     * The parameters for Amazon Redshift.
     *
     * The `ClusterId` field can be blank if `Host` and `Port` are both set. The `Host` and `Port` fields can be blank if the `ClusterId` field is set.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-redshiftparameters.html
     */
    interface RedshiftParametersProperty {
        /**
         * Cluster ID.
         *
         * This field can be blank if the `Host` and `Port` are provided.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-redshiftparameters.html#cfn-quicksight-datasource-redshiftparameters-clusterid
         */
        readonly clusterId?: string;
        /**
         * Database.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-redshiftparameters.html#cfn-quicksight-datasource-redshiftparameters-database
         */
        readonly database: string;
        /**
         * Host.
         *
         * This field can be blank if `ClusterId` is provided.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-redshiftparameters.html#cfn-quicksight-datasource-redshiftparameters-host
         */
        readonly host?: string;
        /**
         * Port.
         *
         * This field can be blank if the `ClusterId` is provided.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-redshiftparameters.html#cfn-quicksight-datasource-redshiftparameters-port
         */
        readonly port?: number;
    }
    /**
     * The parameters for MySQL.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-mysqlparameters.html
     */
    interface MySqlParametersProperty {
        /**
         * Database.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-mysqlparameters.html#cfn-quicksight-datasource-mysqlparameters-database
         */
        readonly database: string;
        /**
         * Host.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-mysqlparameters.html#cfn-quicksight-datasource-mysqlparameters-host
         */
        readonly host: string;
        /**
         * Port.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-mysqlparameters.html#cfn-quicksight-datasource-mysqlparameters-port
         */
        readonly port: number;
    }
    /**
     * The parameters for SQL Server.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-sqlserverparameters.html
     */
    interface SqlServerParametersProperty {
        /**
         * Database.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-sqlserverparameters.html#cfn-quicksight-datasource-sqlserverparameters-database
         */
        readonly database: string;
        /**
         * Host.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-sqlserverparameters.html#cfn-quicksight-datasource-sqlserverparameters-host
         */
        readonly host: string;
        /**
         * Port.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-sqlserverparameters.html#cfn-quicksight-datasource-sqlserverparameters-port
         */
        readonly port: number;
    }
    /**
     * The parameters for Snowflake.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-snowflakeparameters.html
     */
    interface SnowflakeParametersProperty {
        /**
         * Database.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-snowflakeparameters.html#cfn-quicksight-datasource-snowflakeparameters-database
         */
        readonly database: string;
        /**
         * Host.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-snowflakeparameters.html#cfn-quicksight-datasource-snowflakeparameters-host
         */
        readonly host: string;
        /**
         * Warehouse.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-snowflakeparameters.html#cfn-quicksight-datasource-snowflakeparameters-warehouse
         */
        readonly warehouse: string;
    }
    /**
     * The parameters for OpenSearch.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-amazonelasticsearchparameters.html
     */
    interface AmazonElasticsearchParametersProperty {
        /**
         * The OpenSearch domain.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-amazonelasticsearchparameters.html#cfn-quicksight-datasource-amazonelasticsearchparameters-domain
         */
        readonly domain: string;
    }
    /**
     * The parameters for OpenSearch.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-amazonopensearchparameters.html
     */
    interface AmazonOpenSearchParametersProperty {
        /**
         * The OpenSearch domain.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-amazonopensearchparameters.html#cfn-quicksight-datasource-amazonopensearchparameters-domain
         */
        readonly domain: string;
    }
    /**
     * The parameters for PostgreSQL.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-postgresqlparameters.html
     */
    interface PostgreSqlParametersProperty {
        /**
         * Database.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-postgresqlparameters.html#cfn-quicksight-datasource-postgresqlparameters-database
         */
        readonly database: string;
        /**
         * Host.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-postgresqlparameters.html#cfn-quicksight-datasource-postgresqlparameters-host
         */
        readonly host: string;
        /**
         * Port.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-postgresqlparameters.html#cfn-quicksight-datasource-postgresqlparameters-port
         */
        readonly port: number;
    }
    /**
     * Parameters for Amazon Aurora.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-auroraparameters.html
     */
    interface AuroraParametersProperty {
        /**
         * Database.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-auroraparameters.html#cfn-quicksight-datasource-auroraparameters-database
         */
        readonly database: string;
        /**
         * Host.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-auroraparameters.html#cfn-quicksight-datasource-auroraparameters-host
         */
        readonly host: string;
        /**
         * Port.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-auroraparameters.html#cfn-quicksight-datasource-auroraparameters-port
         */
        readonly port: number;
    }
    /**
     * The parameters for S3.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-s3parameters.html
     */
    interface S3ParametersProperty {
        /**
         * Location of the Amazon S3 manifest file.
         *
         * This is NULL if the manifest file was uploaded into Amazon QuickSight.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-s3parameters.html#cfn-quicksight-datasource-s3parameters-manifestfilelocation
         */
        readonly manifestFileLocation: cdk.IResolvable | CfnDataSource.ManifestFileLocationProperty;
        /**
         * Use the `RoleArn` structure to override an account-wide role for a specific S3 data source.
         *
         * For example, say an account administrator has turned off all S3 access with an account-wide role. The administrator can then use `RoleArn` to bypass the account-wide role and allow S3 access for the single S3 data source that is specified in the structure, even if the account-wide role forbidding S3 access is still active.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-s3parameters.html#cfn-quicksight-datasource-s3parameters-rolearn
         */
        readonly roleArn?: string;
    }
    /**
     * Amazon S3 manifest file location.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-manifestfilelocation.html
     */
    interface ManifestFileLocationProperty {
        /**
         * Amazon S3 bucket.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-manifestfilelocation.html#cfn-quicksight-datasource-manifestfilelocation-bucket
         */
        readonly bucket: string;
        /**
         * Amazon S3 key that identifies an object.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-manifestfilelocation.html#cfn-quicksight-datasource-manifestfilelocation-key
         */
        readonly key: string;
    }
    /**
     * The required parameters that are needed to connect to a Databricks data source.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-databricksparameters.html
     */
    interface DatabricksParametersProperty {
        /**
         * The host name of the Databricks data source.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-databricksparameters.html#cfn-quicksight-datasource-databricksparameters-host
         */
        readonly host: string;
        /**
         * The port for the Databricks data source.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-databricksparameters.html#cfn-quicksight-datasource-databricksparameters-port
         */
        readonly port: number;
        /**
         * The HTTP path of the Databricks data source.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-databricksparameters.html#cfn-quicksight-datasource-databricksparameters-sqlendpointpath
         */
        readonly sqlEndpointPath: string;
    }
    /**
     * The parameters that are required to connect to a Starburst data source.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-starburstparameters.html
     */
    interface StarburstParametersProperty {
        /**
         * The catalog name for the Starburst data source.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-starburstparameters.html#cfn-quicksight-datasource-starburstparameters-catalog
         */
        readonly catalog: string;
        /**
         * The host name of the Starburst data source.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-starburstparameters.html#cfn-quicksight-datasource-starburstparameters-host
         */
        readonly host: string;
        /**
         * The port for the Starburst data source.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-starburstparameters.html#cfn-quicksight-datasource-starburstparameters-port
         */
        readonly port: number;
        /**
         * The product type for the Starburst data source.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-starburstparameters.html#cfn-quicksight-datasource-starburstparameters-producttype
         */
        readonly productType?: string;
    }
    /**
     * The parameters that are required to connect to a Trino data source.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-trinoparameters.html
     */
    interface TrinoParametersProperty {
        /**
         * The catalog name for the Trino data source.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-trinoparameters.html#cfn-quicksight-datasource-trinoparameters-catalog
         */
        readonly catalog: string;
        /**
         * The host name of the Trino data source.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-trinoparameters.html#cfn-quicksight-datasource-trinoparameters-host
         */
        readonly host: string;
        /**
         * The port for the Trino data source.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-trinoparameters.html#cfn-quicksight-datasource-trinoparameters-port
         */
        readonly port: number;
    }
    /**
     * VPC connection properties.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-vpcconnectionproperties.html
     */
    interface VpcConnectionPropertiesProperty {
        /**
         * The Amazon Resource Name (ARN) for the VPC connection.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-vpcconnectionproperties.html#cfn-quicksight-datasource-vpcconnectionproperties-vpcconnectionarn
         */
        readonly vpcConnectionArn: string;
    }
    /**
     * Error information for the data source creation or update.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceerrorinfo.html
     */
    interface DataSourceErrorInfoProperty {
        /**
         * Error message.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceerrorinfo.html#cfn-quicksight-datasource-datasourceerrorinfo-message
         */
        readonly message?: string;
        /**
         * Error type.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceerrorinfo.html#cfn-quicksight-datasource-datasourceerrorinfo-type
         */
        readonly type?: string;
    }
    /**
     * Permission for the resource.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-resourcepermission.html
     */
    interface ResourcePermissionProperty {
        /**
         * The IAM action to grant or revoke permissions on.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-resourcepermission.html#cfn-quicksight-datasource-resourcepermission-actions
         */
        readonly actions: Array<string>;
        /**
         * The Amazon Resource Name (ARN) of the principal. This can be one of the following:.
         *
         * - The ARN of an Amazon QuickSight user or group associated with a data source or dataset. (This is common.)
         * - The ARN of an Amazon QuickSight user, group, or namespace associated with an analysis, dashboard, template, or theme. (This is common.)
         * - The ARN of an AWS account root: This is an IAM ARN rather than a Amazon QuickSight ARN. Use this option only to share resources (templates) across AWS accounts . (This is less common.)
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-resourcepermission.html#cfn-quicksight-datasource-resourcepermission-principal
         */
        readonly principal: string;
    }
    /**
     * Secure Socket Layer (SSL) properties that apply when Amazon QuickSight connects to your underlying data source.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-sslproperties.html
     */
    interface SslPropertiesProperty {
        /**
         * A Boolean option to control whether SSL should be disabled.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-sslproperties.html#cfn-quicksight-datasource-sslproperties-disablessl
         */
        readonly disableSsl?: boolean | cdk.IResolvable;
    }
    /**
     * Data source credentials.
     *
     * This is a variant type structure. For this structure to be valid, only one of the attributes can be non-null.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourcecredentials.html
     */
    interface DataSourceCredentialsProperty {
        /**
         * The Amazon Resource Name (ARN) of a data source that has the credential pair that you want to use.
         *
         * When `CopySourceArn` is not null, the credential pair from the data source in the ARN is used as the credentials for the `DataSourceCredentials` structure.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourcecredentials.html#cfn-quicksight-datasource-datasourcecredentials-copysourcearn
         */
        readonly copySourceArn?: string;
        /**
         * Credential pair.
         *
         * For more information, see `[CredentialPair](https://docs.aws.amazon.com/quicksight/latest/APIReference/API_CredentialPair.html)` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourcecredentials.html#cfn-quicksight-datasource-datasourcecredentials-credentialpair
         */
        readonly credentialPair?: CfnDataSource.CredentialPairProperty | cdk.IResolvable;
        /**
         * The Amazon Resource Name (ARN) of the secret associated with the data source in AWS Secrets Manager .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourcecredentials.html#cfn-quicksight-datasource-datasourcecredentials-secretarn
         */
        readonly secretArn?: string;
    }
    /**
     * The combination of user name and password that are used as credentials.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-credentialpair.html
     */
    interface CredentialPairProperty {
        /**
         * A set of alternate data source parameters that you want to share for these credentials.
         *
         * The credentials are applied in tandem with the data source parameters when you copy a data source by using a create or update request. The API operation compares the `DataSourceParameters` structure that's in the request with the structures in the `AlternateDataSourceParameters` allow list. If the structures are an exact match, the request is allowed to use the new data source with the existing credentials. If the `AlternateDataSourceParameters` list is null, the `DataSourceParameters` originally used with these `Credentials` is automatically allowed.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-credentialpair.html#cfn-quicksight-datasource-credentialpair-alternatedatasourceparameters
         */
        readonly alternateDataSourceParameters?: Array<CfnDataSource.DataSourceParametersProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * Password.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-credentialpair.html#cfn-quicksight-datasource-credentialpair-password
         */
        readonly password: string;
        /**
         * User name.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-credentialpair.html#cfn-quicksight-datasource-credentialpair-username
         */
        readonly username: string;
    }
}
/**
 * Properties for defining a `CfnDataSource`
 *
 * @struct
 * @stability external
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html
 */
export interface CfnDataSourceProps {
    /**
     * A set of alternate data source parameters that you want to share for the credentials stored with this data source.
     *
     * The credentials are applied in tandem with the data source parameters when you copy a data source by using a create or update request. The API operation compares the `DataSourceParameters` structure that's in the request with the structures in the `AlternateDataSourceParameters` allow list. If the structures are an exact match, the request is allowed to use the credentials from this existing data source. If the `AlternateDataSourceParameters` list is null, the `Credentials` originally used with this `DataSourceParameters` are automatically allowed.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-alternatedatasourceparameters
     */
    readonly alternateDataSourceParameters?: Array<CfnDataSource.DataSourceParametersProperty | cdk.IResolvable> | cdk.IResolvable;
    /**
     * The AWS account ID.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-awsaccountid
     */
    readonly awsAccountId?: string;
    /**
     * The credentials Amazon QuickSight that uses to connect to your underlying source.
     *
     * Currently, only credentials based on user name and password are supported.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-credentials
     */
    readonly credentials?: CfnDataSource.DataSourceCredentialsProperty | cdk.IResolvable;
    /**
     * An ID for the data source.
     *
     * This ID is unique per AWS Region for each AWS account.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-datasourceid
     */
    readonly dataSourceId?: string;
    /**
     * The parameters that Amazon QuickSight uses to connect to your underlying source.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-datasourceparameters
     */
    readonly dataSourceParameters?: CfnDataSource.DataSourceParametersProperty | cdk.IResolvable;
    /**
     * Error information from the last update or the creation of the data source.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-errorinfo
     */
    readonly errorInfo?: CfnDataSource.DataSourceErrorInfoProperty | cdk.IResolvable;
    /**
     * A display name for the data source.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-name
     */
    readonly name?: string;
    /**
     * A list of resource permissions on the data source.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-permissions
     */
    readonly permissions?: Array<cdk.IResolvable | CfnDataSource.ResourcePermissionProperty> | cdk.IResolvable;
    /**
     * Secure Socket Layer (SSL) properties that apply when Amazon QuickSight connects to your underlying source.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-sslproperties
     */
    readonly sslProperties?: cdk.IResolvable | CfnDataSource.SslPropertiesProperty;
    /**
     * Contains a map of the key-value pairs for the resource tag or tags assigned to the data source.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-tags
     */
    readonly tags?: Array<cdk.CfnTag>;
    /**
     * The type of the data source. To return a list of all data sources, use `ListDataSources` .
     *
     * Use `AMAZON_ELASTICSEARCH` for Amazon OpenSearch Service.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-type
     */
    readonly type?: string;
    /**
     * Use this parameter only when you want Amazon QuickSight to use a VPC connection when connecting to your underlying source.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-vpcconnectionproperties
     */
    readonly vpcConnectionProperties?: cdk.IResolvable | CfnDataSource.VpcConnectionPropertiesProperty;
}
/**
 * Creates a refresh schedule for a dataset in Amazon QuickSight .
 *
 * @cloudformationResource AWS::QuickSight::RefreshSchedule
 * @stability external
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-refreshschedule.html
 */
export declare class CfnRefreshSchedule extends cdk.CfnResource implements cdk.IInspectable {
    /**
     * The CloudFormation resource type name for this resource class.
     */
    static readonly CFN_RESOURCE_TYPE_NAME: string;
    /**
     * Build a CfnRefreshSchedule from CloudFormation properties
     *
     * A factory method that creates a new instance of this class from an object
     * containing the CloudFormation properties of this resource.
     * Used in the @aws-cdk/cloudformation-include module.
     *
     * @internal
     */
    static _fromCloudFormation(scope: constructs.Construct, id: string, resourceAttributes: any, options: cfn_parse.FromCloudFormationOptions): CfnRefreshSchedule;
    /**
     * The Amazon Resource Name (ARN) for the refresh schedule.
     *
     * @cloudformationAttribute Arn
     */
    readonly attrArn: string;
    /**
     * The AWS account ID of the account that you are creating a schedule in.
     */
    awsAccountId?: string;
    /**
     * The ID of the dataset that you are creating a refresh schedule for.
     */
    dataSetId?: string;
    /**
     * The refresh schedule of a dataset.
     */
    schedule?: cdk.IResolvable | CfnRefreshSchedule.RefreshScheduleMapProperty;
    /**
     * @param scope Scope in which this resource is defined
     * @param id Construct identifier for this resource (unique in its scope)
     * @param props Resource properties
     */
    constructor(scope: constructs.Construct, id: string, props?: CfnRefreshScheduleProps);
    protected get cfnProperties(): Record<string, any>;
    /**
     * Examines the CloudFormation resource and discloses attributes
     *
     * @param inspector tree inspector to collect and process attributes
     */
    inspect(inspector: cdk.TreeInspector): void;
    protected renderProperties(props: Record<string, any>): Record<string, any>;
}
export declare namespace CfnRefreshSchedule {
    /**
     * A summary of a configured refresh schedule for a dataset.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-refreshschedule-refreshschedulemap.html
     */
    interface RefreshScheduleMapProperty {
        /**
         * The type of refresh that a dataset undergoes. Valid values are as follows:.
         *
         * - `FULL_REFRESH` : A complete refresh of a dataset.
         * - `INCREMENTAL_REFRESH` : A partial refresh of some rows of a dataset, based on the time window specified.
         *
         * For more information on full and incremental refreshes, see [Refreshing SPICE data](https://docs.aws.amazon.com/quicksight/latest/user/refreshing-imported-data.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-refreshschedule-refreshschedulemap.html#cfn-quicksight-refreshschedule-refreshschedulemap-refreshtype
         */
        readonly refreshType?: string;
        /**
         * The frequency for the refresh schedule.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-refreshschedule-refreshschedulemap.html#cfn-quicksight-refreshschedule-refreshschedulemap-schedulefrequency
         */
        readonly scheduleFrequency?: cdk.IResolvable | CfnRefreshSchedule.ScheduleFrequencyProperty;
        /**
         * An identifier for the refresh schedule.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-refreshschedule-refreshschedulemap.html#cfn-quicksight-refreshschedule-refreshschedulemap-scheduleid
         */
        readonly scheduleId?: string;
        /**
         * Time after which the refresh schedule can be started, expressed in `YYYY-MM-DDTHH:MM:SS` format.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-refreshschedule-refreshschedulemap.html#cfn-quicksight-refreshschedule-refreshschedulemap-startafterdatetime
         */
        readonly startAfterDateTime?: string;
    }
    /**
     * The frequency for the refresh schedule.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-refreshschedule-schedulefrequency.html
     */
    interface ScheduleFrequencyProperty {
        /**
         * The interval between scheduled refreshes. Valid values are as follows:.
         *
         * - `MINUTE15` : The dataset refreshes every 15 minutes. This value is only supported for incremental refreshes. This interval can only be used for one schedule per dataset.
         * - `MINUTE30` : The dataset refreshes every 30 minutes. This value is only supported for incremental refreshes. This interval can only be used for one schedule per dataset.
         * - `HOURLY` : The dataset refreshes every hour. This interval can only be used for one schedule per dataset.
         * - `DAILY` : The dataset refreshes every day.
         * - `WEEKLY` : The dataset refreshes every week.
         * - `MONTHLY` : The dataset refreshes every month.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-refreshschedule-schedulefrequency.html#cfn-quicksight-refreshschedule-schedulefrequency-interval
         */
        readonly interval?: string;
        /**
         * The day of the week that you want to schedule the refresh on.
         *
         * This value is required for weekly and monthly refresh intervals.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-refreshschedule-schedulefrequency.html#cfn-quicksight-refreshschedule-schedulefrequency-refreshonday
         */
        readonly refreshOnDay?: cdk.IResolvable | CfnRefreshSchedule.RefreshOnDayProperty;
        /**
         * The time of day that you want the dataset to refresh.
         *
         * This value is expressed in HH:MM format. This field is not required for schedules that refresh hourly.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-refreshschedule-schedulefrequency.html#cfn-quicksight-refreshschedule-schedulefrequency-timeoftheday
         */
        readonly timeOfTheDay?: string;
        /**
         * The timezone that you want the refresh schedule to use.
         *
         * The timezone ID must match a corresponding ID found on `java.util.time.getAvailableIDs()` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-refreshschedule-schedulefrequency.html#cfn-quicksight-refreshschedule-schedulefrequency-timezone
         */
        readonly timeZone?: string;
    }
    /**
     * The day that you want yout dataset to refresh.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-refreshschedule-refreshonday.html
     */
    interface RefreshOnDayProperty {
        /**
         * The day of the month that you want your dataset to refresh.
         *
         * This value is required for monthly refresh intervals.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-refreshschedule-refreshonday.html#cfn-quicksight-refreshschedule-refreshonday-dayofmonth
         */
        readonly dayOfMonth?: string;
        /**
         * The day of the week that you want to schedule the refresh on.
         *
         * This value is required for weekly and monthly refresh intervals.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-refreshschedule-refreshonday.html#cfn-quicksight-refreshschedule-refreshonday-dayofweek
         */
        readonly dayOfWeek?: string;
    }
}
/**
 * Properties for defining a `CfnRefreshSchedule`
 *
 * @struct
 * @stability external
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-refreshschedule.html
 */
export interface CfnRefreshScheduleProps {
    /**
     * The AWS account ID of the account that you are creating a schedule in.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-refreshschedule.html#cfn-quicksight-refreshschedule-awsaccountid
     */
    readonly awsAccountId?: string;
    /**
     * The ID of the dataset that you are creating a refresh schedule for.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-refreshschedule.html#cfn-quicksight-refreshschedule-datasetid
     */
    readonly dataSetId?: string;
    /**
     * The refresh schedule of a dataset.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-refreshschedule.html#cfn-quicksight-refreshschedule-schedule
     */
    readonly schedule?: cdk.IResolvable | CfnRefreshSchedule.RefreshScheduleMapProperty;
}
/**
 * Creates a template from an existing Amazon QuickSight analysis or template.
 *
 * You can use the resulting template to create a dashboard.
 *
 * A *template* is an entity in Amazon QuickSight that encapsulates the metadata required to create an analysis and that you can use to create s dashboard. A template adds a layer of abstraction by using placeholders to replace the dataset associated with the analysis. You can use templates to create dashboards by replacing dataset placeholders with datasets that follow the same schema that was used to create the source analysis and template.
 *
 * @cloudformationResource AWS::QuickSight::Template
 * @stability external
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html
 */
export declare class CfnTemplate extends cdk.CfnResource implements cdk.IInspectable, cdk.ITaggable {
    /**
     * The CloudFormation resource type name for this resource class.
     */
    static readonly CFN_RESOURCE_TYPE_NAME: string;
    /**
     * Build a CfnTemplate from CloudFormation properties
     *
     * A factory method that creates a new instance of this class from an object
     * containing the CloudFormation properties of this resource.
     * Used in the @aws-cdk/cloudformation-include module.
     *
     * @internal
     */
    static _fromCloudFormation(scope: constructs.Construct, id: string, resourceAttributes: any, options: cfn_parse.FromCloudFormationOptions): CfnTemplate;
    /**
     * The Amazon Resource Name (ARN) of the template.
     *
     * @cloudformationAttribute Arn
     */
    readonly attrArn: string;
    /**
     * The time this template was created.
     *
     * @cloudformationAttribute CreatedTime
     */
    readonly attrCreatedTime: string;
    /**
     * The time this template was last updated.
     *
     * @cloudformationAttribute LastUpdatedTime
     */
    readonly attrLastUpdatedTime: string;
    /**
     * The version of the template.
     *
     * @cloudformationAttribute Version
     */
    readonly attrVersion: cdk.IResolvable;
    /**
     * @cloudformationAttribute Version.CreatedTime
     */
    readonly attrVersionCreatedTime: string;
    /**
     * @cloudformationAttribute Version.DataSetConfigurations
     */
    readonly attrVersionDataSetConfigurations: cdk.IResolvable;
    /**
     * @cloudformationAttribute Version.Description
     */
    readonly attrVersionDescription: string;
    /**
     * @cloudformationAttribute Version.Errors
     */
    readonly attrVersionErrors: cdk.IResolvable;
    /**
     * @cloudformationAttribute Version.Sheets
     */
    readonly attrVersionSheets: cdk.IResolvable;
    /**
     * @cloudformationAttribute Version.SourceEntityArn
     */
    readonly attrVersionSourceEntityArn: string;
    /**
     * @cloudformationAttribute Version.Status
     */
    readonly attrVersionStatus: string;
    /**
     * @cloudformationAttribute Version.ThemeArn
     */
    readonly attrVersionThemeArn: string;
    /**
     * @cloudformationAttribute Version.VersionNumber
     */
    readonly attrVersionVersionNumber: cdk.IResolvable;
    /**
     * The ID for the AWS account that the group is in.
     */
    awsAccountId: string;
    definition?: cdk.IResolvable | CfnTemplate.TemplateVersionDefinitionProperty;
    /**
     * A display name for the template.
     */
    name?: string;
    /**
     * A list of resource permissions to be set on the template.
     */
    permissions?: Array<cdk.IResolvable | CfnTemplate.ResourcePermissionProperty> | cdk.IResolvable;
    /**
     * The entity that you are using as a source when you create the template.
     */
    sourceEntity?: cdk.IResolvable | CfnTemplate.TemplateSourceEntityProperty;
    /**
     * Tag Manager which manages the tags for this resource
     */
    readonly tags: cdk.TagManager;
    /**
     * Contains a map of the key-value pairs for the resource tag or tags assigned to the resource.
     */
    tagsRaw?: Array<cdk.CfnTag>;
    /**
     * An ID for the template that you want to create.
     */
    templateId: string;
    /**
     * The option to relax the validation that is required to create and update analyses, dashboards, and templates with definition objects.
     */
    validationStrategy?: cdk.IResolvable | CfnTemplate.ValidationStrategyProperty;
    /**
     * A description of the current template version being created.
     */
    versionDescription?: string;
    /**
     * @param scope Scope in which this resource is defined
     * @param id Construct identifier for this resource (unique in its scope)
     * @param props Resource properties
     */
    constructor(scope: constructs.Construct, id: string, props: CfnTemplateProps);
    protected get cfnProperties(): Record<string, any>;
    /**
     * Examines the CloudFormation resource and discloses attributes
     *
     * @param inspector tree inspector to collect and process attributes
     */
    inspect(inspector: cdk.TreeInspector): void;
    protected renderProperties(props: Record<string, any>): Record<string, any>;
}
export declare namespace CfnTemplate {
    /**
     * The source entity of the template.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templatesourceentity.html
     */
    interface TemplateSourceEntityProperty {
        /**
         * The source analysis, if it is based on an analysis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templatesourceentity.html#cfn-quicksight-template-templatesourceentity-sourceanalysis
         */
        readonly sourceAnalysis?: cdk.IResolvable | CfnTemplate.TemplateSourceAnalysisProperty;
        /**
         * The source template, if it is based on an template.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templatesourceentity.html#cfn-quicksight-template-templatesourceentity-sourcetemplate
         */
        readonly sourceTemplate?: cdk.IResolvable | CfnTemplate.TemplateSourceTemplateProperty;
    }
    /**
     * The source analysis of the template.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templatesourceanalysis.html
     */
    interface TemplateSourceAnalysisProperty {
        /**
         * The Amazon Resource Name (ARN) of the resource.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templatesourceanalysis.html#cfn-quicksight-template-templatesourceanalysis-arn
         */
        readonly arn: string;
        /**
         * A structure containing information about the dataset references used as placeholders in the template.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templatesourceanalysis.html#cfn-quicksight-template-templatesourceanalysis-datasetreferences
         */
        readonly dataSetReferences: Array<CfnTemplate.DataSetReferenceProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * Dataset reference.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datasetreference.html
     */
    interface DataSetReferenceProperty {
        /**
         * Dataset Amazon Resource Name (ARN).
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datasetreference.html#cfn-quicksight-template-datasetreference-datasetarn
         */
        readonly dataSetArn: string;
        /**
         * Dataset placeholder.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datasetreference.html#cfn-quicksight-template-datasetreference-datasetplaceholder
         */
        readonly dataSetPlaceholder: string;
    }
    /**
     * The source template of the template.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templatesourcetemplate.html
     */
    interface TemplateSourceTemplateProperty {
        /**
         * The Amazon Resource Name (ARN) of the resource.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templatesourcetemplate.html#cfn-quicksight-template-templatesourcetemplate-arn
         */
        readonly arn: string;
    }
    /**
     * The detailed definition of a template.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversiondefinition.html
     */
    interface TemplateVersionDefinitionProperty {
        /**
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversiondefinition.html#cfn-quicksight-template-templateversiondefinition-analysisdefaults
         */
        readonly analysisDefaults?: CfnTemplate.AnalysisDefaultsProperty | cdk.IResolvable;
        /**
         * An array of calculated field definitions for the template.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversiondefinition.html#cfn-quicksight-template-templateversiondefinition-calculatedfields
         */
        readonly calculatedFields?: Array<CfnTemplate.CalculatedFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * An array of template-level column configurations.
         *
         * Column configurations are used to set default formatting for a column that's used throughout a template.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversiondefinition.html#cfn-quicksight-template-templateversiondefinition-columnconfigurations
         */
        readonly columnConfigurations?: Array<CfnTemplate.ColumnConfigurationProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * An array of dataset configurations.
         *
         * These configurations define the required columns for each dataset used within a template.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversiondefinition.html#cfn-quicksight-template-templateversiondefinition-datasetconfigurations
         */
        readonly dataSetConfigurations: Array<CfnTemplate.DataSetConfigurationProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * Filter definitions for a template.
         *
         * For more information, see [Filtering Data](https://docs.aws.amazon.com/quicksight/latest/user/filtering-visual-data.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversiondefinition.html#cfn-quicksight-template-templateversiondefinition-filtergroups
         */
        readonly filterGroups?: Array<CfnTemplate.FilterGroupProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * An array of option definitions for a template.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversiondefinition.html#cfn-quicksight-template-templateversiondefinition-options
         */
        readonly options?: CfnTemplate.AssetOptionsProperty | cdk.IResolvable;
        /**
         * An array of parameter declarations for a template.
         *
         * *Parameters* are named variables that can transfer a value for use by an action or an object.
         *
         * For more information, see [Parameters in Amazon QuickSight](https://docs.aws.amazon.com/quicksight/latest/user/parameters-in-quicksight.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversiondefinition.html#cfn-quicksight-template-templateversiondefinition-parameterdeclarations
         */
        readonly parameterDeclarations?: Array<cdk.IResolvable | CfnTemplate.ParameterDeclarationProperty> | cdk.IResolvable;
        /**
         * An array of sheet definitions for a template.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversiondefinition.html#cfn-quicksight-template-templateversiondefinition-sheets
         */
        readonly sheets?: Array<cdk.IResolvable | CfnTemplate.SheetDefinitionProperty> | cdk.IResolvable;
    }
    /**
     * A grouping of individual filters. Filter groups are applied to the same group of visuals.
     *
     * For more information, see [Adding filter conditions (group filters) with AND and OR operators](https://docs.aws.amazon.com/quicksight/latest/user/add-a-compound-filter.html) in the *Amazon QuickSight User Guide* .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtergroup.html
     */
    interface FilterGroupProperty {
        /**
         * The filter new feature which can apply filter group to all data sets. Choose one of the following options:.
         *
         * - `ALL_DATASETS`
         * - `SINGLE_DATASET`
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtergroup.html#cfn-quicksight-template-filtergroup-crossdataset
         */
        readonly crossDataset: string;
        /**
         * The value that uniquely identifies a `FilterGroup` within a dashboard, template, or analysis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtergroup.html#cfn-quicksight-template-filtergroup-filtergroupid
         */
        readonly filterGroupId: string;
        /**
         * The list of filters that are present in a `FilterGroup` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtergroup.html#cfn-quicksight-template-filtergroup-filters
         */
        readonly filters: Array<CfnTemplate.FilterProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The configuration that specifies what scope to apply to a `FilterGroup` .
         *
         * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtergroup.html#cfn-quicksight-template-filtergroup-scopeconfiguration
         */
        readonly scopeConfiguration: CfnTemplate.FilterScopeConfigurationProperty | cdk.IResolvable;
        /**
         * The status of the `FilterGroup` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtergroup.html#cfn-quicksight-template-filtergroup-status
         */
        readonly status?: string;
    }
    /**
     * With a `Filter` , you can remove portions of data from a particular visual or view.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filter.html
     */
    interface FilterProperty {
        /**
         * A `CategoryFilter` filters text values.
         *
         * For more information, see [Adding text filters](https://docs.aws.amazon.com/quicksight/latest/user/add-a-text-filter-data-prep.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filter.html#cfn-quicksight-template-filter-categoryfilter
         */
        readonly categoryFilter?: CfnTemplate.CategoryFilterProperty | cdk.IResolvable;
        /**
         * A `NumericEqualityFilter` filters numeric values that equal or do not equal a given numeric value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filter.html#cfn-quicksight-template-filter-numericequalityfilter
         */
        readonly numericEqualityFilter?: cdk.IResolvable | CfnTemplate.NumericEqualityFilterProperty;
        /**
         * A `NumericRangeFilter` filters numeric values that are either inside or outside a given numeric range.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filter.html#cfn-quicksight-template-filter-numericrangefilter
         */
        readonly numericRangeFilter?: cdk.IResolvable | CfnTemplate.NumericRangeFilterProperty;
        /**
         * A `RelativeDatesFilter` filters date values that are relative to a given date.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filter.html#cfn-quicksight-template-filter-relativedatesfilter
         */
        readonly relativeDatesFilter?: cdk.IResolvable | CfnTemplate.RelativeDatesFilterProperty;
        /**
         * A `TimeEqualityFilter` filters date-time values that equal or do not equal a given date/time value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filter.html#cfn-quicksight-template-filter-timeequalityfilter
         */
        readonly timeEqualityFilter?: cdk.IResolvable | CfnTemplate.TimeEqualityFilterProperty;
        /**
         * A `TimeRangeFilter` filters date-time values that are either inside or outside a given date/time range.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filter.html#cfn-quicksight-template-filter-timerangefilter
         */
        readonly timeRangeFilter?: cdk.IResolvable | CfnTemplate.TimeRangeFilterProperty;
        /**
         * A `TopBottomFilter` filters data to the top or bottom values for a given column.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filter.html#cfn-quicksight-template-filter-topbottomfilter
         */
        readonly topBottomFilter?: cdk.IResolvable | CfnTemplate.TopBottomFilterProperty;
    }
    /**
     * A `NumericEqualityFilter` filters values that are equal to the specified value.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericequalityfilter.html
     */
    interface NumericEqualityFilterProperty {
        /**
         * The aggregation function of the filter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericequalityfilter.html#cfn-quicksight-template-numericequalityfilter-aggregationfunction
         */
        readonly aggregationFunction?: CfnTemplate.AggregationFunctionProperty | cdk.IResolvable;
        /**
         * The column that the filter is applied to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericequalityfilter.html#cfn-quicksight-template-numericequalityfilter-column
         */
        readonly column: CfnTemplate.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericequalityfilter.html#cfn-quicksight-template-numericequalityfilter-filterid
         */
        readonly filterId: string;
        /**
         * The match operator that is used to determine if a filter should be applied.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericequalityfilter.html#cfn-quicksight-template-numericequalityfilter-matchoperator
         */
        readonly matchOperator: string;
        /**
         * This option determines how null values should be treated when filtering data.
         *
         * - `ALL_VALUES` : Include null values in filtered results.
         * - `NULLS_ONLY` : Only include null values in filtered results.
         * - `NON_NULLS_ONLY` : Exclude null values from filtered results.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericequalityfilter.html#cfn-quicksight-template-numericequalityfilter-nulloption
         */
        readonly nullOption: string;
        /**
         * The parameter whose value should be used for the filter value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericequalityfilter.html#cfn-quicksight-template-numericequalityfilter-parametername
         */
        readonly parameterName?: string;
        /**
         * Select all of the values. Null is not the assigned value of select all.
         *
         * - `FILTER_ALL_VALUES`
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericequalityfilter.html#cfn-quicksight-template-numericequalityfilter-selectalloptions
         */
        readonly selectAllOptions?: string;
        /**
         * The input value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericequalityfilter.html#cfn-quicksight-template-numericequalityfilter-value
         */
        readonly value?: number;
    }
    /**
     * An aggregation function aggregates values from a dimension or measure.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-aggregationfunction.html
     */
    interface AggregationFunctionProperty {
        /**
         * Aggregation for attributes.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-aggregationfunction.html#cfn-quicksight-template-aggregationfunction-attributeaggregationfunction
         */
        readonly attributeAggregationFunction?: CfnTemplate.AttributeAggregationFunctionProperty | cdk.IResolvable;
        /**
         * Aggregation for categorical values.
         *
         * - `COUNT` : Aggregate by the total number of values, including duplicates.
         * - `DISTINCT_COUNT` : Aggregate by the total number of distinct values.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-aggregationfunction.html#cfn-quicksight-template-aggregationfunction-categoricalaggregationfunction
         */
        readonly categoricalAggregationFunction?: string;
        /**
         * Aggregation for date values.
         *
         * - `COUNT` : Aggregate by the total number of values, including duplicates.
         * - `DISTINCT_COUNT` : Aggregate by the total number of distinct values.
         * - `MIN` : Select the smallest date value.
         * - `MAX` : Select the largest date value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-aggregationfunction.html#cfn-quicksight-template-aggregationfunction-dateaggregationfunction
         */
        readonly dateAggregationFunction?: string;
        /**
         * Aggregation for numerical values.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-aggregationfunction.html#cfn-quicksight-template-aggregationfunction-numericalaggregationfunction
         */
        readonly numericalAggregationFunction?: cdk.IResolvable | CfnTemplate.NumericalAggregationFunctionProperty;
    }
    /**
     * Aggregation for attributes.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-attributeaggregationfunction.html
     */
    interface AttributeAggregationFunctionProperty {
        /**
         * The built-in aggregation functions for attributes.
         *
         * - `UNIQUE_VALUE` : Returns the unique value for a field, aggregated by the dimension fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-attributeaggregationfunction.html#cfn-quicksight-template-attributeaggregationfunction-simpleattributeaggregation
         */
        readonly simpleAttributeAggregation?: string;
        /**
         * Used by the `UNIQUE_VALUE` aggregation function.
         *
         * If there are multiple values for the field used by the aggregation, the value for this property will be returned instead. Defaults to '*'.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-attributeaggregationfunction.html#cfn-quicksight-template-attributeaggregationfunction-valueformultiplevalues
         */
        readonly valueForMultipleValues?: string;
    }
    /**
     * Aggregation for numerical values.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericalaggregationfunction.html
     */
    interface NumericalAggregationFunctionProperty {
        /**
         * An aggregation based on the percentile of values in a dimension or measure.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericalaggregationfunction.html#cfn-quicksight-template-numericalaggregationfunction-percentileaggregation
         */
        readonly percentileAggregation?: cdk.IResolvable | CfnTemplate.PercentileAggregationProperty;
        /**
         * Built-in aggregation functions for numerical values.
         *
         * - `SUM` : The sum of a dimension or measure.
         * - `AVERAGE` : The average of a dimension or measure.
         * - `MIN` : The minimum value of a dimension or measure.
         * - `MAX` : The maximum value of a dimension or measure.
         * - `COUNT` : The count of a dimension or measure.
         * - `DISTINCT_COUNT` : The count of distinct values in a dimension or measure.
         * - `VAR` : The variance of a dimension or measure.
         * - `VARP` : The partitioned variance of a dimension or measure.
         * - `STDEV` : The standard deviation of a dimension or measure.
         * - `STDEVP` : The partitioned standard deviation of a dimension or measure.
         * - `MEDIAN` : The median value of a dimension or measure.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericalaggregationfunction.html#cfn-quicksight-template-numericalaggregationfunction-simplenumericalaggregation
         */
        readonly simpleNumericalAggregation?: string;
    }
    /**
     * An aggregation based on the percentile of values in a dimension or measure.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-percentileaggregation.html
     */
    interface PercentileAggregationProperty {
        /**
         * The percentile value.
         *
         * This value can be any numeric constant 0–100. A percentile value of 50 computes the median value of the measure.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-percentileaggregation.html#cfn-quicksight-template-percentileaggregation-percentilevalue
         */
        readonly percentileValue?: number;
    }
    /**
     * A column of a data set.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnidentifier.html
     */
    interface ColumnIdentifierProperty {
        /**
         * The name of the column.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnidentifier.html#cfn-quicksight-template-columnidentifier-columnname
         */
        readonly columnName: string;
        /**
         * The data set that the column belongs to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnidentifier.html#cfn-quicksight-template-columnidentifier-datasetidentifier
         */
        readonly dataSetIdentifier: string;
    }
    /**
     * A `NumericRangeFilter` filters values that are within the value range.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericrangefilter.html
     */
    interface NumericRangeFilterProperty {
        /**
         * The aggregation function of the filter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericrangefilter.html#cfn-quicksight-template-numericrangefilter-aggregationfunction
         */
        readonly aggregationFunction?: CfnTemplate.AggregationFunctionProperty | cdk.IResolvable;
        /**
         * The column that the filter is applied to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericrangefilter.html#cfn-quicksight-template-numericrangefilter-column
         */
        readonly column: CfnTemplate.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericrangefilter.html#cfn-quicksight-template-numericrangefilter-filterid
         */
        readonly filterId: string;
        /**
         * Determines whether the maximum value in the filter value range should be included in the filtered results.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericrangefilter.html#cfn-quicksight-template-numericrangefilter-includemaximum
         */
        readonly includeMaximum?: boolean | cdk.IResolvable;
        /**
         * Determines whether the minimum value in the filter value range should be included in the filtered results.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericrangefilter.html#cfn-quicksight-template-numericrangefilter-includeminimum
         */
        readonly includeMinimum?: boolean | cdk.IResolvable;
        /**
         * This option determines how null values should be treated when filtering data.
         *
         * - `ALL_VALUES` : Include null values in filtered results.
         * - `NULLS_ONLY` : Only include null values in filtered results.
         * - `NON_NULLS_ONLY` : Exclude null values from filtered results.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericrangefilter.html#cfn-quicksight-template-numericrangefilter-nulloption
         */
        readonly nullOption: string;
        /**
         * The maximum value for the filter value range.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericrangefilter.html#cfn-quicksight-template-numericrangefilter-rangemaximum
         */
        readonly rangeMaximum?: cdk.IResolvable | CfnTemplate.NumericRangeFilterValueProperty;
        /**
         * The minimum value for the filter value range.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericrangefilter.html#cfn-quicksight-template-numericrangefilter-rangeminimum
         */
        readonly rangeMinimum?: cdk.IResolvable | CfnTemplate.NumericRangeFilterValueProperty;
        /**
         * Select all of the values. Null is not the assigned value of select all.
         *
         * - `FILTER_ALL_VALUES`
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericrangefilter.html#cfn-quicksight-template-numericrangefilter-selectalloptions
         */
        readonly selectAllOptions?: string;
    }
    /**
     * The value input pf the numeric range filter.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericrangefiltervalue.html
     */
    interface NumericRangeFilterValueProperty {
        /**
         * The parameter that is used in the numeric range.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericrangefiltervalue.html#cfn-quicksight-template-numericrangefiltervalue-parameter
         */
        readonly parameter?: string;
        /**
         * The static value of the numeric range filter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericrangefiltervalue.html#cfn-quicksight-template-numericrangefiltervalue-staticvalue
         */
        readonly staticValue?: number;
    }
    /**
     * A `TimeRangeFilter` filters values that are between two specified values.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangefilter.html
     */
    interface TimeRangeFilterProperty {
        /**
         * The column that the filter is applied to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangefilter.html#cfn-quicksight-template-timerangefilter-column
         */
        readonly column: CfnTemplate.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * The exclude period of the time range filter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangefilter.html#cfn-quicksight-template-timerangefilter-excludeperiodconfiguration
         */
        readonly excludePeriodConfiguration?: CfnTemplate.ExcludePeriodConfigurationProperty | cdk.IResolvable;
        /**
         * An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangefilter.html#cfn-quicksight-template-timerangefilter-filterid
         */
        readonly filterId: string;
        /**
         * Determines whether the maximum value in the filter value range should be included in the filtered results.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangefilter.html#cfn-quicksight-template-timerangefilter-includemaximum
         */
        readonly includeMaximum?: boolean | cdk.IResolvable;
        /**
         * Determines whether the minimum value in the filter value range should be included in the filtered results.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangefilter.html#cfn-quicksight-template-timerangefilter-includeminimum
         */
        readonly includeMinimum?: boolean | cdk.IResolvable;
        /**
         * This option determines how null values should be treated when filtering data.
         *
         * - `ALL_VALUES` : Include null values in filtered results.
         * - `NULLS_ONLY` : Only include null values in filtered results.
         * - `NON_NULLS_ONLY` : Exclude null values from filtered results.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangefilter.html#cfn-quicksight-template-timerangefilter-nulloption
         */
        readonly nullOption: string;
        /**
         * The maximum value for the filter value range.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangefilter.html#cfn-quicksight-template-timerangefilter-rangemaximumvalue
         */
        readonly rangeMaximumValue?: cdk.IResolvable | CfnTemplate.TimeRangeFilterValueProperty;
        /**
         * The minimum value for the filter value range.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangefilter.html#cfn-quicksight-template-timerangefilter-rangeminimumvalue
         */
        readonly rangeMinimumValue?: cdk.IResolvable | CfnTemplate.TimeRangeFilterValueProperty;
        /**
         * The level of time precision that is used to aggregate `DateTime` values.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangefilter.html#cfn-quicksight-template-timerangefilter-timegranularity
         */
        readonly timeGranularity?: string;
    }
    /**
     * The value of a time range filter.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangefiltervalue.html
     */
    interface TimeRangeFilterValueProperty {
        /**
         * The parameter type input value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangefiltervalue.html#cfn-quicksight-template-timerangefiltervalue-parameter
         */
        readonly parameter?: string;
        /**
         * The rolling date input value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangefiltervalue.html#cfn-quicksight-template-timerangefiltervalue-rollingdate
         */
        readonly rollingDate?: cdk.IResolvable | CfnTemplate.RollingDateConfigurationProperty;
        /**
         * The static input value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangefiltervalue.html#cfn-quicksight-template-timerangefiltervalue-staticvalue
         */
        readonly staticValue?: string;
    }
    /**
     * The rolling date configuration of a date time filter.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-rollingdateconfiguration.html
     */
    interface RollingDateConfigurationProperty {
        /**
         * The data set that is used in the rolling date configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-rollingdateconfiguration.html#cfn-quicksight-template-rollingdateconfiguration-datasetidentifier
         */
        readonly dataSetIdentifier?: string;
        /**
         * The expression of the rolling date configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-rollingdateconfiguration.html#cfn-quicksight-template-rollingdateconfiguration-expression
         */
        readonly expression: string;
    }
    /**
     * The exclude period of `TimeRangeFilter` or `RelativeDatesFilter` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-excludeperiodconfiguration.html
     */
    interface ExcludePeriodConfigurationProperty {
        /**
         * The amount or number of the exclude period.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-excludeperiodconfiguration.html#cfn-quicksight-template-excludeperiodconfiguration-amount
         */
        readonly amount: number;
        /**
         * The granularity or unit (day, month, year) of the exclude period.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-excludeperiodconfiguration.html#cfn-quicksight-template-excludeperiodconfiguration-granularity
         */
        readonly granularity: string;
        /**
         * The status of the exclude period. Choose from the following options:.
         *
         * - `ENABLED`
         * - `DISABLED`
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-excludeperiodconfiguration.html#cfn-quicksight-template-excludeperiodconfiguration-status
         */
        readonly status?: string;
    }
    /**
     * A `RelativeDatesFilter` filters relative dates values.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-relativedatesfilter.html
     */
    interface RelativeDatesFilterProperty {
        /**
         * The date configuration of the filter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-relativedatesfilter.html#cfn-quicksight-template-relativedatesfilter-anchordateconfiguration
         */
        readonly anchorDateConfiguration: CfnTemplate.AnchorDateConfigurationProperty | cdk.IResolvable;
        /**
         * The column that the filter is applied to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-relativedatesfilter.html#cfn-quicksight-template-relativedatesfilter-column
         */
        readonly column: CfnTemplate.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * The configuration for the exclude period of the filter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-relativedatesfilter.html#cfn-quicksight-template-relativedatesfilter-excludeperiodconfiguration
         */
        readonly excludePeriodConfiguration?: CfnTemplate.ExcludePeriodConfigurationProperty | cdk.IResolvable;
        /**
         * An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-relativedatesfilter.html#cfn-quicksight-template-relativedatesfilter-filterid
         */
        readonly filterId: string;
        /**
         * The minimum granularity (period granularity) of the relative dates filter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-relativedatesfilter.html#cfn-quicksight-template-relativedatesfilter-minimumgranularity
         */
        readonly minimumGranularity?: string;
        /**
         * This option determines how null values should be treated when filtering data.
         *
         * - `ALL_VALUES` : Include null values in filtered results.
         * - `NULLS_ONLY` : Only include null values in filtered results.
         * - `NON_NULLS_ONLY` : Exclude null values from filtered results.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-relativedatesfilter.html#cfn-quicksight-template-relativedatesfilter-nulloption
         */
        readonly nullOption: string;
        /**
         * The parameter whose value should be used for the filter value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-relativedatesfilter.html#cfn-quicksight-template-relativedatesfilter-parametername
         */
        readonly parameterName?: string;
        /**
         * The range date type of the filter. Choose one of the options below:.
         *
         * - `PREVIOUS`
         * - `THIS`
         * - `LAST`
         * - `NOW`
         * - `NEXT`
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-relativedatesfilter.html#cfn-quicksight-template-relativedatesfilter-relativedatetype
         */
        readonly relativeDateType: string;
        /**
         * The date value of the filter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-relativedatesfilter.html#cfn-quicksight-template-relativedatesfilter-relativedatevalue
         */
        readonly relativeDateValue?: number;
        /**
         * The level of time precision that is used to aggregate `DateTime` values.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-relativedatesfilter.html#cfn-quicksight-template-relativedatesfilter-timegranularity
         */
        readonly timeGranularity: string;
    }
    /**
     * The date configuration of the filter.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-anchordateconfiguration.html
     */
    interface AnchorDateConfigurationProperty {
        /**
         * The options for the date configuration. Choose one of the options below:.
         *
         * - `NOW`
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-anchordateconfiguration.html#cfn-quicksight-template-anchordateconfiguration-anchoroption
         */
        readonly anchorOption?: string;
        /**
         * The name of the parameter that is used for the anchor date configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-anchordateconfiguration.html#cfn-quicksight-template-anchordateconfiguration-parametername
         */
        readonly parameterName?: string;
    }
    /**
     * A `TopBottomFilter` filters values that are at the top or the bottom.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottomfilter.html
     */
    interface TopBottomFilterProperty {
        /**
         * The aggregation and sort configuration of the top bottom filter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottomfilter.html#cfn-quicksight-template-topbottomfilter-aggregationsortconfigurations
         */
        readonly aggregationSortConfigurations: Array<CfnTemplate.AggregationSortConfigurationProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The column that the filter is applied to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottomfilter.html#cfn-quicksight-template-topbottomfilter-column
         */
        readonly column: CfnTemplate.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottomfilter.html#cfn-quicksight-template-topbottomfilter-filterid
         */
        readonly filterId: string;
        /**
         * The number of items to include in the top bottom filter results.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottomfilter.html#cfn-quicksight-template-topbottomfilter-limit
         */
        readonly limit?: number;
        /**
         * The parameter whose value should be used for the filter value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottomfilter.html#cfn-quicksight-template-topbottomfilter-parametername
         */
        readonly parameterName?: string;
        /**
         * The level of time precision that is used to aggregate `DateTime` values.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottomfilter.html#cfn-quicksight-template-topbottomfilter-timegranularity
         */
        readonly timeGranularity?: string;
    }
    /**
     * The configuration options to sort aggregated values.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-aggregationsortconfiguration.html
     */
    interface AggregationSortConfigurationProperty {
        /**
         * The function that aggregates the values in `Column` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-aggregationsortconfiguration.html#cfn-quicksight-template-aggregationsortconfiguration-aggregationfunction
         */
        readonly aggregationFunction?: CfnTemplate.AggregationFunctionProperty | cdk.IResolvable;
        /**
         * The column that determines the sort order of aggregated values.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-aggregationsortconfiguration.html#cfn-quicksight-template-aggregationsortconfiguration-column
         */
        readonly column: CfnTemplate.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * The sort direction of values.
         *
         * - `ASC` : Sort in ascending order.
         * - `DESC` : Sort in descending order.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-aggregationsortconfiguration.html#cfn-quicksight-template-aggregationsortconfiguration-sortdirection
         */
        readonly sortDirection: string;
    }
    /**
     * A `TimeEqualityFilter` filters values that are equal to a given value.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timeequalityfilter.html
     */
    interface TimeEqualityFilterProperty {
        /**
         * The column that the filter is applied to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timeequalityfilter.html#cfn-quicksight-template-timeequalityfilter-column
         */
        readonly column: CfnTemplate.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timeequalityfilter.html#cfn-quicksight-template-timeequalityfilter-filterid
         */
        readonly filterId: string;
        /**
         * The parameter whose value should be used for the filter value.
         *
         * This field is mutually exclusive to `Value` and `RollingDate` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timeequalityfilter.html#cfn-quicksight-template-timeequalityfilter-parametername
         */
        readonly parameterName?: string;
        /**
         * The rolling date input for the `TimeEquality` filter.
         *
         * This field is mutually exclusive to `Value` and `ParameterName` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timeequalityfilter.html#cfn-quicksight-template-timeequalityfilter-rollingdate
         */
        readonly rollingDate?: cdk.IResolvable | CfnTemplate.RollingDateConfigurationProperty;
        /**
         * The level of time precision that is used to aggregate `DateTime` values.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timeequalityfilter.html#cfn-quicksight-template-timeequalityfilter-timegranularity
         */
        readonly timeGranularity?: string;
        /**
         * The value of a `TimeEquality` filter.
         *
         * This field is mutually exclusive to `RollingDate` and `ParameterName` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timeequalityfilter.html#cfn-quicksight-template-timeequalityfilter-value
         */
        readonly value?: string;
    }
    /**
     * A `CategoryFilter` filters text values.
     *
     * For more information, see [Adding text filters](https://docs.aws.amazon.com/quicksight/latest/user/add-a-text-filter-data-prep.html) in the *Amazon QuickSight User Guide* .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoryfilter.html
     */
    interface CategoryFilterProperty {
        /**
         * The column that the filter is applied to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoryfilter.html#cfn-quicksight-template-categoryfilter-column
         */
        readonly column: CfnTemplate.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * The configuration for a `CategoryFilter` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoryfilter.html#cfn-quicksight-template-categoryfilter-configuration
         */
        readonly configuration: CfnTemplate.CategoryFilterConfigurationProperty | cdk.IResolvable;
        /**
         * An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoryfilter.html#cfn-quicksight-template-categoryfilter-filterid
         */
        readonly filterId: string;
    }
    /**
     * The configuration for a `CategoryFilter` .
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoryfilterconfiguration.html
     */
    interface CategoryFilterConfigurationProperty {
        /**
         * A custom filter that filters based on a single value.
         *
         * This filter can be partially matched.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoryfilterconfiguration.html#cfn-quicksight-template-categoryfilterconfiguration-customfilterconfiguration
         */
        readonly customFilterConfiguration?: CfnTemplate.CustomFilterConfigurationProperty | cdk.IResolvable;
        /**
         * A list of custom filter values.
         *
         * In the Amazon QuickSight console, this filter type is called a custom filter list.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoryfilterconfiguration.html#cfn-quicksight-template-categoryfilterconfiguration-customfilterlistconfiguration
         */
        readonly customFilterListConfiguration?: CfnTemplate.CustomFilterListConfigurationProperty | cdk.IResolvable;
        /**
         * A list of filter configurations.
         *
         * In the Amazon QuickSight console, this filter type is called a filter list.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoryfilterconfiguration.html#cfn-quicksight-template-categoryfilterconfiguration-filterlistconfiguration
         */
        readonly filterListConfiguration?: CfnTemplate.FilterListConfigurationProperty | cdk.IResolvable;
    }
    /**
     * A list of custom filter values.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customfilterlistconfiguration.html
     */
    interface CustomFilterListConfigurationProperty {
        /**
         * The list of category values for the filter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customfilterlistconfiguration.html#cfn-quicksight-template-customfilterlistconfiguration-categoryvalues
         */
        readonly categoryValues?: Array<string>;
        /**
         * The match operator that is used to determine if a filter should be applied.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customfilterlistconfiguration.html#cfn-quicksight-template-customfilterlistconfiguration-matchoperator
         */
        readonly matchOperator: string;
        /**
         * This option determines how null values should be treated when filtering data.
         *
         * - `ALL_VALUES` : Include null values in filtered results.
         * - `NULLS_ONLY` : Only include null values in filtered results.
         * - `NON_NULLS_ONLY` : Exclude null values from filtered results.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customfilterlistconfiguration.html#cfn-quicksight-template-customfilterlistconfiguration-nulloption
         */
        readonly nullOption: string;
        /**
         * Select all of the values. Null is not the assigned value of select all.
         *
         * - `FILTER_ALL_VALUES`
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customfilterlistconfiguration.html#cfn-quicksight-template-customfilterlistconfiguration-selectalloptions
         */
        readonly selectAllOptions?: string;
    }
    /**
     * A custom filter that filters based on a single value.
     *
     * This filter can be partially matched.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customfilterconfiguration.html
     */
    interface CustomFilterConfigurationProperty {
        /**
         * The category value for the filter.
         *
         * This field is mutually exclusive to `ParameterName` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customfilterconfiguration.html#cfn-quicksight-template-customfilterconfiguration-categoryvalue
         */
        readonly categoryValue?: string;
        /**
         * The match operator that is used to determine if a filter should be applied.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customfilterconfiguration.html#cfn-quicksight-template-customfilterconfiguration-matchoperator
         */
        readonly matchOperator: string;
        /**
         * This option determines how null values should be treated when filtering data.
         *
         * - `ALL_VALUES` : Include null values in filtered results.
         * - `NULLS_ONLY` : Only include null values in filtered results.
         * - `NON_NULLS_ONLY` : Exclude null values from filtered results.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customfilterconfiguration.html#cfn-quicksight-template-customfilterconfiguration-nulloption
         */
        readonly nullOption: string;
        /**
         * The parameter whose value should be used for the filter value.
         *
         * This field is mutually exclusive to `CategoryValue` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customfilterconfiguration.html#cfn-quicksight-template-customfilterconfiguration-parametername
         */
        readonly parameterName?: string;
        /**
         * Select all of the values. Null is not the assigned value of select all.
         *
         * - `FILTER_ALL_VALUES`
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customfilterconfiguration.html#cfn-quicksight-template-customfilterconfiguration-selectalloptions
         */
        readonly selectAllOptions?: string;
    }
    /**
     * A list of filter configurations.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterlistconfiguration.html
     */
    interface FilterListConfigurationProperty {
        /**
         * The list of category values for the filter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterlistconfiguration.html#cfn-quicksight-template-filterlistconfiguration-categoryvalues
         */
        readonly categoryValues?: Array<string>;
        /**
         * The match operator that is used to determine if a filter should be applied.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterlistconfiguration.html#cfn-quicksight-template-filterlistconfiguration-matchoperator
         */
        readonly matchOperator: string;
        /**
         * This option determines how null values should be treated when filtering data.
         *
         * - `ALL_VALUES` : Include null values in filtered results.
         * - `NULLS_ONLY` : Only include null values in filtered results.
         * - `NON_NULLS_ONLY` : Exclude null values from filtered results.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterlistconfiguration.html#cfn-quicksight-template-filterlistconfiguration-nulloption
         */
        readonly nullOption?: string;
        /**
         * Select all of the values. Null is not the assigned value of select all.
         *
         * - `FILTER_ALL_VALUES`
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterlistconfiguration.html#cfn-quicksight-template-filterlistconfiguration-selectalloptions
         */
        readonly selectAllOptions?: string;
    }
    /**
     * The scope configuration for a `FilterGroup` .
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterscopeconfiguration.html
     */
    interface FilterScopeConfigurationProperty {
        /**
         * The configuration for applying a filter to all sheets.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterscopeconfiguration.html#cfn-quicksight-template-filterscopeconfiguration-allsheets
         */
        readonly allSheets?: any | cdk.IResolvable;
        /**
         * The configuration for applying a filter to specific sheets.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterscopeconfiguration.html#cfn-quicksight-template-filterscopeconfiguration-selectedsheets
         */
        readonly selectedSheets?: cdk.IResolvable | CfnTemplate.SelectedSheetsFilterScopeConfigurationProperty;
    }
    /**
     * The configuration for applying a filter to specific sheets or visuals.
     *
     * You can apply this filter to multiple visuals that are on one sheet or to all visuals on a sheet.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-selectedsheetsfilterscopeconfiguration.html
     */
    interface SelectedSheetsFilterScopeConfigurationProperty {
        /**
         * The sheet ID and visual IDs of the sheet and visuals that the filter is applied to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-selectedsheetsfilterscopeconfiguration.html#cfn-quicksight-template-selectedsheetsfilterscopeconfiguration-sheetvisualscopingconfigurations
         */
        readonly sheetVisualScopingConfigurations?: Array<cdk.IResolvable | CfnTemplate.SheetVisualScopingConfigurationProperty> | cdk.IResolvable;
    }
    /**
     * The filter that is applied to the options.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetvisualscopingconfiguration.html
     */
    interface SheetVisualScopingConfigurationProperty {
        /**
         * The scope of the applied entities. Choose one of the following options:.
         *
         * - `ALL_VISUALS`
         * - `SELECTED_VISUALS`
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetvisualscopingconfiguration.html#cfn-quicksight-template-sheetvisualscopingconfiguration-scope
         */
        readonly scope: string;
        /**
         * The selected sheet that the filter is applied to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetvisualscopingconfiguration.html#cfn-quicksight-template-sheetvisualscopingconfiguration-sheetid
         */
        readonly sheetId: string;
        /**
         * The selected visuals that the filter is applied to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetvisualscopingconfiguration.html#cfn-quicksight-template-sheetvisualscopingconfiguration-visualids
         */
        readonly visualIds?: Array<string>;
    }
    /**
     * The calculated field of an analysis.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-calculatedfield.html
     */
    interface CalculatedFieldProperty {
        /**
         * The data set that is used in this calculated field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-calculatedfield.html#cfn-quicksight-template-calculatedfield-datasetidentifier
         */
        readonly dataSetIdentifier: string;
        /**
         * The expression of the calculated field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-calculatedfield.html#cfn-quicksight-template-calculatedfield-expression
         */
        readonly expression: string;
        /**
         * The name of the calculated field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-calculatedfield.html#cfn-quicksight-template-calculatedfield-name
         */
        readonly name: string;
    }
    /**
     * Dataset configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datasetconfiguration.html
     */
    interface DataSetConfigurationProperty {
        /**
         * A structure containing the list of column group schemas.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datasetconfiguration.html#cfn-quicksight-template-datasetconfiguration-columngroupschemalist
         */
        readonly columnGroupSchemaList?: Array<CfnTemplate.ColumnGroupSchemaProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * Dataset schema.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datasetconfiguration.html#cfn-quicksight-template-datasetconfiguration-datasetschema
         */
        readonly dataSetSchema?: CfnTemplate.DataSetSchemaProperty | cdk.IResolvable;
        /**
         * Placeholder.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datasetconfiguration.html#cfn-quicksight-template-datasetconfiguration-placeholder
         */
        readonly placeholder?: string;
    }
    /**
     * Dataset schema.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datasetschema.html
     */
    interface DataSetSchemaProperty {
        /**
         * A structure containing the list of column schemas.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datasetschema.html#cfn-quicksight-template-datasetschema-columnschemalist
         */
        readonly columnSchemaList?: Array<CfnTemplate.ColumnSchemaProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * The column schema.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnschema.html
     */
    interface ColumnSchemaProperty {
        /**
         * The data type of the column schema.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnschema.html#cfn-quicksight-template-columnschema-datatype
         */
        readonly dataType?: string;
        /**
         * The geographic role of the column schema.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnschema.html#cfn-quicksight-template-columnschema-geographicrole
         */
        readonly geographicRole?: string;
        /**
         * The name of the column schema.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnschema.html#cfn-quicksight-template-columnschema-name
         */
        readonly name?: string;
    }
    /**
     * The column group schema.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columngroupschema.html
     */
    interface ColumnGroupSchemaProperty {
        /**
         * A structure containing the list of schemas for column group columns.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columngroupschema.html#cfn-quicksight-template-columngroupschema-columngroupcolumnschemalist
         */
        readonly columnGroupColumnSchemaList?: Array<CfnTemplate.ColumnGroupColumnSchemaProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The name of the column group schema.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columngroupschema.html#cfn-quicksight-template-columngroupschema-name
         */
        readonly name?: string;
    }
    /**
     * A structure describing the name, data type, and geographic role of the columns.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columngroupcolumnschema.html
     */
    interface ColumnGroupColumnSchemaProperty {
        /**
         * The name of the column group's column schema.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columngroupcolumnschema.html#cfn-quicksight-template-columngroupcolumnschema-name
         */
        readonly name?: string;
    }
    /**
     * The general configuration of a column.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnconfiguration.html
     */
    interface ColumnConfigurationProperty {
        /**
         * The color configurations of the column.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnconfiguration.html#cfn-quicksight-template-columnconfiguration-colorsconfiguration
         */
        readonly colorsConfiguration?: CfnTemplate.ColorsConfigurationProperty | cdk.IResolvable;
        /**
         * The column.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnconfiguration.html#cfn-quicksight-template-columnconfiguration-column
         */
        readonly column: CfnTemplate.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * The format configuration of a column.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnconfiguration.html#cfn-quicksight-template-columnconfiguration-formatconfiguration
         */
        readonly formatConfiguration?: CfnTemplate.FormatConfigurationProperty | cdk.IResolvable;
        /**
         * The role of the column.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnconfiguration.html#cfn-quicksight-template-columnconfiguration-role
         */
        readonly role?: string;
    }
    /**
     * The formatting configuration for all types of field.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-formatconfiguration.html
     */
    interface FormatConfigurationProperty {
        /**
         * Formatting configuration for `DateTime` fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-formatconfiguration.html#cfn-quicksight-template-formatconfiguration-datetimeformatconfiguration
         */
        readonly dateTimeFormatConfiguration?: CfnTemplate.DateTimeFormatConfigurationProperty | cdk.IResolvable;
        /**
         * Formatting configuration for number fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-formatconfiguration.html#cfn-quicksight-template-formatconfiguration-numberformatconfiguration
         */
        readonly numberFormatConfiguration?: cdk.IResolvable | CfnTemplate.NumberFormatConfigurationProperty;
        /**
         * Formatting configuration for string fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-formatconfiguration.html#cfn-quicksight-template-formatconfiguration-stringformatconfiguration
         */
        readonly stringFormatConfiguration?: cdk.IResolvable | CfnTemplate.StringFormatConfigurationProperty;
    }
    /**
     * Formatting configuration for number fields.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numberformatconfiguration.html
     */
    interface NumberFormatConfigurationProperty {
        /**
         * The options that determine the numeric format configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numberformatconfiguration.html#cfn-quicksight-template-numberformatconfiguration-formatconfiguration
         */
        readonly formatConfiguration?: cdk.IResolvable | CfnTemplate.NumericFormatConfigurationProperty;
    }
    /**
     * The options that determine the numeric format configuration.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericformatconfiguration.html
     */
    interface NumericFormatConfigurationProperty {
        /**
         * The options that determine the currency display format configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericformatconfiguration.html#cfn-quicksight-template-numericformatconfiguration-currencydisplayformatconfiguration
         */
        readonly currencyDisplayFormatConfiguration?: CfnTemplate.CurrencyDisplayFormatConfigurationProperty | cdk.IResolvable;
        /**
         * The options that determine the number display format configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericformatconfiguration.html#cfn-quicksight-template-numericformatconfiguration-numberdisplayformatconfiguration
         */
        readonly numberDisplayFormatConfiguration?: cdk.IResolvable | CfnTemplate.NumberDisplayFormatConfigurationProperty;
        /**
         * The options that determine the percentage display format configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericformatconfiguration.html#cfn-quicksight-template-numericformatconfiguration-percentagedisplayformatconfiguration
         */
        readonly percentageDisplayFormatConfiguration?: cdk.IResolvable | CfnTemplate.PercentageDisplayFormatConfigurationProperty;
    }
    /**
     * The options that determine the number display format configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numberdisplayformatconfiguration.html
     */
    interface NumberDisplayFormatConfigurationProperty {
        /**
         * The option that determines the decimal places configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numberdisplayformatconfiguration.html#cfn-quicksight-template-numberdisplayformatconfiguration-decimalplacesconfiguration
         */
        readonly decimalPlacesConfiguration?: CfnTemplate.DecimalPlacesConfigurationProperty | cdk.IResolvable;
        /**
         * The options that determine the negative value configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numberdisplayformatconfiguration.html#cfn-quicksight-template-numberdisplayformatconfiguration-negativevalueconfiguration
         */
        readonly negativeValueConfiguration?: cdk.IResolvable | CfnTemplate.NegativeValueConfigurationProperty;
        /**
         * The options that determine the null value format configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numberdisplayformatconfiguration.html#cfn-quicksight-template-numberdisplayformatconfiguration-nullvalueformatconfiguration
         */
        readonly nullValueFormatConfiguration?: cdk.IResolvable | CfnTemplate.NullValueFormatConfigurationProperty;
        /**
         * Determines the number scale value of the number format.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numberdisplayformatconfiguration.html#cfn-quicksight-template-numberdisplayformatconfiguration-numberscale
         */
        readonly numberScale?: string;
        /**
         * Determines the prefix value of the number format.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numberdisplayformatconfiguration.html#cfn-quicksight-template-numberdisplayformatconfiguration-prefix
         */
        readonly prefix?: string;
        /**
         * The options that determine the numeric separator configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numberdisplayformatconfiguration.html#cfn-quicksight-template-numberdisplayformatconfiguration-separatorconfiguration
         */
        readonly separatorConfiguration?: cdk.IResolvable | CfnTemplate.NumericSeparatorConfigurationProperty;
        /**
         * Determines the suffix value of the number format.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numberdisplayformatconfiguration.html#cfn-quicksight-template-numberdisplayformatconfiguration-suffix
         */
        readonly suffix?: string;
    }
    /**
     * The options that determine the negative value configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-negativevalueconfiguration.html
     */
    interface NegativeValueConfigurationProperty {
        /**
         * Determines the display mode of the negative value configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-negativevalueconfiguration.html#cfn-quicksight-template-negativevalueconfiguration-displaymode
         */
        readonly displayMode: string;
    }
    /**
     * The option that determines the decimal places configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-decimalplacesconfiguration.html
     */
    interface DecimalPlacesConfigurationProperty {
        /**
         * The values of the decimal places.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-decimalplacesconfiguration.html#cfn-quicksight-template-decimalplacesconfiguration-decimalplaces
         */
        readonly decimalPlaces: number;
    }
    /**
     * The options that determine the null value format configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-nullvalueformatconfiguration.html
     */
    interface NullValueFormatConfigurationProperty {
        /**
         * Determines the null string of null values.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-nullvalueformatconfiguration.html#cfn-quicksight-template-nullvalueformatconfiguration-nullstring
         */
        readonly nullString: string;
    }
    /**
     * The options that determine the numeric separator configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericseparatorconfiguration.html
     */
    interface NumericSeparatorConfigurationProperty {
        /**
         * Determines the decimal separator.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericseparatorconfiguration.html#cfn-quicksight-template-numericseparatorconfiguration-decimalseparator
         */
        readonly decimalSeparator?: string;
        /**
         * The options that determine the thousands separator configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericseparatorconfiguration.html#cfn-quicksight-template-numericseparatorconfiguration-thousandsseparator
         */
        readonly thousandsSeparator?: cdk.IResolvable | CfnTemplate.ThousandSeparatorOptionsProperty;
    }
    /**
     * The options that determine the thousands separator configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-thousandseparatoroptions.html
     */
    interface ThousandSeparatorOptionsProperty {
        /**
         * Determines the thousands separator symbol.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-thousandseparatoroptions.html#cfn-quicksight-template-thousandseparatoroptions-symbol
         */
        readonly symbol?: string;
        /**
         * Determines the visibility of the thousands separator.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-thousandseparatoroptions.html#cfn-quicksight-template-thousandseparatoroptions-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The options that determine the currency display format configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-currencydisplayformatconfiguration.html
     */
    interface CurrencyDisplayFormatConfigurationProperty {
        /**
         * The option that determines the decimal places configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-currencydisplayformatconfiguration.html#cfn-quicksight-template-currencydisplayformatconfiguration-decimalplacesconfiguration
         */
        readonly decimalPlacesConfiguration?: CfnTemplate.DecimalPlacesConfigurationProperty | cdk.IResolvable;
        /**
         * The options that determine the negative value configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-currencydisplayformatconfiguration.html#cfn-quicksight-template-currencydisplayformatconfiguration-negativevalueconfiguration
         */
        readonly negativeValueConfiguration?: cdk.IResolvable | CfnTemplate.NegativeValueConfigurationProperty;
        /**
         * The options that determine the null value format configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-currencydisplayformatconfiguration.html#cfn-quicksight-template-currencydisplayformatconfiguration-nullvalueformatconfiguration
         */
        readonly nullValueFormatConfiguration?: cdk.IResolvable | CfnTemplate.NullValueFormatConfigurationProperty;
        /**
         * Determines the number scale value for the currency format.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-currencydisplayformatconfiguration.html#cfn-quicksight-template-currencydisplayformatconfiguration-numberscale
         */
        readonly numberScale?: string;
        /**
         * Determines the prefix value of the currency format.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-currencydisplayformatconfiguration.html#cfn-quicksight-template-currencydisplayformatconfiguration-prefix
         */
        readonly prefix?: string;
        /**
         * The options that determine the numeric separator configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-currencydisplayformatconfiguration.html#cfn-quicksight-template-currencydisplayformatconfiguration-separatorconfiguration
         */
        readonly separatorConfiguration?: cdk.IResolvable | CfnTemplate.NumericSeparatorConfigurationProperty;
        /**
         * Determines the suffix value of the currency format.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-currencydisplayformatconfiguration.html#cfn-quicksight-template-currencydisplayformatconfiguration-suffix
         */
        readonly suffix?: string;
        /**
         * Determines the symbol for the currency format.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-currencydisplayformatconfiguration.html#cfn-quicksight-template-currencydisplayformatconfiguration-symbol
         */
        readonly symbol?: string;
    }
    /**
     * The options that determine the percentage display format configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-percentagedisplayformatconfiguration.html
     */
    interface PercentageDisplayFormatConfigurationProperty {
        /**
         * The option that determines the decimal places configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-percentagedisplayformatconfiguration.html#cfn-quicksight-template-percentagedisplayformatconfiguration-decimalplacesconfiguration
         */
        readonly decimalPlacesConfiguration?: CfnTemplate.DecimalPlacesConfigurationProperty | cdk.IResolvable;
        /**
         * The options that determine the negative value configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-percentagedisplayformatconfiguration.html#cfn-quicksight-template-percentagedisplayformatconfiguration-negativevalueconfiguration
         */
        readonly negativeValueConfiguration?: cdk.IResolvable | CfnTemplate.NegativeValueConfigurationProperty;
        /**
         * The options that determine the null value format configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-percentagedisplayformatconfiguration.html#cfn-quicksight-template-percentagedisplayformatconfiguration-nullvalueformatconfiguration
         */
        readonly nullValueFormatConfiguration?: cdk.IResolvable | CfnTemplate.NullValueFormatConfigurationProperty;
        /**
         * Determines the prefix value of the percentage format.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-percentagedisplayformatconfiguration.html#cfn-quicksight-template-percentagedisplayformatconfiguration-prefix
         */
        readonly prefix?: string;
        /**
         * The options that determine the numeric separator configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-percentagedisplayformatconfiguration.html#cfn-quicksight-template-percentagedisplayformatconfiguration-separatorconfiguration
         */
        readonly separatorConfiguration?: cdk.IResolvable | CfnTemplate.NumericSeparatorConfigurationProperty;
        /**
         * Determines the suffix value of the percentage format.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-percentagedisplayformatconfiguration.html#cfn-quicksight-template-percentagedisplayformatconfiguration-suffix
         */
        readonly suffix?: string;
    }
    /**
     * Formatting configuration for `DateTime` fields.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimeformatconfiguration.html
     */
    interface DateTimeFormatConfigurationProperty {
        /**
         * Determines the `DateTime` format.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimeformatconfiguration.html#cfn-quicksight-template-datetimeformatconfiguration-datetimeformat
         */
        readonly dateTimeFormat?: string;
        /**
         * The options that determine the null value format configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimeformatconfiguration.html#cfn-quicksight-template-datetimeformatconfiguration-nullvalueformatconfiguration
         */
        readonly nullValueFormatConfiguration?: cdk.IResolvable | CfnTemplate.NullValueFormatConfigurationProperty;
        /**
         * The formatting configuration for numeric `DateTime` fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimeformatconfiguration.html#cfn-quicksight-template-datetimeformatconfiguration-numericformatconfiguration
         */
        readonly numericFormatConfiguration?: cdk.IResolvable | CfnTemplate.NumericFormatConfigurationProperty;
    }
    /**
     * Formatting configuration for string fields.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringformatconfiguration.html
     */
    interface StringFormatConfigurationProperty {
        /**
         * The options that determine the null value format configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringformatconfiguration.html#cfn-quicksight-template-stringformatconfiguration-nullvalueformatconfiguration
         */
        readonly nullValueFormatConfiguration?: cdk.IResolvable | CfnTemplate.NullValueFormatConfigurationProperty;
        /**
         * The formatting configuration for numeric strings.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringformatconfiguration.html#cfn-quicksight-template-stringformatconfiguration-numericformatconfiguration
         */
        readonly numericFormatConfiguration?: cdk.IResolvable | CfnTemplate.NumericFormatConfigurationProperty;
    }
    /**
     * The color configurations for a column.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-colorsconfiguration.html
     */
    interface ColorsConfigurationProperty {
        /**
         * A list of up to 50 custom colors.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-colorsconfiguration.html#cfn-quicksight-template-colorsconfiguration-customcolors
         */
        readonly customColors?: Array<CfnTemplate.CustomColorProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * Determines the color that's applied to a particular data value in a column.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcolor.html
     */
    interface CustomColorProperty {
        /**
         * The color that is applied to the data value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcolor.html#cfn-quicksight-template-customcolor-color
         */
        readonly color: string;
        /**
         * The data value that the color is applied to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcolor.html#cfn-quicksight-template-customcolor-fieldvalue
         */
        readonly fieldValue?: string;
        /**
         * The value of a special data value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcolor.html#cfn-quicksight-template-customcolor-specialvalue
         */
        readonly specialValue?: string;
    }
    /**
     * The configuration for default analysis settings.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-analysisdefaults.html
     */
    interface AnalysisDefaultsProperty {
        /**
         * The configuration for default new sheet settings.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-analysisdefaults.html#cfn-quicksight-template-analysisdefaults-defaultnewsheetconfiguration
         */
        readonly defaultNewSheetConfiguration: CfnTemplate.DefaultNewSheetConfigurationProperty | cdk.IResolvable;
    }
    /**
     * The configuration for default new sheet settings.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultnewsheetconfiguration.html
     */
    interface DefaultNewSheetConfigurationProperty {
        /**
         * The options that determine the default settings for interactive layout configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultnewsheetconfiguration.html#cfn-quicksight-template-defaultnewsheetconfiguration-interactivelayoutconfiguration
         */
        readonly interactiveLayoutConfiguration?: CfnTemplate.DefaultInteractiveLayoutConfigurationProperty | cdk.IResolvable;
        /**
         * The options that determine the default settings for a paginated layout configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultnewsheetconfiguration.html#cfn-quicksight-template-defaultnewsheetconfiguration-paginatedlayoutconfiguration
         */
        readonly paginatedLayoutConfiguration?: CfnTemplate.DefaultPaginatedLayoutConfigurationProperty | cdk.IResolvable;
        /**
         * The option that determines the sheet content type.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultnewsheetconfiguration.html#cfn-quicksight-template-defaultnewsheetconfiguration-sheetcontenttype
         */
        readonly sheetContentType?: string;
    }
    /**
     * The options that determine the default settings for interactive layout configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultinteractivelayoutconfiguration.html
     */
    interface DefaultInteractiveLayoutConfigurationProperty {
        /**
         * The options that determine the default settings of a free-form layout configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultinteractivelayoutconfiguration.html#cfn-quicksight-template-defaultinteractivelayoutconfiguration-freeform
         */
        readonly freeForm?: CfnTemplate.DefaultFreeFormLayoutConfigurationProperty | cdk.IResolvable;
        /**
         * The options that determine the default settings for a grid layout configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultinteractivelayoutconfiguration.html#cfn-quicksight-template-defaultinteractivelayoutconfiguration-grid
         */
        readonly grid?: CfnTemplate.DefaultGridLayoutConfigurationProperty | cdk.IResolvable;
    }
    /**
     * The options that determine the default settings of a free-form layout configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultfreeformlayoutconfiguration.html
     */
    interface DefaultFreeFormLayoutConfigurationProperty {
        /**
         * Determines the screen canvas size options for a free-form layout.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultfreeformlayoutconfiguration.html#cfn-quicksight-template-defaultfreeformlayoutconfiguration-canvassizeoptions
         */
        readonly canvasSizeOptions: CfnTemplate.FreeFormLayoutCanvasSizeOptionsProperty | cdk.IResolvable;
    }
    /**
     * Configuration options for the canvas of a free-form layout.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutcanvassizeoptions.html
     */
    interface FreeFormLayoutCanvasSizeOptionsProperty {
        /**
         * The options that determine the sizing of the canvas used in a free-form layout.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutcanvassizeoptions.html#cfn-quicksight-template-freeformlayoutcanvassizeoptions-screencanvassizeoptions
         */
        readonly screenCanvasSizeOptions?: CfnTemplate.FreeFormLayoutScreenCanvasSizeOptionsProperty | cdk.IResolvable;
    }
    /**
     * The options that determine the sizing of the canvas used in a free-form layout.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutscreencanvassizeoptions.html
     */
    interface FreeFormLayoutScreenCanvasSizeOptionsProperty {
        /**
         * The width that the view port will be optimized for when the layout renders.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutscreencanvassizeoptions.html#cfn-quicksight-template-freeformlayoutscreencanvassizeoptions-optimizedviewportwidth
         */
        readonly optimizedViewPortWidth: string;
    }
    /**
     * The options that determine the default settings for a grid layout configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultgridlayoutconfiguration.html
     */
    interface DefaultGridLayoutConfigurationProperty {
        /**
         * Determines the screen canvas size options for a grid layout.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultgridlayoutconfiguration.html#cfn-quicksight-template-defaultgridlayoutconfiguration-canvassizeoptions
         */
        readonly canvasSizeOptions: CfnTemplate.GridLayoutCanvasSizeOptionsProperty | cdk.IResolvable;
    }
    /**
     * Configuration options for the canvas of a grid layout.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutcanvassizeoptions.html
     */
    interface GridLayoutCanvasSizeOptionsProperty {
        /**
         * The options that determine the sizing of the canvas used in a grid layout.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutcanvassizeoptions.html#cfn-quicksight-template-gridlayoutcanvassizeoptions-screencanvassizeoptions
         */
        readonly screenCanvasSizeOptions?: CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty | cdk.IResolvable;
    }
    /**
     * The options that determine the sizing of the canvas used in a grid layout.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutscreencanvassizeoptions.html
     */
    interface GridLayoutScreenCanvasSizeOptionsProperty {
        /**
         * The width that the view port will be optimized for when the layout renders.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutscreencanvassizeoptions.html#cfn-quicksight-template-gridlayoutscreencanvassizeoptions-optimizedviewportwidth
         */
        readonly optimizedViewPortWidth?: string;
        /**
         * This value determines the layout behavior when the viewport is resized.
         *
         * - `FIXED` : A fixed width will be used when optimizing the layout. In the Amazon QuickSight console, this option is called `Classic` .
         * - `RESPONSIVE` : The width of the canvas will be responsive and optimized to the view port. In the Amazon QuickSight console, this option is called `Tiled` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutscreencanvassizeoptions.html#cfn-quicksight-template-gridlayoutscreencanvassizeoptions-resizeoption
         */
        readonly resizeOption: string;
    }
    /**
     * The options that determine the default settings for a paginated layout configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultpaginatedlayoutconfiguration.html
     */
    interface DefaultPaginatedLayoutConfigurationProperty {
        /**
         * The options that determine the default settings for a section-based layout configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultpaginatedlayoutconfiguration.html#cfn-quicksight-template-defaultpaginatedlayoutconfiguration-sectionbased
         */
        readonly sectionBased?: CfnTemplate.DefaultSectionBasedLayoutConfigurationProperty | cdk.IResolvable;
    }
    /**
     * The options that determine the default settings for a section-based layout configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultsectionbasedlayoutconfiguration.html
     */
    interface DefaultSectionBasedLayoutConfigurationProperty {
        /**
         * Determines the screen canvas size options for a section-based layout.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultsectionbasedlayoutconfiguration.html#cfn-quicksight-template-defaultsectionbasedlayoutconfiguration-canvassizeoptions
         */
        readonly canvasSizeOptions: cdk.IResolvable | CfnTemplate.SectionBasedLayoutCanvasSizeOptionsProperty;
    }
    /**
     * The options for the canvas of a section-based layout.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionbasedlayoutcanvassizeoptions.html
     */
    interface SectionBasedLayoutCanvasSizeOptionsProperty {
        /**
         * The options for a paper canvas of a section-based layout.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionbasedlayoutcanvassizeoptions.html#cfn-quicksight-template-sectionbasedlayoutcanvassizeoptions-papercanvassizeoptions
         */
        readonly paperCanvasSizeOptions?: cdk.IResolvable | CfnTemplate.SectionBasedLayoutPaperCanvasSizeOptionsProperty;
    }
    /**
     * The options for a paper canvas of a section-based layout.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionbasedlayoutpapercanvassizeoptions.html
     */
    interface SectionBasedLayoutPaperCanvasSizeOptionsProperty {
        /**
         * Defines the spacing between the canvas content and the top, bottom, left, and right edges.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionbasedlayoutpapercanvassizeoptions.html#cfn-quicksight-template-sectionbasedlayoutpapercanvassizeoptions-papermargin
         */
        readonly paperMargin?: cdk.IResolvable | CfnTemplate.SpacingProperty;
        /**
         * The paper orientation that is used to define canvas dimensions. Choose one of the following options:.
         *
         * - PORTRAIT
         * - LANDSCAPE
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionbasedlayoutpapercanvassizeoptions.html#cfn-quicksight-template-sectionbasedlayoutpapercanvassizeoptions-paperorientation
         */
        readonly paperOrientation?: string;
        /**
         * The paper size that is used to define canvas dimensions.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionbasedlayoutpapercanvassizeoptions.html#cfn-quicksight-template-sectionbasedlayoutpapercanvassizeoptions-papersize
         */
        readonly paperSize?: string;
    }
    /**
     * The configuration of spacing (often a margin or padding).
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-spacing.html
     */
    interface SpacingProperty {
        /**
         * Define the bottom spacing.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-spacing.html#cfn-quicksight-template-spacing-bottom
         */
        readonly bottom?: string;
        /**
         * Define the left spacing.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-spacing.html#cfn-quicksight-template-spacing-left
         */
        readonly left?: string;
        /**
         * Define the right spacing.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-spacing.html#cfn-quicksight-template-spacing-right
         */
        readonly right?: string;
        /**
         * Define the top spacing.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-spacing.html#cfn-quicksight-template-spacing-top
         */
        readonly top?: string;
    }
    /**
     * A sheet is an object that contains a set of visuals that are viewed together on one page in a paginated report.
     *
     * Every analysis and dashboard must contain at least one sheet.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetdefinition.html
     */
    interface SheetDefinitionProperty {
        /**
         * The layout content type of the sheet. Choose one of the following options:.
         *
         * - `PAGINATED` : Creates a sheet for a paginated report.
         * - `INTERACTIVE` : Creates a sheet for an interactive dashboard.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetdefinition.html#cfn-quicksight-template-sheetdefinition-contenttype
         */
        readonly contentType?: string;
        /**
         * A description of the sheet.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetdefinition.html#cfn-quicksight-template-sheetdefinition-description
         */
        readonly description?: string;
        /**
         * The list of filter controls that are on a sheet.
         *
         * For more information, see [Adding filter controls to analysis sheets](https://docs.aws.amazon.com/quicksight/latest/user/filter-controls.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetdefinition.html#cfn-quicksight-template-sheetdefinition-filtercontrols
         */
        readonly filterControls?: Array<CfnTemplate.FilterControlProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * Layouts define how the components of a sheet are arranged.
         *
         * For more information, see [Types of layout](https://docs.aws.amazon.com/quicksight/latest/user/types-of-layout.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetdefinition.html#cfn-quicksight-template-sheetdefinition-layouts
         */
        readonly layouts?: Array<cdk.IResolvable | CfnTemplate.LayoutProperty> | cdk.IResolvable;
        /**
         * The name of the sheet.
         *
         * This name is displayed on the sheet's tab in the Amazon QuickSight console.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetdefinition.html#cfn-quicksight-template-sheetdefinition-name
         */
        readonly name?: string;
        /**
         * The list of parameter controls that are on a sheet.
         *
         * For more information, see [Using a Control with a Parameter in Amazon QuickSight](https://docs.aws.amazon.com/quicksight/latest/user/parameters-controls.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetdefinition.html#cfn-quicksight-template-sheetdefinition-parametercontrols
         */
        readonly parameterControls?: Array<cdk.IResolvable | CfnTemplate.ParameterControlProperty> | cdk.IResolvable;
        /**
         * The control layouts of the sheet.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetdefinition.html#cfn-quicksight-template-sheetdefinition-sheetcontrollayouts
         */
        readonly sheetControlLayouts?: Array<cdk.IResolvable | CfnTemplate.SheetControlLayoutProperty> | cdk.IResolvable;
        /**
         * The unique identifier of a sheet.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetdefinition.html#cfn-quicksight-template-sheetdefinition-sheetid
         */
        readonly sheetId: string;
        /**
         * The text boxes that are on a sheet.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetdefinition.html#cfn-quicksight-template-sheetdefinition-textboxes
         */
        readonly textBoxes?: Array<cdk.IResolvable | CfnTemplate.SheetTextBoxProperty> | cdk.IResolvable;
        /**
         * The title of the sheet.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetdefinition.html#cfn-quicksight-template-sheetdefinition-title
         */
        readonly title?: string;
        /**
         * A list of the visuals that are on a sheet.
         *
         * Visual placement is determined by the layout of the sheet.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetdefinition.html#cfn-quicksight-template-sheetdefinition-visuals
         */
        readonly visuals?: Array<cdk.IResolvable | CfnTemplate.VisualProperty> | cdk.IResolvable;
    }
    /**
     * The control of a parameter that users can interact with in a dashboard or an analysis.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametercontrol.html
     */
    interface ParameterControlProperty {
        /**
         * A control from a date parameter that specifies date and time.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametercontrol.html#cfn-quicksight-template-parametercontrol-datetimepicker
         */
        readonly dateTimePicker?: cdk.IResolvable | CfnTemplate.ParameterDateTimePickerControlProperty;
        /**
         * A control to display a dropdown list with buttons that are used to select a single value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametercontrol.html#cfn-quicksight-template-parametercontrol-dropdown
         */
        readonly dropdown?: cdk.IResolvable | CfnTemplate.ParameterDropDownControlProperty;
        /**
         * A control to display a list with buttons or boxes that are used to select either a single value or multiple values.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametercontrol.html#cfn-quicksight-template-parametercontrol-list
         */
        readonly list?: cdk.IResolvable | CfnTemplate.ParameterListControlProperty;
        /**
         * A control to display a horizontal toggle bar.
         *
         * This is used to change a value by sliding the toggle.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametercontrol.html#cfn-quicksight-template-parametercontrol-slider
         */
        readonly slider?: cdk.IResolvable | CfnTemplate.ParameterSliderControlProperty;
        /**
         * A control to display a text box that is used to enter multiple entries.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametercontrol.html#cfn-quicksight-template-parametercontrol-textarea
         */
        readonly textArea?: cdk.IResolvable | CfnTemplate.ParameterTextAreaControlProperty;
        /**
         * A control to display a text box that is used to enter a single entry.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametercontrol.html#cfn-quicksight-template-parametercontrol-textfield
         */
        readonly textField?: cdk.IResolvable | CfnTemplate.ParameterTextFieldControlProperty;
    }
    /**
     * A control to display a horizontal toggle bar.
     *
     * This is used to change a value by sliding the toggle.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterslidercontrol.html
     */
    interface ParameterSliderControlProperty {
        /**
         * The display options of a control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterslidercontrol.html#cfn-quicksight-template-parameterslidercontrol-displayoptions
         */
        readonly displayOptions?: cdk.IResolvable | CfnTemplate.SliderControlDisplayOptionsProperty;
        /**
         * The smaller value that is displayed at the left of the slider.
         *
         * @default - 0
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterslidercontrol.html#cfn-quicksight-template-parameterslidercontrol-maximumvalue
         */
        readonly maximumValue: number;
        /**
         * The larger value that is displayed at the right of the slider.
         *
         * @default - 0
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterslidercontrol.html#cfn-quicksight-template-parameterslidercontrol-minimumvalue
         */
        readonly minimumValue: number;
        /**
         * The ID of the `ParameterSliderControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterslidercontrol.html#cfn-quicksight-template-parameterslidercontrol-parametercontrolid
         */
        readonly parameterControlId: string;
        /**
         * The source parameter name of the `ParameterSliderControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterslidercontrol.html#cfn-quicksight-template-parameterslidercontrol-sourceparametername
         */
        readonly sourceParameterName: string;
        /**
         * The number of increments that the slider bar is divided into.
         *
         * @default - 0
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterslidercontrol.html#cfn-quicksight-template-parameterslidercontrol-stepsize
         */
        readonly stepSize: number;
        /**
         * The title of the `ParameterSliderControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterslidercontrol.html#cfn-quicksight-template-parameterslidercontrol-title
         */
        readonly title: string;
    }
    /**
     * The display options of a control.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-slidercontroldisplayoptions.html
     */
    interface SliderControlDisplayOptionsProperty {
        /**
         * The configuration of info icon label options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-slidercontroldisplayoptions.html#cfn-quicksight-template-slidercontroldisplayoptions-infoiconlabeloptions
         */
        readonly infoIconLabelOptions?: cdk.IResolvable | CfnTemplate.SheetControlInfoIconLabelOptionsProperty;
        /**
         * The options to configure the title visibility, name, and font size.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-slidercontroldisplayoptions.html#cfn-quicksight-template-slidercontroldisplayoptions-titleoptions
         */
        readonly titleOptions?: cdk.IResolvable | CfnTemplate.LabelOptionsProperty;
    }
    /**
     * The share label options for the labels.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-labeloptions.html
     */
    interface LabelOptionsProperty {
        /**
         * The text for the label.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-labeloptions.html#cfn-quicksight-template-labeloptions-customlabel
         */
        readonly customLabel?: string;
        /**
         * The font configuration of the label.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-labeloptions.html#cfn-quicksight-template-labeloptions-fontconfiguration
         */
        readonly fontConfiguration?: CfnTemplate.FontConfigurationProperty | cdk.IResolvable;
        /**
         * Determines whether or not the label is visible.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-labeloptions.html#cfn-quicksight-template-labeloptions-visibility
         */
        readonly visibility?: string;
    }
    /**
     * Configures the display properties of the given text.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fontconfiguration.html
     */
    interface FontConfigurationProperty {
        /**
         * Determines the color of the text.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fontconfiguration.html#cfn-quicksight-template-fontconfiguration-fontcolor
         */
        readonly fontColor?: string;
        /**
         * Determines the appearance of decorative lines on the text.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fontconfiguration.html#cfn-quicksight-template-fontconfiguration-fontdecoration
         */
        readonly fontDecoration?: string;
        /**
         * The option that determines the text display size.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fontconfiguration.html#cfn-quicksight-template-fontconfiguration-fontsize
         */
        readonly fontSize?: CfnTemplate.FontSizeProperty | cdk.IResolvable;
        /**
         * Determines the text display face that is inherited by the given font family.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fontconfiguration.html#cfn-quicksight-template-fontconfiguration-fontstyle
         */
        readonly fontStyle?: string;
        /**
         * The option that determines the text display weight, or boldness.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fontconfiguration.html#cfn-quicksight-template-fontconfiguration-fontweight
         */
        readonly fontWeight?: CfnTemplate.FontWeightProperty | cdk.IResolvable;
    }
    /**
     * The option that determines the text display size.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fontsize.html
     */
    interface FontSizeProperty {
        /**
         * The lexical name for the text size, proportional to its surrounding context.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fontsize.html#cfn-quicksight-template-fontsize-relative
         */
        readonly relative?: string;
    }
    /**
     * The option that determines the text display weight, or boldness.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fontweight.html
     */
    interface FontWeightProperty {
        /**
         * The lexical name for the level of boldness of the text display.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fontweight.html#cfn-quicksight-template-fontweight-name
         */
        readonly name?: string;
    }
    /**
     * A control to display info icons for filters and parameters.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetcontrolinfoiconlabeloptions.html
     */
    interface SheetControlInfoIconLabelOptionsProperty {
        /**
         * The text content of info icon.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetcontrolinfoiconlabeloptions.html#cfn-quicksight-template-sheetcontrolinfoiconlabeloptions-infoicontext
         */
        readonly infoIconText?: string;
        /**
         * The visibility configuration of info icon label options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetcontrolinfoiconlabeloptions.html#cfn-quicksight-template-sheetcontrolinfoiconlabeloptions-visibility
         */
        readonly visibility?: string;
    }
    /**
     * A control to display a text box that is used to enter multiple entries.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametertextareacontrol.html
     */
    interface ParameterTextAreaControlProperty {
        /**
         * The delimiter that is used to separate the lines in text.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametertextareacontrol.html#cfn-quicksight-template-parametertextareacontrol-delimiter
         */
        readonly delimiter?: string;
        /**
         * The display options of a control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametertextareacontrol.html#cfn-quicksight-template-parametertextareacontrol-displayoptions
         */
        readonly displayOptions?: cdk.IResolvable | CfnTemplate.TextAreaControlDisplayOptionsProperty;
        /**
         * The ID of the `ParameterTextAreaControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametertextareacontrol.html#cfn-quicksight-template-parametertextareacontrol-parametercontrolid
         */
        readonly parameterControlId: string;
        /**
         * The source parameter name of the `ParameterTextAreaControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametertextareacontrol.html#cfn-quicksight-template-parametertextareacontrol-sourceparametername
         */
        readonly sourceParameterName: string;
        /**
         * The title of the `ParameterTextAreaControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametertextareacontrol.html#cfn-quicksight-template-parametertextareacontrol-title
         */
        readonly title: string;
    }
    /**
     * The display options of a control.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-textareacontroldisplayoptions.html
     */
    interface TextAreaControlDisplayOptionsProperty {
        /**
         * The configuration of info icon label options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-textareacontroldisplayoptions.html#cfn-quicksight-template-textareacontroldisplayoptions-infoiconlabeloptions
         */
        readonly infoIconLabelOptions?: cdk.IResolvable | CfnTemplate.SheetControlInfoIconLabelOptionsProperty;
        /**
         * The configuration of the placeholder options in a text area control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-textareacontroldisplayoptions.html#cfn-quicksight-template-textareacontroldisplayoptions-placeholderoptions
         */
        readonly placeholderOptions?: cdk.IResolvable | CfnTemplate.TextControlPlaceholderOptionsProperty;
        /**
         * The options to configure the title visibility, name, and font size.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-textareacontroldisplayoptions.html#cfn-quicksight-template-textareacontroldisplayoptions-titleoptions
         */
        readonly titleOptions?: cdk.IResolvable | CfnTemplate.LabelOptionsProperty;
    }
    /**
     * The configuration of the placeholder options in a text control.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-textcontrolplaceholderoptions.html
     */
    interface TextControlPlaceholderOptionsProperty {
        /**
         * The visibility configuration of the placeholder options in a text control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-textcontrolplaceholderoptions.html#cfn-quicksight-template-textcontrolplaceholderoptions-visibility
         */
        readonly visibility?: string;
    }
    /**
     * A control to display a dropdown list with buttons that are used to select a single value.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdropdowncontrol.html
     */
    interface ParameterDropDownControlProperty {
        /**
         * The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdropdowncontrol.html#cfn-quicksight-template-parameterdropdowncontrol-cascadingcontrolconfiguration
         */
        readonly cascadingControlConfiguration?: CfnTemplate.CascadingControlConfigurationProperty | cdk.IResolvable;
        /**
         * The display options of a control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdropdowncontrol.html#cfn-quicksight-template-parameterdropdowncontrol-displayoptions
         */
        readonly displayOptions?: CfnTemplate.DropDownControlDisplayOptionsProperty | cdk.IResolvable;
        /**
         * The ID of the `ParameterDropDownControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdropdowncontrol.html#cfn-quicksight-template-parameterdropdowncontrol-parametercontrolid
         */
        readonly parameterControlId: string;
        /**
         * A list of selectable values that are used in a control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdropdowncontrol.html#cfn-quicksight-template-parameterdropdowncontrol-selectablevalues
         */
        readonly selectableValues?: cdk.IResolvable | CfnTemplate.ParameterSelectableValuesProperty;
        /**
         * The source parameter name of the `ParameterDropDownControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdropdowncontrol.html#cfn-quicksight-template-parameterdropdowncontrol-sourceparametername
         */
        readonly sourceParameterName: string;
        /**
         * The title of the `ParameterDropDownControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdropdowncontrol.html#cfn-quicksight-template-parameterdropdowncontrol-title
         */
        readonly title: string;
        /**
         * The type parameter name of the `ParameterDropDownControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdropdowncontrol.html#cfn-quicksight-template-parameterdropdowncontrol-type
         */
        readonly type?: string;
    }
    /**
     * The display options of a control.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-dropdowncontroldisplayoptions.html
     */
    interface DropDownControlDisplayOptionsProperty {
        /**
         * The configuration of info icon label options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-dropdowncontroldisplayoptions.html#cfn-quicksight-template-dropdowncontroldisplayoptions-infoiconlabeloptions
         */
        readonly infoIconLabelOptions?: cdk.IResolvable | CfnTemplate.SheetControlInfoIconLabelOptionsProperty;
        /**
         * The configuration of the `Select all` options in a dropdown control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-dropdowncontroldisplayoptions.html#cfn-quicksight-template-dropdowncontroldisplayoptions-selectalloptions
         */
        readonly selectAllOptions?: cdk.IResolvable | CfnTemplate.ListControlSelectAllOptionsProperty;
        /**
         * The options to configure the title visibility, name, and font size.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-dropdowncontroldisplayoptions.html#cfn-quicksight-template-dropdowncontroldisplayoptions-titleoptions
         */
        readonly titleOptions?: cdk.IResolvable | CfnTemplate.LabelOptionsProperty;
    }
    /**
     * The configuration of the `Select all` options in a list control.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-listcontrolselectalloptions.html
     */
    interface ListControlSelectAllOptionsProperty {
        /**
         * The visibility configuration of the `Select all` options in a list control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-listcontrolselectalloptions.html#cfn-quicksight-template-listcontrolselectalloptions-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-cascadingcontrolconfiguration.html
     */
    interface CascadingControlConfigurationProperty {
        /**
         * A list of source controls that determine the values that are used in the current control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-cascadingcontrolconfiguration.html#cfn-quicksight-template-cascadingcontrolconfiguration-sourcecontrols
         */
        readonly sourceControls?: Array<CfnTemplate.CascadingControlSourceProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * The source controls that are used in a `CascadingControlConfiguration` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-cascadingcontrolsource.html
     */
    interface CascadingControlSourceProperty {
        /**
         * The column identifier that determines which column to look up for the source sheet control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-cascadingcontrolsource.html#cfn-quicksight-template-cascadingcontrolsource-columntomatch
         */
        readonly columnToMatch?: CfnTemplate.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * The source sheet control ID of a `CascadingControlSource` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-cascadingcontrolsource.html#cfn-quicksight-template-cascadingcontrolsource-sourcesheetcontrolid
         */
        readonly sourceSheetControlId?: string;
    }
    /**
     * A list of selectable values that are used in a control.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterselectablevalues.html
     */
    interface ParameterSelectableValuesProperty {
        /**
         * The column identifier that fetches values from the data set.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterselectablevalues.html#cfn-quicksight-template-parameterselectablevalues-linktodatasetcolumn
         */
        readonly linkToDataSetColumn?: CfnTemplate.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * The values that are used in `ParameterSelectableValues` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterselectablevalues.html#cfn-quicksight-template-parameterselectablevalues-values
         */
        readonly values?: Array<string>;
    }
    /**
     * A control to display a text box that is used to enter a single entry.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametertextfieldcontrol.html
     */
    interface ParameterTextFieldControlProperty {
        /**
         * The display options of a control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametertextfieldcontrol.html#cfn-quicksight-template-parametertextfieldcontrol-displayoptions
         */
        readonly displayOptions?: cdk.IResolvable | CfnTemplate.TextFieldControlDisplayOptionsProperty;
        /**
         * The ID of the `ParameterTextFieldControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametertextfieldcontrol.html#cfn-quicksight-template-parametertextfieldcontrol-parametercontrolid
         */
        readonly parameterControlId: string;
        /**
         * The source parameter name of the `ParameterTextFieldControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametertextfieldcontrol.html#cfn-quicksight-template-parametertextfieldcontrol-sourceparametername
         */
        readonly sourceParameterName: string;
        /**
         * The title of the `ParameterTextFieldControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametertextfieldcontrol.html#cfn-quicksight-template-parametertextfieldcontrol-title
         */
        readonly title: string;
    }
    /**
     * The display options of a control.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-textfieldcontroldisplayoptions.html
     */
    interface TextFieldControlDisplayOptionsProperty {
        /**
         * The configuration of info icon label options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-textfieldcontroldisplayoptions.html#cfn-quicksight-template-textfieldcontroldisplayoptions-infoiconlabeloptions
         */
        readonly infoIconLabelOptions?: cdk.IResolvable | CfnTemplate.SheetControlInfoIconLabelOptionsProperty;
        /**
         * The configuration of the placeholder options in a text field control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-textfieldcontroldisplayoptions.html#cfn-quicksight-template-textfieldcontroldisplayoptions-placeholderoptions
         */
        readonly placeholderOptions?: cdk.IResolvable | CfnTemplate.TextControlPlaceholderOptionsProperty;
        /**
         * The options to configure the title visibility, name, and font size.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-textfieldcontroldisplayoptions.html#cfn-quicksight-template-textfieldcontroldisplayoptions-titleoptions
         */
        readonly titleOptions?: cdk.IResolvable | CfnTemplate.LabelOptionsProperty;
    }
    /**
     * A control to display a list with buttons or boxes that are used to select either a single value or multiple values.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterlistcontrol.html
     */
    interface ParameterListControlProperty {
        /**
         * The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterlistcontrol.html#cfn-quicksight-template-parameterlistcontrol-cascadingcontrolconfiguration
         */
        readonly cascadingControlConfiguration?: CfnTemplate.CascadingControlConfigurationProperty | cdk.IResolvable;
        /**
         * The display options of a control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterlistcontrol.html#cfn-quicksight-template-parameterlistcontrol-displayoptions
         */
        readonly displayOptions?: cdk.IResolvable | CfnTemplate.ListControlDisplayOptionsProperty;
        /**
         * The ID of the `ParameterListControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterlistcontrol.html#cfn-quicksight-template-parameterlistcontrol-parametercontrolid
         */
        readonly parameterControlId: string;
        /**
         * A list of selectable values that are used in a control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterlistcontrol.html#cfn-quicksight-template-parameterlistcontrol-selectablevalues
         */
        readonly selectableValues?: cdk.IResolvable | CfnTemplate.ParameterSelectableValuesProperty;
        /**
         * The source parameter name of the `ParameterListControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterlistcontrol.html#cfn-quicksight-template-parameterlistcontrol-sourceparametername
         */
        readonly sourceParameterName: string;
        /**
         * The title of the `ParameterListControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterlistcontrol.html#cfn-quicksight-template-parameterlistcontrol-title
         */
        readonly title: string;
        /**
         * The type of `ParameterListControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterlistcontrol.html#cfn-quicksight-template-parameterlistcontrol-type
         */
        readonly type?: string;
    }
    /**
     * The display options of a control.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-listcontroldisplayoptions.html
     */
    interface ListControlDisplayOptionsProperty {
        /**
         * The configuration of info icon label options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-listcontroldisplayoptions.html#cfn-quicksight-template-listcontroldisplayoptions-infoiconlabeloptions
         */
        readonly infoIconLabelOptions?: cdk.IResolvable | CfnTemplate.SheetControlInfoIconLabelOptionsProperty;
        /**
         * The configuration of the search options in a list control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-listcontroldisplayoptions.html#cfn-quicksight-template-listcontroldisplayoptions-searchoptions
         */
        readonly searchOptions?: cdk.IResolvable | CfnTemplate.ListControlSearchOptionsProperty;
        /**
         * The configuration of the `Select all` options in a list control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-listcontroldisplayoptions.html#cfn-quicksight-template-listcontroldisplayoptions-selectalloptions
         */
        readonly selectAllOptions?: cdk.IResolvable | CfnTemplate.ListControlSelectAllOptionsProperty;
        /**
         * The options to configure the title visibility, name, and font size.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-listcontroldisplayoptions.html#cfn-quicksight-template-listcontroldisplayoptions-titleoptions
         */
        readonly titleOptions?: cdk.IResolvable | CfnTemplate.LabelOptionsProperty;
    }
    /**
     * The configuration of the search options in a list control.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-listcontrolsearchoptions.html
     */
    interface ListControlSearchOptionsProperty {
        /**
         * The visibility configuration of the search options in a list control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-listcontrolsearchoptions.html#cfn-quicksight-template-listcontrolsearchoptions-visibility
         */
        readonly visibility?: string;
    }
    /**
     * A control from a date parameter that specifies date and time.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdatetimepickercontrol.html
     */
    interface ParameterDateTimePickerControlProperty {
        /**
         * The display options of a control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdatetimepickercontrol.html#cfn-quicksight-template-parameterdatetimepickercontrol-displayoptions
         */
        readonly displayOptions?: CfnTemplate.DateTimePickerControlDisplayOptionsProperty | cdk.IResolvable;
        /**
         * The ID of the `ParameterDateTimePickerControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdatetimepickercontrol.html#cfn-quicksight-template-parameterdatetimepickercontrol-parametercontrolid
         */
        readonly parameterControlId: string;
        /**
         * The name of the `ParameterDateTimePickerControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdatetimepickercontrol.html#cfn-quicksight-template-parameterdatetimepickercontrol-sourceparametername
         */
        readonly sourceParameterName: string;
        /**
         * The title of the `ParameterDateTimePickerControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdatetimepickercontrol.html#cfn-quicksight-template-parameterdatetimepickercontrol-title
         */
        readonly title: string;
    }
    /**
     * The display options of a control.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimepickercontroldisplayoptions.html
     */
    interface DateTimePickerControlDisplayOptionsProperty {
        /**
         * Customize how dates are formatted in controls.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimepickercontroldisplayoptions.html#cfn-quicksight-template-datetimepickercontroldisplayoptions-datetimeformat
         */
        readonly dateTimeFormat?: string;
        /**
         * The configuration of info icon label options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimepickercontroldisplayoptions.html#cfn-quicksight-template-datetimepickercontroldisplayoptions-infoiconlabeloptions
         */
        readonly infoIconLabelOptions?: cdk.IResolvable | CfnTemplate.SheetControlInfoIconLabelOptionsProperty;
        /**
         * The options to configure the title visibility, name, and font size.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimepickercontroldisplayoptions.html#cfn-quicksight-template-datetimepickercontroldisplayoptions-titleoptions
         */
        readonly titleOptions?: cdk.IResolvable | CfnTemplate.LabelOptionsProperty;
    }
    /**
     * A text box.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheettextbox.html
     */
    interface SheetTextBoxProperty {
        /**
         * The content that is displayed in the text box.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheettextbox.html#cfn-quicksight-template-sheettextbox-content
         */
        readonly content?: string;
        /**
         * The unique identifier for a text box.
         *
         * This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have text boxes that share identifiers.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheettextbox.html#cfn-quicksight-template-sheettextbox-sheettextboxid
         */
        readonly sheetTextBoxId: string;
    }
    /**
     * A `Layout` defines the placement of elements within a sheet.
     *
     * For more information, see [Types of layout](https://docs.aws.amazon.com/quicksight/latest/user/types-of-layout.html) in the *Amazon QuickSight User Guide* .
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-layout.html
     */
    interface LayoutProperty {
        /**
         * The configuration that determines what the type of layout for a sheet.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-layout.html#cfn-quicksight-template-layout-configuration
         */
        readonly configuration: cdk.IResolvable | CfnTemplate.LayoutConfigurationProperty;
    }
    /**
     * The configuration that determines what the type of layout will be used on a sheet.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-layoutconfiguration.html
     */
    interface LayoutConfigurationProperty {
        /**
         * A free-form is optimized for a fixed width and has more control over the exact placement of layout elements.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-layoutconfiguration.html#cfn-quicksight-template-layoutconfiguration-freeformlayout
         */
        readonly freeFormLayout?: CfnTemplate.FreeFormLayoutConfigurationProperty | cdk.IResolvable;
        /**
         * A type of layout that can be used on a sheet.
         *
         * In a grid layout, visuals snap to a grid with standard spacing and alignment. Dashboards are displayed as designed, with options to fit to screen or view at actual size. A grid layout can be configured to behave in one of two ways when the viewport is resized: `FIXED` or `RESPONSIVE` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-layoutconfiguration.html#cfn-quicksight-template-layoutconfiguration-gridlayout
         */
        readonly gridLayout?: CfnTemplate.GridLayoutConfigurationProperty | cdk.IResolvable;
        /**
         * A section based layout organizes visuals into multiple sections and has customized header, footer and page break.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-layoutconfiguration.html#cfn-quicksight-template-layoutconfiguration-sectionbasedlayout
         */
        readonly sectionBasedLayout?: cdk.IResolvable | CfnTemplate.SectionBasedLayoutConfigurationProperty;
    }
    /**
     * The configuration for a grid layout. Also called a tiled layout.
     *
     * Visuals snap to a grid with standard spacing and alignment. Dashboards are displayed as designed, with options to fit to screen or view at actual size.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutconfiguration.html
     */
    interface GridLayoutConfigurationProperty {
        /**
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutconfiguration.html#cfn-quicksight-template-gridlayoutconfiguration-canvassizeoptions
         */
        readonly canvasSizeOptions?: CfnTemplate.GridLayoutCanvasSizeOptionsProperty | cdk.IResolvable;
        /**
         * The elements that are included in a grid layout.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutconfiguration.html#cfn-quicksight-template-gridlayoutconfiguration-elements
         */
        readonly elements: Array<CfnTemplate.GridLayoutElementProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * An element within a grid layout.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutelement.html
     */
    interface GridLayoutElementProperty {
        /**
         * The column index for the upper left corner of an element.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutelement.html#cfn-quicksight-template-gridlayoutelement-columnindex
         */
        readonly columnIndex?: number;
        /**
         * The width of a grid element expressed as a number of grid columns.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutelement.html#cfn-quicksight-template-gridlayoutelement-columnspan
         */
        readonly columnSpan: number;
        /**
         * A unique identifier for an element within a grid layout.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutelement.html#cfn-quicksight-template-gridlayoutelement-elementid
         */
        readonly elementId: string;
        /**
         * The type of element.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutelement.html#cfn-quicksight-template-gridlayoutelement-elementtype
         */
        readonly elementType: string;
        /**
         * The row index for the upper left corner of an element.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutelement.html#cfn-quicksight-template-gridlayoutelement-rowindex
         */
        readonly rowIndex?: number;
        /**
         * The height of a grid element expressed as a number of grid rows.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutelement.html#cfn-quicksight-template-gridlayoutelement-rowspan
         */
        readonly rowSpan: number;
    }
    /**
     * The configuration of a free-form layout.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutconfiguration.html
     */
    interface FreeFormLayoutConfigurationProperty {
        /**
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutconfiguration.html#cfn-quicksight-template-freeformlayoutconfiguration-canvassizeoptions
         */
        readonly canvasSizeOptions?: CfnTemplate.FreeFormLayoutCanvasSizeOptionsProperty | cdk.IResolvable;
        /**
         * The elements that are included in a free-form layout.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutconfiguration.html#cfn-quicksight-template-freeformlayoutconfiguration-elements
         */
        readonly elements: Array<CfnTemplate.FreeFormLayoutElementProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * An element within a free-form layout.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelement.html
     */
    interface FreeFormLayoutElementProperty {
        /**
         * The background style configuration of a free-form layout element.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelement.html#cfn-quicksight-template-freeformlayoutelement-backgroundstyle
         */
        readonly backgroundStyle?: CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty | cdk.IResolvable;
        /**
         * The border style configuration of a free-form layout element.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelement.html#cfn-quicksight-template-freeformlayoutelement-borderstyle
         */
        readonly borderStyle?: CfnTemplate.FreeFormLayoutElementBorderStyleProperty | cdk.IResolvable;
        /**
         * A unique identifier for an element within a free-form layout.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelement.html#cfn-quicksight-template-freeformlayoutelement-elementid
         */
        readonly elementId: string;
        /**
         * The type of element.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelement.html#cfn-quicksight-template-freeformlayoutelement-elementtype
         */
        readonly elementType: string;
        /**
         * The height of an element within a free-form layout.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelement.html#cfn-quicksight-template-freeformlayoutelement-height
         */
        readonly height: string;
        /**
         * The loading animation configuration of a free-form layout element.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelement.html#cfn-quicksight-template-freeformlayoutelement-loadinganimation
         */
        readonly loadingAnimation?: cdk.IResolvable | CfnTemplate.LoadingAnimationProperty;
        /**
         * The rendering rules that determine when an element should be displayed within a free-form layout.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelement.html#cfn-quicksight-template-freeformlayoutelement-renderingrules
         */
        readonly renderingRules?: Array<cdk.IResolvable | CfnTemplate.SheetElementRenderingRuleProperty> | cdk.IResolvable;
        /**
         * The border style configuration of a free-form layout element.
         *
         * This border style is used when the element is selected.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelement.html#cfn-quicksight-template-freeformlayoutelement-selectedborderstyle
         */
        readonly selectedBorderStyle?: CfnTemplate.FreeFormLayoutElementBorderStyleProperty | cdk.IResolvable;
        /**
         * The visibility of an element within a free-form layout.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelement.html#cfn-quicksight-template-freeformlayoutelement-visibility
         */
        readonly visibility?: string;
        /**
         * The width of an element within a free-form layout.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelement.html#cfn-quicksight-template-freeformlayoutelement-width
         */
        readonly width: string;
        /**
         * The x-axis coordinate of the element.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelement.html#cfn-quicksight-template-freeformlayoutelement-xaxislocation
         */
        readonly xAxisLocation: string;
        /**
         * The y-axis coordinate of the element.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelement.html#cfn-quicksight-template-freeformlayoutelement-yaxislocation
         */
        readonly yAxisLocation: string;
    }
    /**
     * The background style configuration of a free-form layout element.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelementborderstyle.html
     */
    interface FreeFormLayoutElementBorderStyleProperty {
        /**
         * The border color of a free-form layout element.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelementborderstyle.html#cfn-quicksight-template-freeformlayoutelementborderstyle-color
         */
        readonly color?: string;
        /**
         * The border visibility of a free-form layout element.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelementborderstyle.html#cfn-quicksight-template-freeformlayoutelementborderstyle-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The rendering rules of a sheet that uses a free-form layout.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetelementrenderingrule.html
     */
    interface SheetElementRenderingRuleProperty {
        /**
         * The override configuration of the rendering rules of a sheet.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetelementrenderingrule.html#cfn-quicksight-template-sheetelementrenderingrule-configurationoverrides
         */
        readonly configurationOverrides: cdk.IResolvable | CfnTemplate.SheetElementConfigurationOverridesProperty;
        /**
         * The expression of the rendering rules of a sheet.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetelementrenderingrule.html#cfn-quicksight-template-sheetelementrenderingrule-expression
         */
        readonly expression: string;
    }
    /**
     * The override configuration of the rendering rules of a sheet.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetelementconfigurationoverrides.html
     */
    interface SheetElementConfigurationOverridesProperty {
        /**
         * Determines whether or not the overrides are visible. Choose one of the following options:.
         *
         * - `VISIBLE`
         * - `HIDDEN`
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetelementconfigurationoverrides.html#cfn-quicksight-template-sheetelementconfigurationoverrides-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The configuration of loading animation in free-form layout.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-loadinganimation.html
     */
    interface LoadingAnimationProperty {
        /**
         * The visibility configuration of `LoadingAnimation` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-loadinganimation.html#cfn-quicksight-template-loadinganimation-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The background style configuration of a free-form layout element.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelementbackgroundstyle.html
     */
    interface FreeFormLayoutElementBackgroundStyleProperty {
        /**
         * The background color of a free-form layout element.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelementbackgroundstyle.html#cfn-quicksight-template-freeformlayoutelementbackgroundstyle-color
         */
        readonly color?: string;
        /**
         * The background visibility of a free-form layout element.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelementbackgroundstyle.html#cfn-quicksight-template-freeformlayoutelementbackgroundstyle-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The configuration for a section-based layout.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionbasedlayoutconfiguration.html
     */
    interface SectionBasedLayoutConfigurationProperty {
        /**
         * A list of body section configurations.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionbasedlayoutconfiguration.html#cfn-quicksight-template-sectionbasedlayoutconfiguration-bodysections
         */
        readonly bodySections: Array<CfnTemplate.BodySectionConfigurationProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The options for the canvas of a section-based layout.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionbasedlayoutconfiguration.html#cfn-quicksight-template-sectionbasedlayoutconfiguration-canvassizeoptions
         */
        readonly canvasSizeOptions: cdk.IResolvable | CfnTemplate.SectionBasedLayoutCanvasSizeOptionsProperty;
        /**
         * A list of footer section configurations.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionbasedlayoutconfiguration.html#cfn-quicksight-template-sectionbasedlayoutconfiguration-footersections
         */
        readonly footerSections: Array<CfnTemplate.HeaderFooterSectionConfigurationProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * A list of header section configurations.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionbasedlayoutconfiguration.html#cfn-quicksight-template-sectionbasedlayoutconfiguration-headersections
         */
        readonly headerSections: Array<CfnTemplate.HeaderFooterSectionConfigurationProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * The configuration of a header or footer section.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-headerfootersectionconfiguration.html
     */
    interface HeaderFooterSectionConfigurationProperty {
        /**
         * The layout configuration of the header or footer section.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-headerfootersectionconfiguration.html#cfn-quicksight-template-headerfootersectionconfiguration-layout
         */
        readonly layout: cdk.IResolvable | CfnTemplate.SectionLayoutConfigurationProperty;
        /**
         * The unique identifier of the header or footer section.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-headerfootersectionconfiguration.html#cfn-quicksight-template-headerfootersectionconfiguration-sectionid
         */
        readonly sectionId: string;
        /**
         * The style options of a header or footer section.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-headerfootersectionconfiguration.html#cfn-quicksight-template-headerfootersectionconfiguration-style
         */
        readonly style?: cdk.IResolvable | CfnTemplate.SectionStyleProperty;
    }
    /**
     * The layout configuration of a section.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionlayoutconfiguration.html
     */
    interface SectionLayoutConfigurationProperty {
        /**
         * The free-form layout configuration of a section.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionlayoutconfiguration.html#cfn-quicksight-template-sectionlayoutconfiguration-freeformlayout
         */
        readonly freeFormLayout: CfnTemplate.FreeFormSectionLayoutConfigurationProperty | cdk.IResolvable;
    }
    /**
     * The free-form layout configuration of a section.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformsectionlayoutconfiguration.html
     */
    interface FreeFormSectionLayoutConfigurationProperty {
        /**
         * The elements that are included in the free-form layout.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformsectionlayoutconfiguration.html#cfn-quicksight-template-freeformsectionlayoutconfiguration-elements
         */
        readonly elements: Array<CfnTemplate.FreeFormLayoutElementProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * The options that style a section.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionstyle.html
     */
    interface SectionStyleProperty {
        /**
         * The height of a section.
         *
         * Heights can only be defined for header and footer sections. The default height margin is 0.5 inches.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionstyle.html#cfn-quicksight-template-sectionstyle-height
         */
        readonly height?: string;
        /**
         * The spacing between section content and its top, bottom, left, and right edges.
         *
         * There is no padding by default.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionstyle.html#cfn-quicksight-template-sectionstyle-padding
         */
        readonly padding?: cdk.IResolvable | CfnTemplate.SpacingProperty;
    }
    /**
     * The configuration of a body section.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-bodysectionconfiguration.html
     */
    interface BodySectionConfigurationProperty {
        /**
         * The configuration of content in a body section.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-bodysectionconfiguration.html#cfn-quicksight-template-bodysectionconfiguration-content
         */
        readonly content: CfnTemplate.BodySectionContentProperty | cdk.IResolvable;
        /**
         * The configuration of a page break for a section.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-bodysectionconfiguration.html#cfn-quicksight-template-bodysectionconfiguration-pagebreakconfiguration
         */
        readonly pageBreakConfiguration?: cdk.IResolvable | CfnTemplate.SectionPageBreakConfigurationProperty;
        /**
         * The unique identifier of a body section.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-bodysectionconfiguration.html#cfn-quicksight-template-bodysectionconfiguration-sectionid
         */
        readonly sectionId: string;
        /**
         * The style options of a body section.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-bodysectionconfiguration.html#cfn-quicksight-template-bodysectionconfiguration-style
         */
        readonly style?: cdk.IResolvable | CfnTemplate.SectionStyleProperty;
    }
    /**
     * The configuration of content in a body section.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-bodysectioncontent.html
     */
    interface BodySectionContentProperty {
        /**
         * The layout configuration of a body section.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-bodysectioncontent.html#cfn-quicksight-template-bodysectioncontent-layout
         */
        readonly layout?: cdk.IResolvable | CfnTemplate.SectionLayoutConfigurationProperty;
    }
    /**
     * The configuration of a page break for a section.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionpagebreakconfiguration.html
     */
    interface SectionPageBreakConfigurationProperty {
        /**
         * The configuration of a page break after a section.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionpagebreakconfiguration.html#cfn-quicksight-template-sectionpagebreakconfiguration-after
         */
        readonly after?: cdk.IResolvable | CfnTemplate.SectionAfterPageBreakProperty;
    }
    /**
     * The configuration of a page break after a section.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionafterpagebreak.html
     */
    interface SectionAfterPageBreakProperty {
        /**
         * The option that enables or disables a page break at the end of a section.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionafterpagebreak.html#cfn-quicksight-template-sectionafterpagebreak-status
         */
        readonly status?: string;
    }
    /**
     * The control of a filter that is used to interact with a dashboard or an analysis.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtercontrol.html
     */
    interface FilterControlProperty {
        /**
         * A control from a date filter that is used to specify date and time.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtercontrol.html#cfn-quicksight-template-filtercontrol-datetimepicker
         */
        readonly dateTimePicker?: CfnTemplate.FilterDateTimePickerControlProperty | cdk.IResolvable;
        /**
         * A control to display a dropdown list with buttons that are used to select a single value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtercontrol.html#cfn-quicksight-template-filtercontrol-dropdown
         */
        readonly dropdown?: CfnTemplate.FilterDropDownControlProperty | cdk.IResolvable;
        /**
         * A control to display a list of buttons or boxes.
         *
         * This is used to select either a single value or multiple values.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtercontrol.html#cfn-quicksight-template-filtercontrol-list
         */
        readonly list?: CfnTemplate.FilterListControlProperty | cdk.IResolvable;
        /**
         * A control from a date filter that is used to specify the relative date.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtercontrol.html#cfn-quicksight-template-filtercontrol-relativedatetime
         */
        readonly relativeDateTime?: CfnTemplate.FilterRelativeDateTimeControlProperty | cdk.IResolvable;
        /**
         * A control to display a horizontal toggle bar.
         *
         * This is used to change a value by sliding the toggle.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtercontrol.html#cfn-quicksight-template-filtercontrol-slider
         */
        readonly slider?: CfnTemplate.FilterSliderControlProperty | cdk.IResolvable;
        /**
         * A control to display a text box that is used to enter multiple entries.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtercontrol.html#cfn-quicksight-template-filtercontrol-textarea
         */
        readonly textArea?: CfnTemplate.FilterTextAreaControlProperty | cdk.IResolvable;
        /**
         * A control to display a text box that is used to enter a single entry.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtercontrol.html#cfn-quicksight-template-filtercontrol-textfield
         */
        readonly textField?: CfnTemplate.FilterTextFieldControlProperty | cdk.IResolvable;
    }
    /**
     * A control to display a horizontal toggle bar.
     *
     * This is used to change a value by sliding the toggle.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterslidercontrol.html
     */
    interface FilterSliderControlProperty {
        /**
         * The display options of a control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterslidercontrol.html#cfn-quicksight-template-filterslidercontrol-displayoptions
         */
        readonly displayOptions?: cdk.IResolvable | CfnTemplate.SliderControlDisplayOptionsProperty;
        /**
         * The ID of the `FilterSliderControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterslidercontrol.html#cfn-quicksight-template-filterslidercontrol-filtercontrolid
         */
        readonly filterControlId: string;
        /**
         * The smaller value that is displayed at the left of the slider.
         *
         * @default - 0
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterslidercontrol.html#cfn-quicksight-template-filterslidercontrol-maximumvalue
         */
        readonly maximumValue: number;
        /**
         * The larger value that is displayed at the right of the slider.
         *
         * @default - 0
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterslidercontrol.html#cfn-quicksight-template-filterslidercontrol-minimumvalue
         */
        readonly minimumValue: number;
        /**
         * The source filter ID of the `FilterSliderControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterslidercontrol.html#cfn-quicksight-template-filterslidercontrol-sourcefilterid
         */
        readonly sourceFilterId: string;
        /**
         * The number of increments that the slider bar is divided into.
         *
         * @default - 0
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterslidercontrol.html#cfn-quicksight-template-filterslidercontrol-stepsize
         */
        readonly stepSize: number;
        /**
         * The title of the `FilterSliderControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterslidercontrol.html#cfn-quicksight-template-filterslidercontrol-title
         */
        readonly title: string;
        /**
         * The type of `FilterSliderControl` . Choose one of the following options:.
         *
         * - `SINGLE_POINT` : Filter against(equals) a single data point.
         * - `RANGE` : Filter data that is in a specified range.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterslidercontrol.html#cfn-quicksight-template-filterslidercontrol-type
         */
        readonly type?: string;
    }
    /**
     * A control to display a text box that is used to enter multiple entries.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtertextareacontrol.html
     */
    interface FilterTextAreaControlProperty {
        /**
         * The delimiter that is used to separate the lines in text.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtertextareacontrol.html#cfn-quicksight-template-filtertextareacontrol-delimiter
         */
        readonly delimiter?: string;
        /**
         * The display options of a control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtertextareacontrol.html#cfn-quicksight-template-filtertextareacontrol-displayoptions
         */
        readonly displayOptions?: cdk.IResolvable | CfnTemplate.TextAreaControlDisplayOptionsProperty;
        /**
         * The ID of the `FilterTextAreaControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtertextareacontrol.html#cfn-quicksight-template-filtertextareacontrol-filtercontrolid
         */
        readonly filterControlId: string;
        /**
         * The source filter ID of the `FilterTextAreaControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtertextareacontrol.html#cfn-quicksight-template-filtertextareacontrol-sourcefilterid
         */
        readonly sourceFilterId: string;
        /**
         * The title of the `FilterTextAreaControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtertextareacontrol.html#cfn-quicksight-template-filtertextareacontrol-title
         */
        readonly title: string;
    }
    /**
     * A control to display a dropdown list with buttons that are used to select a single value.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterdropdowncontrol.html
     */
    interface FilterDropDownControlProperty {
        /**
         * The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterdropdowncontrol.html#cfn-quicksight-template-filterdropdowncontrol-cascadingcontrolconfiguration
         */
        readonly cascadingControlConfiguration?: CfnTemplate.CascadingControlConfigurationProperty | cdk.IResolvable;
        /**
         * The display options of the `FilterDropDownControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterdropdowncontrol.html#cfn-quicksight-template-filterdropdowncontrol-displayoptions
         */
        readonly displayOptions?: CfnTemplate.DropDownControlDisplayOptionsProperty | cdk.IResolvable;
        /**
         * The ID of the `FilterDropDownControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterdropdowncontrol.html#cfn-quicksight-template-filterdropdowncontrol-filtercontrolid
         */
        readonly filterControlId: string;
        /**
         * A list of selectable values that are used in a control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterdropdowncontrol.html#cfn-quicksight-template-filterdropdowncontrol-selectablevalues
         */
        readonly selectableValues?: CfnTemplate.FilterSelectableValuesProperty | cdk.IResolvable;
        /**
         * The source filter ID of the `FilterDropDownControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterdropdowncontrol.html#cfn-quicksight-template-filterdropdowncontrol-sourcefilterid
         */
        readonly sourceFilterId: string;
        /**
         * The title of the `FilterDropDownControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterdropdowncontrol.html#cfn-quicksight-template-filterdropdowncontrol-title
         */
        readonly title: string;
        /**
         * The type of the `FilterDropDownControl` . Choose one of the following options:.
         *
         * - `MULTI_SELECT` : The user can select multiple entries from a dropdown menu.
         * - `SINGLE_SELECT` : The user can select a single entry from a dropdown menu.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterdropdowncontrol.html#cfn-quicksight-template-filterdropdowncontrol-type
         */
        readonly type?: string;
    }
    /**
     * A list of selectable values that are used in a control.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterselectablevalues.html
     */
    interface FilterSelectableValuesProperty {
        /**
         * The values that are used in the `FilterSelectableValues` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterselectablevalues.html#cfn-quicksight-template-filterselectablevalues-values
         */
        readonly values?: Array<string>;
    }
    /**
     * A control to display a text box that is used to enter a single entry.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtertextfieldcontrol.html
     */
    interface FilterTextFieldControlProperty {
        /**
         * The display options of a control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtertextfieldcontrol.html#cfn-quicksight-template-filtertextfieldcontrol-displayoptions
         */
        readonly displayOptions?: cdk.IResolvable | CfnTemplate.TextFieldControlDisplayOptionsProperty;
        /**
         * The ID of the `FilterTextFieldControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtertextfieldcontrol.html#cfn-quicksight-template-filtertextfieldcontrol-filtercontrolid
         */
        readonly filterControlId: string;
        /**
         * The source filter ID of the `FilterTextFieldControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtertextfieldcontrol.html#cfn-quicksight-template-filtertextfieldcontrol-sourcefilterid
         */
        readonly sourceFilterId: string;
        /**
         * The title of the `FilterTextFieldControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtertextfieldcontrol.html#cfn-quicksight-template-filtertextfieldcontrol-title
         */
        readonly title: string;
    }
    /**
     * A control to display a list of buttons or boxes.
     *
     * This is used to select either a single value or multiple values.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterlistcontrol.html
     */
    interface FilterListControlProperty {
        /**
         * The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterlistcontrol.html#cfn-quicksight-template-filterlistcontrol-cascadingcontrolconfiguration
         */
        readonly cascadingControlConfiguration?: CfnTemplate.CascadingControlConfigurationProperty | cdk.IResolvable;
        /**
         * The display options of a control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterlistcontrol.html#cfn-quicksight-template-filterlistcontrol-displayoptions
         */
        readonly displayOptions?: cdk.IResolvable | CfnTemplate.ListControlDisplayOptionsProperty;
        /**
         * The ID of the `FilterListControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterlistcontrol.html#cfn-quicksight-template-filterlistcontrol-filtercontrolid
         */
        readonly filterControlId: string;
        /**
         * A list of selectable values that are used in a control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterlistcontrol.html#cfn-quicksight-template-filterlistcontrol-selectablevalues
         */
        readonly selectableValues?: CfnTemplate.FilterSelectableValuesProperty | cdk.IResolvable;
        /**
         * The source filter ID of the `FilterListControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterlistcontrol.html#cfn-quicksight-template-filterlistcontrol-sourcefilterid
         */
        readonly sourceFilterId: string;
        /**
         * The title of the `FilterListControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterlistcontrol.html#cfn-quicksight-template-filterlistcontrol-title
         */
        readonly title: string;
        /**
         * The type of `FilterListControl` . Choose one of the following options:.
         *
         * - `MULTI_SELECT` : The user can select multiple entries from the list.
         * - `SINGLE_SELECT` : The user can select a single entry from the list.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterlistcontrol.html#cfn-quicksight-template-filterlistcontrol-type
         */
        readonly type?: string;
    }
    /**
     * A control from a date filter that is used to specify date and time.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterdatetimepickercontrol.html
     */
    interface FilterDateTimePickerControlProperty {
        /**
         * The display options of a control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterdatetimepickercontrol.html#cfn-quicksight-template-filterdatetimepickercontrol-displayoptions
         */
        readonly displayOptions?: CfnTemplate.DateTimePickerControlDisplayOptionsProperty | cdk.IResolvable;
        /**
         * The ID of the `FilterDateTimePickerControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterdatetimepickercontrol.html#cfn-quicksight-template-filterdatetimepickercontrol-filtercontrolid
         */
        readonly filterControlId: string;
        /**
         * The source filter ID of the `FilterDateTimePickerControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterdatetimepickercontrol.html#cfn-quicksight-template-filterdatetimepickercontrol-sourcefilterid
         */
        readonly sourceFilterId: string;
        /**
         * The title of the `FilterDateTimePickerControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterdatetimepickercontrol.html#cfn-quicksight-template-filterdatetimepickercontrol-title
         */
        readonly title: string;
        /**
         * The date time picker type of a `FilterDateTimePickerControl` . Choose one of the following options:.
         *
         * - `SINGLE_VALUED` : The filter condition is a fixed date.
         * - `DATE_RANGE` : The filter condition is a date time range.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterdatetimepickercontrol.html#cfn-quicksight-template-filterdatetimepickercontrol-type
         */
        readonly type?: string;
    }
    /**
     * A control from a date filter that is used to specify the relative date.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterrelativedatetimecontrol.html
     */
    interface FilterRelativeDateTimeControlProperty {
        /**
         * The display options of a control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterrelativedatetimecontrol.html#cfn-quicksight-template-filterrelativedatetimecontrol-displayoptions
         */
        readonly displayOptions?: cdk.IResolvable | CfnTemplate.RelativeDateTimeControlDisplayOptionsProperty;
        /**
         * The ID of the `FilterTextAreaControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterrelativedatetimecontrol.html#cfn-quicksight-template-filterrelativedatetimecontrol-filtercontrolid
         */
        readonly filterControlId: string;
        /**
         * The source filter ID of the `FilterTextAreaControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterrelativedatetimecontrol.html#cfn-quicksight-template-filterrelativedatetimecontrol-sourcefilterid
         */
        readonly sourceFilterId: string;
        /**
         * The title of the `FilterTextAreaControl` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterrelativedatetimecontrol.html#cfn-quicksight-template-filterrelativedatetimecontrol-title
         */
        readonly title: string;
    }
    /**
     * The display options of a control.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-relativedatetimecontroldisplayoptions.html
     */
    interface RelativeDateTimeControlDisplayOptionsProperty {
        /**
         * Customize how dates are formatted in controls.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-relativedatetimecontroldisplayoptions.html#cfn-quicksight-template-relativedatetimecontroldisplayoptions-datetimeformat
         */
        readonly dateTimeFormat?: string;
        /**
         * The configuration of info icon label options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-relativedatetimecontroldisplayoptions.html#cfn-quicksight-template-relativedatetimecontroldisplayoptions-infoiconlabeloptions
         */
        readonly infoIconLabelOptions?: cdk.IResolvable | CfnTemplate.SheetControlInfoIconLabelOptionsProperty;
        /**
         * The options to configure the title visibility, name, and font size.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-relativedatetimecontroldisplayoptions.html#cfn-quicksight-template-relativedatetimecontroldisplayoptions-titleoptions
         */
        readonly titleOptions?: cdk.IResolvable | CfnTemplate.LabelOptionsProperty;
    }
    /**
     * A grid layout to define the placement of sheet control.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetcontrollayout.html
     */
    interface SheetControlLayoutProperty {
        /**
         * The configuration that determines the elements and canvas size options of sheet control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetcontrollayout.html#cfn-quicksight-template-sheetcontrollayout-configuration
         */
        readonly configuration: cdk.IResolvable | CfnTemplate.SheetControlLayoutConfigurationProperty;
    }
    /**
     * The configuration that determines the elements and canvas size options of sheet control.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetcontrollayoutconfiguration.html
     */
    interface SheetControlLayoutConfigurationProperty {
        /**
         * The configuration that determines the elements and canvas size options of sheet control.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetcontrollayoutconfiguration.html#cfn-quicksight-template-sheetcontrollayoutconfiguration-gridlayout
         */
        readonly gridLayout?: CfnTemplate.GridLayoutConfigurationProperty | cdk.IResolvable;
    }
    /**
     * A visual displayed on a sheet in an analysis, dashboard, or template.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html
     */
    interface VisualProperty {
        /**
         * A bar chart.
         *
         * For more information, see [Using bar charts](https://docs.aws.amazon.com/quicksight/latest/user/bar-charts.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-barchartvisual
         */
        readonly barChartVisual?: CfnTemplate.BarChartVisualProperty | cdk.IResolvable;
        /**
         * A box plot.
         *
         * For more information, see [Using box plots](https://docs.aws.amazon.com/quicksight/latest/user/box-plots.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-boxplotvisual
         */
        readonly boxPlotVisual?: CfnTemplate.BoxPlotVisualProperty | cdk.IResolvable;
        /**
         * A combo chart.
         *
         * For more information, see [Using combo charts](https://docs.aws.amazon.com/quicksight/latest/user/combo-charts.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-combochartvisual
         */
        readonly comboChartVisual?: CfnTemplate.ComboChartVisualProperty | cdk.IResolvable;
        /**
         * A visual that contains custom content.
         *
         * For more information, see [Using custom visual content](https://docs.aws.amazon.com/quicksight/latest/user/custom-visual-content.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-customcontentvisual
         */
        readonly customContentVisual?: CfnTemplate.CustomContentVisualProperty | cdk.IResolvable;
        /**
         * An empty visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-emptyvisual
         */
        readonly emptyVisual?: CfnTemplate.EmptyVisualProperty | cdk.IResolvable;
        /**
         * A filled map.
         *
         * For more information, see [Creating filled maps](https://docs.aws.amazon.com/quicksight/latest/user/filled-maps.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-filledmapvisual
         */
        readonly filledMapVisual?: CfnTemplate.FilledMapVisualProperty | cdk.IResolvable;
        /**
         * A funnel chart.
         *
         * For more information, see [Using funnel charts](https://docs.aws.amazon.com/quicksight/latest/user/funnel-visual-content.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-funnelchartvisual
         */
        readonly funnelChartVisual?: CfnTemplate.FunnelChartVisualProperty | cdk.IResolvable;
        /**
         * A gauge chart.
         *
         * For more information, see [Using gauge charts](https://docs.aws.amazon.com/quicksight/latest/user/gauge-chart.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-gaugechartvisual
         */
        readonly gaugeChartVisual?: CfnTemplate.GaugeChartVisualProperty | cdk.IResolvable;
        /**
         * A geospatial map or a points on map visual.
         *
         * For more information, see [Creating point maps](https://docs.aws.amazon.com/quicksight/latest/user/point-maps.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-geospatialmapvisual
         */
        readonly geospatialMapVisual?: CfnTemplate.GeospatialMapVisualProperty | cdk.IResolvable;
        /**
         * A heat map.
         *
         * For more information, see [Using heat maps](https://docs.aws.amazon.com/quicksight/latest/user/heat-map.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-heatmapvisual
         */
        readonly heatMapVisual?: CfnTemplate.HeatMapVisualProperty | cdk.IResolvable;
        /**
         * A histogram.
         *
         * For more information, see [Using histograms](https://docs.aws.amazon.com/quicksight/latest/user/histogram-charts.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-histogramvisual
         */
        readonly histogramVisual?: CfnTemplate.HistogramVisualProperty | cdk.IResolvable;
        /**
         * An insight visual.
         *
         * For more information, see [Working with insights](https://docs.aws.amazon.com/quicksight/latest/user/computational-insights.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-insightvisual
         */
        readonly insightVisual?: CfnTemplate.InsightVisualProperty | cdk.IResolvable;
        /**
         * A key performance indicator (KPI).
         *
         * For more information, see [Using KPIs](https://docs.aws.amazon.com/quicksight/latest/user/kpi.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-kpivisual
         */
        readonly kpiVisual?: cdk.IResolvable | CfnTemplate.KPIVisualProperty;
        /**
         * A line chart.
         *
         * For more information, see [Using line charts](https://docs.aws.amazon.com/quicksight/latest/user/line-charts.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-linechartvisual
         */
        readonly lineChartVisual?: cdk.IResolvable | CfnTemplate.LineChartVisualProperty;
        /**
         * A pie or donut chart.
         *
         * For more information, see [Using pie charts](https://docs.aws.amazon.com/quicksight/latest/user/pie-chart.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-piechartvisual
         */
        readonly pieChartVisual?: cdk.IResolvable | CfnTemplate.PieChartVisualProperty;
        /**
         * A pivot table.
         *
         * For more information, see [Using pivot tables](https://docs.aws.amazon.com/quicksight/latest/user/pivot-table.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-pivottablevisual
         */
        readonly pivotTableVisual?: cdk.IResolvable | CfnTemplate.PivotTableVisualProperty;
        /**
         * A radar chart visual.
         *
         * For more information, see [Using radar charts](https://docs.aws.amazon.com/quicksight/latest/user/radar-chart.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-radarchartvisual
         */
        readonly radarChartVisual?: cdk.IResolvable | CfnTemplate.RadarChartVisualProperty;
        /**
         * A sankey diagram.
         *
         * For more information, see [Using Sankey diagrams](https://docs.aws.amazon.com/quicksight/latest/user/sankey-diagram.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-sankeydiagramvisual
         */
        readonly sankeyDiagramVisual?: cdk.IResolvable | CfnTemplate.SankeyDiagramVisualProperty;
        /**
         * A scatter plot.
         *
         * For more information, see [Using scatter plots](https://docs.aws.amazon.com/quicksight/latest/user/scatter-plot.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-scatterplotvisual
         */
        readonly scatterPlotVisual?: cdk.IResolvable | CfnTemplate.ScatterPlotVisualProperty;
        /**
         * A table visual.
         *
         * For more information, see [Using tables as visuals](https://docs.aws.amazon.com/quicksight/latest/user/tabular.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-tablevisual
         */
        readonly tableVisual?: cdk.IResolvable | CfnTemplate.TableVisualProperty;
        /**
         * A tree map.
         *
         * For more information, see [Using tree maps](https://docs.aws.amazon.com/quicksight/latest/user/tree-map.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-treemapvisual
         */
        readonly treeMapVisual?: cdk.IResolvable | CfnTemplate.TreeMapVisualProperty;
        /**
         * A waterfall chart.
         *
         * For more information, see [Using waterfall charts](https://docs.aws.amazon.com/quicksight/latest/user/waterfall-chart.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-waterfallvisual
         */
        readonly waterfallVisual?: cdk.IResolvable | CfnTemplate.WaterfallVisualProperty;
        /**
         * A word cloud.
         *
         * For more information, see [Using word clouds](https://docs.aws.amazon.com/quicksight/latest/user/word-cloud.html) in the *Amazon QuickSight User Guide* .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-wordcloudvisual
         */
        readonly wordCloudVisual?: cdk.IResolvable | CfnTemplate.WordCloudVisualProperty;
    }
    /**
     * A funnel chart.
     *
     * For more information, see [Using funnel charts](https://docs.aws.amazon.com/quicksight/latest/user/funnel-visual-content.html) in the *Amazon QuickSight User Guide* .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartvisual.html
     */
    interface FunnelChartVisualProperty {
        /**
         * The list of custom actions that are configured for a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartvisual.html#cfn-quicksight-template-funnelchartvisual-actions
         */
        readonly actions?: Array<cdk.IResolvable | CfnTemplate.VisualCustomActionProperty> | cdk.IResolvable;
        /**
         * The configuration of a `FunnelChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartvisual.html#cfn-quicksight-template-funnelchartvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnTemplate.FunnelChartConfigurationProperty | cdk.IResolvable;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartvisual.html#cfn-quicksight-template-funnelchartvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnTemplate.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The subtitle that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartvisual.html#cfn-quicksight-template-funnelchartvisual-subtitle
         */
        readonly subtitle?: cdk.IResolvable | CfnTemplate.VisualSubtitleLabelOptionsProperty;
        /**
         * The title that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartvisual.html#cfn-quicksight-template-funnelchartvisual-title
         */
        readonly title?: cdk.IResolvable | CfnTemplate.VisualTitleLabelOptionsProperty;
        /**
         * The unique identifier of a visual.
         *
         * This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartvisual.html#cfn-quicksight-template-funnelchartvisual-visualid
         */
        readonly visualId: string;
    }
    /**
     * The subtitle label options for a visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualsubtitlelabeloptions.html
     */
    interface VisualSubtitleLabelOptionsProperty {
        /**
         * The long text format of the subtitle label, such as plain text or rich text.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualsubtitlelabeloptions.html#cfn-quicksight-template-visualsubtitlelabeloptions-formattext
         */
        readonly formatText?: cdk.IResolvable | CfnTemplate.LongFormatTextProperty;
        /**
         * The visibility of the subtitle label.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualsubtitlelabeloptions.html#cfn-quicksight-template-visualsubtitlelabeloptions-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The text format for a subtitle.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-longformattext.html
     */
    interface LongFormatTextProperty {
        /**
         * Plain text format.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-longformattext.html#cfn-quicksight-template-longformattext-plaintext
         */
        readonly plainText?: string;
        /**
         * Rich text.
         *
         * Examples of rich text include bold, underline, and italics.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-longformattext.html#cfn-quicksight-template-longformattext-richtext
         */
        readonly richText?: string;
    }
    /**
     * The configuration of a `FunnelChartVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartconfiguration.html
     */
    interface FunnelChartConfigurationProperty {
        /**
         * The label options of the categories that are displayed in a `FunnelChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartconfiguration.html#cfn-quicksight-template-funnelchartconfiguration-categorylabeloptions
         */
        readonly categoryLabelOptions?: CfnTemplate.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The options that determine the presentation of the data labels.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartconfiguration.html#cfn-quicksight-template-funnelchartconfiguration-datalabeloptions
         */
        readonly dataLabelOptions?: CfnTemplate.FunnelChartDataLabelOptionsProperty | cdk.IResolvable;
        /**
         * The field well configuration of a `FunnelChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartconfiguration.html#cfn-quicksight-template-funnelchartconfiguration-fieldwells
         */
        readonly fieldWells?: CfnTemplate.FunnelChartFieldWellsProperty | cdk.IResolvable;
        /**
         * The sort configuration of a `FunnelChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartconfiguration.html#cfn-quicksight-template-funnelchartconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: CfnTemplate.FunnelChartSortConfigurationProperty | cdk.IResolvable;
        /**
         * The tooltip configuration of a `FunnelChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartconfiguration.html#cfn-quicksight-template-funnelchartconfiguration-tooltip
         */
        readonly tooltip?: cdk.IResolvable | CfnTemplate.TooltipOptionsProperty;
        /**
         * The label options for the values that are displayed in a `FunnelChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartconfiguration.html#cfn-quicksight-template-funnelchartconfiguration-valuelabeloptions
         */
        readonly valueLabelOptions?: CfnTemplate.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The visual palette configuration of a `FunnelChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartconfiguration.html#cfn-quicksight-template-funnelchartconfiguration-visualpalette
         */
        readonly visualPalette?: cdk.IResolvable | CfnTemplate.VisualPaletteProperty;
    }
    /**
     * The sort configuration of a `FunnelChartVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartsortconfiguration.html
     */
    interface FunnelChartSortConfigurationProperty {
        /**
         * The limit on the number of categories displayed.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartsortconfiguration.html#cfn-quicksight-template-funnelchartsortconfiguration-categoryitemslimit
         */
        readonly categoryItemsLimit?: cdk.IResolvable | CfnTemplate.ItemsLimitConfigurationProperty;
        /**
         * The sort configuration of the category fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartsortconfiguration.html#cfn-quicksight-template-funnelchartsortconfiguration-categorysort
         */
        readonly categorySort?: Array<CfnTemplate.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * The limit configuration of the visual display for an axis.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-itemslimitconfiguration.html
     */
    interface ItemsLimitConfigurationProperty {
        /**
         * The limit on how many items of a field are showed in the chart.
         *
         * For example, the number of slices that are displayed in a pie chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-itemslimitconfiguration.html#cfn-quicksight-template-itemslimitconfiguration-itemslimit
         */
        readonly itemsLimit?: number;
        /**
         * The `Show other` of an axis in the chart. Choose one of the following options:.
         *
         * - `INCLUDE`
         * - `EXCLUDE`
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-itemslimitconfiguration.html#cfn-quicksight-template-itemslimitconfiguration-othercategories
         */
        readonly otherCategories?: string;
    }
    /**
     * The field sort options in a chart configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldsortoptions.html
     */
    interface FieldSortOptionsProperty {
        /**
         * The sort configuration for a column that is not used in a field well.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldsortoptions.html#cfn-quicksight-template-fieldsortoptions-columnsort
         */
        readonly columnSort?: CfnTemplate.ColumnSortProperty | cdk.IResolvable;
        /**
         * The sort configuration for a field in a field well.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldsortoptions.html#cfn-quicksight-template-fieldsortoptions-fieldsort
         */
        readonly fieldSort?: CfnTemplate.FieldSortProperty | cdk.IResolvable;
    }
    /**
     * The sort configuration for a field in a field well.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldsort.html
     */
    interface FieldSortProperty {
        /**
         * The sort direction. Choose one of the following options:.
         *
         * - `ASC` : Ascending
         * - `DESC` : Descending
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldsort.html#cfn-quicksight-template-fieldsort-direction
         */
        readonly direction: string;
        /**
         * The sort configuration target field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldsort.html#cfn-quicksight-template-fieldsort-fieldid
         */
        readonly fieldId: string;
    }
    /**
     * The sort configuration for a column that is not used in a field well.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnsort.html
     */
    interface ColumnSortProperty {
        /**
         * The aggregation function that is defined in the column sort.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnsort.html#cfn-quicksight-template-columnsort-aggregationfunction
         */
        readonly aggregationFunction?: CfnTemplate.AggregationFunctionProperty | cdk.IResolvable;
        /**
         * The sort direction.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnsort.html#cfn-quicksight-template-columnsort-direction
         */
        readonly direction: string;
        /**
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnsort.html#cfn-quicksight-template-columnsort-sortby
         */
        readonly sortBy: CfnTemplate.ColumnIdentifierProperty | cdk.IResolvable;
    }
    /**
     * The options that determine the presentation of the data labels.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartdatalabeloptions.html
     */
    interface FunnelChartDataLabelOptionsProperty {
        /**
         * The visibility of the category labels within the data labels.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartdatalabeloptions.html#cfn-quicksight-template-funnelchartdatalabeloptions-categorylabelvisibility
         */
        readonly categoryLabelVisibility?: string;
        /**
         * The color of the data label text.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartdatalabeloptions.html#cfn-quicksight-template-funnelchartdatalabeloptions-labelcolor
         */
        readonly labelColor?: string;
        /**
         * The font configuration for the data labels.
         *
         * Only the `FontSize` attribute of the font configuration is used for data labels.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartdatalabeloptions.html#cfn-quicksight-template-funnelchartdatalabeloptions-labelfontconfiguration
         */
        readonly labelFontConfiguration?: CfnTemplate.FontConfigurationProperty | cdk.IResolvable;
        /**
         * Determines the style of the metric labels.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartdatalabeloptions.html#cfn-quicksight-template-funnelchartdatalabeloptions-measuredatalabelstyle
         */
        readonly measureDataLabelStyle?: string;
        /**
         * The visibility of the measure labels within the data labels.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartdatalabeloptions.html#cfn-quicksight-template-funnelchartdatalabeloptions-measurelabelvisibility
         */
        readonly measureLabelVisibility?: string;
        /**
         * Determines the positioning of the data label relative to a section of the funnel.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartdatalabeloptions.html#cfn-quicksight-template-funnelchartdatalabeloptions-position
         */
        readonly position?: string;
        /**
         * The visibility option that determines if data labels are displayed.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartdatalabeloptions.html#cfn-quicksight-template-funnelchartdatalabeloptions-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The label options for an axis on a chart.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-chartaxislabeloptions.html
     */
    interface ChartAxisLabelOptionsProperty {
        /**
         * The label options for a chart axis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-chartaxislabeloptions.html#cfn-quicksight-template-chartaxislabeloptions-axislabeloptions
         */
        readonly axisLabelOptions?: Array<CfnTemplate.AxisLabelOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The visibility configuration of the sort icon on a chart's axis label.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-chartaxislabeloptions.html#cfn-quicksight-template-chartaxislabeloptions-sorticonvisibility
         */
        readonly sortIconVisibility?: string;
        /**
         * The visibility of an axis label on a chart. Choose one of the following options:.
         *
         * - `VISIBLE` : Shows the axis.
         * - `HIDDEN` : Hides the axis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-chartaxislabeloptions.html#cfn-quicksight-template-chartaxislabeloptions-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The label options for a chart axis.
     *
     * You must specify the field that the label is targeted to.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axislabeloptions.html
     */
    interface AxisLabelOptionsProperty {
        /**
         * The options that indicate which field the label belongs to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axislabeloptions.html#cfn-quicksight-template-axislabeloptions-applyto
         */
        readonly applyTo?: CfnTemplate.AxisLabelReferenceOptionsProperty | cdk.IResolvable;
        /**
         * The text for the axis label.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axislabeloptions.html#cfn-quicksight-template-axislabeloptions-customlabel
         */
        readonly customLabel?: string;
        /**
         * The font configuration of the axis label.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axislabeloptions.html#cfn-quicksight-template-axislabeloptions-fontconfiguration
         */
        readonly fontConfiguration?: CfnTemplate.FontConfigurationProperty | cdk.IResolvable;
    }
    /**
     * The reference that specifies where the axis label is applied to.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axislabelreferenceoptions.html
     */
    interface AxisLabelReferenceOptionsProperty {
        /**
         * The column that the axis label is targeted to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axislabelreferenceoptions.html#cfn-quicksight-template-axislabelreferenceoptions-column
         */
        readonly column: CfnTemplate.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * The field that the axis label is targeted to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axislabelreferenceoptions.html#cfn-quicksight-template-axislabelreferenceoptions-fieldid
         */
        readonly fieldId: string;
    }
    /**
     * The field well configuration of a `FunnelChartVisual` .
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartfieldwells.html
     */
    interface FunnelChartFieldWellsProperty {
        /**
         * The field well configuration of a `FunnelChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartfieldwells.html#cfn-quicksight-template-funnelchartfieldwells-funnelchartaggregatedfieldwells
         */
        readonly funnelChartAggregatedFieldWells?: CfnTemplate.FunnelChartAggregatedFieldWellsProperty | cdk.IResolvable;
    }
    /**
     * The field well configuration of a `FunnelChartVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartaggregatedfieldwells.html
     */
    interface FunnelChartAggregatedFieldWellsProperty {
        /**
         * The category field wells of a funnel chart.
         *
         * Values are grouped by category fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartaggregatedfieldwells.html#cfn-quicksight-template-funnelchartaggregatedfieldwells-category
         */
        readonly category?: Array<CfnTemplate.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The value field wells of a funnel chart.
         *
         * Values are aggregated based on categories.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartaggregatedfieldwells.html#cfn-quicksight-template-funnelchartaggregatedfieldwells-values
         */
        readonly values?: Array<cdk.IResolvable | CfnTemplate.MeasureFieldProperty> | cdk.IResolvable;
    }
    /**
     * The dimension type field.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-dimensionfield.html
     */
    interface DimensionFieldProperty {
        /**
         * The dimension type field with categorical type columns.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-dimensionfield.html#cfn-quicksight-template-dimensionfield-categoricaldimensionfield
         */
        readonly categoricalDimensionField?: CfnTemplate.CategoricalDimensionFieldProperty | cdk.IResolvable;
        /**
         * The dimension type field with date type columns.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-dimensionfield.html#cfn-quicksight-template-dimensionfield-datedimensionfield
         */
        readonly dateDimensionField?: CfnTemplate.DateDimensionFieldProperty | cdk.IResolvable;
        /**
         * The dimension type field with numerical type columns.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-dimensionfield.html#cfn-quicksight-template-dimensionfield-numericaldimensionfield
         */
        readonly numericalDimensionField?: cdk.IResolvable | CfnTemplate.NumericalDimensionFieldProperty;
    }
    /**
     * The dimension type field with date type columns.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datedimensionfield.html
     */
    interface DateDimensionFieldProperty {
        /**
         * The column that is used in the `DateDimensionField` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datedimensionfield.html#cfn-quicksight-template-datedimensionfield-column
         */
        readonly column: CfnTemplate.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * The date granularity of the `DateDimensionField` . Choose one of the following options:.
         *
         * - `YEAR`
         * - `QUARTER`
         * - `MONTH`
         * - `WEEK`
         * - `DAY`
         * - `HOUR`
         * - `MINUTE`
         * - `SECOND`
         * - `MILLISECOND`
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datedimensionfield.html#cfn-quicksight-template-datedimensionfield-dategranularity
         */
        readonly dateGranularity?: string;
        /**
         * The custom field ID.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datedimensionfield.html#cfn-quicksight-template-datedimensionfield-fieldid
         */
        readonly fieldId: string;
        /**
         * The format configuration of the field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datedimensionfield.html#cfn-quicksight-template-datedimensionfield-formatconfiguration
         */
        readonly formatConfiguration?: CfnTemplate.DateTimeFormatConfigurationProperty | cdk.IResolvable;
        /**
         * The custom hierarchy ID.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datedimensionfield.html#cfn-quicksight-template-datedimensionfield-hierarchyid
         */
        readonly hierarchyId?: string;
    }
    /**
     * The dimension type field with numerical type columns.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericaldimensionfield.html
     */
    interface NumericalDimensionFieldProperty {
        /**
         * The column that is used in the `NumericalDimensionField` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericaldimensionfield.html#cfn-quicksight-template-numericaldimensionfield-column
         */
        readonly column: CfnTemplate.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * The custom field ID.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericaldimensionfield.html#cfn-quicksight-template-numericaldimensionfield-fieldid
         */
        readonly fieldId: string;
        /**
         * The format configuration of the field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericaldimensionfield.html#cfn-quicksight-template-numericaldimensionfield-formatconfiguration
         */
        readonly formatConfiguration?: cdk.IResolvable | CfnTemplate.NumberFormatConfigurationProperty;
        /**
         * The custom hierarchy ID.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericaldimensionfield.html#cfn-quicksight-template-numericaldimensionfield-hierarchyid
         */
        readonly hierarchyId?: string;
    }
    /**
     * The dimension type field with categorical type columns..
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoricaldimensionfield.html
     */
    interface CategoricalDimensionFieldProperty {
        /**
         * The column that is used in the `CategoricalDimensionField` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoricaldimensionfield.html#cfn-quicksight-template-categoricaldimensionfield-column
         */
        readonly column: CfnTemplate.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * The custom field ID.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoricaldimensionfield.html#cfn-quicksight-template-categoricaldimensionfield-fieldid
         */
        readonly fieldId: string;
        /**
         * The format configuration of the field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoricaldimensionfield.html#cfn-quicksight-template-categoricaldimensionfield-formatconfiguration
         */
        readonly formatConfiguration?: cdk.IResolvable | CfnTemplate.StringFormatConfigurationProperty;
        /**
         * The custom hierarchy ID.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoricaldimensionfield.html#cfn-quicksight-template-categoricaldimensionfield-hierarchyid
         */
        readonly hierarchyId?: string;
    }
    /**
     * The measure (metric) type field.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-measurefield.html
     */
    interface MeasureFieldProperty {
        /**
         * The calculated measure field only used in pivot tables.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-measurefield.html#cfn-quicksight-template-measurefield-calculatedmeasurefield
         */
        readonly calculatedMeasureField?: CfnTemplate.CalculatedMeasureFieldProperty | cdk.IResolvable;
        /**
         * The measure type field with categorical type columns.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-measurefield.html#cfn-quicksight-template-measurefield-categoricalmeasurefield
         */
        readonly categoricalMeasureField?: CfnTemplate.CategoricalMeasureFieldProperty | cdk.IResolvable;
        /**
         * The measure type field with date type columns.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-measurefield.html#cfn-quicksight-template-measurefield-datemeasurefield
         */
        readonly dateMeasureField?: CfnTemplate.DateMeasureFieldProperty | cdk.IResolvable;
        /**
         * The measure type field with numerical type columns.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-measurefield.html#cfn-quicksight-template-measurefield-numericalmeasurefield
         */
        readonly numericalMeasureField?: cdk.IResolvable | CfnTemplate.NumericalMeasureFieldProperty;
    }
    /**
     * The measure type field with date type columns.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datemeasurefield.html
     */
    interface DateMeasureFieldProperty {
        /**
         * The aggregation function of the measure field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datemeasurefield.html#cfn-quicksight-template-datemeasurefield-aggregationfunction
         */
        readonly aggregationFunction?: string;
        /**
         * The column that is used in the `DateMeasureField` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datemeasurefield.html#cfn-quicksight-template-datemeasurefield-column
         */
        readonly column: CfnTemplate.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * The custom field ID.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datemeasurefield.html#cfn-quicksight-template-datemeasurefield-fieldid
         */
        readonly fieldId: string;
        /**
         * The format configuration of the field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datemeasurefield.html#cfn-quicksight-template-datemeasurefield-formatconfiguration
         */
        readonly formatConfiguration?: CfnTemplate.DateTimeFormatConfigurationProperty | cdk.IResolvable;
    }
    /**
     * The measure type field with numerical type columns.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericalmeasurefield.html
     */
    interface NumericalMeasureFieldProperty {
        /**
         * The aggregation function of the measure field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericalmeasurefield.html#cfn-quicksight-template-numericalmeasurefield-aggregationfunction
         */
        readonly aggregationFunction?: cdk.IResolvable | CfnTemplate.NumericalAggregationFunctionProperty;
        /**
         * The column that is used in the `NumericalMeasureField` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericalmeasurefield.html#cfn-quicksight-template-numericalmeasurefield-column
         */
        readonly column: CfnTemplate.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * The custom field ID.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericalmeasurefield.html#cfn-quicksight-template-numericalmeasurefield-fieldid
         */
        readonly fieldId: string;
        /**
         * The format configuration of the field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericalmeasurefield.html#cfn-quicksight-template-numericalmeasurefield-formatconfiguration
         */
        readonly formatConfiguration?: cdk.IResolvable | CfnTemplate.NumberFormatConfigurationProperty;
    }
    /**
     * The measure type field with categorical type columns.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoricalmeasurefield.html
     */
    interface CategoricalMeasureFieldProperty {
        /**
         * The aggregation function of the measure field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoricalmeasurefield.html#cfn-quicksight-template-categoricalmeasurefield-aggregationfunction
         */
        readonly aggregationFunction?: string;
        /**
         * The column that is used in the `CategoricalMeasureField` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoricalmeasurefield.html#cfn-quicksight-template-categoricalmeasurefield-column
         */
        readonly column: CfnTemplate.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * The custom field ID.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoricalmeasurefield.html#cfn-quicksight-template-categoricalmeasurefield-fieldid
         */
        readonly fieldId: string;
        /**
         * The format configuration of the field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoricalmeasurefield.html#cfn-quicksight-template-categoricalmeasurefield-formatconfiguration
         */
        readonly formatConfiguration?: cdk.IResolvable | CfnTemplate.StringFormatConfigurationProperty;
    }
    /**
     * The table calculation measure field for pivot tables.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-calculatedmeasurefield.html
     */
    interface CalculatedMeasureFieldProperty {
        /**
         * The expression in the table calculation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-calculatedmeasurefield.html#cfn-quicksight-template-calculatedmeasurefield-expression
         */
        readonly expression: string;
        /**
         * The custom field ID.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-calculatedmeasurefield.html#cfn-quicksight-template-calculatedmeasurefield-fieldid
         */
        readonly fieldId: string;
    }
    /**
     * The display options for the visual tooltip.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tooltipoptions.html
     */
    interface TooltipOptionsProperty {
        /**
         * The setup for the detailed tooltip.
         *
         * The tooltip setup is always saved. The display type is decided based on the tooltip type.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tooltipoptions.html#cfn-quicksight-template-tooltipoptions-fieldbasedtooltip
         */
        readonly fieldBasedTooltip?: CfnTemplate.FieldBasedTooltipProperty | cdk.IResolvable;
        /**
         * The selected type for the tooltip. Choose one of the following options:.
         *
         * - `BASIC` : A basic tooltip.
         * - `DETAILED` : A detailed tooltip.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tooltipoptions.html#cfn-quicksight-template-tooltipoptions-selectedtooltiptype
         */
        readonly selectedTooltipType?: string;
        /**
         * Determines whether or not the tooltip is visible.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tooltipoptions.html#cfn-quicksight-template-tooltipoptions-tooltipvisibility
         */
        readonly tooltipVisibility?: string;
    }
    /**
     * The setup for the detailed tooltip.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldbasedtooltip.html
     */
    interface FieldBasedTooltipProperty {
        /**
         * The visibility of `Show aggregations` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldbasedtooltip.html#cfn-quicksight-template-fieldbasedtooltip-aggregationvisibility
         */
        readonly aggregationVisibility?: string;
        /**
         * The fields configuration in the tooltip.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldbasedtooltip.html#cfn-quicksight-template-fieldbasedtooltip-tooltipfields
         */
        readonly tooltipFields?: Array<cdk.IResolvable | CfnTemplate.TooltipItemProperty> | cdk.IResolvable;
        /**
         * The type for the >tooltip title. Choose one of the following options:.
         *
         * - `NONE` : Doesn't use the primary value as the title.
         * - `PRIMARY_VALUE` : Uses primary value as the title.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldbasedtooltip.html#cfn-quicksight-template-fieldbasedtooltip-tooltiptitletype
         */
        readonly tooltipTitleType?: string;
    }
    /**
     * The tooltip.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tooltipitem.html
     */
    interface TooltipItemProperty {
        /**
         * The tooltip item for the columns that are not part of a field well.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tooltipitem.html#cfn-quicksight-template-tooltipitem-columntooltipitem
         */
        readonly columnTooltipItem?: CfnTemplate.ColumnTooltipItemProperty | cdk.IResolvable;
        /**
         * The tooltip item for the fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tooltipitem.html#cfn-quicksight-template-tooltipitem-fieldtooltipitem
         */
        readonly fieldTooltipItem?: CfnTemplate.FieldTooltipItemProperty | cdk.IResolvable;
    }
    /**
     * The tooltip item for the fields.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldtooltipitem.html
     */
    interface FieldTooltipItemProperty {
        /**
         * The unique ID of the field that is targeted by the tooltip.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldtooltipitem.html#cfn-quicksight-template-fieldtooltipitem-fieldid
         */
        readonly fieldId: string;
        /**
         * The label of the tooltip item.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldtooltipitem.html#cfn-quicksight-template-fieldtooltipitem-label
         */
        readonly label?: string;
        /**
         * The visibility of the tooltip item.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldtooltipitem.html#cfn-quicksight-template-fieldtooltipitem-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The tooltip item for the columns that are not part of a field well.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columntooltipitem.html
     */
    interface ColumnTooltipItemProperty {
        /**
         * The aggregation function of the column tooltip item.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columntooltipitem.html#cfn-quicksight-template-columntooltipitem-aggregation
         */
        readonly aggregation?: CfnTemplate.AggregationFunctionProperty | cdk.IResolvable;
        /**
         * The target column of the tooltip item.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columntooltipitem.html#cfn-quicksight-template-columntooltipitem-column
         */
        readonly column: CfnTemplate.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * The label of the tooltip item.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columntooltipitem.html#cfn-quicksight-template-columntooltipitem-label
         */
        readonly label?: string;
        /**
         * The visibility of the tooltip item.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columntooltipitem.html#cfn-quicksight-template-columntooltipitem-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The visual display options for the visual palette.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualpalette.html
     */
    interface VisualPaletteProperty {
        /**
         * The chart color options for the visual palette.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualpalette.html#cfn-quicksight-template-visualpalette-chartcolor
         */
        readonly chartColor?: string;
        /**
         * The color map options for the visual palette.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualpalette.html#cfn-quicksight-template-visualpalette-colormap
         */
        readonly colorMap?: Array<CfnTemplate.DataPathColorProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * The color map that determines the color options for a particular element.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathcolor.html
     */
    interface DataPathColorProperty {
        /**
         * The color that needs to be applied to the element.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathcolor.html#cfn-quicksight-template-datapathcolor-color
         */
        readonly color: string;
        /**
         * The element that the color needs to be applied to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathcolor.html#cfn-quicksight-template-datapathcolor-element
         */
        readonly element: CfnTemplate.DataPathValueProperty | cdk.IResolvable;
        /**
         * The time granularity of the field that the color needs to be applied to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathcolor.html#cfn-quicksight-template-datapathcolor-timegranularity
         */
        readonly timeGranularity?: string;
    }
    /**
     * The data path that needs to be sorted.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathvalue.html
     */
    interface DataPathValueProperty {
        /**
         * The type configuration of the field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathvalue.html#cfn-quicksight-template-datapathvalue-datapathtype
         */
        readonly dataPathType?: CfnTemplate.DataPathTypeProperty | cdk.IResolvable;
        /**
         * The field ID of the field that needs to be sorted.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathvalue.html#cfn-quicksight-template-datapathvalue-fieldid
         */
        readonly fieldId?: string;
        /**
         * The actual value of the field that needs to be sorted.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathvalue.html#cfn-quicksight-template-datapathvalue-fieldvalue
         */
        readonly fieldValue?: string;
    }
    /**
     * The type of the data path value.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathtype.html
     */
    interface DataPathTypeProperty {
        /**
         * The type of data path value utilized in a pivot table. Choose one of the following options:.
         *
         * - `HIERARCHY_ROWS_LAYOUT_COLUMN` - The type of data path for the rows layout column, when `RowsLayout` is set to `HIERARCHY` .
         * - `MULTIPLE_ROW_METRICS_COLUMN` - The type of data path for the metric column when the row is set to Metric Placement.
         * - `EMPTY_COLUMN_HEADER` - The type of data path for the column with empty column header, when there is no field in `ColumnsFieldWell` and the row is set to Metric Placement.
         * - `COUNT_METRIC_COLUMN` - The type of data path for the column with `COUNT` as the metric, when there is no field in the `ValuesFieldWell` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathtype.html#cfn-quicksight-template-datapathtype-pivottabledatapathtype
         */
        readonly pivotTableDataPathType?: string;
    }
    /**
     * A custom action defined on a visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualcustomaction.html
     */
    interface VisualCustomActionProperty {
        /**
         * A list of `VisualCustomActionOperations` .
         *
         * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualcustomaction.html#cfn-quicksight-template-visualcustomaction-actionoperations
         */
        readonly actionOperations: Array<cdk.IResolvable | CfnTemplate.VisualCustomActionOperationProperty> | cdk.IResolvable;
        /**
         * The ID of the `VisualCustomAction` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualcustomaction.html#cfn-quicksight-template-visualcustomaction-customactionid
         */
        readonly customActionId: string;
        /**
         * The name of the `VisualCustomAction` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualcustomaction.html#cfn-quicksight-template-visualcustomaction-name
         */
        readonly name: string;
        /**
         * The status of the `VisualCustomAction` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualcustomaction.html#cfn-quicksight-template-visualcustomaction-status
         */
        readonly status?: string;
        /**
         * The trigger of the `VisualCustomAction` .
         *
         * Valid values are defined as follows:
         *
         * - `DATA_POINT_CLICK` : Initiates a custom action by a left pointer click on a data point.
         * - `DATA_POINT_MENU` : Initiates a custom action by right pointer click from the menu.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualcustomaction.html#cfn-quicksight-template-visualcustomaction-trigger
         */
        readonly trigger: string;
    }
    /**
     * The operation that is defined by the custom action.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualcustomactionoperation.html
     */
    interface VisualCustomActionOperationProperty {
        /**
         * The filter operation that filters data included in a visual or in an entire sheet.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualcustomactionoperation.html#cfn-quicksight-template-visualcustomactionoperation-filteroperation
         */
        readonly filterOperation?: CfnTemplate.CustomActionFilterOperationProperty | cdk.IResolvable;
        /**
         * The navigation operation that navigates between different sheets in the same analysis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualcustomactionoperation.html#cfn-quicksight-template-visualcustomactionoperation-navigationoperation
         */
        readonly navigationOperation?: CfnTemplate.CustomActionNavigationOperationProperty | cdk.IResolvable;
        /**
         * The set parameter operation that sets parameters in custom action.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualcustomactionoperation.html#cfn-quicksight-template-visualcustomactionoperation-setparametersoperation
         */
        readonly setParametersOperation?: CfnTemplate.CustomActionSetParametersOperationProperty | cdk.IResolvable;
        /**
         * The URL operation that opens a link to another webpage.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualcustomactionoperation.html#cfn-quicksight-template-visualcustomactionoperation-urloperation
         */
        readonly urlOperation?: CfnTemplate.CustomActionURLOperationProperty | cdk.IResolvable;
    }
    /**
     * The navigation operation that navigates between different sheets in the same analysis.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customactionnavigationoperation.html
     */
    interface CustomActionNavigationOperationProperty {
        /**
         * The configuration that chooses the navigation target.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customactionnavigationoperation.html#cfn-quicksight-template-customactionnavigationoperation-localnavigationconfiguration
         */
        readonly localNavigationConfiguration?: cdk.IResolvable | CfnTemplate.LocalNavigationConfigurationProperty;
    }
    /**
     * The navigation configuration for `CustomActionNavigationOperation` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-localnavigationconfiguration.html
     */
    interface LocalNavigationConfigurationProperty {
        /**
         * The sheet that is targeted for navigation in the same analysis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-localnavigationconfiguration.html#cfn-quicksight-template-localnavigationconfiguration-targetsheetid
         */
        readonly targetSheetId: string;
    }
    /**
     * The set parameter operation that sets parameters in custom action.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customactionsetparametersoperation.html
     */
    interface CustomActionSetParametersOperationProperty {
        /**
         * The parameter that determines the value configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customactionsetparametersoperation.html#cfn-quicksight-template-customactionsetparametersoperation-parametervalueconfigurations
         */
        readonly parameterValueConfigurations: Array<cdk.IResolvable | CfnTemplate.SetParameterValueConfigurationProperty> | cdk.IResolvable;
    }
    /**
     * The configuration of adding parameters in action.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-setparametervalueconfiguration.html
     */
    interface SetParameterValueConfigurationProperty {
        /**
         * The destination parameter name of the `SetParameterValueConfiguration` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-setparametervalueconfiguration.html#cfn-quicksight-template-setparametervalueconfiguration-destinationparametername
         */
        readonly destinationParameterName: string;
        /**
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-setparametervalueconfiguration.html#cfn-quicksight-template-setparametervalueconfiguration-value
         */
        readonly value: CfnTemplate.DestinationParameterValueConfigurationProperty | cdk.IResolvable;
    }
    /**
     * The configuration of destination parameter values.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-destinationparametervalueconfiguration.html
     */
    interface DestinationParameterValueConfigurationProperty {
        /**
         * The configuration of custom values for destination parameter in `DestinationParameterValueConfiguration` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-destinationparametervalueconfiguration.html#cfn-quicksight-template-destinationparametervalueconfiguration-customvaluesconfiguration
         */
        readonly customValuesConfiguration?: CfnTemplate.CustomValuesConfigurationProperty | cdk.IResolvable;
        /**
         * The configuration that selects all options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-destinationparametervalueconfiguration.html#cfn-quicksight-template-destinationparametervalueconfiguration-selectallvalueoptions
         */
        readonly selectAllValueOptions?: string;
        /**
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-destinationparametervalueconfiguration.html#cfn-quicksight-template-destinationparametervalueconfiguration-sourcecolumn
         */
        readonly sourceColumn?: CfnTemplate.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * The source field ID of the destination parameter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-destinationparametervalueconfiguration.html#cfn-quicksight-template-destinationparametervalueconfiguration-sourcefield
         */
        readonly sourceField?: string;
        /**
         * The source parameter name of the destination parameter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-destinationparametervalueconfiguration.html#cfn-quicksight-template-destinationparametervalueconfiguration-sourceparametername
         */
        readonly sourceParameterName?: string;
    }
    /**
     * The configuration of custom values for the destination parameter in `DestinationParameterValueConfiguration` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customvaluesconfiguration.html
     */
    interface CustomValuesConfigurationProperty {
        /**
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customvaluesconfiguration.html#cfn-quicksight-template-customvaluesconfiguration-customvalues
         */
        readonly customValues: CfnTemplate.CustomParameterValuesProperty | cdk.IResolvable;
        /**
         * Includes the null value in custom action parameter values.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customvaluesconfiguration.html#cfn-quicksight-template-customvaluesconfiguration-includenullvalue
         */
        readonly includeNullValue?: boolean | cdk.IResolvable;
    }
    /**
     * The customized parameter values.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customparametervalues.html
     */
    interface CustomParameterValuesProperty {
        /**
         * A list of datetime-type parameter values.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customparametervalues.html#cfn-quicksight-template-customparametervalues-datetimevalues
         */
        readonly dateTimeValues?: Array<string>;
        /**
         * A list of decimal-type parameter values.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customparametervalues.html#cfn-quicksight-template-customparametervalues-decimalvalues
         */
        readonly decimalValues?: Array<number> | cdk.IResolvable;
        /**
         * A list of integer-type parameter values.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customparametervalues.html#cfn-quicksight-template-customparametervalues-integervalues
         */
        readonly integerValues?: Array<number> | cdk.IResolvable;
        /**
         * A list of string-type parameter values.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customparametervalues.html#cfn-quicksight-template-customparametervalues-stringvalues
         */
        readonly stringValues?: Array<string>;
    }
    /**
     * The filter operation that filters data included in a visual or in an entire sheet.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customactionfilteroperation.html
     */
    interface CustomActionFilterOperationProperty {
        /**
         * The configuration that chooses the fields to be filtered.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customactionfilteroperation.html#cfn-quicksight-template-customactionfilteroperation-selectedfieldsconfiguration
         */
        readonly selectedFieldsConfiguration: CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty | cdk.IResolvable;
        /**
         * The configuration that chooses the target visuals to be filtered.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customactionfilteroperation.html#cfn-quicksight-template-customactionfilteroperation-targetvisualsconfiguration
         */
        readonly targetVisualsConfiguration: CfnTemplate.FilterOperationTargetVisualsConfigurationProperty | cdk.IResolvable;
    }
    /**
     * The configuration of selected fields in the `CustomActionFilterOperation` .
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filteroperationselectedfieldsconfiguration.html
     */
    interface FilterOperationSelectedFieldsConfigurationProperty {
        /**
         * The selected columns of a dataset.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filteroperationselectedfieldsconfiguration.html#cfn-quicksight-template-filteroperationselectedfieldsconfiguration-selectedcolumns
         */
        readonly selectedColumns?: Array<CfnTemplate.ColumnIdentifierProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * A structure that contains the options that choose which fields are filtered in the `CustomActionFilterOperation` .
         *
         * Valid values are defined as follows:
         *
         * - `ALL_FIELDS` : Applies the filter operation to all fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filteroperationselectedfieldsconfiguration.html#cfn-quicksight-template-filteroperationselectedfieldsconfiguration-selectedfieldoptions
         */
        readonly selectedFieldOptions?: string;
        /**
         * Chooses the fields that are filtered in `CustomActionFilterOperation` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filteroperationselectedfieldsconfiguration.html#cfn-quicksight-template-filteroperationselectedfieldsconfiguration-selectedfields
         */
        readonly selectedFields?: Array<string>;
    }
    /**
     * The configuration of target visuals that you want to be filtered.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filteroperationtargetvisualsconfiguration.html
     */
    interface FilterOperationTargetVisualsConfigurationProperty {
        /**
         * The configuration of the same-sheet target visuals that you want to be filtered.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filteroperationtargetvisualsconfiguration.html#cfn-quicksight-template-filteroperationtargetvisualsconfiguration-samesheettargetvisualconfiguration
         */
        readonly sameSheetTargetVisualConfiguration?: cdk.IResolvable | CfnTemplate.SameSheetTargetVisualConfigurationProperty;
    }
    /**
     * The configuration of the same-sheet target visuals that you want to be filtered.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-samesheettargetvisualconfiguration.html
     */
    interface SameSheetTargetVisualConfigurationProperty {
        /**
         * The options that choose the target visual in the same sheet.
         *
         * Valid values are defined as follows:
         *
         * - `ALL_VISUALS` : Applies the filter operation to all visuals in the same sheet.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-samesheettargetvisualconfiguration.html#cfn-quicksight-template-samesheettargetvisualconfiguration-targetvisualoptions
         */
        readonly targetVisualOptions?: string;
        /**
         * A list of the target visual IDs that are located in the same sheet of the analysis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-samesheettargetvisualconfiguration.html#cfn-quicksight-template-samesheettargetvisualconfiguration-targetvisuals
         */
        readonly targetVisuals?: Array<string>;
    }
    /**
     * The URL operation that opens a link to another webpage.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customactionurloperation.html
     */
    interface CustomActionURLOperationProperty {
        /**
         * The target of the `CustomActionURLOperation` .
         *
         * Valid values are defined as follows:
         *
         * - `NEW_TAB` : Opens the target URL in a new browser tab.
         * - `NEW_WINDOW` : Opens the target URL in a new browser window.
         * - `SAME_TAB` : Opens the target URL in the same browser tab.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customactionurloperation.html#cfn-quicksight-template-customactionurloperation-urltarget
         */
        readonly urlTarget: string;
        /**
         * THe URL link of the `CustomActionURLOperation` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customactionurloperation.html#cfn-quicksight-template-customactionurloperation-urltemplate
         */
        readonly urlTemplate: string;
    }
    /**
     * The title label options for a visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualtitlelabeloptions.html
     */
    interface VisualTitleLabelOptionsProperty {
        /**
         * The short text format of the title label, such as plain text or rich text.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualtitlelabeloptions.html#cfn-quicksight-template-visualtitlelabeloptions-formattext
         */
        readonly formatText?: cdk.IResolvable | CfnTemplate.ShortFormatTextProperty;
        /**
         * The visibility of the title label.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualtitlelabeloptions.html#cfn-quicksight-template-visualtitlelabeloptions-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The text format for the title.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-shortformattext.html
     */
    interface ShortFormatTextProperty {
        /**
         * Plain text format.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-shortformattext.html#cfn-quicksight-template-shortformattext-plaintext
         */
        readonly plainText?: string;
        /**
         * Rich text.
         *
         * Examples of rich text include bold, underline, and italics.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-shortformattext.html#cfn-quicksight-template-shortformattext-richtext
         */
        readonly richText?: string;
    }
    /**
     * The option that determines the hierarchy of the fields for a visual element.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnhierarchy.html
     */
    interface ColumnHierarchyProperty {
        /**
         * The option that determines the hierarchy of any `DateTime` fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnhierarchy.html#cfn-quicksight-template-columnhierarchy-datetimehierarchy
         */
        readonly dateTimeHierarchy?: CfnTemplate.DateTimeHierarchyProperty | cdk.IResolvable;
        /**
         * The option that determines the hierarchy of the fields that are built within a visual's field wells.
         *
         * These fields can't be duplicated to other visuals.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnhierarchy.html#cfn-quicksight-template-columnhierarchy-explicithierarchy
         */
        readonly explicitHierarchy?: CfnTemplate.ExplicitHierarchyProperty | cdk.IResolvable;
        /**
         * The option that determines the hierarchy of the fields that are defined during data preparation.
         *
         * These fields are available to use in any analysis that uses the data source.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnhierarchy.html#cfn-quicksight-template-columnhierarchy-predefinedhierarchy
         */
        readonly predefinedHierarchy?: cdk.IResolvable | CfnTemplate.PredefinedHierarchyProperty;
    }
    /**
     * The option that determines the hierarchy of any `DateTime` fields.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimehierarchy.html
     */
    interface DateTimeHierarchyProperty {
        /**
         * The option that determines the drill down filters for the `DateTime` hierarchy.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimehierarchy.html#cfn-quicksight-template-datetimehierarchy-drilldownfilters
         */
        readonly drillDownFilters?: Array<CfnTemplate.DrillDownFilterProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The hierarchy ID of the `DateTime` hierarchy.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimehierarchy.html#cfn-quicksight-template-datetimehierarchy-hierarchyid
         */
        readonly hierarchyId: string;
    }
    /**
     * The drill down filter for the column hierarchies.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-drilldownfilter.html
     */
    interface DrillDownFilterProperty {
        /**
         * The category type drill down filter.
         *
         * This filter is used for string type columns.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-drilldownfilter.html#cfn-quicksight-template-drilldownfilter-categoryfilter
         */
        readonly categoryFilter?: CfnTemplate.CategoryDrillDownFilterProperty | cdk.IResolvable;
        /**
         * The numeric equality type drill down filter.
         *
         * This filter is used for number type columns.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-drilldownfilter.html#cfn-quicksight-template-drilldownfilter-numericequalityfilter
         */
        readonly numericEqualityFilter?: cdk.IResolvable | CfnTemplate.NumericEqualityDrillDownFilterProperty;
        /**
         * The time range drill down filter.
         *
         * This filter is used for date time columns.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-drilldownfilter.html#cfn-quicksight-template-drilldownfilter-timerangefilter
         */
        readonly timeRangeFilter?: cdk.IResolvable | CfnTemplate.TimeRangeDrillDownFilterProperty;
    }
    /**
     * The category drill down filter.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericequalitydrilldownfilter.html
     */
    interface NumericEqualityDrillDownFilterProperty {
        /**
         * The column that the filter is applied to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericequalitydrilldownfilter.html#cfn-quicksight-template-numericequalitydrilldownfilter-column
         */
        readonly column: CfnTemplate.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * The value of the double input numeric drill down filter.
         *
         * @default - 0
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericequalitydrilldownfilter.html#cfn-quicksight-template-numericequalitydrilldownfilter-value
         */
        readonly value: number;
    }
    /**
     * The time range drill down filter.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangedrilldownfilter.html
     */
    interface TimeRangeDrillDownFilterProperty {
        /**
         * The column that the filter is applied to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangedrilldownfilter.html#cfn-quicksight-template-timerangedrilldownfilter-column
         */
        readonly column: CfnTemplate.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * The maximum value for the filter value range.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangedrilldownfilter.html#cfn-quicksight-template-timerangedrilldownfilter-rangemaximum
         */
        readonly rangeMaximum: string;
        /**
         * The minimum value for the filter value range.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangedrilldownfilter.html#cfn-quicksight-template-timerangedrilldownfilter-rangeminimum
         */
        readonly rangeMinimum: string;
        /**
         * The level of time precision that is used to aggregate `DateTime` values.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangedrilldownfilter.html#cfn-quicksight-template-timerangedrilldownfilter-timegranularity
         */
        readonly timeGranularity: string;
    }
    /**
     * The numeric equality type drill down filter.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categorydrilldownfilter.html
     */
    interface CategoryDrillDownFilterProperty {
        /**
         * A list of the string inputs that are the values of the category drill down filter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categorydrilldownfilter.html#cfn-quicksight-template-categorydrilldownfilter-categoryvalues
         */
        readonly categoryValues: Array<string>;
        /**
         * The column that the filter is applied to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categorydrilldownfilter.html#cfn-quicksight-template-categorydrilldownfilter-column
         */
        readonly column: CfnTemplate.ColumnIdentifierProperty | cdk.IResolvable;
    }
    /**
     * The option that determines the hierarchy of the fields that are built within a visual's field wells.
     *
     * These fields can't be duplicated to other visuals.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-explicithierarchy.html
     */
    interface ExplicitHierarchyProperty {
        /**
         * The list of columns that define the explicit hierarchy.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-explicithierarchy.html#cfn-quicksight-template-explicithierarchy-columns
         */
        readonly columns: Array<CfnTemplate.ColumnIdentifierProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The option that determines the drill down filters for the explicit hierarchy.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-explicithierarchy.html#cfn-quicksight-template-explicithierarchy-drilldownfilters
         */
        readonly drillDownFilters?: Array<CfnTemplate.DrillDownFilterProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The hierarchy ID of the explicit hierarchy.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-explicithierarchy.html#cfn-quicksight-template-explicithierarchy-hierarchyid
         */
        readonly hierarchyId: string;
    }
    /**
     * The option that determines the hierarchy of the fields that are defined during data preparation.
     *
     * These fields are available to use in any analysis that uses the data source.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-predefinedhierarchy.html
     */
    interface PredefinedHierarchyProperty {
        /**
         * The list of columns that define the predefined hierarchy.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-predefinedhierarchy.html#cfn-quicksight-template-predefinedhierarchy-columns
         */
        readonly columns: Array<CfnTemplate.ColumnIdentifierProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The option that determines the drill down filters for the predefined hierarchy.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-predefinedhierarchy.html#cfn-quicksight-template-predefinedhierarchy-drilldownfilters
         */
        readonly drillDownFilters?: Array<CfnTemplate.DrillDownFilterProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The hierarchy ID of the predefined hierarchy.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-predefinedhierarchy.html#cfn-quicksight-template-predefinedhierarchy-hierarchyid
         */
        readonly hierarchyId: string;
    }
    /**
     * A filled map.
     *
     * For more information, see [Creating filled maps](https://docs.aws.amazon.com/quicksight/latest/user/filled-maps.html) in the *Amazon QuickSight User Guide* .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapvisual.html
     */
    interface FilledMapVisualProperty {
        /**
         * The list of custom actions that are configured for a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapvisual.html#cfn-quicksight-template-filledmapvisual-actions
         */
        readonly actions?: Array<cdk.IResolvable | CfnTemplate.VisualCustomActionProperty> | cdk.IResolvable;
        /**
         * The configuration settings of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapvisual.html#cfn-quicksight-template-filledmapvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnTemplate.FilledMapConfigurationProperty | cdk.IResolvable;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapvisual.html#cfn-quicksight-template-filledmapvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnTemplate.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The conditional formatting of a `FilledMapVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapvisual.html#cfn-quicksight-template-filledmapvisual-conditionalformatting
         */
        readonly conditionalFormatting?: CfnTemplate.FilledMapConditionalFormattingProperty | cdk.IResolvable;
        /**
         * The subtitle that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapvisual.html#cfn-quicksight-template-filledmapvisual-subtitle
         */
        readonly subtitle?: cdk.IResolvable | CfnTemplate.VisualSubtitleLabelOptionsProperty;
        /**
         * The title that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapvisual.html#cfn-quicksight-template-filledmapvisual-title
         */
        readonly title?: cdk.IResolvable | CfnTemplate.VisualTitleLabelOptionsProperty;
        /**
         * The unique identifier of a visual.
         *
         * This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapvisual.html#cfn-quicksight-template-filledmapvisual-visualid
         */
        readonly visualId: string;
    }
    /**
     * The conditional formatting of a `FilledMapVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapconditionalformatting.html
     */
    interface FilledMapConditionalFormattingProperty {
        /**
         * Conditional formatting options of a `FilledMapVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapconditionalformatting.html#cfn-quicksight-template-filledmapconditionalformatting-conditionalformattingoptions
         */
        readonly conditionalFormattingOptions: Array<CfnTemplate.FilledMapConditionalFormattingOptionProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * Conditional formatting options of a `FilledMapVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapconditionalformattingoption.html
     */
    interface FilledMapConditionalFormattingOptionProperty {
        /**
         * The conditional formatting that determines the shape of the filled map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapconditionalformattingoption.html#cfn-quicksight-template-filledmapconditionalformattingoption-shape
         */
        readonly shape: CfnTemplate.FilledMapShapeConditionalFormattingProperty | cdk.IResolvable;
    }
    /**
     * The conditional formatting that determines the shape of the filled map.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapshapeconditionalformatting.html
     */
    interface FilledMapShapeConditionalFormattingProperty {
        /**
         * The field ID of the filled map shape.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapshapeconditionalformatting.html#cfn-quicksight-template-filledmapshapeconditionalformatting-fieldid
         */
        readonly fieldId: string;
        /**
         * The conditional formatting that determines the background color of a filled map's shape.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapshapeconditionalformatting.html#cfn-quicksight-template-filledmapshapeconditionalformatting-format
         */
        readonly format?: cdk.IResolvable | CfnTemplate.ShapeConditionalFormatProperty;
    }
    /**
     * The shape conditional formatting of a filled map visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-shapeconditionalformat.html
     */
    interface ShapeConditionalFormatProperty {
        /**
         * The conditional formatting for the shape background color of a filled map visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-shapeconditionalformat.html#cfn-quicksight-template-shapeconditionalformat-backgroundcolor
         */
        readonly backgroundColor: CfnTemplate.ConditionalFormattingColorProperty | cdk.IResolvable;
    }
    /**
     * The formatting configuration for the color.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingcolor.html
     */
    interface ConditionalFormattingColorProperty {
        /**
         * Formatting configuration for gradient color.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingcolor.html#cfn-quicksight-template-conditionalformattingcolor-gradient
         */
        readonly gradient?: CfnTemplate.ConditionalFormattingGradientColorProperty | cdk.IResolvable;
        /**
         * Formatting configuration for solid color.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingcolor.html#cfn-quicksight-template-conditionalformattingcolor-solid
         */
        readonly solid?: CfnTemplate.ConditionalFormattingSolidColorProperty | cdk.IResolvable;
    }
    /**
     * Formatting configuration for gradient color.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattinggradientcolor.html
     */
    interface ConditionalFormattingGradientColorProperty {
        /**
         * Determines the color.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattinggradientcolor.html#cfn-quicksight-template-conditionalformattinggradientcolor-color
         */
        readonly color: CfnTemplate.GradientColorProperty | cdk.IResolvable;
        /**
         * The expression that determines the formatting configuration for gradient color.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattinggradientcolor.html#cfn-quicksight-template-conditionalformattinggradientcolor-expression
         */
        readonly expression: string;
    }
    /**
     * Determines the gradient color settings.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gradientcolor.html
     */
    interface GradientColorProperty {
        /**
         * The list of gradient color stops.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gradientcolor.html#cfn-quicksight-template-gradientcolor-stops
         */
        readonly stops?: Array<CfnTemplate.GradientStopProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * Determines the gradient stop configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gradientstop.html
     */
    interface GradientStopProperty {
        /**
         * Determines the color.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gradientstop.html#cfn-quicksight-template-gradientstop-color
         */
        readonly color?: string;
        /**
         * Determines the data value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gradientstop.html#cfn-quicksight-template-gradientstop-datavalue
         */
        readonly dataValue?: number;
        /**
         * Determines gradient offset value.
         *
         * @default - 0
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gradientstop.html#cfn-quicksight-template-gradientstop-gradientoffset
         */
        readonly gradientOffset: number;
    }
    /**
     * Formatting configuration for solid color.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingsolidcolor.html
     */
    interface ConditionalFormattingSolidColorProperty {
        /**
         * Determines the color.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingsolidcolor.html#cfn-quicksight-template-conditionalformattingsolidcolor-color
         */
        readonly color?: string;
        /**
         * The expression that determines the formatting configuration for solid color.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingsolidcolor.html#cfn-quicksight-template-conditionalformattingsolidcolor-expression
         */
        readonly expression: string;
    }
    /**
     * The configuration for a `FilledMapVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapconfiguration.html
     */
    interface FilledMapConfigurationProperty {
        /**
         * The field wells of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapconfiguration.html#cfn-quicksight-template-filledmapconfiguration-fieldwells
         */
        readonly fieldWells?: CfnTemplate.FilledMapFieldWellsProperty | cdk.IResolvable;
        /**
         * The legend display setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapconfiguration.html#cfn-quicksight-template-filledmapconfiguration-legend
         */
        readonly legend?: cdk.IResolvable | CfnTemplate.LegendOptionsProperty;
        /**
         * The map style options of the filled map visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapconfiguration.html#cfn-quicksight-template-filledmapconfiguration-mapstyleoptions
         */
        readonly mapStyleOptions?: CfnTemplate.GeospatialMapStyleOptionsProperty | cdk.IResolvable;
        /**
         * The sort configuration of a `FilledMapVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapconfiguration.html#cfn-quicksight-template-filledmapconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: CfnTemplate.FilledMapSortConfigurationProperty | cdk.IResolvable;
        /**
         * The tooltip display setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapconfiguration.html#cfn-quicksight-template-filledmapconfiguration-tooltip
         */
        readonly tooltip?: cdk.IResolvable | CfnTemplate.TooltipOptionsProperty;
        /**
         * The window options of the filled map visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapconfiguration.html#cfn-quicksight-template-filledmapconfiguration-windowoptions
         */
        readonly windowOptions?: CfnTemplate.GeospatialWindowOptionsProperty | cdk.IResolvable;
    }
    /**
     * The sort configuration of a `FilledMapVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapsortconfiguration.html
     */
    interface FilledMapSortConfigurationProperty {
        /**
         * The sort configuration of the location fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapsortconfiguration.html#cfn-quicksight-template-filledmapsortconfiguration-categorysort
         */
        readonly categorySort?: Array<CfnTemplate.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * The options for the legend setup of a visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-legendoptions.html
     */
    interface LegendOptionsProperty {
        /**
         * The height of the legend.
         *
         * If this value is omitted, a default height is used when rendering.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-legendoptions.html#cfn-quicksight-template-legendoptions-height
         */
        readonly height?: string;
        /**
         * The positions for the legend. Choose one of the following options:.
         *
         * - `AUTO`
         * - `RIGHT`
         * - `BOTTOM`
         * - `LEFT`
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-legendoptions.html#cfn-quicksight-template-legendoptions-position
         */
        readonly position?: string;
        /**
         * The custom title for the legend.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-legendoptions.html#cfn-quicksight-template-legendoptions-title
         */
        readonly title?: cdk.IResolvable | CfnTemplate.LabelOptionsProperty;
        /**
         * Determines whether or not the legend is visible.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-legendoptions.html#cfn-quicksight-template-legendoptions-visibility
         */
        readonly visibility?: string;
        /**
         * The width of the legend.
         *
         * If this value is omitted, a default width is used when rendering.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-legendoptions.html#cfn-quicksight-template-legendoptions-width
         */
        readonly width?: string;
    }
    /**
     * The map style options of the geospatial map.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapstyleoptions.html
     */
    interface GeospatialMapStyleOptionsProperty {
        /**
         * The base map style of the geospatial map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapstyleoptions.html#cfn-quicksight-template-geospatialmapstyleoptions-basemapstyle
         */
        readonly baseMapStyle?: string;
    }
    /**
     * The field wells of a `FilledMapVisual` .
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapfieldwells.html
     */
    interface FilledMapFieldWellsProperty {
        /**
         * The aggregated field well of the filled map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapfieldwells.html#cfn-quicksight-template-filledmapfieldwells-filledmapaggregatedfieldwells
         */
        readonly filledMapAggregatedFieldWells?: CfnTemplate.FilledMapAggregatedFieldWellsProperty | cdk.IResolvable;
    }
    /**
     * The aggregated field well of the filled map.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapaggregatedfieldwells.html
     */
    interface FilledMapAggregatedFieldWellsProperty {
        /**
         * The aggregated location field well of the filled map.
         *
         * Values are grouped by location fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapaggregatedfieldwells.html#cfn-quicksight-template-filledmapaggregatedfieldwells-geospatial
         */
        readonly geospatial?: Array<CfnTemplate.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The aggregated color field well of a filled map.
         *
         * Values are aggregated based on location fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapaggregatedfieldwells.html#cfn-quicksight-template-filledmapaggregatedfieldwells-values
         */
        readonly values?: Array<cdk.IResolvable | CfnTemplate.MeasureFieldProperty> | cdk.IResolvable;
    }
    /**
     * The window options of the geospatial map visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialwindowoptions.html
     */
    interface GeospatialWindowOptionsProperty {
        /**
         * The bounds options (north, south, west, east) of the geospatial window options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialwindowoptions.html#cfn-quicksight-template-geospatialwindowoptions-bounds
         */
        readonly bounds?: CfnTemplate.GeospatialCoordinateBoundsProperty | cdk.IResolvable;
        /**
         * The map zoom modes (manual, auto) of the geospatial window options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialwindowoptions.html#cfn-quicksight-template-geospatialwindowoptions-mapzoommode
         */
        readonly mapZoomMode?: string;
    }
    /**
     * The bound options (north, south, west, east) of the geospatial window options.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialcoordinatebounds.html
     */
    interface GeospatialCoordinateBoundsProperty {
        /**
         * The longitude of the east bound of the geospatial coordinate bounds.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialcoordinatebounds.html#cfn-quicksight-template-geospatialcoordinatebounds-east
         */
        readonly east: number;
        /**
         * The latitude of the north bound of the geospatial coordinate bounds.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialcoordinatebounds.html#cfn-quicksight-template-geospatialcoordinatebounds-north
         */
        readonly north: number;
        /**
         * The latitude of the south bound of the geospatial coordinate bounds.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialcoordinatebounds.html#cfn-quicksight-template-geospatialcoordinatebounds-south
         */
        readonly south: number;
        /**
         * The longitude of the west bound of the geospatial coordinate bounds.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialcoordinatebounds.html#cfn-quicksight-template-geospatialcoordinatebounds-west
         */
        readonly west: number;
    }
    /**
     * A box plot.
     *
     * For more information, see [Using box plots](https://docs.aws.amazon.com/quicksight/latest/user/box-plots.html) in the *Amazon QuickSight User Guide* .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotvisual.html
     */
    interface BoxPlotVisualProperty {
        /**
         * The list of custom actions that are configured for a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotvisual.html#cfn-quicksight-template-boxplotvisual-actions
         */
        readonly actions?: Array<cdk.IResolvable | CfnTemplate.VisualCustomActionProperty> | cdk.IResolvable;
        /**
         * The configuration settings of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotvisual.html#cfn-quicksight-template-boxplotvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnTemplate.BoxPlotChartConfigurationProperty | cdk.IResolvable;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotvisual.html#cfn-quicksight-template-boxplotvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnTemplate.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The subtitle that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotvisual.html#cfn-quicksight-template-boxplotvisual-subtitle
         */
        readonly subtitle?: cdk.IResolvable | CfnTemplate.VisualSubtitleLabelOptionsProperty;
        /**
         * The title that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotvisual.html#cfn-quicksight-template-boxplotvisual-title
         */
        readonly title?: cdk.IResolvable | CfnTemplate.VisualTitleLabelOptionsProperty;
        /**
         * The unique identifier of a visual.
         *
         * This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotvisual.html#cfn-quicksight-template-boxplotvisual-visualid
         */
        readonly visualId: string;
    }
    /**
     * The configuration of a `BoxPlotVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotchartconfiguration.html
     */
    interface BoxPlotChartConfigurationProperty {
        /**
         * The box plot chart options for a box plot visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotchartconfiguration.html#cfn-quicksight-template-boxplotchartconfiguration-boxplotoptions
         */
        readonly boxPlotOptions?: CfnTemplate.BoxPlotOptionsProperty | cdk.IResolvable;
        /**
         * The label display options (grid line, range, scale, axis step) of a box plot category.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotchartconfiguration.html#cfn-quicksight-template-boxplotchartconfiguration-categoryaxis
         */
        readonly categoryAxis?: CfnTemplate.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * The label options (label text, label visibility and sort Icon visibility) of a box plot category.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotchartconfiguration.html#cfn-quicksight-template-boxplotchartconfiguration-categorylabeloptions
         */
        readonly categoryLabelOptions?: CfnTemplate.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The field wells of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotchartconfiguration.html#cfn-quicksight-template-boxplotchartconfiguration-fieldwells
         */
        readonly fieldWells?: CfnTemplate.BoxPlotFieldWellsProperty | cdk.IResolvable;
        /**
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotchartconfiguration.html#cfn-quicksight-template-boxplotchartconfiguration-legend
         */
        readonly legend?: cdk.IResolvable | CfnTemplate.LegendOptionsProperty;
        /**
         * The label display options (grid line, range, scale, axis step) of a box plot category.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotchartconfiguration.html#cfn-quicksight-template-boxplotchartconfiguration-primaryyaxisdisplayoptions
         */
        readonly primaryYAxisDisplayOptions?: CfnTemplate.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * The label options (label text, label visibility and sort icon visibility) of a box plot value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotchartconfiguration.html#cfn-quicksight-template-boxplotchartconfiguration-primaryyaxislabeloptions
         */
        readonly primaryYAxisLabelOptions?: CfnTemplate.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The reference line setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotchartconfiguration.html#cfn-quicksight-template-boxplotchartconfiguration-referencelines
         */
        readonly referenceLines?: Array<cdk.IResolvable | CfnTemplate.ReferenceLineProperty> | cdk.IResolvable;
        /**
         * The sort configuration of a `BoxPlotVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotchartconfiguration.html#cfn-quicksight-template-boxplotchartconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: CfnTemplate.BoxPlotSortConfigurationProperty | cdk.IResolvable;
        /**
         * The tooltip display setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotchartconfiguration.html#cfn-quicksight-template-boxplotchartconfiguration-tooltip
         */
        readonly tooltip?: cdk.IResolvable | CfnTemplate.TooltipOptionsProperty;
        /**
         * The palette (chart color) display setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotchartconfiguration.html#cfn-quicksight-template-boxplotchartconfiguration-visualpalette
         */
        readonly visualPalette?: cdk.IResolvable | CfnTemplate.VisualPaletteProperty;
    }
    /**
     * The sort configuration of a `BoxPlotVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotsortconfiguration.html
     */
    interface BoxPlotSortConfigurationProperty {
        /**
         * The sort configuration of a group by fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotsortconfiguration.html#cfn-quicksight-template-boxplotsortconfiguration-categorysort
         */
        readonly categorySort?: Array<CfnTemplate.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The pagination configuration of a table visual or box plot.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotsortconfiguration.html#cfn-quicksight-template-boxplotsortconfiguration-paginationconfiguration
         */
        readonly paginationConfiguration?: cdk.IResolvable | CfnTemplate.PaginationConfigurationProperty;
    }
    /**
     * The pagination configuration for a table visual or boxplot.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-paginationconfiguration.html
     */
    interface PaginationConfigurationProperty {
        /**
         * Indicates the page number.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-paginationconfiguration.html#cfn-quicksight-template-paginationconfiguration-pagenumber
         */
        readonly pageNumber: number;
        /**
         * Indicates how many items render in one page.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-paginationconfiguration.html#cfn-quicksight-template-paginationconfiguration-pagesize
         */
        readonly pageSize: number;
    }
    /**
     * The reference line visual display options.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referenceline.html
     */
    interface ReferenceLineProperty {
        /**
         * The data configuration of the reference line.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referenceline.html#cfn-quicksight-template-referenceline-dataconfiguration
         */
        readonly dataConfiguration: cdk.IResolvable | CfnTemplate.ReferenceLineDataConfigurationProperty;
        /**
         * The label configuration of the reference line.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referenceline.html#cfn-quicksight-template-referenceline-labelconfiguration
         */
        readonly labelConfiguration?: cdk.IResolvable | CfnTemplate.ReferenceLineLabelConfigurationProperty;
        /**
         * The status of the reference line. Choose one of the following options:.
         *
         * - `ENABLE`
         * - `DISABLE`
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referenceline.html#cfn-quicksight-template-referenceline-status
         */
        readonly status?: string;
        /**
         * The style configuration of the reference line.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referenceline.html#cfn-quicksight-template-referenceline-styleconfiguration
         */
        readonly styleConfiguration?: cdk.IResolvable | CfnTemplate.ReferenceLineStyleConfigurationProperty;
    }
    /**
     * The data configuration of the reference line.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinedataconfiguration.html
     */
    interface ReferenceLineDataConfigurationProperty {
        /**
         * The axis binding type of the reference line. Choose one of the following options:.
         *
         * - `PrimaryY`
         * - `SecondaryY`
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinedataconfiguration.html#cfn-quicksight-template-referencelinedataconfiguration-axisbinding
         */
        readonly axisBinding?: string;
        /**
         * The dynamic configuration of the reference line data configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinedataconfiguration.html#cfn-quicksight-template-referencelinedataconfiguration-dynamicconfiguration
         */
        readonly dynamicConfiguration?: cdk.IResolvable | CfnTemplate.ReferenceLineDynamicDataConfigurationProperty;
        /**
         * The series type of the reference line data configuration. Choose one of the following options:.
         *
         * - `BAR`
         * - `LINE`
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinedataconfiguration.html#cfn-quicksight-template-referencelinedataconfiguration-seriestype
         */
        readonly seriesType?: string;
        /**
         * The static data configuration of the reference line data configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinedataconfiguration.html#cfn-quicksight-template-referencelinedataconfiguration-staticconfiguration
         */
        readonly staticConfiguration?: cdk.IResolvable | CfnTemplate.ReferenceLineStaticDataConfigurationProperty;
    }
    /**
     * The dynamic configuration of the reference line data configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinedynamicdataconfiguration.html
     */
    interface ReferenceLineDynamicDataConfigurationProperty {
        /**
         * The calculation that is used in the dynamic data.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinedynamicdataconfiguration.html#cfn-quicksight-template-referencelinedynamicdataconfiguration-calculation
         */
        readonly calculation: cdk.IResolvable | CfnTemplate.NumericalAggregationFunctionProperty;
        /**
         * The column that the dynamic data targets.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinedynamicdataconfiguration.html#cfn-quicksight-template-referencelinedynamicdataconfiguration-column
         */
        readonly column: CfnTemplate.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * The aggregation function that is used in the dynamic data.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinedynamicdataconfiguration.html#cfn-quicksight-template-referencelinedynamicdataconfiguration-measureaggregationfunction
         */
        readonly measureAggregationFunction?: CfnTemplate.AggregationFunctionProperty | cdk.IResolvable;
    }
    /**
     * The static data configuration of the reference line data configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinestaticdataconfiguration.html
     */
    interface ReferenceLineStaticDataConfigurationProperty {
        /**
         * The double input of the static data.
         *
         * @default - 0
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinestaticdataconfiguration.html#cfn-quicksight-template-referencelinestaticdataconfiguration-value
         */
        readonly value: number;
    }
    /**
     * The label configuration of a reference line.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinelabelconfiguration.html
     */
    interface ReferenceLineLabelConfigurationProperty {
        /**
         * The custom label configuration of the label in a reference line.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinelabelconfiguration.html#cfn-quicksight-template-referencelinelabelconfiguration-customlabelconfiguration
         */
        readonly customLabelConfiguration?: cdk.IResolvable | CfnTemplate.ReferenceLineCustomLabelConfigurationProperty;
        /**
         * The font color configuration of the label in a reference line.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinelabelconfiguration.html#cfn-quicksight-template-referencelinelabelconfiguration-fontcolor
         */
        readonly fontColor?: string;
        /**
         * The font configuration of the label in a reference line.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinelabelconfiguration.html#cfn-quicksight-template-referencelinelabelconfiguration-fontconfiguration
         */
        readonly fontConfiguration?: CfnTemplate.FontConfigurationProperty | cdk.IResolvable;
        /**
         * The horizontal position configuration of the label in a reference line. Choose one of the following options:.
         *
         * - `LEFT`
         * - `CENTER`
         * - `RIGHT`
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinelabelconfiguration.html#cfn-quicksight-template-referencelinelabelconfiguration-horizontalposition
         */
        readonly horizontalPosition?: string;
        /**
         * The value label configuration of the label in a reference line.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinelabelconfiguration.html#cfn-quicksight-template-referencelinelabelconfiguration-valuelabelconfiguration
         */
        readonly valueLabelConfiguration?: cdk.IResolvable | CfnTemplate.ReferenceLineValueLabelConfigurationProperty;
        /**
         * The vertical position configuration of the label in a reference line. Choose one of the following options:.
         *
         * - `ABOVE`
         * - `BELOW`
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinelabelconfiguration.html#cfn-quicksight-template-referencelinelabelconfiguration-verticalposition
         */
        readonly verticalPosition?: string;
    }
    /**
     * The value label configuration of the label in a reference line.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinevaluelabelconfiguration.html
     */
    interface ReferenceLineValueLabelConfigurationProperty {
        /**
         * The format configuration of the value label.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinevaluelabelconfiguration.html#cfn-quicksight-template-referencelinevaluelabelconfiguration-formatconfiguration
         */
        readonly formatConfiguration?: cdk.IResolvable | CfnTemplate.NumericFormatConfigurationProperty;
        /**
         * The relative position of the value label. Choose one of the following options:.
         *
         * - `BEFORE_CUSTOM_LABEL`
         * - `AFTER_CUSTOM_LABEL`
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinevaluelabelconfiguration.html#cfn-quicksight-template-referencelinevaluelabelconfiguration-relativeposition
         */
        readonly relativePosition?: string;
    }
    /**
     * The configuration for a custom label on a `ReferenceLine` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinecustomlabelconfiguration.html
     */
    interface ReferenceLineCustomLabelConfigurationProperty {
        /**
         * The string text of the custom label.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinecustomlabelconfiguration.html#cfn-quicksight-template-referencelinecustomlabelconfiguration-customlabel
         */
        readonly customLabel: string;
    }
    /**
     * The style configuration of the reference line.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinestyleconfiguration.html
     */
    interface ReferenceLineStyleConfigurationProperty {
        /**
         * The hex color of the reference line.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinestyleconfiguration.html#cfn-quicksight-template-referencelinestyleconfiguration-color
         */
        readonly color?: string;
        /**
         * The pattern type of the line style. Choose one of the following options:.
         *
         * - `SOLID`
         * - `DASHED`
         * - `DOTTED`
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinestyleconfiguration.html#cfn-quicksight-template-referencelinestyleconfiguration-pattern
         */
        readonly pattern?: string;
    }
    /**
     * The display options for the axis label.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdisplayoptions.html
     */
    interface AxisDisplayOptionsProperty {
        /**
         * Determines whether or not the axis line is visible.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdisplayoptions.html#cfn-quicksight-template-axisdisplayoptions-axislinevisibility
         */
        readonly axisLineVisibility?: string;
        /**
         * The offset value that determines the starting placement of the axis within a visual's bounds.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdisplayoptions.html#cfn-quicksight-template-axisdisplayoptions-axisoffset
         */
        readonly axisOffset?: string;
        /**
         * The data options for an axis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdisplayoptions.html#cfn-quicksight-template-axisdisplayoptions-dataoptions
         */
        readonly dataOptions?: CfnTemplate.AxisDataOptionsProperty | cdk.IResolvable;
        /**
         * Determines whether or not the grid line is visible.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdisplayoptions.html#cfn-quicksight-template-axisdisplayoptions-gridlinevisibility
         */
        readonly gridLineVisibility?: string;
        /**
         * The scroll bar options for an axis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdisplayoptions.html#cfn-quicksight-template-axisdisplayoptions-scrollbaroptions
         */
        readonly scrollbarOptions?: cdk.IResolvable | CfnTemplate.ScrollBarOptionsProperty;
        /**
         * The tick label options of an axis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdisplayoptions.html#cfn-quicksight-template-axisdisplayoptions-ticklabeloptions
         */
        readonly tickLabelOptions?: CfnTemplate.AxisTickLabelOptionsProperty | cdk.IResolvable;
    }
    /**
     * The data options for an axis.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdataoptions.html
     */
    interface AxisDataOptionsProperty {
        /**
         * The options for an axis with a date field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdataoptions.html#cfn-quicksight-template-axisdataoptions-dateaxisoptions
         */
        readonly dateAxisOptions?: CfnTemplate.DateAxisOptionsProperty | cdk.IResolvable;
        /**
         * The options for an axis with a numeric field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdataoptions.html#cfn-quicksight-template-axisdataoptions-numericaxisoptions
         */
        readonly numericAxisOptions?: cdk.IResolvable | CfnTemplate.NumericAxisOptionsProperty;
    }
    /**
     * The options that determine how a date axis is displayed.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-dateaxisoptions.html
     */
    interface DateAxisOptionsProperty {
        /**
         * Determines whether or not missing dates are displayed.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-dateaxisoptions.html#cfn-quicksight-template-dateaxisoptions-missingdatevisibility
         */
        readonly missingDateVisibility?: string;
    }
    /**
     * The options for an axis with a numeric field.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericaxisoptions.html
     */
    interface NumericAxisOptionsProperty {
        /**
         * The range setup of a numeric axis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericaxisoptions.html#cfn-quicksight-template-numericaxisoptions-range
         */
        readonly range?: CfnTemplate.AxisDisplayRangeProperty | cdk.IResolvable;
        /**
         * The scale setup of a numeric axis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericaxisoptions.html#cfn-quicksight-template-numericaxisoptions-scale
         */
        readonly scale?: CfnTemplate.AxisScaleProperty | cdk.IResolvable;
    }
    /**
     * The scale setup options for a numeric axis display.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisscale.html
     */
    interface AxisScaleProperty {
        /**
         * The linear axis scale setup.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisscale.html#cfn-quicksight-template-axisscale-linear
         */
        readonly linear?: CfnTemplate.AxisLinearScaleProperty | cdk.IResolvable;
        /**
         * The logarithmic axis scale setup.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisscale.html#cfn-quicksight-template-axisscale-logarithmic
         */
        readonly logarithmic?: CfnTemplate.AxisLogarithmicScaleProperty | cdk.IResolvable;
    }
    /**
     * The logarithmic axis scale setup.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axislogarithmicscale.html
     */
    interface AxisLogarithmicScaleProperty {
        /**
         * The base setup of a logarithmic axis scale.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axislogarithmicscale.html#cfn-quicksight-template-axislogarithmicscale-base
         */
        readonly base?: number;
    }
    /**
     * The liner axis scale setup.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axislinearscale.html
     */
    interface AxisLinearScaleProperty {
        /**
         * The step count setup of a linear axis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axislinearscale.html#cfn-quicksight-template-axislinearscale-stepcount
         */
        readonly stepCount?: number;
        /**
         * The step size setup of a linear axis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axislinearscale.html#cfn-quicksight-template-axislinearscale-stepsize
         */
        readonly stepSize?: number;
    }
    /**
     * The range setup of a numeric axis display range.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdisplayrange.html
     */
    interface AxisDisplayRangeProperty {
        /**
         * The data-driven setup of an axis display range.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdisplayrange.html#cfn-quicksight-template-axisdisplayrange-datadriven
         */
        readonly dataDriven?: any | cdk.IResolvable;
        /**
         * The minimum and maximum setup of an axis display range.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdisplayrange.html#cfn-quicksight-template-axisdisplayrange-minmax
         */
        readonly minMax?: CfnTemplate.AxisDisplayMinMaxRangeProperty | cdk.IResolvable;
    }
    /**
     * The minimum and maximum setup for an axis display range.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdisplayminmaxrange.html
     */
    interface AxisDisplayMinMaxRangeProperty {
        /**
         * The maximum setup for an axis display range.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdisplayminmaxrange.html#cfn-quicksight-template-axisdisplayminmaxrange-maximum
         */
        readonly maximum?: number;
        /**
         * The minimum setup for an axis display range.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdisplayminmaxrange.html#cfn-quicksight-template-axisdisplayminmaxrange-minimum
         */
        readonly minimum?: number;
    }
    /**
     * The tick label options of an axis.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisticklabeloptions.html
     */
    interface AxisTickLabelOptionsProperty {
        /**
         * Determines whether or not the axis ticks are visible.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisticklabeloptions.html#cfn-quicksight-template-axisticklabeloptions-labeloptions
         */
        readonly labelOptions?: cdk.IResolvable | CfnTemplate.LabelOptionsProperty;
        /**
         * The rotation angle of the axis tick labels.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisticklabeloptions.html#cfn-quicksight-template-axisticklabeloptions-rotationangle
         */
        readonly rotationAngle?: number;
    }
    /**
     * The visual display options for a data zoom scroll bar.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scrollbaroptions.html
     */
    interface ScrollBarOptionsProperty {
        /**
         * The visibility of the data zoom scroll bar.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scrollbaroptions.html#cfn-quicksight-template-scrollbaroptions-visibility
         */
        readonly visibility?: string;
        /**
         * The visibility range for the data zoom scroll bar.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scrollbaroptions.html#cfn-quicksight-template-scrollbaroptions-visiblerange
         */
        readonly visibleRange?: cdk.IResolvable | CfnTemplate.VisibleRangeOptionsProperty;
    }
    /**
     * The range options for the data zoom scroll bar.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visiblerangeoptions.html
     */
    interface VisibleRangeOptionsProperty {
        /**
         * The percent range in the visible range.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visiblerangeoptions.html#cfn-quicksight-template-visiblerangeoptions-percentrange
         */
        readonly percentRange?: cdk.IResolvable | CfnTemplate.PercentVisibleRangeProperty;
    }
    /**
     * The percent range in the visible range.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-percentvisiblerange.html
     */
    interface PercentVisibleRangeProperty {
        /**
         * The lower bound of the range.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-percentvisiblerange.html#cfn-quicksight-template-percentvisiblerange-from
         */
        readonly from?: number;
        /**
         * The top bound of the range.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-percentvisiblerange.html#cfn-quicksight-template-percentvisiblerange-to
         */
        readonly to?: number;
    }
    /**
     * The field wells of a `BoxPlotVisual` .
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotfieldwells.html
     */
    interface BoxPlotFieldWellsProperty {
        /**
         * The aggregated field wells of a box plot.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotfieldwells.html#cfn-quicksight-template-boxplotfieldwells-boxplotaggregatedfieldwells
         */
        readonly boxPlotAggregatedFieldWells?: CfnTemplate.BoxPlotAggregatedFieldWellsProperty | cdk.IResolvable;
    }
    /**
     * The aggregated field well for a box plot.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotaggregatedfieldwells.html
     */
    interface BoxPlotAggregatedFieldWellsProperty {
        /**
         * The group by field well of a box plot chart.
         *
         * Values are grouped based on group by fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotaggregatedfieldwells.html#cfn-quicksight-template-boxplotaggregatedfieldwells-groupby
         */
        readonly groupBy?: Array<CfnTemplate.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The value field well of a box plot chart.
         *
         * Values are aggregated based on group by fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotaggregatedfieldwells.html#cfn-quicksight-template-boxplotaggregatedfieldwells-values
         */
        readonly values?: Array<cdk.IResolvable | CfnTemplate.MeasureFieldProperty> | cdk.IResolvable;
    }
    /**
     * The options of a box plot visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotoptions.html
     */
    interface BoxPlotOptionsProperty {
        /**
         * Determines the visibility of all data points of the box plot.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotoptions.html#cfn-quicksight-template-boxplotoptions-alldatapointsvisibility
         */
        readonly allDataPointsVisibility?: string;
        /**
         * Determines the visibility of the outlier in a box plot.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotoptions.html#cfn-quicksight-template-boxplotoptions-outliervisibility
         */
        readonly outlierVisibility?: string;
        /**
         * The style options of the box plot.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotoptions.html#cfn-quicksight-template-boxplotoptions-styleoptions
         */
        readonly styleOptions?: CfnTemplate.BoxPlotStyleOptionsProperty | cdk.IResolvable;
    }
    /**
     * The style options of the box plot.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotstyleoptions.html
     */
    interface BoxPlotStyleOptionsProperty {
        /**
         * The fill styles (solid, transparent) of the box plot.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotstyleoptions.html#cfn-quicksight-template-boxplotstyleoptions-fillstyle
         */
        readonly fillStyle?: string;
    }
    /**
     * A waterfall chart.
     *
     * For more information, see [Using waterfall charts](https://docs.aws.amazon.com/quicksight/latest/user/waterfall-chart.html) in the *Amazon QuickSight User Guide* .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallvisual.html
     */
    interface WaterfallVisualProperty {
        /**
         * The list of custom actions that are configured for a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallvisual.html#cfn-quicksight-template-waterfallvisual-actions
         */
        readonly actions?: Array<cdk.IResolvable | CfnTemplate.VisualCustomActionProperty> | cdk.IResolvable;
        /**
         * The configuration for a waterfall visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallvisual.html#cfn-quicksight-template-waterfallvisual-chartconfiguration
         */
        readonly chartConfiguration?: cdk.IResolvable | CfnTemplate.WaterfallChartConfigurationProperty;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallvisual.html#cfn-quicksight-template-waterfallvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnTemplate.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The subtitle that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallvisual.html#cfn-quicksight-template-waterfallvisual-subtitle
         */
        readonly subtitle?: cdk.IResolvable | CfnTemplate.VisualSubtitleLabelOptionsProperty;
        /**
         * The title that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallvisual.html#cfn-quicksight-template-waterfallvisual-title
         */
        readonly title?: cdk.IResolvable | CfnTemplate.VisualTitleLabelOptionsProperty;
        /**
         * The unique identifier of a visual.
         *
         * This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallvisual.html#cfn-quicksight-template-waterfallvisual-visualid
         */
        readonly visualId: string;
    }
    /**
     * The configuration for a waterfall visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartconfiguration.html
     */
    interface WaterfallChartConfigurationProperty {
        /**
         * The options that determine the presentation of the category axis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartconfiguration.html#cfn-quicksight-template-waterfallchartconfiguration-categoryaxisdisplayoptions
         */
        readonly categoryAxisDisplayOptions?: CfnTemplate.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * The options that determine the presentation of the category axis label.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartconfiguration.html#cfn-quicksight-template-waterfallchartconfiguration-categoryaxislabeloptions
         */
        readonly categoryAxisLabelOptions?: CfnTemplate.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The data label configuration of a waterfall visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartconfiguration.html#cfn-quicksight-template-waterfallchartconfiguration-datalabels
         */
        readonly dataLabels?: CfnTemplate.DataLabelOptionsProperty | cdk.IResolvable;
        /**
         * The field well configuration of a waterfall visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartconfiguration.html#cfn-quicksight-template-waterfallchartconfiguration-fieldwells
         */
        readonly fieldWells?: cdk.IResolvable | CfnTemplate.WaterfallChartFieldWellsProperty;
        /**
         * The legend configuration of a waterfall visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartconfiguration.html#cfn-quicksight-template-waterfallchartconfiguration-legend
         */
        readonly legend?: cdk.IResolvable | CfnTemplate.LegendOptionsProperty;
        /**
         * The options that determine the presentation of the y-axis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartconfiguration.html#cfn-quicksight-template-waterfallchartconfiguration-primaryyaxisdisplayoptions
         */
        readonly primaryYAxisDisplayOptions?: CfnTemplate.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * The options that determine the presentation of the y-axis label.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartconfiguration.html#cfn-quicksight-template-waterfallchartconfiguration-primaryyaxislabeloptions
         */
        readonly primaryYAxisLabelOptions?: CfnTemplate.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The sort configuration of a waterfall visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartconfiguration.html#cfn-quicksight-template-waterfallchartconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: cdk.IResolvable | CfnTemplate.WaterfallChartSortConfigurationProperty;
        /**
         * The visual palette configuration of a waterfall visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartconfiguration.html#cfn-quicksight-template-waterfallchartconfiguration-visualpalette
         */
        readonly visualPalette?: cdk.IResolvable | CfnTemplate.VisualPaletteProperty;
        /**
         * The options that determine the presentation of a waterfall visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartconfiguration.html#cfn-quicksight-template-waterfallchartconfiguration-waterfallchartoptions
         */
        readonly waterfallChartOptions?: cdk.IResolvable | CfnTemplate.WaterfallChartOptionsProperty;
    }
    /**
     * The sort configuration of a waterfall visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartsortconfiguration.html
     */
    interface WaterfallChartSortConfigurationProperty {
        /**
         * The limit on the number of bar groups that are displayed.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartsortconfiguration.html#cfn-quicksight-template-waterfallchartsortconfiguration-breakdownitemslimit
         */
        readonly breakdownItemsLimit?: cdk.IResolvable | CfnTemplate.ItemsLimitConfigurationProperty;
        /**
         * The sort configuration of the category fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartsortconfiguration.html#cfn-quicksight-template-waterfallchartsortconfiguration-categorysort
         */
        readonly categorySort?: Array<CfnTemplate.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * The options that determine the presentation of the data labels.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeloptions.html
     */
    interface DataLabelOptionsProperty {
        /**
         * Determines the visibility of the category field labels.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeloptions.html#cfn-quicksight-template-datalabeloptions-categorylabelvisibility
         */
        readonly categoryLabelVisibility?: string;
        /**
         * The option that determines the data label type.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeloptions.html#cfn-quicksight-template-datalabeloptions-datalabeltypes
         */
        readonly dataLabelTypes?: Array<CfnTemplate.DataLabelTypeProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * Determines the color of the data labels.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeloptions.html#cfn-quicksight-template-datalabeloptions-labelcolor
         */
        readonly labelColor?: string;
        /**
         * Determines the content of the data labels.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeloptions.html#cfn-quicksight-template-datalabeloptions-labelcontent
         */
        readonly labelContent?: string;
        /**
         * Determines the font configuration of the data labels.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeloptions.html#cfn-quicksight-template-datalabeloptions-labelfontconfiguration
         */
        readonly labelFontConfiguration?: CfnTemplate.FontConfigurationProperty | cdk.IResolvable;
        /**
         * Determines the visibility of the measure field labels.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeloptions.html#cfn-quicksight-template-datalabeloptions-measurelabelvisibility
         */
        readonly measureLabelVisibility?: string;
        /**
         * Determines whether overlap is enabled or disabled for the data labels.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeloptions.html#cfn-quicksight-template-datalabeloptions-overlap
         */
        readonly overlap?: string;
        /**
         * Determines the position of the data labels.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeloptions.html#cfn-quicksight-template-datalabeloptions-position
         */
        readonly position?: string;
        /**
         * Determines the visibility of the total.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeloptions.html#cfn-quicksight-template-datalabeloptions-totalsvisibility
         */
        readonly totalsVisibility?: string;
        /**
         * Determines the visibility of the data labels.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeloptions.html#cfn-quicksight-template-datalabeloptions-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The option that determines the data label type.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeltype.html
     */
    interface DataLabelTypeProperty {
        /**
         * The option that specifies individual data values for labels.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeltype.html#cfn-quicksight-template-datalabeltype-datapathlabeltype
         */
        readonly dataPathLabelType?: CfnTemplate.DataPathLabelTypeProperty | cdk.IResolvable;
        /**
         * Determines the label configuration for the entire field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeltype.html#cfn-quicksight-template-datalabeltype-fieldlabeltype
         */
        readonly fieldLabelType?: CfnTemplate.FieldLabelTypeProperty | cdk.IResolvable;
        /**
         * Determines the label configuration for the maximum value in a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeltype.html#cfn-quicksight-template-datalabeltype-maximumlabeltype
         */
        readonly maximumLabelType?: cdk.IResolvable | CfnTemplate.MaximumLabelTypeProperty;
        /**
         * Determines the label configuration for the minimum value in a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeltype.html#cfn-quicksight-template-datalabeltype-minimumlabeltype
         */
        readonly minimumLabelType?: cdk.IResolvable | CfnTemplate.MinimumLabelTypeProperty;
        /**
         * Determines the label configuration for range end value in a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeltype.html#cfn-quicksight-template-datalabeltype-rangeendslabeltype
         */
        readonly rangeEndsLabelType?: cdk.IResolvable | CfnTemplate.RangeEndsLabelTypeProperty;
    }
    /**
     * The maximum label of a data path label.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-maximumlabeltype.html
     */
    interface MaximumLabelTypeProperty {
        /**
         * The visibility of the maximum label.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-maximumlabeltype.html#cfn-quicksight-template-maximumlabeltype-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The option that specifies individual data values for labels.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathlabeltype.html
     */
    interface DataPathLabelTypeProperty {
        /**
         * The field ID of the field that the data label needs to be applied to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathlabeltype.html#cfn-quicksight-template-datapathlabeltype-fieldid
         */
        readonly fieldId?: string;
        /**
         * The actual value of the field that is labeled.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathlabeltype.html#cfn-quicksight-template-datapathlabeltype-fieldvalue
         */
        readonly fieldValue?: string;
        /**
         * The visibility of the data label.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathlabeltype.html#cfn-quicksight-template-datapathlabeltype-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The range ends label type of a data path label.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-rangeendslabeltype.html
     */
    interface RangeEndsLabelTypeProperty {
        /**
         * The visibility of the range ends label.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-rangeendslabeltype.html#cfn-quicksight-template-rangeendslabeltype-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The field label type.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldlabeltype.html
     */
    interface FieldLabelTypeProperty {
        /**
         * Indicates the field that is targeted by the field label.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldlabeltype.html#cfn-quicksight-template-fieldlabeltype-fieldid
         */
        readonly fieldId?: string;
        /**
         * The visibility of the field label.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldlabeltype.html#cfn-quicksight-template-fieldlabeltype-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The minimum label of a data path label.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-minimumlabeltype.html
     */
    interface MinimumLabelTypeProperty {
        /**
         * The visibility of the minimum label.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-minimumlabeltype.html#cfn-quicksight-template-minimumlabeltype-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The field well configuration of a waterfall visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartfieldwells.html
     */
    interface WaterfallChartFieldWellsProperty {
        /**
         * The field well configuration of a waterfall visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartfieldwells.html#cfn-quicksight-template-waterfallchartfieldwells-waterfallchartaggregatedfieldwells
         */
        readonly waterfallChartAggregatedFieldWells?: cdk.IResolvable | CfnTemplate.WaterfallChartAggregatedFieldWellsProperty;
    }
    /**
     * The field well configuration of a waterfall visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartaggregatedfieldwells.html
     */
    interface WaterfallChartAggregatedFieldWellsProperty {
        /**
         * The breakdown field wells of a waterfall visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartaggregatedfieldwells.html#cfn-quicksight-template-waterfallchartaggregatedfieldwells-breakdowns
         */
        readonly breakdowns?: Array<CfnTemplate.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The category field wells of a waterfall visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartaggregatedfieldwells.html#cfn-quicksight-template-waterfallchartaggregatedfieldwells-categories
         */
        readonly categories?: Array<CfnTemplate.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The value field wells of a waterfall visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartaggregatedfieldwells.html#cfn-quicksight-template-waterfallchartaggregatedfieldwells-values
         */
        readonly values?: Array<cdk.IResolvable | CfnTemplate.MeasureFieldProperty> | cdk.IResolvable;
    }
    /**
     * The options that determine the presentation of a waterfall visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartoptions.html
     */
    interface WaterfallChartOptionsProperty {
        /**
         * This option determines the total bar label of a waterfall visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartoptions.html#cfn-quicksight-template-waterfallchartoptions-totalbarlabel
         */
        readonly totalBarLabel?: string;
    }
    /**
     * A visual that contains custom content.
     *
     * For more information, see [Using custom visual content](https://docs.aws.amazon.com/quicksight/latest/user/custom-visual-content.html) in the *Amazon QuickSight User Guide* .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcontentvisual.html
     */
    interface CustomContentVisualProperty {
        /**
         * The list of custom actions that are configured for a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcontentvisual.html#cfn-quicksight-template-customcontentvisual-actions
         */
        readonly actions?: Array<cdk.IResolvable | CfnTemplate.VisualCustomActionProperty> | cdk.IResolvable;
        /**
         * The configuration of a `CustomContentVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcontentvisual.html#cfn-quicksight-template-customcontentvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnTemplate.CustomContentConfigurationProperty | cdk.IResolvable;
        /**
         * The dataset that is used to create the custom content visual.
         *
         * You can't create a visual without a dataset.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcontentvisual.html#cfn-quicksight-template-customcontentvisual-datasetidentifier
         */
        readonly dataSetIdentifier: string;
        /**
         * The subtitle that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcontentvisual.html#cfn-quicksight-template-customcontentvisual-subtitle
         */
        readonly subtitle?: cdk.IResolvable | CfnTemplate.VisualSubtitleLabelOptionsProperty;
        /**
         * The title that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcontentvisual.html#cfn-quicksight-template-customcontentvisual-title
         */
        readonly title?: cdk.IResolvable | CfnTemplate.VisualTitleLabelOptionsProperty;
        /**
         * The unique identifier of a visual.
         *
         * This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcontentvisual.html#cfn-quicksight-template-customcontentvisual-visualid
         */
        readonly visualId: string;
    }
    /**
     * The configuration of a `CustomContentVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcontentconfiguration.html
     */
    interface CustomContentConfigurationProperty {
        /**
         * The content type of the custom content visual.
         *
         * You can use this to have the visual render as an image.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcontentconfiguration.html#cfn-quicksight-template-customcontentconfiguration-contenttype
         */
        readonly contentType?: string;
        /**
         * The input URL that links to the custom content that you want in the custom visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcontentconfiguration.html#cfn-quicksight-template-customcontentconfiguration-contenturl
         */
        readonly contentUrl?: string;
        /**
         * The sizing options for the size of the custom content visual.
         *
         * This structure is required when the `ContentType` of the visual is `'IMAGE'` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcontentconfiguration.html#cfn-quicksight-template-customcontentconfiguration-imagescaling
         */
        readonly imageScaling?: string;
    }
    /**
     * A pie or donut chart.
     *
     * The `PieChartVisual` structure describes a visual that is a member of the pie chart family.
     *
     * The following charts can be described by using this structure:
     *
     * - Pie charts
     * - Donut charts
     *
     * For more information, see [Using pie charts](https://docs.aws.amazon.com/quicksight/latest/user/pie-chart.html) in the *Amazon QuickSight User Guide* .
     *
     * For more information, see [Using donut charts](https://docs.aws.amazon.com/quicksight/latest/user/donut-chart.html) in the *Amazon QuickSight User Guide* .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartvisual.html
     */
    interface PieChartVisualProperty {
        /**
         * The list of custom actions that are configured for a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartvisual.html#cfn-quicksight-template-piechartvisual-actions
         */
        readonly actions?: Array<cdk.IResolvable | CfnTemplate.VisualCustomActionProperty> | cdk.IResolvable;
        /**
         * The configuration of a pie chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartvisual.html#cfn-quicksight-template-piechartvisual-chartconfiguration
         */
        readonly chartConfiguration?: cdk.IResolvable | CfnTemplate.PieChartConfigurationProperty;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartvisual.html#cfn-quicksight-template-piechartvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnTemplate.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The subtitle that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartvisual.html#cfn-quicksight-template-piechartvisual-subtitle
         */
        readonly subtitle?: cdk.IResolvable | CfnTemplate.VisualSubtitleLabelOptionsProperty;
        /**
         * The title that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartvisual.html#cfn-quicksight-template-piechartvisual-title
         */
        readonly title?: cdk.IResolvable | CfnTemplate.VisualTitleLabelOptionsProperty;
        /**
         * The unique identifier of a visual.
         *
         * This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartvisual.html#cfn-quicksight-template-piechartvisual-visualid
         */
        readonly visualId: string;
    }
    /**
     * The configuration of a pie chart.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartconfiguration.html
     */
    interface PieChartConfigurationProperty {
        /**
         * The label options of the group/color that is displayed in a pie chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartconfiguration.html#cfn-quicksight-template-piechartconfiguration-categorylabeloptions
         */
        readonly categoryLabelOptions?: CfnTemplate.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The contribution analysis (anomaly configuration) setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartconfiguration.html#cfn-quicksight-template-piechartconfiguration-contributionanalysisdefaults
         */
        readonly contributionAnalysisDefaults?: Array<CfnTemplate.ContributionAnalysisDefaultProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The options that determine if visual data labels are displayed.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartconfiguration.html#cfn-quicksight-template-piechartconfiguration-datalabels
         */
        readonly dataLabels?: CfnTemplate.DataLabelOptionsProperty | cdk.IResolvable;
        /**
         * The options that determine the shape of the chart.
         *
         * This option determines whether the chart is a pie chart or a donut chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartconfiguration.html#cfn-quicksight-template-piechartconfiguration-donutoptions
         */
        readonly donutOptions?: CfnTemplate.DonutOptionsProperty | cdk.IResolvable;
        /**
         * The field wells of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartconfiguration.html#cfn-quicksight-template-piechartconfiguration-fieldwells
         */
        readonly fieldWells?: cdk.IResolvable | CfnTemplate.PieChartFieldWellsProperty;
        /**
         * The legend display setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartconfiguration.html#cfn-quicksight-template-piechartconfiguration-legend
         */
        readonly legend?: cdk.IResolvable | CfnTemplate.LegendOptionsProperty;
        /**
         * The small multiples setup for the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartconfiguration.html#cfn-quicksight-template-piechartconfiguration-smallmultiplesoptions
         */
        readonly smallMultiplesOptions?: cdk.IResolvable | CfnTemplate.SmallMultiplesOptionsProperty;
        /**
         * The sort configuration of a pie chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartconfiguration.html#cfn-quicksight-template-piechartconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: cdk.IResolvable | CfnTemplate.PieChartSortConfigurationProperty;
        /**
         * The tooltip display setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartconfiguration.html#cfn-quicksight-template-piechartconfiguration-tooltip
         */
        readonly tooltip?: cdk.IResolvable | CfnTemplate.TooltipOptionsProperty;
        /**
         * The label options for the value that is displayed in a pie chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartconfiguration.html#cfn-quicksight-template-piechartconfiguration-valuelabeloptions
         */
        readonly valueLabelOptions?: CfnTemplate.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The palette (chart color) display setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartconfiguration.html#cfn-quicksight-template-piechartconfiguration-visualpalette
         */
        readonly visualPalette?: cdk.IResolvable | CfnTemplate.VisualPaletteProperty;
    }
    /**
     * The sort configuration of a pie chart.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartsortconfiguration.html
     */
    interface PieChartSortConfigurationProperty {
        /**
         * The limit on the number of categories that are displayed in a pie chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartsortconfiguration.html#cfn-quicksight-template-piechartsortconfiguration-categoryitemslimit
         */
        readonly categoryItemsLimit?: cdk.IResolvable | CfnTemplate.ItemsLimitConfigurationProperty;
        /**
         * The sort configuration of the category fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartsortconfiguration.html#cfn-quicksight-template-piechartsortconfiguration-categorysort
         */
        readonly categorySort?: Array<CfnTemplate.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The limit on the number of small multiples panels that are displayed.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartsortconfiguration.html#cfn-quicksight-template-piechartsortconfiguration-smallmultipleslimitconfiguration
         */
        readonly smallMultiplesLimitConfiguration?: cdk.IResolvable | CfnTemplate.ItemsLimitConfigurationProperty;
        /**
         * The sort configuration of the small multiples field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartsortconfiguration.html#cfn-quicksight-template-piechartsortconfiguration-smallmultiplessort
         */
        readonly smallMultiplesSort?: Array<CfnTemplate.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * The contribution analysis visual display for a line, pie, or bar chart.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-contributionanalysisdefault.html
     */
    interface ContributionAnalysisDefaultProperty {
        /**
         * The dimensions columns that are used in the contribution analysis, usually a list of `ColumnIdentifiers` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-contributionanalysisdefault.html#cfn-quicksight-template-contributionanalysisdefault-contributordimensions
         */
        readonly contributorDimensions: Array<CfnTemplate.ColumnIdentifierProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The measure field that is used in the contribution analysis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-contributionanalysisdefault.html#cfn-quicksight-template-contributionanalysisdefault-measurefieldid
         */
        readonly measureFieldId: string;
    }
    /**
     * The field well configuration of a pie chart.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartfieldwells.html
     */
    interface PieChartFieldWellsProperty {
        /**
         * The field well configuration of a pie chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartfieldwells.html#cfn-quicksight-template-piechartfieldwells-piechartaggregatedfieldwells
         */
        readonly pieChartAggregatedFieldWells?: cdk.IResolvable | CfnTemplate.PieChartAggregatedFieldWellsProperty;
    }
    /**
     * The field well configuration of a pie chart.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartaggregatedfieldwells.html
     */
    interface PieChartAggregatedFieldWellsProperty {
        /**
         * The category (group/color) field wells of a pie chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartaggregatedfieldwells.html#cfn-quicksight-template-piechartaggregatedfieldwells-category
         */
        readonly category?: Array<CfnTemplate.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The small multiples field well of a pie chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartaggregatedfieldwells.html#cfn-quicksight-template-piechartaggregatedfieldwells-smallmultiples
         */
        readonly smallMultiples?: Array<CfnTemplate.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The value field wells of a pie chart.
         *
         * Values are aggregated based on categories.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartaggregatedfieldwells.html#cfn-quicksight-template-piechartaggregatedfieldwells-values
         */
        readonly values?: Array<cdk.IResolvable | CfnTemplate.MeasureFieldProperty> | cdk.IResolvable;
    }
    /**
     * The options for configuring a donut chart or pie chart.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-donutoptions.html
     */
    interface DonutOptionsProperty {
        /**
         * The option for define the arc of the chart shape. Valid values are as follows:.
         *
         * - `WHOLE` - A pie chart
         * - `SMALL` - A small-sized donut chart
         * - `MEDIUM` - A medium-sized donut chart
         * - `LARGE` - A large-sized donut chart
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-donutoptions.html#cfn-quicksight-template-donutoptions-arcoptions
         */
        readonly arcOptions?: CfnTemplate.ArcOptionsProperty | cdk.IResolvable;
        /**
         * The label options of the label that is displayed in the center of a donut chart.
         *
         * This option isn't available for pie charts.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-donutoptions.html#cfn-quicksight-template-donutoptions-donutcenteroptions
         */
        readonly donutCenterOptions?: CfnTemplate.DonutCenterOptionsProperty | cdk.IResolvable;
    }
    /**
     * The label options of the label that is displayed in the center of a donut chart.
     *
     * This option isn't available for pie charts.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-donutcenteroptions.html
     */
    interface DonutCenterOptionsProperty {
        /**
         * Determines the visibility of the label in a donut chart.
         *
         * In the Amazon QuickSight console, this option is called `'Show total'` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-donutcenteroptions.html#cfn-quicksight-template-donutcenteroptions-labelvisibility
         */
        readonly labelVisibility?: string;
    }
    /**
     * The options that determine the arc thickness of a `GaugeChartVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-arcoptions.html
     */
    interface ArcOptionsProperty {
        /**
         * The arc thickness of a `GaugeChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-arcoptions.html#cfn-quicksight-template-arcoptions-arcthickness
         */
        readonly arcThickness?: string;
    }
    /**
     * Options that determine the layout and display options of a chart's small multiples.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-smallmultiplesoptions.html
     */
    interface SmallMultiplesOptionsProperty {
        /**
         * Sets the maximum number of visible columns to display in the grid of small multiples panels.
         *
         * The default is `Auto` , which automatically adjusts the columns in the grid to fit the overall layout and size of the given chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-smallmultiplesoptions.html#cfn-quicksight-template-smallmultiplesoptions-maxvisiblecolumns
         */
        readonly maxVisibleColumns?: number;
        /**
         * Sets the maximum number of visible rows to display in the grid of small multiples panels.
         *
         * The default value is `Auto` , which automatically adjusts the rows in the grid to fit the overall layout and size of the given chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-smallmultiplesoptions.html#cfn-quicksight-template-smallmultiplesoptions-maxvisiblerows
         */
        readonly maxVisibleRows?: number;
        /**
         * Configures the display options for each small multiples panel.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-smallmultiplesoptions.html#cfn-quicksight-template-smallmultiplesoptions-panelconfiguration
         */
        readonly panelConfiguration?: cdk.IResolvable | CfnTemplate.PanelConfigurationProperty;
        /**
         * The properties of a small multiples X axis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-smallmultiplesoptions.html#cfn-quicksight-template-smallmultiplesoptions-xaxis
         */
        readonly xAxis?: cdk.IResolvable | CfnTemplate.SmallMultiplesAxisPropertiesProperty;
        /**
         * The properties of a small multiples Y axis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-smallmultiplesoptions.html#cfn-quicksight-template-smallmultiplesoptions-yaxis
         */
        readonly yAxis?: cdk.IResolvable | CfnTemplate.SmallMultiplesAxisPropertiesProperty;
    }
    /**
     * A collection of options that configure how each panel displays in a small multiples chart.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-panelconfiguration.html
     */
    interface PanelConfigurationProperty {
        /**
         * Sets the background color for each panel.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-panelconfiguration.html#cfn-quicksight-template-panelconfiguration-backgroundcolor
         */
        readonly backgroundColor?: string;
        /**
         * Determines whether or not a background for each small multiples panel is rendered.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-panelconfiguration.html#cfn-quicksight-template-panelconfiguration-backgroundvisibility
         */
        readonly backgroundVisibility?: string;
        /**
         * Sets the line color of panel borders.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-panelconfiguration.html#cfn-quicksight-template-panelconfiguration-bordercolor
         */
        readonly borderColor?: string;
        /**
         * Sets the line style of panel borders.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-panelconfiguration.html#cfn-quicksight-template-panelconfiguration-borderstyle
         */
        readonly borderStyle?: string;
        /**
         * Sets the line thickness of panel borders.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-panelconfiguration.html#cfn-quicksight-template-panelconfiguration-borderthickness
         */
        readonly borderThickness?: string;
        /**
         * Determines whether or not each panel displays a border.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-panelconfiguration.html#cfn-quicksight-template-panelconfiguration-bordervisibility
         */
        readonly borderVisibility?: string;
        /**
         * Sets the total amount of negative space to display between sibling panels.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-panelconfiguration.html#cfn-quicksight-template-panelconfiguration-gutterspacing
         */
        readonly gutterSpacing?: string;
        /**
         * Determines whether or not negative space between sibling panels is rendered.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-panelconfiguration.html#cfn-quicksight-template-panelconfiguration-guttervisibility
         */
        readonly gutterVisibility?: string;
        /**
         * Configures the title display within each small multiples panel.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-panelconfiguration.html#cfn-quicksight-template-panelconfiguration-title
         */
        readonly title?: cdk.IResolvable | CfnTemplate.PanelTitleOptionsProperty;
    }
    /**
     * The options that determine the title styles for each small multiples panel.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-paneltitleoptions.html
     */
    interface PanelTitleOptionsProperty {
        /**
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-paneltitleoptions.html#cfn-quicksight-template-paneltitleoptions-fontconfiguration
         */
        readonly fontConfiguration?: CfnTemplate.FontConfigurationProperty | cdk.IResolvable;
        /**
         * Sets the horizontal text alignment of the title within each panel.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-paneltitleoptions.html#cfn-quicksight-template-paneltitleoptions-horizontaltextalignment
         */
        readonly horizontalTextAlignment?: string;
        /**
         * Determines whether or not panel titles are displayed.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-paneltitleoptions.html#cfn-quicksight-template-paneltitleoptions-visibility
         */
        readonly visibility?: string;
    }
    /**
     * Configures the properties of a chart's axes that are used by small multiples panels.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-smallmultiplesaxisproperties.html
     */
    interface SmallMultiplesAxisPropertiesProperty {
        /**
         * Defines the placement of the axis.
         *
         * By default, axes are rendered `OUTSIDE` of the panels. Axes with `INDEPENDENT` scale are rendered `INSIDE` the panels.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-smallmultiplesaxisproperties.html#cfn-quicksight-template-smallmultiplesaxisproperties-placement
         */
        readonly placement?: string;
        /**
         * Determines whether scale of the axes are shared or independent.
         *
         * The default value is `SHARED` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-smallmultiplesaxisproperties.html#cfn-quicksight-template-smallmultiplesaxisproperties-scale
         */
        readonly scale?: string;
    }
    /**
     * A key performance indicator (KPI).
     *
     * For more information, see [Using KPIs](https://docs.aws.amazon.com/quicksight/latest/user/kpi.html) in the *Amazon QuickSight User Guide* .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpivisual.html
     */
    interface KPIVisualProperty {
        /**
         * The list of custom actions that are configured for a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpivisual.html#cfn-quicksight-template-kpivisual-actions
         */
        readonly actions?: Array<cdk.IResolvable | CfnTemplate.VisualCustomActionProperty> | cdk.IResolvable;
        /**
         * The configuration of a KPI visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpivisual.html#cfn-quicksight-template-kpivisual-chartconfiguration
         */
        readonly chartConfiguration?: cdk.IResolvable | CfnTemplate.KPIConfigurationProperty;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpivisual.html#cfn-quicksight-template-kpivisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnTemplate.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The conditional formatting of a KPI visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpivisual.html#cfn-quicksight-template-kpivisual-conditionalformatting
         */
        readonly conditionalFormatting?: cdk.IResolvable | CfnTemplate.KPIConditionalFormattingProperty;
        /**
         * The subtitle that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpivisual.html#cfn-quicksight-template-kpivisual-subtitle
         */
        readonly subtitle?: cdk.IResolvable | CfnTemplate.VisualSubtitleLabelOptionsProperty;
        /**
         * The title that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpivisual.html#cfn-quicksight-template-kpivisual-title
         */
        readonly title?: cdk.IResolvable | CfnTemplate.VisualTitleLabelOptionsProperty;
        /**
         * The unique identifier of a visual.
         *
         * This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpivisual.html#cfn-quicksight-template-kpivisual-visualid
         */
        readonly visualId: string;
    }
    /**
     * The conditional formatting of a KPI visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiconditionalformatting.html
     */
    interface KPIConditionalFormattingProperty {
        /**
         * The conditional formatting options of a KPI visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiconditionalformatting.html#cfn-quicksight-template-kpiconditionalformatting-conditionalformattingoptions
         */
        readonly conditionalFormattingOptions?: Array<cdk.IResolvable | CfnTemplate.KPIConditionalFormattingOptionProperty> | cdk.IResolvable;
    }
    /**
     * The conditional formatting options of a KPI visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiconditionalformattingoption.html
     */
    interface KPIConditionalFormattingOptionProperty {
        /**
         * The conditional formatting for the actual value of a KPI visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiconditionalformattingoption.html#cfn-quicksight-template-kpiconditionalformattingoption-actualvalue
         */
        readonly actualValue?: cdk.IResolvable | CfnTemplate.KPIActualValueConditionalFormattingProperty;
        /**
         * The conditional formatting for the comparison value of a KPI visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiconditionalformattingoption.html#cfn-quicksight-template-kpiconditionalformattingoption-comparisonvalue
         */
        readonly comparisonValue?: cdk.IResolvable | CfnTemplate.KPIComparisonValueConditionalFormattingProperty;
        /**
         * The conditional formatting for the primary value of a KPI visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiconditionalformattingoption.html#cfn-quicksight-template-kpiconditionalformattingoption-primaryvalue
         */
        readonly primaryValue?: cdk.IResolvable | CfnTemplate.KPIPrimaryValueConditionalFormattingProperty;
        /**
         * The conditional formatting for the progress bar of a KPI visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiconditionalformattingoption.html#cfn-quicksight-template-kpiconditionalformattingoption-progressbar
         */
        readonly progressBar?: cdk.IResolvable | CfnTemplate.KPIProgressBarConditionalFormattingProperty;
    }
    /**
     * The conditional formatting for the primary value of a KPI visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiprimaryvalueconditionalformatting.html
     */
    interface KPIPrimaryValueConditionalFormattingProperty {
        /**
         * The conditional formatting of the primary value's icon.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiprimaryvalueconditionalformatting.html#cfn-quicksight-template-kpiprimaryvalueconditionalformatting-icon
         */
        readonly icon?: CfnTemplate.ConditionalFormattingIconProperty | cdk.IResolvable;
        /**
         * The conditional formatting of the primary value's text color.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiprimaryvalueconditionalformatting.html#cfn-quicksight-template-kpiprimaryvalueconditionalformatting-textcolor
         */
        readonly textColor?: CfnTemplate.ConditionalFormattingColorProperty | cdk.IResolvable;
    }
    /**
     * The formatting configuration for the icon.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingicon.html
     */
    interface ConditionalFormattingIconProperty {
        /**
         * Determines the custom condition for an icon set.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingicon.html#cfn-quicksight-template-conditionalformattingicon-customcondition
         */
        readonly customCondition?: CfnTemplate.ConditionalFormattingCustomIconConditionProperty | cdk.IResolvable;
        /**
         * Formatting configuration for icon set.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingicon.html#cfn-quicksight-template-conditionalformattingicon-iconset
         */
        readonly iconSet?: CfnTemplate.ConditionalFormattingIconSetProperty | cdk.IResolvable;
    }
    /**
     * Determines the custom condition for an icon set.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingcustomiconcondition.html
     */
    interface ConditionalFormattingCustomIconConditionProperty {
        /**
         * Determines the color of the icon.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingcustomiconcondition.html#cfn-quicksight-template-conditionalformattingcustomiconcondition-color
         */
        readonly color?: string;
        /**
         * Determines the icon display configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingcustomiconcondition.html#cfn-quicksight-template-conditionalformattingcustomiconcondition-displayconfiguration
         */
        readonly displayConfiguration?: CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty | cdk.IResolvable;
        /**
         * The expression that determines the condition of the icon set.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingcustomiconcondition.html#cfn-quicksight-template-conditionalformattingcustomiconcondition-expression
         */
        readonly expression: string;
        /**
         * Custom icon options for an icon set.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingcustomiconcondition.html#cfn-quicksight-template-conditionalformattingcustomiconcondition-iconoptions
         */
        readonly iconOptions: CfnTemplate.ConditionalFormattingCustomIconOptionsProperty | cdk.IResolvable;
    }
    /**
     * Determines the icon display configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingicondisplayconfiguration.html
     */
    interface ConditionalFormattingIconDisplayConfigurationProperty {
        /**
         * Determines the icon display configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingicondisplayconfiguration.html#cfn-quicksight-template-conditionalformattingicondisplayconfiguration-icondisplayoption
         */
        readonly iconDisplayOption?: string;
    }
    /**
     * Custom icon options for an icon set.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingcustomiconoptions.html
     */
    interface ConditionalFormattingCustomIconOptionsProperty {
        /**
         * Determines the type of icon.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingcustomiconoptions.html#cfn-quicksight-template-conditionalformattingcustomiconoptions-icon
         */
        readonly icon?: string;
        /**
         * Determines the Unicode icon type.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingcustomiconoptions.html#cfn-quicksight-template-conditionalformattingcustomiconoptions-unicodeicon
         */
        readonly unicodeIcon?: string;
    }
    /**
     * Formatting configuration for icon set.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingiconset.html
     */
    interface ConditionalFormattingIconSetProperty {
        /**
         * The expression that determines the formatting configuration for the icon set.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingiconset.html#cfn-quicksight-template-conditionalformattingiconset-expression
         */
        readonly expression: string;
        /**
         * Determines the icon set type.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingiconset.html#cfn-quicksight-template-conditionalformattingiconset-iconsettype
         */
        readonly iconSetType?: string;
    }
    /**
     * The conditional formatting for the actual value of a KPI visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiactualvalueconditionalformatting.html
     */
    interface KPIActualValueConditionalFormattingProperty {
        /**
         * The conditional formatting of the actual value's icon.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiactualvalueconditionalformatting.html#cfn-quicksight-template-kpiactualvalueconditionalformatting-icon
         */
        readonly icon?: CfnTemplate.ConditionalFormattingIconProperty | cdk.IResolvable;
        /**
         * The conditional formatting of the actual value's text color.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiactualvalueconditionalformatting.html#cfn-quicksight-template-kpiactualvalueconditionalformatting-textcolor
         */
        readonly textColor?: CfnTemplate.ConditionalFormattingColorProperty | cdk.IResolvable;
    }
    /**
     * The conditional formatting for the comparison value of a KPI visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpicomparisonvalueconditionalformatting.html
     */
    interface KPIComparisonValueConditionalFormattingProperty {
        /**
         * The conditional formatting of the comparison value's icon.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpicomparisonvalueconditionalformatting.html#cfn-quicksight-template-kpicomparisonvalueconditionalformatting-icon
         */
        readonly icon?: CfnTemplate.ConditionalFormattingIconProperty | cdk.IResolvable;
        /**
         * The conditional formatting of the comparison value's text color.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpicomparisonvalueconditionalformatting.html#cfn-quicksight-template-kpicomparisonvalueconditionalformatting-textcolor
         */
        readonly textColor?: CfnTemplate.ConditionalFormattingColorProperty | cdk.IResolvable;
    }
    /**
     * The conditional formatting for the progress bar of a KPI visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiprogressbarconditionalformatting.html
     */
    interface KPIProgressBarConditionalFormattingProperty {
        /**
         * The conditional formatting of the progress bar's foreground color.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiprogressbarconditionalformatting.html#cfn-quicksight-template-kpiprogressbarconditionalformatting-foregroundcolor
         */
        readonly foregroundColor?: CfnTemplate.ConditionalFormattingColorProperty | cdk.IResolvable;
    }
    /**
     * The configuration of a KPI visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiconfiguration.html
     */
    interface KPIConfigurationProperty {
        /**
         * The field well configuration of a KPI visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiconfiguration.html#cfn-quicksight-template-kpiconfiguration-fieldwells
         */
        readonly fieldWells?: cdk.IResolvable | CfnTemplate.KPIFieldWellsProperty;
        /**
         * The options that determine the presentation of a KPI visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiconfiguration.html#cfn-quicksight-template-kpiconfiguration-kpioptions
         */
        readonly kpiOptions?: cdk.IResolvable | CfnTemplate.KPIOptionsProperty;
        /**
         * The sort configuration of a KPI visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiconfiguration.html#cfn-quicksight-template-kpiconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: cdk.IResolvable | CfnTemplate.KPISortConfigurationProperty;
    }
    /**
     * The sort configuration of a KPI visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpisortconfiguration.html
     */
    interface KPISortConfigurationProperty {
        /**
         * The sort configuration of the trend group fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpisortconfiguration.html#cfn-quicksight-template-kpisortconfiguration-trendgroupsort
         */
        readonly trendGroupSort?: Array<CfnTemplate.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * The options that determine the presentation of a KPI visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpioptions.html
     */
    interface KPIOptionsProperty {
        /**
         * The comparison configuration of a KPI visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpioptions.html#cfn-quicksight-template-kpioptions-comparison
         */
        readonly comparison?: CfnTemplate.ComparisonConfigurationProperty | cdk.IResolvable;
        /**
         * The options that determine the primary value display type.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpioptions.html#cfn-quicksight-template-kpioptions-primaryvaluedisplaytype
         */
        readonly primaryValueDisplayType?: string;
        /**
         * The options that determine the primary value font configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpioptions.html#cfn-quicksight-template-kpioptions-primaryvaluefontconfiguration
         */
        readonly primaryValueFontConfiguration?: CfnTemplate.FontConfigurationProperty | cdk.IResolvable;
        /**
         * The options that determine the presentation of the progress bar of a KPI visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpioptions.html#cfn-quicksight-template-kpioptions-progressbar
         */
        readonly progressBar?: cdk.IResolvable | CfnTemplate.ProgressBarOptionsProperty;
        /**
         * The options that determine the presentation of the secondary value of a KPI visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpioptions.html#cfn-quicksight-template-kpioptions-secondaryvalue
         */
        readonly secondaryValue?: cdk.IResolvable | CfnTemplate.SecondaryValueOptionsProperty;
        /**
         * The options that determine the secondary value font configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpioptions.html#cfn-quicksight-template-kpioptions-secondaryvaluefontconfiguration
         */
        readonly secondaryValueFontConfiguration?: CfnTemplate.FontConfigurationProperty | cdk.IResolvable;
        /**
         * The options that determine the visibility, color, type, and tooltip visibility of the sparkline of a KPI visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpioptions.html#cfn-quicksight-template-kpioptions-sparkline
         */
        readonly sparkline?: cdk.IResolvable | CfnTemplate.KPISparklineOptionsProperty;
        /**
         * The options that determine the presentation of trend arrows in a KPI visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpioptions.html#cfn-quicksight-template-kpioptions-trendarrows
         */
        readonly trendArrows?: cdk.IResolvable | CfnTemplate.TrendArrowOptionsProperty;
        /**
         * The options that determine the layout a KPI visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpioptions.html#cfn-quicksight-template-kpioptions-visuallayoutoptions
         */
        readonly visualLayoutOptions?: cdk.IResolvable | CfnTemplate.KPIVisualLayoutOptionsProperty;
    }
    /**
     * The options that determine the layout a KPI visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpivisuallayoutoptions.html
     */
    interface KPIVisualLayoutOptionsProperty {
        /**
         * The standard layout of the KPI visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpivisuallayoutoptions.html#cfn-quicksight-template-kpivisuallayoutoptions-standardlayout
         */
        readonly standardLayout?: cdk.IResolvable | CfnTemplate.KPIVisualStandardLayoutProperty;
    }
    /**
     * The standard layout of the KPI visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpivisualstandardlayout.html
     */
    interface KPIVisualStandardLayoutProperty {
        /**
         * The standard layout type.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpivisualstandardlayout.html#cfn-quicksight-template-kpivisualstandardlayout-type
         */
        readonly type: string;
    }
    /**
     * The options that determine the presentation of trend arrows in a KPI visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-trendarrowoptions.html
     */
    interface TrendArrowOptionsProperty {
        /**
         * The visibility of the trend arrows.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-trendarrowoptions.html#cfn-quicksight-template-trendarrowoptions-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The options that determine the presentation of the secondary value of a KPI visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-secondaryvalueoptions.html
     */
    interface SecondaryValueOptionsProperty {
        /**
         * Determines the visibility of the secondary value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-secondaryvalueoptions.html#cfn-quicksight-template-secondaryvalueoptions-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The comparison display configuration of a KPI or gauge chart.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-comparisonconfiguration.html
     */
    interface ComparisonConfigurationProperty {
        /**
         * The format of the comparison.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-comparisonconfiguration.html#cfn-quicksight-template-comparisonconfiguration-comparisonformat
         */
        readonly comparisonFormat?: CfnTemplate.ComparisonFormatConfigurationProperty | cdk.IResolvable;
        /**
         * The method of the comparison. Choose from the following options:.
         *
         * - `DIFFERENCE`
         * - `PERCENT_DIFFERENCE`
         * - `PERCENT`
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-comparisonconfiguration.html#cfn-quicksight-template-comparisonconfiguration-comparisonmethod
         */
        readonly comparisonMethod?: string;
    }
    /**
     * The format of the comparison.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-comparisonformatconfiguration.html
     */
    interface ComparisonFormatConfigurationProperty {
        /**
         * The number display format.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-comparisonformatconfiguration.html#cfn-quicksight-template-comparisonformatconfiguration-numberdisplayformatconfiguration
         */
        readonly numberDisplayFormatConfiguration?: cdk.IResolvable | CfnTemplate.NumberDisplayFormatConfigurationProperty;
        /**
         * The percentage display format.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-comparisonformatconfiguration.html#cfn-quicksight-template-comparisonformatconfiguration-percentagedisplayformatconfiguration
         */
        readonly percentageDisplayFormatConfiguration?: cdk.IResolvable | CfnTemplate.PercentageDisplayFormatConfigurationProperty;
    }
    /**
     * The options that determine the presentation of the progress bar of a KPI visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-progressbaroptions.html
     */
    interface ProgressBarOptionsProperty {
        /**
         * The visibility of the progress bar.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-progressbaroptions.html#cfn-quicksight-template-progressbaroptions-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The options that determine the visibility, color, type, and tooltip visibility of the sparkline of a KPI visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpisparklineoptions.html
     */
    interface KPISparklineOptionsProperty {
        /**
         * The color of the sparkline.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpisparklineoptions.html#cfn-quicksight-template-kpisparklineoptions-color
         */
        readonly color?: string;
        /**
         * The tooltip visibility of the sparkline.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpisparklineoptions.html#cfn-quicksight-template-kpisparklineoptions-tooltipvisibility
         */
        readonly tooltipVisibility?: string;
        /**
         * The type of the sparkline.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpisparklineoptions.html#cfn-quicksight-template-kpisparklineoptions-type
         */
        readonly type: string;
        /**
         * The visibility of the sparkline.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpisparklineoptions.html#cfn-quicksight-template-kpisparklineoptions-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The field well configuration of a KPI visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpifieldwells.html
     */
    interface KPIFieldWellsProperty {
        /**
         * The target value field wells of a KPI visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpifieldwells.html#cfn-quicksight-template-kpifieldwells-targetvalues
         */
        readonly targetValues?: Array<cdk.IResolvable | CfnTemplate.MeasureFieldProperty> | cdk.IResolvable;
        /**
         * The trend group field wells of a KPI visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpifieldwells.html#cfn-quicksight-template-kpifieldwells-trendgroups
         */
        readonly trendGroups?: Array<CfnTemplate.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The value field wells of a KPI visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpifieldwells.html#cfn-quicksight-template-kpifieldwells-values
         */
        readonly values?: Array<cdk.IResolvable | CfnTemplate.MeasureFieldProperty> | cdk.IResolvable;
    }
    /**
     * A histogram.
     *
     * For more information, see [Using histograms](https://docs.aws.amazon.com/quicksight/latest/user/histogram-charts.html) in the *Amazon QuickSight User Guide* .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramvisual.html
     */
    interface HistogramVisualProperty {
        /**
         * The list of custom actions that are configured for a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramvisual.html#cfn-quicksight-template-histogramvisual-actions
         */
        readonly actions?: Array<cdk.IResolvable | CfnTemplate.VisualCustomActionProperty> | cdk.IResolvable;
        /**
         * The configuration for a `HistogramVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramvisual.html#cfn-quicksight-template-histogramvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnTemplate.HistogramConfigurationProperty | cdk.IResolvable;
        /**
         * The subtitle that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramvisual.html#cfn-quicksight-template-histogramvisual-subtitle
         */
        readonly subtitle?: cdk.IResolvable | CfnTemplate.VisualSubtitleLabelOptionsProperty;
        /**
         * The title that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramvisual.html#cfn-quicksight-template-histogramvisual-title
         */
        readonly title?: cdk.IResolvable | CfnTemplate.VisualTitleLabelOptionsProperty;
        /**
         * The unique identifier of a visual.
         *
         * This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramvisual.html#cfn-quicksight-template-histogramvisual-visualid
         */
        readonly visualId: string;
    }
    /**
     * The configuration for a `HistogramVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramconfiguration.html
     */
    interface HistogramConfigurationProperty {
        /**
         * The options that determine the presentation of histogram bins.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramconfiguration.html#cfn-quicksight-template-histogramconfiguration-binoptions
         */
        readonly binOptions?: CfnTemplate.HistogramBinOptionsProperty | cdk.IResolvable;
        /**
         * The data label configuration of a histogram.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramconfiguration.html#cfn-quicksight-template-histogramconfiguration-datalabels
         */
        readonly dataLabels?: CfnTemplate.DataLabelOptionsProperty | cdk.IResolvable;
        /**
         * The field well configuration of a histogram.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramconfiguration.html#cfn-quicksight-template-histogramconfiguration-fieldwells
         */
        readonly fieldWells?: CfnTemplate.HistogramFieldWellsProperty | cdk.IResolvable;
        /**
         * The tooltip configuration of a histogram.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramconfiguration.html#cfn-quicksight-template-histogramconfiguration-tooltip
         */
        readonly tooltip?: cdk.IResolvable | CfnTemplate.TooltipOptionsProperty;
        /**
         * The visual palette configuration of a histogram.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramconfiguration.html#cfn-quicksight-template-histogramconfiguration-visualpalette
         */
        readonly visualPalette?: cdk.IResolvable | CfnTemplate.VisualPaletteProperty;
        /**
         * The options that determine the presentation of the x-axis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramconfiguration.html#cfn-quicksight-template-histogramconfiguration-xaxisdisplayoptions
         */
        readonly xAxisDisplayOptions?: CfnTemplate.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * The options that determine the presentation of the x-axis label.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramconfiguration.html#cfn-quicksight-template-histogramconfiguration-xaxislabeloptions
         */
        readonly xAxisLabelOptions?: CfnTemplate.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The options that determine the presentation of the y-axis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramconfiguration.html#cfn-quicksight-template-histogramconfiguration-yaxisdisplayoptions
         */
        readonly yAxisDisplayOptions?: CfnTemplate.AxisDisplayOptionsProperty | cdk.IResolvable;
    }
    /**
     * The options that determine the presentation of histogram bins.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogrambinoptions.html
     */
    interface HistogramBinOptionsProperty {
        /**
         * The options that determine the bin count of a histogram.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogrambinoptions.html#cfn-quicksight-template-histogrambinoptions-bincount
         */
        readonly binCount?: CfnTemplate.BinCountOptionsProperty | cdk.IResolvable;
        /**
         * The options that determine the bin width of a histogram.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogrambinoptions.html#cfn-quicksight-template-histogrambinoptions-binwidth
         */
        readonly binWidth?: CfnTemplate.BinWidthOptionsProperty | cdk.IResolvable;
        /**
         * The options that determine the selected bin type.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogrambinoptions.html#cfn-quicksight-template-histogrambinoptions-selectedbintype
         */
        readonly selectedBinType?: string;
        /**
         * The options that determine the bin start value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogrambinoptions.html#cfn-quicksight-template-histogrambinoptions-startvalue
         */
        readonly startValue?: number;
    }
    /**
     * The options that determine the bin width of a histogram.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-binwidthoptions.html
     */
    interface BinWidthOptionsProperty {
        /**
         * The options that determine the bin count limit.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-binwidthoptions.html#cfn-quicksight-template-binwidthoptions-bincountlimit
         */
        readonly binCountLimit?: number;
        /**
         * The options that determine the bin width value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-binwidthoptions.html#cfn-quicksight-template-binwidthoptions-value
         */
        readonly value?: number;
    }
    /**
     * The options that determine the bin count of a histogram.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-bincountoptions.html
     */
    interface BinCountOptionsProperty {
        /**
         * The options that determine the bin count value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-bincountoptions.html#cfn-quicksight-template-bincountoptions-value
         */
        readonly value?: number;
    }
    /**
     * The field well configuration of a histogram.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramfieldwells.html
     */
    interface HistogramFieldWellsProperty {
        /**
         * The field well configuration of a histogram.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramfieldwells.html#cfn-quicksight-template-histogramfieldwells-histogramaggregatedfieldwells
         */
        readonly histogramAggregatedFieldWells?: CfnTemplate.HistogramAggregatedFieldWellsProperty | cdk.IResolvable;
    }
    /**
     * The field well configuration of a histogram.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramaggregatedfieldwells.html
     */
    interface HistogramAggregatedFieldWellsProperty {
        /**
         * The value field wells of a histogram.
         *
         * Values are aggregated by `COUNT` or `DISTINCT_COUNT` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramaggregatedfieldwells.html#cfn-quicksight-template-histogramaggregatedfieldwells-values
         */
        readonly values?: Array<cdk.IResolvable | CfnTemplate.MeasureFieldProperty> | cdk.IResolvable;
    }
    /**
     * A table visual.
     *
     * For more information, see [Using tables as visuals](https://docs.aws.amazon.com/quicksight/latest/user/tabular.html) in the *Amazon QuickSight User Guide* .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablevisual.html
     */
    interface TableVisualProperty {
        /**
         * The list of custom actions that are configured for a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablevisual.html#cfn-quicksight-template-tablevisual-actions
         */
        readonly actions?: Array<cdk.IResolvable | CfnTemplate.VisualCustomActionProperty> | cdk.IResolvable;
        /**
         * The configuration settings of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablevisual.html#cfn-quicksight-template-tablevisual-chartconfiguration
         */
        readonly chartConfiguration?: cdk.IResolvable | CfnTemplate.TableConfigurationProperty;
        /**
         * The conditional formatting for a `PivotTableVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablevisual.html#cfn-quicksight-template-tablevisual-conditionalformatting
         */
        readonly conditionalFormatting?: cdk.IResolvable | CfnTemplate.TableConditionalFormattingProperty;
        /**
         * The subtitle that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablevisual.html#cfn-quicksight-template-tablevisual-subtitle
         */
        readonly subtitle?: cdk.IResolvable | CfnTemplate.VisualSubtitleLabelOptionsProperty;
        /**
         * The title that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablevisual.html#cfn-quicksight-template-tablevisual-title
         */
        readonly title?: cdk.IResolvable | CfnTemplate.VisualTitleLabelOptionsProperty;
        /**
         * The unique identifier of a visual.
         *
         * This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablevisual.html#cfn-quicksight-template-tablevisual-visualid
         */
        readonly visualId: string;
    }
    /**
     * The conditional formatting for a `PivotTableVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableconditionalformatting.html
     */
    interface TableConditionalFormattingProperty {
        /**
         * Conditional formatting options for a `PivotTableVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableconditionalformatting.html#cfn-quicksight-template-tableconditionalformatting-conditionalformattingoptions
         */
        readonly conditionalFormattingOptions?: Array<cdk.IResolvable | CfnTemplate.TableConditionalFormattingOptionProperty> | cdk.IResolvable;
    }
    /**
     * Conditional formatting options for a `PivotTableVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableconditionalformattingoption.html
     */
    interface TableConditionalFormattingOptionProperty {
        /**
         * The cell conditional formatting option for a table.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableconditionalformattingoption.html#cfn-quicksight-template-tableconditionalformattingoption-cell
         */
        readonly cell?: cdk.IResolvable | CfnTemplate.TableCellConditionalFormattingProperty;
        /**
         * The row conditional formatting option for a table.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableconditionalformattingoption.html#cfn-quicksight-template-tableconditionalformattingoption-row
         */
        readonly row?: cdk.IResolvable | CfnTemplate.TableRowConditionalFormattingProperty;
    }
    /**
     * The conditional formatting of a table row.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablerowconditionalformatting.html
     */
    interface TableRowConditionalFormattingProperty {
        /**
         * The conditional formatting color (solid, gradient) of the background for a table row.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablerowconditionalformatting.html#cfn-quicksight-template-tablerowconditionalformatting-backgroundcolor
         */
        readonly backgroundColor?: CfnTemplate.ConditionalFormattingColorProperty | cdk.IResolvable;
        /**
         * The conditional formatting color (solid, gradient) of the text for a table row.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablerowconditionalformatting.html#cfn-quicksight-template-tablerowconditionalformatting-textcolor
         */
        readonly textColor?: CfnTemplate.ConditionalFormattingColorProperty | cdk.IResolvable;
    }
    /**
     * The cell conditional formatting option for a table.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablecellconditionalformatting.html
     */
    interface TableCellConditionalFormattingProperty {
        /**
         * The field ID of the cell for conditional formatting.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablecellconditionalformatting.html#cfn-quicksight-template-tablecellconditionalformatting-fieldid
         */
        readonly fieldId: string;
        /**
         * The text format of the cell for conditional formatting.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablecellconditionalformatting.html#cfn-quicksight-template-tablecellconditionalformatting-textformat
         */
        readonly textFormat?: cdk.IResolvable | CfnTemplate.TextConditionalFormatProperty;
    }
    /**
     * The conditional formatting for the text.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-textconditionalformat.html
     */
    interface TextConditionalFormatProperty {
        /**
         * The conditional formatting for the text background color.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-textconditionalformat.html#cfn-quicksight-template-textconditionalformat-backgroundcolor
         */
        readonly backgroundColor?: CfnTemplate.ConditionalFormattingColorProperty | cdk.IResolvable;
        /**
         * The conditional formatting for the icon.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-textconditionalformat.html#cfn-quicksight-template-textconditionalformat-icon
         */
        readonly icon?: CfnTemplate.ConditionalFormattingIconProperty | cdk.IResolvable;
        /**
         * The conditional formatting for the text color.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-textconditionalformat.html#cfn-quicksight-template-textconditionalformat-textcolor
         */
        readonly textColor?: CfnTemplate.ConditionalFormattingColorProperty | cdk.IResolvable;
    }
    /**
     * The configuration for a `TableVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableconfiguration.html
     */
    interface TableConfigurationProperty {
        /**
         * The field options for a table visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableconfiguration.html#cfn-quicksight-template-tableconfiguration-fieldoptions
         */
        readonly fieldOptions?: cdk.IResolvable | CfnTemplate.TableFieldOptionsProperty;
        /**
         * The field wells of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableconfiguration.html#cfn-quicksight-template-tableconfiguration-fieldwells
         */
        readonly fieldWells?: cdk.IResolvable | CfnTemplate.TableFieldWellsProperty;
        /**
         * The paginated report options for a table visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableconfiguration.html#cfn-quicksight-template-tableconfiguration-paginatedreportoptions
         */
        readonly paginatedReportOptions?: cdk.IResolvable | CfnTemplate.TablePaginatedReportOptionsProperty;
        /**
         * The sort configuration for a `TableVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableconfiguration.html#cfn-quicksight-template-tableconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: cdk.IResolvable | CfnTemplate.TableSortConfigurationProperty;
        /**
         * A collection of inline visualizations to display within a chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableconfiguration.html#cfn-quicksight-template-tableconfiguration-tableinlinevisualizations
         */
        readonly tableInlineVisualizations?: Array<cdk.IResolvable | CfnTemplate.TableInlineVisualizationProperty> | cdk.IResolvable;
        /**
         * The table options for a table visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableconfiguration.html#cfn-quicksight-template-tableconfiguration-tableoptions
         */
        readonly tableOptions?: cdk.IResolvable | CfnTemplate.TableOptionsProperty;
        /**
         * The total options for a table visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableconfiguration.html#cfn-quicksight-template-tableconfiguration-totaloptions
         */
        readonly totalOptions?: cdk.IResolvable | CfnTemplate.TotalOptionsProperty;
    }
    /**
     * The sort configuration for a `TableVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablesortconfiguration.html
     */
    interface TableSortConfigurationProperty {
        /**
         * The pagination configuration (page size, page number) for the table.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablesortconfiguration.html#cfn-quicksight-template-tablesortconfiguration-paginationconfiguration
         */
        readonly paginationConfiguration?: cdk.IResolvable | CfnTemplate.PaginationConfigurationProperty;
        /**
         * The field sort options for rows in the table.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablesortconfiguration.html#cfn-quicksight-template-tablesortconfiguration-rowsort
         */
        readonly rowSort?: Array<CfnTemplate.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * The paginated report options for a table visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablepaginatedreportoptions.html
     */
    interface TablePaginatedReportOptionsProperty {
        /**
         * The visibility of repeating header rows on each page.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablepaginatedreportoptions.html#cfn-quicksight-template-tablepaginatedreportoptions-overflowcolumnheadervisibility
         */
        readonly overflowColumnHeaderVisibility?: string;
        /**
         * The visibility of printing table overflow across pages.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablepaginatedreportoptions.html#cfn-quicksight-template-tablepaginatedreportoptions-verticaloverflowvisibility
         */
        readonly verticalOverflowVisibility?: string;
    }
    /**
     * The table options for a table visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableoptions.html
     */
    interface TableOptionsProperty {
        /**
         * The table cell style of table cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableoptions.html#cfn-quicksight-template-tableoptions-cellstyle
         */
        readonly cellStyle?: cdk.IResolvable | CfnTemplate.TableCellStyleProperty;
        /**
         * The table cell style of a table header.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableoptions.html#cfn-quicksight-template-tableoptions-headerstyle
         */
        readonly headerStyle?: cdk.IResolvable | CfnTemplate.TableCellStyleProperty;
        /**
         * The orientation (vertical, horizontal) for a table.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableoptions.html#cfn-quicksight-template-tableoptions-orientation
         */
        readonly orientation?: string;
        /**
         * The row alternate color options (widget status, row alternate colors) for a table.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableoptions.html#cfn-quicksight-template-tableoptions-rowalternatecoloroptions
         */
        readonly rowAlternateColorOptions?: cdk.IResolvable | CfnTemplate.RowAlternateColorOptionsProperty;
    }
    /**
     * The table cell style for a cell in pivot table or table visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablecellstyle.html
     */
    interface TableCellStyleProperty {
        /**
         * The background color for the table cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablecellstyle.html#cfn-quicksight-template-tablecellstyle-backgroundcolor
         */
        readonly backgroundColor?: string;
        /**
         * The borders for the table cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablecellstyle.html#cfn-quicksight-template-tablecellstyle-border
         */
        readonly border?: CfnTemplate.GlobalTableBorderOptionsProperty | cdk.IResolvable;
        /**
         * The font configuration of the table cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablecellstyle.html#cfn-quicksight-template-tablecellstyle-fontconfiguration
         */
        readonly fontConfiguration?: CfnTemplate.FontConfigurationProperty | cdk.IResolvable;
        /**
         * The height color for the table cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablecellstyle.html#cfn-quicksight-template-tablecellstyle-height
         */
        readonly height?: number;
        /**
         * The horizontal text alignment (left, center, right, auto) for the table cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablecellstyle.html#cfn-quicksight-template-tablecellstyle-horizontaltextalignment
         */
        readonly horizontalTextAlignment?: string;
        /**
         * The text wrap (none, wrap) for the table cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablecellstyle.html#cfn-quicksight-template-tablecellstyle-textwrap
         */
        readonly textWrap?: string;
        /**
         * The vertical text alignment (top, middle, bottom) for the table cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablecellstyle.html#cfn-quicksight-template-tablecellstyle-verticaltextalignment
         */
        readonly verticalTextAlignment?: string;
        /**
         * The visibility of the table cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablecellstyle.html#cfn-quicksight-template-tablecellstyle-visibility
         */
        readonly visibility?: string;
    }
    /**
     * Determines the border options for a table visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-globaltableborderoptions.html
     */
    interface GlobalTableBorderOptionsProperty {
        /**
         * Determines the options for side specific border.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-globaltableborderoptions.html#cfn-quicksight-template-globaltableborderoptions-sidespecificborder
         */
        readonly sideSpecificBorder?: cdk.IResolvable | CfnTemplate.TableSideBorderOptionsProperty;
        /**
         * Determines the options for uniform border.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-globaltableborderoptions.html#cfn-quicksight-template-globaltableborderoptions-uniformborder
         */
        readonly uniformBorder?: cdk.IResolvable | CfnTemplate.TableBorderOptionsProperty;
    }
    /**
     * The border options for a table border.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableborderoptions.html
     */
    interface TableBorderOptionsProperty {
        /**
         * The color of a table border.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableborderoptions.html#cfn-quicksight-template-tableborderoptions-color
         */
        readonly color?: string;
        /**
         * The style (none, solid) of a table border.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableborderoptions.html#cfn-quicksight-template-tableborderoptions-style
         */
        readonly style?: string;
        /**
         * The thickness of a table border.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableborderoptions.html#cfn-quicksight-template-tableborderoptions-thickness
         */
        readonly thickness?: number;
    }
    /**
     * The side border options for a table.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablesideborderoptions.html
     */
    interface TableSideBorderOptionsProperty {
        /**
         * The table border options of the bottom border.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablesideborderoptions.html#cfn-quicksight-template-tablesideborderoptions-bottom
         */
        readonly bottom?: cdk.IResolvable | CfnTemplate.TableBorderOptionsProperty;
        /**
         * The table border options of the inner horizontal border.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablesideborderoptions.html#cfn-quicksight-template-tablesideborderoptions-innerhorizontal
         */
        readonly innerHorizontal?: cdk.IResolvable | CfnTemplate.TableBorderOptionsProperty;
        /**
         * The table border options of the inner vertical border.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablesideborderoptions.html#cfn-quicksight-template-tablesideborderoptions-innervertical
         */
        readonly innerVertical?: cdk.IResolvable | CfnTemplate.TableBorderOptionsProperty;
        /**
         * The table border options of the left border.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablesideborderoptions.html#cfn-quicksight-template-tablesideborderoptions-left
         */
        readonly left?: cdk.IResolvable | CfnTemplate.TableBorderOptionsProperty;
        /**
         * The table border options of the right border.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablesideborderoptions.html#cfn-quicksight-template-tablesideborderoptions-right
         */
        readonly right?: cdk.IResolvable | CfnTemplate.TableBorderOptionsProperty;
        /**
         * The table border options of the top border.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablesideborderoptions.html#cfn-quicksight-template-tablesideborderoptions-top
         */
        readonly top?: cdk.IResolvable | CfnTemplate.TableBorderOptionsProperty;
    }
    /**
     * Determines the row alternate color options.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-rowalternatecoloroptions.html
     */
    interface RowAlternateColorOptionsProperty {
        /**
         * Determines the list of row alternate colors.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-rowalternatecoloroptions.html#cfn-quicksight-template-rowalternatecoloroptions-rowalternatecolors
         */
        readonly rowAlternateColors?: Array<string>;
        /**
         * Determines the widget status.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-rowalternatecoloroptions.html#cfn-quicksight-template-rowalternatecoloroptions-status
         */
        readonly status?: string;
        /**
         * The primary background color options for alternate rows.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-rowalternatecoloroptions.html#cfn-quicksight-template-rowalternatecoloroptions-useprimarybackgroundcolor
         */
        readonly usePrimaryBackgroundColor?: string;
    }
    /**
     * The inline visualization of a specific type to display within a chart.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableinlinevisualization.html
     */
    interface TableInlineVisualizationProperty {
        /**
         * The configuration of the inline visualization of the data bars within a chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableinlinevisualization.html#cfn-quicksight-template-tableinlinevisualization-databars
         */
        readonly dataBars?: CfnTemplate.DataBarsOptionsProperty | cdk.IResolvable;
    }
    /**
     * The options for data bars.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-databarsoptions.html
     */
    interface DataBarsOptionsProperty {
        /**
         * The field ID for the data bars options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-databarsoptions.html#cfn-quicksight-template-databarsoptions-fieldid
         */
        readonly fieldId: string;
        /**
         * The color of the negative data bar.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-databarsoptions.html#cfn-quicksight-template-databarsoptions-negativecolor
         */
        readonly negativeColor?: string;
        /**
         * The color of the positive data bar.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-databarsoptions.html#cfn-quicksight-template-databarsoptions-positivecolor
         */
        readonly positiveColor?: string;
    }
    /**
     * The field wells for a table visual.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldwells.html
     */
    interface TableFieldWellsProperty {
        /**
         * The aggregated field well for the table.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldwells.html#cfn-quicksight-template-tablefieldwells-tableaggregatedfieldwells
         */
        readonly tableAggregatedFieldWells?: cdk.IResolvable | CfnTemplate.TableAggregatedFieldWellsProperty;
        /**
         * The unaggregated field well for the table.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldwells.html#cfn-quicksight-template-tablefieldwells-tableunaggregatedfieldwells
         */
        readonly tableUnaggregatedFieldWells?: cdk.IResolvable | CfnTemplate.TableUnaggregatedFieldWellsProperty;
    }
    /**
     * The unaggregated field well for the table.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableunaggregatedfieldwells.html
     */
    interface TableUnaggregatedFieldWellsProperty {
        /**
         * The values field well for a pivot table.
         *
         * Values are unaggregated for an unaggregated table.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableunaggregatedfieldwells.html#cfn-quicksight-template-tableunaggregatedfieldwells-values
         */
        readonly values?: Array<cdk.IResolvable | CfnTemplate.UnaggregatedFieldProperty> | cdk.IResolvable;
    }
    /**
     * The unaggregated field for a table.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-unaggregatedfield.html
     */
    interface UnaggregatedFieldProperty {
        /**
         * The column that is used in the `UnaggregatedField` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-unaggregatedfield.html#cfn-quicksight-template-unaggregatedfield-column
         */
        readonly column: CfnTemplate.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * The custom field ID.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-unaggregatedfield.html#cfn-quicksight-template-unaggregatedfield-fieldid
         */
        readonly fieldId: string;
        /**
         * The format configuration of the field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-unaggregatedfield.html#cfn-quicksight-template-unaggregatedfield-formatconfiguration
         */
        readonly formatConfiguration?: CfnTemplate.FormatConfigurationProperty | cdk.IResolvable;
    }
    /**
     * The aggregated field well for the table.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableaggregatedfieldwells.html
     */
    interface TableAggregatedFieldWellsProperty {
        /**
         * The group by field well for a pivot table.
         *
         * Values are grouped by group by fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableaggregatedfieldwells.html#cfn-quicksight-template-tableaggregatedfieldwells-groupby
         */
        readonly groupBy?: Array<CfnTemplate.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The values field well for a pivot table.
         *
         * Values are aggregated based on group by fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableaggregatedfieldwells.html#cfn-quicksight-template-tableaggregatedfieldwells-values
         */
        readonly values?: Array<cdk.IResolvable | CfnTemplate.MeasureFieldProperty> | cdk.IResolvable;
    }
    /**
     * The field options of a table visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldoptions.html
     */
    interface TableFieldOptionsProperty {
        /**
         * The order of the field IDs that are configured as field options for a table visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldoptions.html#cfn-quicksight-template-tablefieldoptions-order
         */
        readonly order?: Array<string>;
        /**
         * The settings for the pinned columns of a table visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldoptions.html#cfn-quicksight-template-tablefieldoptions-pinnedfieldoptions
         */
        readonly pinnedFieldOptions?: cdk.IResolvable | CfnTemplate.TablePinnedFieldOptionsProperty;
        /**
         * The field options to be configured to a table.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldoptions.html#cfn-quicksight-template-tablefieldoptions-selectedfieldoptions
         */
        readonly selectedFieldOptions?: Array<cdk.IResolvable | CfnTemplate.TableFieldOptionProperty> | cdk.IResolvable;
    }
    /**
     * The settings for the pinned columns of a table visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablepinnedfieldoptions.html
     */
    interface TablePinnedFieldOptionsProperty {
        /**
         * A list of columns to be pinned to the left of a table visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablepinnedfieldoptions.html#cfn-quicksight-template-tablepinnedfieldoptions-pinnedleftfields
         */
        readonly pinnedLeftFields?: Array<string>;
    }
    /**
     * The options for a table field.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldoption.html
     */
    interface TableFieldOptionProperty {
        /**
         * The custom label for a table field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldoption.html#cfn-quicksight-template-tablefieldoption-customlabel
         */
        readonly customLabel?: string;
        /**
         * The field ID for a table field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldoption.html#cfn-quicksight-template-tablefieldoption-fieldid
         */
        readonly fieldId: string;
        /**
         * The URL configuration for a table field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldoption.html#cfn-quicksight-template-tablefieldoption-urlstyling
         */
        readonly urlStyling?: cdk.IResolvable | CfnTemplate.TableFieldURLConfigurationProperty;
        /**
         * The visibility of a table field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldoption.html#cfn-quicksight-template-tablefieldoption-visibility
         */
        readonly visibility?: string;
        /**
         * The width for a table field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldoption.html#cfn-quicksight-template-tablefieldoption-width
         */
        readonly width?: string;
    }
    /**
     * The URL configuration for a table field.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldurlconfiguration.html
     */
    interface TableFieldURLConfigurationProperty {
        /**
         * The image configuration of a table field URL.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldurlconfiguration.html#cfn-quicksight-template-tablefieldurlconfiguration-imageconfiguration
         */
        readonly imageConfiguration?: cdk.IResolvable | CfnTemplate.TableFieldImageConfigurationProperty;
        /**
         * The link configuration of a table field URL.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldurlconfiguration.html#cfn-quicksight-template-tablefieldurlconfiguration-linkconfiguration
         */
        readonly linkConfiguration?: cdk.IResolvable | CfnTemplate.TableFieldLinkConfigurationProperty;
    }
    /**
     * The link configuration of a table field URL.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldlinkconfiguration.html
     */
    interface TableFieldLinkConfigurationProperty {
        /**
         * The URL content (text, icon) for the table link configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldlinkconfiguration.html#cfn-quicksight-template-tablefieldlinkconfiguration-content
         */
        readonly content: cdk.IResolvable | CfnTemplate.TableFieldLinkContentConfigurationProperty;
        /**
         * The URL target (new tab, new window, same tab) for the table link configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldlinkconfiguration.html#cfn-quicksight-template-tablefieldlinkconfiguration-target
         */
        readonly target: string;
    }
    /**
     * The URL content (text, icon) for the table link configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldlinkcontentconfiguration.html
     */
    interface TableFieldLinkContentConfigurationProperty {
        /**
         * The custom icon content for the table link content configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldlinkcontentconfiguration.html#cfn-quicksight-template-tablefieldlinkcontentconfiguration-customiconcontent
         */
        readonly customIconContent?: cdk.IResolvable | CfnTemplate.TableFieldCustomIconContentProperty;
        /**
         * The custom text content (value, font configuration) for the table link content configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldlinkcontentconfiguration.html#cfn-quicksight-template-tablefieldlinkcontentconfiguration-customtextcontent
         */
        readonly customTextContent?: cdk.IResolvable | CfnTemplate.TableFieldCustomTextContentProperty;
    }
    /**
     * The custom icon content for the table link content configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldcustomiconcontent.html
     */
    interface TableFieldCustomIconContentProperty {
        /**
         * The icon set type (link) of the custom icon content for table URL link content.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldcustomiconcontent.html#cfn-quicksight-template-tablefieldcustomiconcontent-icon
         */
        readonly icon?: string;
    }
    /**
     * The custom text content (value, font configuration) for the table link content configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldcustomtextcontent.html
     */
    interface TableFieldCustomTextContentProperty {
        /**
         * The font configuration of the custom text content for the table URL link content.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldcustomtextcontent.html#cfn-quicksight-template-tablefieldcustomtextcontent-fontconfiguration
         */
        readonly fontConfiguration: CfnTemplate.FontConfigurationProperty | cdk.IResolvable;
        /**
         * The string value of the custom text content for the table URL link content.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldcustomtextcontent.html#cfn-quicksight-template-tablefieldcustomtextcontent-value
         */
        readonly value?: string;
    }
    /**
     * The image configuration of a table field URL.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldimageconfiguration.html
     */
    interface TableFieldImageConfigurationProperty {
        /**
         * The sizing options for the table image configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldimageconfiguration.html#cfn-quicksight-template-tablefieldimageconfiguration-sizingoptions
         */
        readonly sizingOptions?: cdk.IResolvable | CfnTemplate.TableCellImageSizingConfigurationProperty;
    }
    /**
     * The sizing options for the table image configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablecellimagesizingconfiguration.html
     */
    interface TableCellImageSizingConfigurationProperty {
        /**
         * The cell scaling configuration of the sizing options for the table image configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablecellimagesizingconfiguration.html#cfn-quicksight-template-tablecellimagesizingconfiguration-tablecellimagescalingconfiguration
         */
        readonly tableCellImageScalingConfiguration?: string;
    }
    /**
     * The total options for a table visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-totaloptions.html
     */
    interface TotalOptionsProperty {
        /**
         * The custom label string for the total cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-totaloptions.html#cfn-quicksight-template-totaloptions-customlabel
         */
        readonly customLabel?: string;
        /**
         * The placement (start, end) for the total cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-totaloptions.html#cfn-quicksight-template-totaloptions-placement
         */
        readonly placement?: string;
        /**
         * The scroll status (pinned, scrolled) for the total cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-totaloptions.html#cfn-quicksight-template-totaloptions-scrollstatus
         */
        readonly scrollStatus?: string;
        /**
         * The total aggregation settings for each value field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-totaloptions.html#cfn-quicksight-template-totaloptions-totalaggregationoptions
         */
        readonly totalAggregationOptions?: Array<cdk.IResolvable | CfnTemplate.TotalAggregationOptionProperty> | cdk.IResolvable;
        /**
         * Cell styling options for the total cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-totaloptions.html#cfn-quicksight-template-totaloptions-totalcellstyle
         */
        readonly totalCellStyle?: cdk.IResolvable | CfnTemplate.TableCellStyleProperty;
        /**
         * The visibility configuration for the total cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-totaloptions.html#cfn-quicksight-template-totaloptions-totalsvisibility
         */
        readonly totalsVisibility?: string;
    }
    /**
     * The total aggregation settings map of a field id.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-totalaggregationoption.html
     */
    interface TotalAggregationOptionProperty {
        /**
         * The field id that's associated with the total aggregation option.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-totalaggregationoption.html#cfn-quicksight-template-totalaggregationoption-fieldid
         */
        readonly fieldId: string;
        /**
         * The total aggregation function that you want to set for a specified field id.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-totalaggregationoption.html#cfn-quicksight-template-totalaggregationoption-totalaggregationfunction
         */
        readonly totalAggregationFunction: cdk.IResolvable | CfnTemplate.TotalAggregationFunctionProperty;
    }
    /**
     * An aggregation function that aggregates the total values of a measure.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-totalaggregationfunction.html
     */
    interface TotalAggregationFunctionProperty {
        /**
         * A built in aggregation function for total values.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-totalaggregationfunction.html#cfn-quicksight-template-totalaggregationfunction-simpletotalaggregationfunction
         */
        readonly simpleTotalAggregationFunction?: string;
    }
    /**
     * A pivot table.
     *
     * For more information, see [Using pivot tables](https://docs.aws.amazon.com/quicksight/latest/user/pivot-table.html) in the *Amazon QuickSight User Guide* .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablevisual.html
     */
    interface PivotTableVisualProperty {
        /**
         * The list of custom actions that are configured for a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablevisual.html#cfn-quicksight-template-pivottablevisual-actions
         */
        readonly actions?: Array<cdk.IResolvable | CfnTemplate.VisualCustomActionProperty> | cdk.IResolvable;
        /**
         * The configuration settings of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablevisual.html#cfn-quicksight-template-pivottablevisual-chartconfiguration
         */
        readonly chartConfiguration?: cdk.IResolvable | CfnTemplate.PivotTableConfigurationProperty;
        /**
         * The conditional formatting for a `PivotTableVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablevisual.html#cfn-quicksight-template-pivottablevisual-conditionalformatting
         */
        readonly conditionalFormatting?: cdk.IResolvable | CfnTemplate.PivotTableConditionalFormattingProperty;
        /**
         * The subtitle that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablevisual.html#cfn-quicksight-template-pivottablevisual-subtitle
         */
        readonly subtitle?: cdk.IResolvable | CfnTemplate.VisualSubtitleLabelOptionsProperty;
        /**
         * The title that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablevisual.html#cfn-quicksight-template-pivottablevisual-title
         */
        readonly title?: cdk.IResolvable | CfnTemplate.VisualTitleLabelOptionsProperty;
        /**
         * The unique identifier of a visual.
         *
         * This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablevisual.html#cfn-quicksight-template-pivottablevisual-visualid
         */
        readonly visualId: string;
    }
    /**
     * The conditional formatting for a `PivotTableVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableconditionalformatting.html
     */
    interface PivotTableConditionalFormattingProperty {
        /**
         * Conditional formatting options for a `PivotTableVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableconditionalformatting.html#cfn-quicksight-template-pivottableconditionalformatting-conditionalformattingoptions
         */
        readonly conditionalFormattingOptions?: Array<cdk.IResolvable | CfnTemplate.PivotTableConditionalFormattingOptionProperty> | cdk.IResolvable;
    }
    /**
     * Conditional formatting options for a `PivotTableVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableconditionalformattingoption.html
     */
    interface PivotTableConditionalFormattingOptionProperty {
        /**
         * The cell conditional formatting option for a pivot table.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableconditionalformattingoption.html#cfn-quicksight-template-pivottableconditionalformattingoption-cell
         */
        readonly cell?: cdk.IResolvable | CfnTemplate.PivotTableCellConditionalFormattingProperty;
    }
    /**
     * The cell conditional formatting option for a pivot table.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablecellconditionalformatting.html
     */
    interface PivotTableCellConditionalFormattingProperty {
        /**
         * The field ID of the cell for conditional formatting.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablecellconditionalformatting.html#cfn-quicksight-template-pivottablecellconditionalformatting-fieldid
         */
        readonly fieldId: string;
        /**
         * The scope of the cell for conditional formatting.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablecellconditionalformatting.html#cfn-quicksight-template-pivottablecellconditionalformatting-scope
         */
        readonly scope?: cdk.IResolvable | CfnTemplate.PivotTableConditionalFormattingScopeProperty;
        /**
         * A list of cell scopes for conditional formatting.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablecellconditionalformatting.html#cfn-quicksight-template-pivottablecellconditionalformatting-scopes
         */
        readonly scopes?: Array<cdk.IResolvable | CfnTemplate.PivotTableConditionalFormattingScopeProperty> | cdk.IResolvable;
        /**
         * The text format of the cell for conditional formatting.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablecellconditionalformatting.html#cfn-quicksight-template-pivottablecellconditionalformatting-textformat
         */
        readonly textFormat?: cdk.IResolvable | CfnTemplate.TextConditionalFormatProperty;
    }
    /**
     * The scope of the cell for conditional formatting.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableconditionalformattingscope.html
     */
    interface PivotTableConditionalFormattingScopeProperty {
        /**
         * The role (field, field total, grand total) of the cell for conditional formatting.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableconditionalformattingscope.html#cfn-quicksight-template-pivottableconditionalformattingscope-role
         */
        readonly role?: string;
    }
    /**
     * The configuration for a `PivotTableVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableconfiguration.html
     */
    interface PivotTableConfigurationProperty {
        /**
         * The field options for a pivot table visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableconfiguration.html#cfn-quicksight-template-pivottableconfiguration-fieldoptions
         */
        readonly fieldOptions?: cdk.IResolvable | CfnTemplate.PivotTableFieldOptionsProperty;
        /**
         * The field wells of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableconfiguration.html#cfn-quicksight-template-pivottableconfiguration-fieldwells
         */
        readonly fieldWells?: cdk.IResolvable | CfnTemplate.PivotTableFieldWellsProperty;
        /**
         * The paginated report options for a pivot table visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableconfiguration.html#cfn-quicksight-template-pivottableconfiguration-paginatedreportoptions
         */
        readonly paginatedReportOptions?: cdk.IResolvable | CfnTemplate.PivotTablePaginatedReportOptionsProperty;
        /**
         * The sort configuration for a `PivotTableVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableconfiguration.html#cfn-quicksight-template-pivottableconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: cdk.IResolvable | CfnTemplate.PivotTableSortConfigurationProperty;
        /**
         * The table options for a pivot table visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableconfiguration.html#cfn-quicksight-template-pivottableconfiguration-tableoptions
         */
        readonly tableOptions?: cdk.IResolvable | CfnTemplate.PivotTableOptionsProperty;
        /**
         * The total options for a pivot table visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableconfiguration.html#cfn-quicksight-template-pivottableconfiguration-totaloptions
         */
        readonly totalOptions?: cdk.IResolvable | CfnTemplate.PivotTableTotalOptionsProperty;
    }
    /**
     * The sort configuration for a `PivotTableVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablesortconfiguration.html
     */
    interface PivotTableSortConfigurationProperty {
        /**
         * The field sort options for a pivot table sort configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablesortconfiguration.html#cfn-quicksight-template-pivottablesortconfiguration-fieldsortoptions
         */
        readonly fieldSortOptions?: Array<cdk.IResolvable | CfnTemplate.PivotFieldSortOptionsProperty> | cdk.IResolvable;
    }
    /**
     * The field sort options for a pivot table sort configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivotfieldsortoptions.html
     */
    interface PivotFieldSortOptionsProperty {
        /**
         * The field ID for the field sort options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivotfieldsortoptions.html#cfn-quicksight-template-pivotfieldsortoptions-fieldid
         */
        readonly fieldId: string;
        /**
         * The sort by field for the field sort options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivotfieldsortoptions.html#cfn-quicksight-template-pivotfieldsortoptions-sortby
         */
        readonly sortBy: cdk.IResolvable | CfnTemplate.PivotTableSortByProperty;
    }
    /**
     * The sort by field for the field sort options.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablesortby.html
     */
    interface PivotTableSortByProperty {
        /**
         * The column sort (field id, direction) for the pivot table sort by options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablesortby.html#cfn-quicksight-template-pivottablesortby-column
         */
        readonly column?: CfnTemplate.ColumnSortProperty | cdk.IResolvable;
        /**
         * The data path sort (data path value, direction) for the pivot table sort by options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablesortby.html#cfn-quicksight-template-pivottablesortby-datapath
         */
        readonly dataPath?: CfnTemplate.DataPathSortProperty | cdk.IResolvable;
        /**
         * The field sort (field id, direction) for the pivot table sort by options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablesortby.html#cfn-quicksight-template-pivottablesortby-field
         */
        readonly field?: CfnTemplate.FieldSortProperty | cdk.IResolvable;
    }
    /**
     * Allows data paths to be sorted by a specific data value.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathsort.html
     */
    interface DataPathSortProperty {
        /**
         * Determines the sort direction.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathsort.html#cfn-quicksight-template-datapathsort-direction
         */
        readonly direction: string;
        /**
         * The list of data paths that need to be sorted.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathsort.html#cfn-quicksight-template-datapathsort-sortpaths
         */
        readonly sortPaths: Array<CfnTemplate.DataPathValueProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * The paginated report options for a pivot table visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablepaginatedreportoptions.html
     */
    interface PivotTablePaginatedReportOptionsProperty {
        /**
         * The visibility of the repeating header rows on each page.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablepaginatedreportoptions.html#cfn-quicksight-template-pivottablepaginatedreportoptions-overflowcolumnheadervisibility
         */
        readonly overflowColumnHeaderVisibility?: string;
        /**
         * The visibility of the printing table overflow across pages.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablepaginatedreportoptions.html#cfn-quicksight-template-pivottablepaginatedreportoptions-verticaloverflowvisibility
         */
        readonly verticalOverflowVisibility?: string;
    }
    /**
     * The table options for a pivot table visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableoptions.html
     */
    interface PivotTableOptionsProperty {
        /**
         * The table cell style of cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableoptions.html#cfn-quicksight-template-pivottableoptions-cellstyle
         */
        readonly cellStyle?: cdk.IResolvable | CfnTemplate.TableCellStyleProperty;
        /**
         * The visibility setting of a pivot table's collapsed row dimension fields.
         *
         * If the value of this structure is `HIDDEN` , all collapsed columns in a pivot table are automatically hidden. The default value is `VISIBLE` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableoptions.html#cfn-quicksight-template-pivottableoptions-collapsedrowdimensionsvisibility
         */
        readonly collapsedRowDimensionsVisibility?: string;
        /**
         * The table cell style of the column header.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableoptions.html#cfn-quicksight-template-pivottableoptions-columnheaderstyle
         */
        readonly columnHeaderStyle?: cdk.IResolvable | CfnTemplate.TableCellStyleProperty;
        /**
         * The visibility of the column names.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableoptions.html#cfn-quicksight-template-pivottableoptions-columnnamesvisibility
         */
        readonly columnNamesVisibility?: string;
        /**
         * The default cell width of the pivot table.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableoptions.html#cfn-quicksight-template-pivottableoptions-defaultcellwidth
         */
        readonly defaultCellWidth?: string;
        /**
         * The metric placement (row, column) options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableoptions.html#cfn-quicksight-template-pivottableoptions-metricplacement
         */
        readonly metricPlacement?: string;
        /**
         * The row alternate color options (widget status, row alternate colors).
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableoptions.html#cfn-quicksight-template-pivottableoptions-rowalternatecoloroptions
         */
        readonly rowAlternateColorOptions?: cdk.IResolvable | CfnTemplate.RowAlternateColorOptionsProperty;
        /**
         * The table cell style of row field names.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableoptions.html#cfn-quicksight-template-pivottableoptions-rowfieldnamesstyle
         */
        readonly rowFieldNamesStyle?: cdk.IResolvable | CfnTemplate.TableCellStyleProperty;
        /**
         * The table cell style of the row headers.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableoptions.html#cfn-quicksight-template-pivottableoptions-rowheaderstyle
         */
        readonly rowHeaderStyle?: cdk.IResolvable | CfnTemplate.TableCellStyleProperty;
        /**
         * The options for the label that is located above the row headers.
         *
         * This option is only applicable when `RowsLayout` is set to `HIERARCHY` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableoptions.html#cfn-quicksight-template-pivottableoptions-rowslabeloptions
         */
        readonly rowsLabelOptions?: cdk.IResolvable | CfnTemplate.PivotTableRowsLabelOptionsProperty;
        /**
         * The layout for the row dimension headers of a pivot table. Choose one of the following options.
         *
         * - `TABULAR` : (Default) Each row field is displayed in a separate column.
         * - `HIERARCHY` : All row fields are displayed in a single column. Indentation is used to differentiate row headers of different fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableoptions.html#cfn-quicksight-template-pivottableoptions-rowslayout
         */
        readonly rowsLayout?: string;
        /**
         * The visibility of the single metric options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableoptions.html#cfn-quicksight-template-pivottableoptions-singlemetricvisibility
         */
        readonly singleMetricVisibility?: string;
        /**
         * Determines the visibility of the pivot table.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableoptions.html#cfn-quicksight-template-pivottableoptions-togglebuttonsvisibility
         */
        readonly toggleButtonsVisibility?: string;
    }
    /**
     * The options for the label thta is located above the row headers.
     *
     * This option is only applicable when `RowsLayout` is set to `HIERARCHY` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablerowslabeloptions.html
     */
    interface PivotTableRowsLabelOptionsProperty {
        /**
         * The custom label string for the rows label.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablerowslabeloptions.html#cfn-quicksight-template-pivottablerowslabeloptions-customlabel
         */
        readonly customLabel?: string;
        /**
         * The visibility of the rows label.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablerowslabeloptions.html#cfn-quicksight-template-pivottablerowslabeloptions-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The field wells for a pivot table visual.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablefieldwells.html
     */
    interface PivotTableFieldWellsProperty {
        /**
         * The aggregated field well for the pivot table.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablefieldwells.html#cfn-quicksight-template-pivottablefieldwells-pivottableaggregatedfieldwells
         */
        readonly pivotTableAggregatedFieldWells?: cdk.IResolvable | CfnTemplate.PivotTableAggregatedFieldWellsProperty;
    }
    /**
     * The aggregated field well for the pivot table.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableaggregatedfieldwells.html
     */
    interface PivotTableAggregatedFieldWellsProperty {
        /**
         * The columns field well for a pivot table.
         *
         * Values are grouped by columns fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableaggregatedfieldwells.html#cfn-quicksight-template-pivottableaggregatedfieldwells-columns
         */
        readonly columns?: Array<CfnTemplate.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The rows field well for a pivot table.
         *
         * Values are grouped by rows fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableaggregatedfieldwells.html#cfn-quicksight-template-pivottableaggregatedfieldwells-rows
         */
        readonly rows?: Array<CfnTemplate.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The values field well for a pivot table.
         *
         * Values are aggregated based on rows and columns fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableaggregatedfieldwells.html#cfn-quicksight-template-pivottableaggregatedfieldwells-values
         */
        readonly values?: Array<cdk.IResolvable | CfnTemplate.MeasureFieldProperty> | cdk.IResolvable;
    }
    /**
     * The field options for a pivot table visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablefieldoptions.html
     */
    interface PivotTableFieldOptionsProperty {
        /**
         * The collapse state options for the pivot table field options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablefieldoptions.html#cfn-quicksight-template-pivottablefieldoptions-collapsestateoptions
         */
        readonly collapseStateOptions?: Array<cdk.IResolvable | CfnTemplate.PivotTableFieldCollapseStateOptionProperty> | cdk.IResolvable;
        /**
         * The data path options for the pivot table field options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablefieldoptions.html#cfn-quicksight-template-pivottablefieldoptions-datapathoptions
         */
        readonly dataPathOptions?: Array<cdk.IResolvable | CfnTemplate.PivotTableDataPathOptionProperty> | cdk.IResolvable;
        /**
         * The selected field options for the pivot table field options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablefieldoptions.html#cfn-quicksight-template-pivottablefieldoptions-selectedfieldoptions
         */
        readonly selectedFieldOptions?: Array<cdk.IResolvable | CfnTemplate.PivotTableFieldOptionProperty> | cdk.IResolvable;
    }
    /**
     * The collapse state options for the pivot table field options.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablefieldcollapsestateoption.html
     */
    interface PivotTableFieldCollapseStateOptionProperty {
        /**
         * The state of the field target of a pivot table. Choose one of the following options:.
         *
         * - `COLLAPSED`
         * - `EXPANDED`
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablefieldcollapsestateoption.html#cfn-quicksight-template-pivottablefieldcollapsestateoption-state
         */
        readonly state?: string;
        /**
         * A tagged-union object that sets the collapse state.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablefieldcollapsestateoption.html#cfn-quicksight-template-pivottablefieldcollapsestateoption-target
         */
        readonly target: cdk.IResolvable | CfnTemplate.PivotTableFieldCollapseStateTargetProperty;
    }
    /**
     * The target of a pivot table field collapse state.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablefieldcollapsestatetarget.html
     */
    interface PivotTableFieldCollapseStateTargetProperty {
        /**
         * The data path of the pivot table's header.
         *
         * Used to set the collapse state.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablefieldcollapsestatetarget.html#cfn-quicksight-template-pivottablefieldcollapsestatetarget-fielddatapathvalues
         */
        readonly fieldDataPathValues?: Array<CfnTemplate.DataPathValueProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The field ID of the pivot table that the collapse state needs to be set to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablefieldcollapsestatetarget.html#cfn-quicksight-template-pivottablefieldcollapsestatetarget-fieldid
         */
        readonly fieldId?: string;
    }
    /**
     * The data path options for the pivot table field options.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottabledatapathoption.html
     */
    interface PivotTableDataPathOptionProperty {
        /**
         * The list of data path values for the data path options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottabledatapathoption.html#cfn-quicksight-template-pivottabledatapathoption-datapathlist
         */
        readonly dataPathList: Array<CfnTemplate.DataPathValueProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The width of the data path option.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottabledatapathoption.html#cfn-quicksight-template-pivottabledatapathoption-width
         */
        readonly width?: string;
    }
    /**
     * The selected field options for the pivot table field options.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablefieldoption.html
     */
    interface PivotTableFieldOptionProperty {
        /**
         * The custom label of the pivot table field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablefieldoption.html#cfn-quicksight-template-pivottablefieldoption-customlabel
         */
        readonly customLabel?: string;
        /**
         * The field ID of the pivot table field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablefieldoption.html#cfn-quicksight-template-pivottablefieldoption-fieldid
         */
        readonly fieldId: string;
        /**
         * The visibility of the pivot table field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablefieldoption.html#cfn-quicksight-template-pivottablefieldoption-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The total options for a pivot table visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottabletotaloptions.html
     */
    interface PivotTableTotalOptionsProperty {
        /**
         * The column subtotal options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottabletotaloptions.html#cfn-quicksight-template-pivottabletotaloptions-columnsubtotaloptions
         */
        readonly columnSubtotalOptions?: cdk.IResolvable | CfnTemplate.SubtotalOptionsProperty;
        /**
         * The column total options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottabletotaloptions.html#cfn-quicksight-template-pivottabletotaloptions-columntotaloptions
         */
        readonly columnTotalOptions?: cdk.IResolvable | CfnTemplate.PivotTotalOptionsProperty;
        /**
         * The row subtotal options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottabletotaloptions.html#cfn-quicksight-template-pivottabletotaloptions-rowsubtotaloptions
         */
        readonly rowSubtotalOptions?: cdk.IResolvable | CfnTemplate.SubtotalOptionsProperty;
        /**
         * The row total options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottabletotaloptions.html#cfn-quicksight-template-pivottabletotaloptions-rowtotaloptions
         */
        readonly rowTotalOptions?: cdk.IResolvable | CfnTemplate.PivotTotalOptionsProperty;
    }
    /**
     * The subtotal options.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-subtotaloptions.html
     */
    interface SubtotalOptionsProperty {
        /**
         * The custom label string for the subtotal cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-subtotaloptions.html#cfn-quicksight-template-subtotaloptions-customlabel
         */
        readonly customLabel?: string;
        /**
         * The field level (all, custom, last) for the subtotal cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-subtotaloptions.html#cfn-quicksight-template-subtotaloptions-fieldlevel
         */
        readonly fieldLevel?: string;
        /**
         * The optional configuration of subtotal cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-subtotaloptions.html#cfn-quicksight-template-subtotaloptions-fieldleveloptions
         */
        readonly fieldLevelOptions?: Array<cdk.IResolvable | CfnTemplate.PivotTableFieldSubtotalOptionsProperty> | cdk.IResolvable;
        /**
         * The cell styling options for the subtotals of header cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-subtotaloptions.html#cfn-quicksight-template-subtotaloptions-metricheadercellstyle
         */
        readonly metricHeaderCellStyle?: cdk.IResolvable | CfnTemplate.TableCellStyleProperty;
        /**
         * The style targets options for subtotals.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-subtotaloptions.html#cfn-quicksight-template-subtotaloptions-styletargets
         */
        readonly styleTargets?: Array<cdk.IResolvable | CfnTemplate.TableStyleTargetProperty> | cdk.IResolvable;
        /**
         * The cell styling options for the subtotal cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-subtotaloptions.html#cfn-quicksight-template-subtotaloptions-totalcellstyle
         */
        readonly totalCellStyle?: cdk.IResolvable | CfnTemplate.TableCellStyleProperty;
        /**
         * The visibility configuration for the subtotal cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-subtotaloptions.html#cfn-quicksight-template-subtotaloptions-totalsvisibility
         */
        readonly totalsVisibility?: string;
        /**
         * The cell styling options for the subtotals of value cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-subtotaloptions.html#cfn-quicksight-template-subtotaloptions-valuecellstyle
         */
        readonly valueCellStyle?: cdk.IResolvable | CfnTemplate.TableCellStyleProperty;
    }
    /**
     * The optional configuration of subtotals cells.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablefieldsubtotaloptions.html
     */
    interface PivotTableFieldSubtotalOptionsProperty {
        /**
         * The field ID of the subtotal options.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablefieldsubtotaloptions.html#cfn-quicksight-template-pivottablefieldsubtotaloptions-fieldid
         */
        readonly fieldId?: string;
    }
    /**
     * The table style target.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablestyletarget.html
     */
    interface TableStyleTargetProperty {
        /**
         * The cell type of the table style target.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablestyletarget.html#cfn-quicksight-template-tablestyletarget-celltype
         */
        readonly cellType: string;
    }
    /**
     * The optional configuration of totals cells in a `PivotTableVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottotaloptions.html
     */
    interface PivotTotalOptionsProperty {
        /**
         * The custom label string for the total cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottotaloptions.html#cfn-quicksight-template-pivottotaloptions-customlabel
         */
        readonly customLabel?: string;
        /**
         * The cell styling options for the total of header cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottotaloptions.html#cfn-quicksight-template-pivottotaloptions-metricheadercellstyle
         */
        readonly metricHeaderCellStyle?: cdk.IResolvable | CfnTemplate.TableCellStyleProperty;
        /**
         * The placement (start, end) for the total cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottotaloptions.html#cfn-quicksight-template-pivottotaloptions-placement
         */
        readonly placement?: string;
        /**
         * The scroll status (pinned, scrolled) for the total cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottotaloptions.html#cfn-quicksight-template-pivottotaloptions-scrollstatus
         */
        readonly scrollStatus?: string;
        /**
         * The total aggregation options for each value field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottotaloptions.html#cfn-quicksight-template-pivottotaloptions-totalaggregationoptions
         */
        readonly totalAggregationOptions?: Array<cdk.IResolvable | CfnTemplate.TotalAggregationOptionProperty> | cdk.IResolvable;
        /**
         * The cell styling options for the total cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottotaloptions.html#cfn-quicksight-template-pivottotaloptions-totalcellstyle
         */
        readonly totalCellStyle?: cdk.IResolvable | CfnTemplate.TableCellStyleProperty;
        /**
         * The visibility configuration for the total cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottotaloptions.html#cfn-quicksight-template-pivottotaloptions-totalsvisibility
         */
        readonly totalsVisibility?: string;
        /**
         * The cell styling options for the totals of value cells.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottotaloptions.html#cfn-quicksight-template-pivottotaloptions-valuecellstyle
         */
        readonly valueCellStyle?: cdk.IResolvable | CfnTemplate.TableCellStyleProperty;
    }
    /**
     * A geospatial map or a points on map visual.
     *
     * For more information, see [Creating point maps](https://docs.aws.amazon.com/quicksight/latest/user/point-maps.html) in the *Amazon QuickSight User Guide* .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapvisual.html
     */
    interface GeospatialMapVisualProperty {
        /**
         * The list of custom actions that are configured for a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapvisual.html#cfn-quicksight-template-geospatialmapvisual-actions
         */
        readonly actions?: Array<cdk.IResolvable | CfnTemplate.VisualCustomActionProperty> | cdk.IResolvable;
        /**
         * The configuration settings of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapvisual.html#cfn-quicksight-template-geospatialmapvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnTemplate.GeospatialMapConfigurationProperty | cdk.IResolvable;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapvisual.html#cfn-quicksight-template-geospatialmapvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnTemplate.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The subtitle that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapvisual.html#cfn-quicksight-template-geospatialmapvisual-subtitle
         */
        readonly subtitle?: cdk.IResolvable | CfnTemplate.VisualSubtitleLabelOptionsProperty;
        /**
         * The title that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapvisual.html#cfn-quicksight-template-geospatialmapvisual-title
         */
        readonly title?: cdk.IResolvable | CfnTemplate.VisualTitleLabelOptionsProperty;
        /**
         * The unique identifier of a visual.
         *
         * This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapvisual.html#cfn-quicksight-template-geospatialmapvisual-visualid
         */
        readonly visualId: string;
    }
    /**
     * The configuration of a `GeospatialMapVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapconfiguration.html
     */
    interface GeospatialMapConfigurationProperty {
        /**
         * The field wells of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapconfiguration.html#cfn-quicksight-template-geospatialmapconfiguration-fieldwells
         */
        readonly fieldWells?: CfnTemplate.GeospatialMapFieldWellsProperty | cdk.IResolvable;
        /**
         * The legend display setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapconfiguration.html#cfn-quicksight-template-geospatialmapconfiguration-legend
         */
        readonly legend?: cdk.IResolvable | CfnTemplate.LegendOptionsProperty;
        /**
         * The map style options of the geospatial map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapconfiguration.html#cfn-quicksight-template-geospatialmapconfiguration-mapstyleoptions
         */
        readonly mapStyleOptions?: CfnTemplate.GeospatialMapStyleOptionsProperty | cdk.IResolvable;
        /**
         * The point style options of the geospatial map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapconfiguration.html#cfn-quicksight-template-geospatialmapconfiguration-pointstyleoptions
         */
        readonly pointStyleOptions?: CfnTemplate.GeospatialPointStyleOptionsProperty | cdk.IResolvable;
        /**
         * The tooltip display setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapconfiguration.html#cfn-quicksight-template-geospatialmapconfiguration-tooltip
         */
        readonly tooltip?: cdk.IResolvable | CfnTemplate.TooltipOptionsProperty;
        /**
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapconfiguration.html#cfn-quicksight-template-geospatialmapconfiguration-visualpalette
         */
        readonly visualPalette?: cdk.IResolvable | CfnTemplate.VisualPaletteProperty;
        /**
         * The window options of the geospatial map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapconfiguration.html#cfn-quicksight-template-geospatialmapconfiguration-windowoptions
         */
        readonly windowOptions?: CfnTemplate.GeospatialWindowOptionsProperty | cdk.IResolvable;
    }
    /**
     * The field wells of a `GeospatialMapVisual` .
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapfieldwells.html
     */
    interface GeospatialMapFieldWellsProperty {
        /**
         * The aggregated field well for a geospatial map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapfieldwells.html#cfn-quicksight-template-geospatialmapfieldwells-geospatialmapaggregatedfieldwells
         */
        readonly geospatialMapAggregatedFieldWells?: CfnTemplate.GeospatialMapAggregatedFieldWellsProperty | cdk.IResolvable;
    }
    /**
     * The aggregated field wells for a geospatial map.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapaggregatedfieldwells.html
     */
    interface GeospatialMapAggregatedFieldWellsProperty {
        /**
         * The color field wells of a geospatial map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapaggregatedfieldwells.html#cfn-quicksight-template-geospatialmapaggregatedfieldwells-colors
         */
        readonly colors?: Array<CfnTemplate.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The geospatial field wells of a geospatial map.
         *
         * Values are grouped by geospatial fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapaggregatedfieldwells.html#cfn-quicksight-template-geospatialmapaggregatedfieldwells-geospatial
         */
        readonly geospatial?: Array<CfnTemplate.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The size field wells of a geospatial map.
         *
         * Values are aggregated based on geospatial fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapaggregatedfieldwells.html#cfn-quicksight-template-geospatialmapaggregatedfieldwells-values
         */
        readonly values?: Array<cdk.IResolvable | CfnTemplate.MeasureFieldProperty> | cdk.IResolvable;
    }
    /**
     * The point style of the geospatial map.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialpointstyleoptions.html
     */
    interface GeospatialPointStyleOptionsProperty {
        /**
         * The cluster marker configuration of the geospatial point style.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialpointstyleoptions.html#cfn-quicksight-template-geospatialpointstyleoptions-clustermarkerconfiguration
         */
        readonly clusterMarkerConfiguration?: CfnTemplate.ClusterMarkerConfigurationProperty | cdk.IResolvable;
        /**
         * The heatmap configuration of the geospatial point style.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialpointstyleoptions.html#cfn-quicksight-template-geospatialpointstyleoptions-heatmapconfiguration
         */
        readonly heatmapConfiguration?: CfnTemplate.GeospatialHeatmapConfigurationProperty | cdk.IResolvable;
        /**
         * The selected point styles (point, cluster) of the geospatial map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialpointstyleoptions.html#cfn-quicksight-template-geospatialpointstyleoptions-selectedpointstyle
         */
        readonly selectedPointStyle?: string;
    }
    /**
     * The cluster marker configuration of the geospatial map selected point style.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-clustermarkerconfiguration.html
     */
    interface ClusterMarkerConfigurationProperty {
        /**
         * The cluster marker that is a part of the cluster marker configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-clustermarkerconfiguration.html#cfn-quicksight-template-clustermarkerconfiguration-clustermarker
         */
        readonly clusterMarker?: CfnTemplate.ClusterMarkerProperty | cdk.IResolvable;
    }
    /**
     * The cluster marker that is a part of the cluster marker configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-clustermarker.html
     */
    interface ClusterMarkerProperty {
        /**
         * The simple cluster marker of the cluster marker.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-clustermarker.html#cfn-quicksight-template-clustermarker-simpleclustermarker
         */
        readonly simpleClusterMarker?: cdk.IResolvable | CfnTemplate.SimpleClusterMarkerProperty;
    }
    /**
     * The simple cluster marker of the cluster marker.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-simpleclustermarker.html
     */
    interface SimpleClusterMarkerProperty {
        /**
         * The color of the simple cluster marker.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-simpleclustermarker.html#cfn-quicksight-template-simpleclustermarker-color
         */
        readonly color?: string;
    }
    /**
     * The heatmap configuration of the geospatial point style.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialheatmapconfiguration.html
     */
    interface GeospatialHeatmapConfigurationProperty {
        /**
         * The color scale specification for the heatmap point style.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialheatmapconfiguration.html#cfn-quicksight-template-geospatialheatmapconfiguration-heatmapcolor
         */
        readonly heatmapColor?: CfnTemplate.GeospatialHeatmapColorScaleProperty | cdk.IResolvable;
    }
    /**
     * The color scale specification for the heatmap point style.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialheatmapcolorscale.html
     */
    interface GeospatialHeatmapColorScaleProperty {
        /**
         * The list of colors to be used in heatmap point style.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialheatmapcolorscale.html#cfn-quicksight-template-geospatialheatmapcolorscale-colors
         */
        readonly colors?: Array<CfnTemplate.GeospatialHeatmapDataColorProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * The color to be used in the heatmap point style.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialheatmapdatacolor.html
     */
    interface GeospatialHeatmapDataColorProperty {
        /**
         * The hex color to be used in the heatmap point style.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialheatmapdatacolor.html#cfn-quicksight-template-geospatialheatmapdatacolor-color
         */
        readonly color: string;
    }
    /**
     * A bar chart.
     *
     * The `BarChartVisual` structure describes a visual that is a member of the bar chart family. The following charts can be described using this structure:
     *
     * - Horizontal bar chart
     * - Vertical bar chart
     * - Horizontal stacked bar chart
     * - Vertical stacked bar chart
     * - Horizontal stacked 100% bar chart
     * - Vertical stacked 100% bar chart
     *
     * For more information, see [Using bar charts](https://docs.aws.amazon.com/quicksight/latest/user/bar-charts.html) in the *Amazon QuickSight User Guide* .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartvisual.html
     */
    interface BarChartVisualProperty {
        /**
         * The list of custom actions that are configured for a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartvisual.html#cfn-quicksight-template-barchartvisual-actions
         */
        readonly actions?: Array<cdk.IResolvable | CfnTemplate.VisualCustomActionProperty> | cdk.IResolvable;
        /**
         * The configuration settings of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartvisual.html#cfn-quicksight-template-barchartvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnTemplate.BarChartConfigurationProperty | cdk.IResolvable;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartvisual.html#cfn-quicksight-template-barchartvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnTemplate.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The subtitle that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartvisual.html#cfn-quicksight-template-barchartvisual-subtitle
         */
        readonly subtitle?: cdk.IResolvable | CfnTemplate.VisualSubtitleLabelOptionsProperty;
        /**
         * The title that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartvisual.html#cfn-quicksight-template-barchartvisual-title
         */
        readonly title?: cdk.IResolvable | CfnTemplate.VisualTitleLabelOptionsProperty;
        /**
         * The unique identifier of a visual.
         *
         * This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartvisual.html#cfn-quicksight-template-barchartvisual-visualid
         */
        readonly visualId: string;
    }
    /**
     * The configuration of a `BarChartVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html
     */
    interface BarChartConfigurationProperty {
        /**
         * Determines the arrangement of the bars.
         *
         * The orientation and arrangement of bars determine the type of bar that is used in the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-barsarrangement
         */
        readonly barsArrangement?: string;
        /**
         * The label display options (grid line, range, scale, axis step) for bar chart category.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-categoryaxis
         */
        readonly categoryAxis?: CfnTemplate.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * The label options (label text, label visibility and sort icon visibility) for a bar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-categorylabeloptions
         */
        readonly categoryLabelOptions?: CfnTemplate.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The label options (label text, label visibility and sort icon visibility) for a color that is used in a bar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-colorlabeloptions
         */
        readonly colorLabelOptions?: CfnTemplate.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The contribution analysis (anomaly configuration) setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-contributionanalysisdefaults
         */
        readonly contributionAnalysisDefaults?: Array<CfnTemplate.ContributionAnalysisDefaultProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The options that determine if visual data labels are displayed.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-datalabels
         */
        readonly dataLabels?: CfnTemplate.DataLabelOptionsProperty | cdk.IResolvable;
        /**
         * The field wells of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-fieldwells
         */
        readonly fieldWells?: CfnTemplate.BarChartFieldWellsProperty | cdk.IResolvable;
        /**
         * The legend display setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-legend
         */
        readonly legend?: cdk.IResolvable | CfnTemplate.LegendOptionsProperty;
        /**
         * The orientation of the bars in a bar chart visual. There are two valid values in this structure:.
         *
         * - `HORIZONTAL` : Used for charts that have horizontal bars. Visuals that use this value are horizontal bar charts, horizontal stacked bar charts, and horizontal stacked 100% bar charts.
         * - `VERTICAL` : Used for charts that have vertical bars. Visuals that use this value are vertical bar charts, vertical stacked bar charts, and vertical stacked 100% bar charts.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-orientation
         */
        readonly orientation?: string;
        /**
         * The reference line setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-referencelines
         */
        readonly referenceLines?: Array<cdk.IResolvable | CfnTemplate.ReferenceLineProperty> | cdk.IResolvable;
        /**
         * The small multiples setup for the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-smallmultiplesoptions
         */
        readonly smallMultiplesOptions?: cdk.IResolvable | CfnTemplate.SmallMultiplesOptionsProperty;
        /**
         * The sort configuration of a `BarChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: CfnTemplate.BarChartSortConfigurationProperty | cdk.IResolvable;
        /**
         * The tooltip display setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-tooltip
         */
        readonly tooltip?: cdk.IResolvable | CfnTemplate.TooltipOptionsProperty;
        /**
         * The label display options (grid line, range, scale, axis step) for a bar chart value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-valueaxis
         */
        readonly valueAxis?: CfnTemplate.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * The label options (label text, label visibility and sort icon visibility) for a bar chart value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-valuelabeloptions
         */
        readonly valueLabelOptions?: CfnTemplate.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The palette (chart color) display setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-visualpalette
         */
        readonly visualPalette?: cdk.IResolvable | CfnTemplate.VisualPaletteProperty;
    }
    /**
     * sort-configuration-description.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartsortconfiguration.html
     */
    interface BarChartSortConfigurationProperty {
        /**
         * The limit on the number of categories displayed in a bar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartsortconfiguration.html#cfn-quicksight-template-barchartsortconfiguration-categoryitemslimit
         */
        readonly categoryItemsLimit?: cdk.IResolvable | CfnTemplate.ItemsLimitConfigurationProperty;
        /**
         * The sort configuration of category fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartsortconfiguration.html#cfn-quicksight-template-barchartsortconfiguration-categorysort
         */
        readonly categorySort?: Array<CfnTemplate.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The limit on the number of values displayed in a bar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartsortconfiguration.html#cfn-quicksight-template-barchartsortconfiguration-coloritemslimit
         */
        readonly colorItemsLimit?: cdk.IResolvable | CfnTemplate.ItemsLimitConfigurationProperty;
        /**
         * The sort configuration of color fields in a bar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartsortconfiguration.html#cfn-quicksight-template-barchartsortconfiguration-colorsort
         */
        readonly colorSort?: Array<CfnTemplate.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The limit on the number of small multiples panels that are displayed.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartsortconfiguration.html#cfn-quicksight-template-barchartsortconfiguration-smallmultipleslimitconfiguration
         */
        readonly smallMultiplesLimitConfiguration?: cdk.IResolvable | CfnTemplate.ItemsLimitConfigurationProperty;
        /**
         * The sort configuration of the small multiples field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartsortconfiguration.html#cfn-quicksight-template-barchartsortconfiguration-smallmultiplessort
         */
        readonly smallMultiplesSort?: Array<CfnTemplate.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * The field wells of a `BarChartVisual` .
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartfieldwells.html
     */
    interface BarChartFieldWellsProperty {
        /**
         * The aggregated field wells of a bar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartfieldwells.html#cfn-quicksight-template-barchartfieldwells-barchartaggregatedfieldwells
         */
        readonly barChartAggregatedFieldWells?: CfnTemplate.BarChartAggregatedFieldWellsProperty | cdk.IResolvable;
    }
    /**
     * The aggregated field wells of a bar chart.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartaggregatedfieldwells.html
     */
    interface BarChartAggregatedFieldWellsProperty {
        /**
         * The category (y-axis) field well of a bar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartaggregatedfieldwells.html#cfn-quicksight-template-barchartaggregatedfieldwells-category
         */
        readonly category?: Array<CfnTemplate.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The color (group/color) field well of a bar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartaggregatedfieldwells.html#cfn-quicksight-template-barchartaggregatedfieldwells-colors
         */
        readonly colors?: Array<CfnTemplate.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The small multiples field well of a bar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartaggregatedfieldwells.html#cfn-quicksight-template-barchartaggregatedfieldwells-smallmultiples
         */
        readonly smallMultiples?: Array<CfnTemplate.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The value field wells of a bar chart.
         *
         * Values are aggregated by category.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartaggregatedfieldwells.html#cfn-quicksight-template-barchartaggregatedfieldwells-values
         */
        readonly values?: Array<cdk.IResolvable | CfnTemplate.MeasureFieldProperty> | cdk.IResolvable;
    }
    /**
     * A scatter plot.
     *
     * For more information, see [Using scatter plots](https://docs.aws.amazon.com/quicksight/latest/user/scatter-plot.html) in the *Amazon QuickSight User Guide* .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotvisual.html
     */
    interface ScatterPlotVisualProperty {
        /**
         * The list of custom actions that are configured for a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotvisual.html#cfn-quicksight-template-scatterplotvisual-actions
         */
        readonly actions?: Array<cdk.IResolvable | CfnTemplate.VisualCustomActionProperty> | cdk.IResolvable;
        /**
         * The configuration settings of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotvisual.html#cfn-quicksight-template-scatterplotvisual-chartconfiguration
         */
        readonly chartConfiguration?: cdk.IResolvable | CfnTemplate.ScatterPlotConfigurationProperty;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotvisual.html#cfn-quicksight-template-scatterplotvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnTemplate.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The subtitle that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotvisual.html#cfn-quicksight-template-scatterplotvisual-subtitle
         */
        readonly subtitle?: cdk.IResolvable | CfnTemplate.VisualSubtitleLabelOptionsProperty;
        /**
         * The title that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotvisual.html#cfn-quicksight-template-scatterplotvisual-title
         */
        readonly title?: cdk.IResolvable | CfnTemplate.VisualTitleLabelOptionsProperty;
        /**
         * The unique identifier of a visual.
         *
         * This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotvisual.html#cfn-quicksight-template-scatterplotvisual-visualid
         */
        readonly visualId: string;
    }
    /**
     * The configuration of a scatter plot.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotconfiguration.html
     */
    interface ScatterPlotConfigurationProperty {
        /**
         * The options that determine if visual data labels are displayed.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotconfiguration.html#cfn-quicksight-template-scatterplotconfiguration-datalabels
         */
        readonly dataLabels?: CfnTemplate.DataLabelOptionsProperty | cdk.IResolvable;
        /**
         * The field wells of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotconfiguration.html#cfn-quicksight-template-scatterplotconfiguration-fieldwells
         */
        readonly fieldWells?: cdk.IResolvable | CfnTemplate.ScatterPlotFieldWellsProperty;
        /**
         * The legend display setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotconfiguration.html#cfn-quicksight-template-scatterplotconfiguration-legend
         */
        readonly legend?: cdk.IResolvable | CfnTemplate.LegendOptionsProperty;
        /**
         * The legend display setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotconfiguration.html#cfn-quicksight-template-scatterplotconfiguration-tooltip
         */
        readonly tooltip?: cdk.IResolvable | CfnTemplate.TooltipOptionsProperty;
        /**
         * The palette (chart color) display setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotconfiguration.html#cfn-quicksight-template-scatterplotconfiguration-visualpalette
         */
        readonly visualPalette?: cdk.IResolvable | CfnTemplate.VisualPaletteProperty;
        /**
         * The label display options (grid line, range, scale, and axis step) of the scatter plot's x-axis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotconfiguration.html#cfn-quicksight-template-scatterplotconfiguration-xaxisdisplayoptions
         */
        readonly xAxisDisplayOptions?: CfnTemplate.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * The label options (label text, label visibility, and sort icon visibility) of the scatter plot's x-axis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotconfiguration.html#cfn-quicksight-template-scatterplotconfiguration-xaxislabeloptions
         */
        readonly xAxisLabelOptions?: CfnTemplate.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The label display options (grid line, range, scale, and axis step) of the scatter plot's y-axis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotconfiguration.html#cfn-quicksight-template-scatterplotconfiguration-yaxisdisplayoptions
         */
        readonly yAxisDisplayOptions?: CfnTemplate.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * The label options (label text, label visibility, and sort icon visibility) of the scatter plot's y-axis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotconfiguration.html#cfn-quicksight-template-scatterplotconfiguration-yaxislabeloptions
         */
        readonly yAxisLabelOptions?: CfnTemplate.ChartAxisLabelOptionsProperty | cdk.IResolvable;
    }
    /**
     * The field well configuration of a scatter plot.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotfieldwells.html
     */
    interface ScatterPlotFieldWellsProperty {
        /**
         * The aggregated field wells of a scatter plot.
         *
         * The x and y-axes of scatter plots with aggregated field wells are aggregated by category, label, or both.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotfieldwells.html#cfn-quicksight-template-scatterplotfieldwells-scatterplotcategoricallyaggregatedfieldwells
         */
        readonly scatterPlotCategoricallyAggregatedFieldWells?: cdk.IResolvable | CfnTemplate.ScatterPlotCategoricallyAggregatedFieldWellsProperty;
        /**
         * The unaggregated field wells of a scatter plot.
         *
         * The x and y-axes of these scatter plots are unaggregated.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotfieldwells.html#cfn-quicksight-template-scatterplotfieldwells-scatterplotunaggregatedfieldwells
         */
        readonly scatterPlotUnaggregatedFieldWells?: cdk.IResolvable | CfnTemplate.ScatterPlotUnaggregatedFieldWellsProperty;
    }
    /**
     * The unaggregated field wells of a scatter plot.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotunaggregatedfieldwells.html
     */
    interface ScatterPlotUnaggregatedFieldWellsProperty {
        /**
         * The category field well of a scatter plot.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotunaggregatedfieldwells.html#cfn-quicksight-template-scatterplotunaggregatedfieldwells-category
         */
        readonly category?: Array<CfnTemplate.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The label field well of a scatter plot.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotunaggregatedfieldwells.html#cfn-quicksight-template-scatterplotunaggregatedfieldwells-label
         */
        readonly label?: Array<CfnTemplate.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The size field well of a scatter plot.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotunaggregatedfieldwells.html#cfn-quicksight-template-scatterplotunaggregatedfieldwells-size
         */
        readonly size?: Array<cdk.IResolvable | CfnTemplate.MeasureFieldProperty> | cdk.IResolvable;
        /**
         * The x-axis field well of a scatter plot.
         *
         * The x-axis is a dimension field and cannot be aggregated.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotunaggregatedfieldwells.html#cfn-quicksight-template-scatterplotunaggregatedfieldwells-xaxis
         */
        readonly xAxis?: Array<CfnTemplate.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The y-axis field well of a scatter plot.
         *
         * The y-axis is a dimension field and cannot be aggregated.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotunaggregatedfieldwells.html#cfn-quicksight-template-scatterplotunaggregatedfieldwells-yaxis
         */
        readonly yAxis?: Array<CfnTemplate.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * The aggregated field well of a scatter plot.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotcategoricallyaggregatedfieldwells.html
     */
    interface ScatterPlotCategoricallyAggregatedFieldWellsProperty {
        /**
         * The category field well of a scatter plot.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotcategoricallyaggregatedfieldwells.html#cfn-quicksight-template-scatterplotcategoricallyaggregatedfieldwells-category
         */
        readonly category?: Array<CfnTemplate.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The label field well of a scatter plot.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotcategoricallyaggregatedfieldwells.html#cfn-quicksight-template-scatterplotcategoricallyaggregatedfieldwells-label
         */
        readonly label?: Array<CfnTemplate.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The size field well of a scatter plot.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotcategoricallyaggregatedfieldwells.html#cfn-quicksight-template-scatterplotcategoricallyaggregatedfieldwells-size
         */
        readonly size?: Array<cdk.IResolvable | CfnTemplate.MeasureFieldProperty> | cdk.IResolvable;
        /**
         * The x-axis field well of a scatter plot.
         *
         * The x-axis is aggregated by category.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotcategoricallyaggregatedfieldwells.html#cfn-quicksight-template-scatterplotcategoricallyaggregatedfieldwells-xaxis
         */
        readonly xAxis?: Array<cdk.IResolvable | CfnTemplate.MeasureFieldProperty> | cdk.IResolvable;
        /**
         * The y-axis field well of a scatter plot.
         *
         * The y-axis is aggregated by category.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotcategoricallyaggregatedfieldwells.html#cfn-quicksight-template-scatterplotcategoricallyaggregatedfieldwells-yaxis
         */
        readonly yAxis?: Array<cdk.IResolvable | CfnTemplate.MeasureFieldProperty> | cdk.IResolvable;
    }
    /**
     * A radar chart visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartvisual.html
     */
    interface RadarChartVisualProperty {
        /**
         * The list of custom actions that are configured for a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartvisual.html#cfn-quicksight-template-radarchartvisual-actions
         */
        readonly actions?: Array<cdk.IResolvable | CfnTemplate.VisualCustomActionProperty> | cdk.IResolvable;
        /**
         * The configuration settings of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartvisual.html#cfn-quicksight-template-radarchartvisual-chartconfiguration
         */
        readonly chartConfiguration?: cdk.IResolvable | CfnTemplate.RadarChartConfigurationProperty;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartvisual.html#cfn-quicksight-template-radarchartvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnTemplate.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The subtitle that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartvisual.html#cfn-quicksight-template-radarchartvisual-subtitle
         */
        readonly subtitle?: cdk.IResolvable | CfnTemplate.VisualSubtitleLabelOptionsProperty;
        /**
         * The title that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartvisual.html#cfn-quicksight-template-radarchartvisual-title
         */
        readonly title?: cdk.IResolvable | CfnTemplate.VisualTitleLabelOptionsProperty;
        /**
         * The unique identifier of a visual.
         *
         * This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartvisual.html#cfn-quicksight-template-radarchartvisual-visualid
         */
        readonly visualId: string;
    }
    /**
     * The configuration of a `RadarChartVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html
     */
    interface RadarChartConfigurationProperty {
        /**
         * Determines the visibility of the colors of alternatign bands in a radar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html#cfn-quicksight-template-radarchartconfiguration-alternatebandcolorsvisibility
         */
        readonly alternateBandColorsVisibility?: string;
        /**
         * The color of the even-numbered alternate bands of a radar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html#cfn-quicksight-template-radarchartconfiguration-alternatebandevencolor
         */
        readonly alternateBandEvenColor?: string;
        /**
         * The color of the odd-numbered alternate bands of a radar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html#cfn-quicksight-template-radarchartconfiguration-alternatebandoddcolor
         */
        readonly alternateBandOddColor?: string;
        /**
         * The axis behavior options of a radar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html#cfn-quicksight-template-radarchartconfiguration-axesrangescale
         */
        readonly axesRangeScale?: string;
        /**
         * The base sreies settings of a radar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html#cfn-quicksight-template-radarchartconfiguration-baseseriessettings
         */
        readonly baseSeriesSettings?: cdk.IResolvable | CfnTemplate.RadarChartSeriesSettingsProperty;
        /**
         * The category axis of a radar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html#cfn-quicksight-template-radarchartconfiguration-categoryaxis
         */
        readonly categoryAxis?: CfnTemplate.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * The category label options of a radar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html#cfn-quicksight-template-radarchartconfiguration-categorylabeloptions
         */
        readonly categoryLabelOptions?: CfnTemplate.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The color axis of a radar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html#cfn-quicksight-template-radarchartconfiguration-coloraxis
         */
        readonly colorAxis?: CfnTemplate.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * The color label options of a radar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html#cfn-quicksight-template-radarchartconfiguration-colorlabeloptions
         */
        readonly colorLabelOptions?: CfnTemplate.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The field well configuration of a `RadarChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html#cfn-quicksight-template-radarchartconfiguration-fieldwells
         */
        readonly fieldWells?: cdk.IResolvable | CfnTemplate.RadarChartFieldWellsProperty;
        /**
         * The legend display setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html#cfn-quicksight-template-radarchartconfiguration-legend
         */
        readonly legend?: cdk.IResolvable | CfnTemplate.LegendOptionsProperty;
        /**
         * The shape of the radar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html#cfn-quicksight-template-radarchartconfiguration-shape
         */
        readonly shape?: string;
        /**
         * The sort configuration of a `RadarChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html#cfn-quicksight-template-radarchartconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: cdk.IResolvable | CfnTemplate.RadarChartSortConfigurationProperty;
        /**
         * The start angle of a radar chart's axis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html#cfn-quicksight-template-radarchartconfiguration-startangle
         */
        readonly startAngle?: number;
        /**
         * The palette (chart color) display setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html#cfn-quicksight-template-radarchartconfiguration-visualpalette
         */
        readonly visualPalette?: cdk.IResolvable | CfnTemplate.VisualPaletteProperty;
    }
    /**
     * The sort configuration of a `RadarChartVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartsortconfiguration.html
     */
    interface RadarChartSortConfigurationProperty {
        /**
         * The category items limit for a radar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartsortconfiguration.html#cfn-quicksight-template-radarchartsortconfiguration-categoryitemslimit
         */
        readonly categoryItemsLimit?: cdk.IResolvable | CfnTemplate.ItemsLimitConfigurationProperty;
        /**
         * The category sort options of a radar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartsortconfiguration.html#cfn-quicksight-template-radarchartsortconfiguration-categorysort
         */
        readonly categorySort?: Array<CfnTemplate.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The color items limit of a radar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartsortconfiguration.html#cfn-quicksight-template-radarchartsortconfiguration-coloritemslimit
         */
        readonly colorItemsLimit?: cdk.IResolvable | CfnTemplate.ItemsLimitConfigurationProperty;
        /**
         * The color sort configuration of a radar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartsortconfiguration.html#cfn-quicksight-template-radarchartsortconfiguration-colorsort
         */
        readonly colorSort?: Array<CfnTemplate.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * The series settings of a radar chart.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartseriessettings.html
     */
    interface RadarChartSeriesSettingsProperty {
        /**
         * The area style settings of a radar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartseriessettings.html#cfn-quicksight-template-radarchartseriessettings-areastylesettings
         */
        readonly areaStyleSettings?: cdk.IResolvable | CfnTemplate.RadarChartAreaStyleSettingsProperty;
    }
    /**
     * The configured style settings of a radar chart.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartareastylesettings.html
     */
    interface RadarChartAreaStyleSettingsProperty {
        /**
         * The visibility settings of a radar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartareastylesettings.html#cfn-quicksight-template-radarchartareastylesettings-visibility
         */
        readonly visibility?: string;
    }
    /**
     * The field wells of a radar chart visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartfieldwells.html
     */
    interface RadarChartFieldWellsProperty {
        /**
         * The aggregated field wells of a radar chart visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartfieldwells.html#cfn-quicksight-template-radarchartfieldwells-radarchartaggregatedfieldwells
         */
        readonly radarChartAggregatedFieldWells?: cdk.IResolvable | CfnTemplate.RadarChartAggregatedFieldWellsProperty;
    }
    /**
     * The aggregated field well configuration of a `RadarChartVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartaggregatedfieldwells.html
     */
    interface RadarChartAggregatedFieldWellsProperty {
        /**
         * The aggregated field well categories of a radar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartaggregatedfieldwells.html#cfn-quicksight-template-radarchartaggregatedfieldwells-category
         */
        readonly category?: Array<CfnTemplate.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The color that are assigned to the aggregated field wells of a radar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartaggregatedfieldwells.html#cfn-quicksight-template-radarchartaggregatedfieldwells-color
         */
        readonly color?: Array<CfnTemplate.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The values that are assigned to the aggregated field wells of a radar chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartaggregatedfieldwells.html#cfn-quicksight-template-radarchartaggregatedfieldwells-values
         */
        readonly values?: Array<cdk.IResolvable | CfnTemplate.MeasureFieldProperty> | cdk.IResolvable;
    }
    /**
     * A heat map.
     *
     * For more information, see [Using heat maps](https://docs.aws.amazon.com/quicksight/latest/user/heat-map.html) in the *Amazon QuickSight User Guide* .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapvisual.html
     */
    interface HeatMapVisualProperty {
        /**
         * The list of custom actions that are configured for a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapvisual.html#cfn-quicksight-template-heatmapvisual-actions
         */
        readonly actions?: Array<cdk.IResolvable | CfnTemplate.VisualCustomActionProperty> | cdk.IResolvable;
        /**
         * The configuration of a heat map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapvisual.html#cfn-quicksight-template-heatmapvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnTemplate.HeatMapConfigurationProperty | cdk.IResolvable;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapvisual.html#cfn-quicksight-template-heatmapvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnTemplate.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The subtitle that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapvisual.html#cfn-quicksight-template-heatmapvisual-subtitle
         */
        readonly subtitle?: cdk.IResolvable | CfnTemplate.VisualSubtitleLabelOptionsProperty;
        /**
         * The title that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapvisual.html#cfn-quicksight-template-heatmapvisual-title
         */
        readonly title?: cdk.IResolvable | CfnTemplate.VisualTitleLabelOptionsProperty;
        /**
         * The unique identifier of a visual.
         *
         * This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapvisual.html#cfn-quicksight-template-heatmapvisual-visualid
         */
        readonly visualId: string;
    }
    /**
     * The configuration of a heat map.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapconfiguration.html
     */
    interface HeatMapConfigurationProperty {
        /**
         * The color options (gradient color, point of divergence) in a heat map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapconfiguration.html#cfn-quicksight-template-heatmapconfiguration-colorscale
         */
        readonly colorScale?: CfnTemplate.ColorScaleProperty | cdk.IResolvable;
        /**
         * The label options of the column that is displayed in a heat map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapconfiguration.html#cfn-quicksight-template-heatmapconfiguration-columnlabeloptions
         */
        readonly columnLabelOptions?: CfnTemplate.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The options that determine if visual data labels are displayed.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapconfiguration.html#cfn-quicksight-template-heatmapconfiguration-datalabels
         */
        readonly dataLabels?: CfnTemplate.DataLabelOptionsProperty | cdk.IResolvable;
        /**
         * The field wells of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapconfiguration.html#cfn-quicksight-template-heatmapconfiguration-fieldwells
         */
        readonly fieldWells?: CfnTemplate.HeatMapFieldWellsProperty | cdk.IResolvable;
        /**
         * The legend display setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapconfiguration.html#cfn-quicksight-template-heatmapconfiguration-legend
         */
        readonly legend?: cdk.IResolvable | CfnTemplate.LegendOptionsProperty;
        /**
         * The label options of the row that is displayed in a `heat map` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapconfiguration.html#cfn-quicksight-template-heatmapconfiguration-rowlabeloptions
         */
        readonly rowLabelOptions?: CfnTemplate.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The sort configuration of a heat map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapconfiguration.html#cfn-quicksight-template-heatmapconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: CfnTemplate.HeatMapSortConfigurationProperty | cdk.IResolvable;
        /**
         * The tooltip display setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapconfiguration.html#cfn-quicksight-template-heatmapconfiguration-tooltip
         */
        readonly tooltip?: cdk.IResolvable | CfnTemplate.TooltipOptionsProperty;
    }
    /**
     * The sort configuration of a heat map.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapsortconfiguration.html
     */
    interface HeatMapSortConfigurationProperty {
        /**
         * The limit on the number of columns that are displayed in a heat map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapsortconfiguration.html#cfn-quicksight-template-heatmapsortconfiguration-heatmapcolumnitemslimitconfiguration
         */
        readonly heatMapColumnItemsLimitConfiguration?: cdk.IResolvable | CfnTemplate.ItemsLimitConfigurationProperty;
        /**
         * The column sort configuration for heat map for columns that aren't a part of a field well.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapsortconfiguration.html#cfn-quicksight-template-heatmapsortconfiguration-heatmapcolumnsort
         */
        readonly heatMapColumnSort?: Array<CfnTemplate.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The limit on the number of rows that are displayed in a heat map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapsortconfiguration.html#cfn-quicksight-template-heatmapsortconfiguration-heatmaprowitemslimitconfiguration
         */
        readonly heatMapRowItemsLimitConfiguration?: cdk.IResolvable | CfnTemplate.ItemsLimitConfigurationProperty;
        /**
         * The field sort configuration of the rows fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapsortconfiguration.html#cfn-quicksight-template-heatmapsortconfiguration-heatmaprowsort
         */
        readonly heatMapRowSort?: Array<CfnTemplate.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * The field well configuration of a heat map.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapfieldwells.html
     */
    interface HeatMapFieldWellsProperty {
        /**
         * The aggregated field wells of a heat map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapfieldwells.html#cfn-quicksight-template-heatmapfieldwells-heatmapaggregatedfieldwells
         */
        readonly heatMapAggregatedFieldWells?: CfnTemplate.HeatMapAggregatedFieldWellsProperty | cdk.IResolvable;
    }
    /**
     * The aggregated field wells of a heat map.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapaggregatedfieldwells.html
     */
    interface HeatMapAggregatedFieldWellsProperty {
        /**
         * The columns field well of a heat map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapaggregatedfieldwells.html#cfn-quicksight-template-heatmapaggregatedfieldwells-columns
         */
        readonly columns?: Array<CfnTemplate.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The rows field well of a heat map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapaggregatedfieldwells.html#cfn-quicksight-template-heatmapaggregatedfieldwells-rows
         */
        readonly rows?: Array<CfnTemplate.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The values field well of a heat map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapaggregatedfieldwells.html#cfn-quicksight-template-heatmapaggregatedfieldwells-values
         */
        readonly values?: Array<cdk.IResolvable | CfnTemplate.MeasureFieldProperty> | cdk.IResolvable;
    }
    /**
     * Determines the color scale that is applied to the visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-colorscale.html
     */
    interface ColorScaleProperty {
        /**
         * Determines the color fill type.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-colorscale.html#cfn-quicksight-template-colorscale-colorfilltype
         */
        readonly colorFillType: string;
        /**
         * Determines the list of colors that are applied to the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-colorscale.html#cfn-quicksight-template-colorscale-colors
         */
        readonly colors: Array<CfnTemplate.DataColorProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * Determines the color that is applied to null values.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-colorscale.html#cfn-quicksight-template-colorscale-nullvaluecolor
         */
        readonly nullValueColor?: CfnTemplate.DataColorProperty | cdk.IResolvable;
    }
    /**
     * Determines the color that is applied to a particular data value.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datacolor.html
     */
    interface DataColorProperty {
        /**
         * The color that is applied to the data value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datacolor.html#cfn-quicksight-template-datacolor-color
         */
        readonly color?: string;
        /**
         * The data value that the color is applied to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datacolor.html#cfn-quicksight-template-datacolor-datavalue
         */
        readonly dataValue?: number;
    }
    /**
     * A tree map.
     *
     * For more information, see [Using tree maps](https://docs.aws.amazon.com/quicksight/latest/user/tree-map.html) in the *Amazon QuickSight User Guide* .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapvisual.html
     */
    interface TreeMapVisualProperty {
        /**
         * The list of custom actions that are configured for a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapvisual.html#cfn-quicksight-template-treemapvisual-actions
         */
        readonly actions?: Array<cdk.IResolvable | CfnTemplate.VisualCustomActionProperty> | cdk.IResolvable;
        /**
         * The configuration settings of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapvisual.html#cfn-quicksight-template-treemapvisual-chartconfiguration
         */
        readonly chartConfiguration?: cdk.IResolvable | CfnTemplate.TreeMapConfigurationProperty;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapvisual.html#cfn-quicksight-template-treemapvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnTemplate.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The subtitle that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapvisual.html#cfn-quicksight-template-treemapvisual-subtitle
         */
        readonly subtitle?: cdk.IResolvable | CfnTemplate.VisualSubtitleLabelOptionsProperty;
        /**
         * The title that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapvisual.html#cfn-quicksight-template-treemapvisual-title
         */
        readonly title?: cdk.IResolvable | CfnTemplate.VisualTitleLabelOptionsProperty;
        /**
         * The unique identifier of a visual.
         *
         * This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapvisual.html#cfn-quicksight-template-treemapvisual-visualid
         */
        readonly visualId: string;
    }
    /**
     * The configuration of a tree map.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapconfiguration.html
     */
    interface TreeMapConfigurationProperty {
        /**
         * The label options (label text, label visibility) for the colors displayed in a tree map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapconfiguration.html#cfn-quicksight-template-treemapconfiguration-colorlabeloptions
         */
        readonly colorLabelOptions?: CfnTemplate.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The color options (gradient color, point of divergence) of a tree map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapconfiguration.html#cfn-quicksight-template-treemapconfiguration-colorscale
         */
        readonly colorScale?: CfnTemplate.ColorScaleProperty | cdk.IResolvable;
        /**
         * The options that determine if visual data labels are displayed.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapconfiguration.html#cfn-quicksight-template-treemapconfiguration-datalabels
         */
        readonly dataLabels?: CfnTemplate.DataLabelOptionsProperty | cdk.IResolvable;
        /**
         * The field wells of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapconfiguration.html#cfn-quicksight-template-treemapconfiguration-fieldwells
         */
        readonly fieldWells?: cdk.IResolvable | CfnTemplate.TreeMapFieldWellsProperty;
        /**
         * The label options (label text, label visibility) of the groups that are displayed in a tree map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapconfiguration.html#cfn-quicksight-template-treemapconfiguration-grouplabeloptions
         */
        readonly groupLabelOptions?: CfnTemplate.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The legend display setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapconfiguration.html#cfn-quicksight-template-treemapconfiguration-legend
         */
        readonly legend?: cdk.IResolvable | CfnTemplate.LegendOptionsProperty;
        /**
         * The label options (label text, label visibility) of the sizes that are displayed in a tree map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapconfiguration.html#cfn-quicksight-template-treemapconfiguration-sizelabeloptions
         */
        readonly sizeLabelOptions?: CfnTemplate.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The sort configuration of a tree map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapconfiguration.html#cfn-quicksight-template-treemapconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: cdk.IResolvable | CfnTemplate.TreeMapSortConfigurationProperty;
        /**
         * The tooltip display setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapconfiguration.html#cfn-quicksight-template-treemapconfiguration-tooltip
         */
        readonly tooltip?: cdk.IResolvable | CfnTemplate.TooltipOptionsProperty;
    }
    /**
     * The sort configuration of a tree map.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapsortconfiguration.html
     */
    interface TreeMapSortConfigurationProperty {
        /**
         * The limit on the number of groups that are displayed.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapsortconfiguration.html#cfn-quicksight-template-treemapsortconfiguration-treemapgroupitemslimitconfiguration
         */
        readonly treeMapGroupItemsLimitConfiguration?: cdk.IResolvable | CfnTemplate.ItemsLimitConfigurationProperty;
        /**
         * The sort configuration of group by fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapsortconfiguration.html#cfn-quicksight-template-treemapsortconfiguration-treemapsort
         */
        readonly treeMapSort?: Array<CfnTemplate.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * The field wells of a tree map.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapfieldwells.html
     */
    interface TreeMapFieldWellsProperty {
        /**
         * The aggregated field wells of a tree map.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapfieldwells.html#cfn-quicksight-template-treemapfieldwells-treemapaggregatedfieldwells
         */
        readonly treeMapAggregatedFieldWells?: cdk.IResolvable | CfnTemplate.TreeMapAggregatedFieldWellsProperty;
    }
    /**
     * Aggregated field wells of a tree map.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapaggregatedfieldwells.html
     */
    interface TreeMapAggregatedFieldWellsProperty {
        /**
         * The color field well of a tree map.
         *
         * Values are grouped by aggregations based on group by fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapaggregatedfieldwells.html#cfn-quicksight-template-treemapaggregatedfieldwells-colors
         */
        readonly colors?: Array<cdk.IResolvable | CfnTemplate.MeasureFieldProperty> | cdk.IResolvable;
        /**
         * The group by field well of a tree map.
         *
         * Values are grouped based on group by fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapaggregatedfieldwells.html#cfn-quicksight-template-treemapaggregatedfieldwells-groups
         */
        readonly groups?: Array<CfnTemplate.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The size field well of a tree map.
         *
         * Values are aggregated based on group by fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapaggregatedfieldwells.html#cfn-quicksight-template-treemapaggregatedfieldwells-sizes
         */
        readonly sizes?: Array<cdk.IResolvable | CfnTemplate.MeasureFieldProperty> | cdk.IResolvable;
    }
    /**
     * A combo chart.
     *
     * The `ComboChartVisual` includes stacked bar combo charts and clustered bar combo charts
     *
     * For more information, see [Using combo charts](https://docs.aws.amazon.com/quicksight/latest/user/combo-charts.html) in the *Amazon QuickSight User Guide* .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartvisual.html
     */
    interface ComboChartVisualProperty {
        /**
         * The list of custom actions that are configured for a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartvisual.html#cfn-quicksight-template-combochartvisual-actions
         */
        readonly actions?: Array<cdk.IResolvable | CfnTemplate.VisualCustomActionProperty> | cdk.IResolvable;
        /**
         * The configuration settings of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartvisual.html#cfn-quicksight-template-combochartvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnTemplate.ComboChartConfigurationProperty | cdk.IResolvable;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartvisual.html#cfn-quicksight-template-combochartvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnTemplate.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The subtitle that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartvisual.html#cfn-quicksight-template-combochartvisual-subtitle
         */
        readonly subtitle?: cdk.IResolvable | CfnTemplate.VisualSubtitleLabelOptionsProperty;
        /**
         * The title that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartvisual.html#cfn-quicksight-template-combochartvisual-title
         */
        readonly title?: cdk.IResolvable | CfnTemplate.VisualTitleLabelOptionsProperty;
        /**
         * The unique identifier of a visual.
         *
         * This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartvisual.html#cfn-quicksight-template-combochartvisual-visualid
         */
        readonly visualId: string;
    }
    /**
     * The configuration of a `ComboChartVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html
     */
    interface ComboChartConfigurationProperty {
        /**
         * The options that determine if visual data labels are displayed.
         *
         * The data label options for a bar in a combo chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-bardatalabels
         */
        readonly barDataLabels?: CfnTemplate.DataLabelOptionsProperty | cdk.IResolvable;
        /**
         * Determines the bar arrangement in a combo chart. The following are valid values in this structure:.
         *
         * - `CLUSTERED` : For clustered bar combo charts.
         * - `STACKED` : For stacked bar combo charts.
         * - `STACKED_PERCENT` : Do not use. If you use this value, the operation returns a validation error.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-barsarrangement
         */
        readonly barsArrangement?: string;
        /**
         * The category axis of a combo chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-categoryaxis
         */
        readonly categoryAxis?: CfnTemplate.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * The label options (label text, label visibility, and sort icon visibility) of a combo chart category (group/color) field well.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-categorylabeloptions
         */
        readonly categoryLabelOptions?: CfnTemplate.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The label options (label text, label visibility, and sort icon visibility) of a combo chart's color field well.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-colorlabeloptions
         */
        readonly colorLabelOptions?: CfnTemplate.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The field wells of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-fieldwells
         */
        readonly fieldWells?: CfnTemplate.ComboChartFieldWellsProperty | cdk.IResolvable;
        /**
         * The legend display setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-legend
         */
        readonly legend?: cdk.IResolvable | CfnTemplate.LegendOptionsProperty;
        /**
         * The options that determine if visual data labels are displayed.
         *
         * The data label options for a line in a combo chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-linedatalabels
         */
        readonly lineDataLabels?: CfnTemplate.DataLabelOptionsProperty | cdk.IResolvable;
        /**
         * The label display options (grid line, range, scale, and axis step) of a combo chart's primary y-axis (bar) field well.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-primaryyaxisdisplayoptions
         */
        readonly primaryYAxisDisplayOptions?: CfnTemplate.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * The label options (label text, label visibility, and sort icon visibility) of a combo chart's primary y-axis (bar) field well.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-primaryyaxislabeloptions
         */
        readonly primaryYAxisLabelOptions?: CfnTemplate.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The reference line setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-referencelines
         */
        readonly referenceLines?: Array<cdk.IResolvable | CfnTemplate.ReferenceLineProperty> | cdk.IResolvable;
        /**
         * The label display options (grid line, range, scale, axis step) of a combo chart's secondary y-axis (line) field well.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-secondaryyaxisdisplayoptions
         */
        readonly secondaryYAxisDisplayOptions?: CfnTemplate.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * The label options (label text, label visibility, and sort icon visibility) of a combo chart's secondary y-axis(line) field well.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-secondaryyaxislabeloptions
         */
        readonly secondaryYAxisLabelOptions?: CfnTemplate.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The sort configuration of a `ComboChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: CfnTemplate.ComboChartSortConfigurationProperty | cdk.IResolvable;
        /**
         * The legend display setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-tooltip
         */
        readonly tooltip?: cdk.IResolvable | CfnTemplate.TooltipOptionsProperty;
        /**
         * The palette (chart color) display setup of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-visualpalette
         */
        readonly visualPalette?: cdk.IResolvable | CfnTemplate.VisualPaletteProperty;
    }
    /**
     * The sort configuration of a `ComboChartVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartsortconfiguration.html
     */
    interface ComboChartSortConfigurationProperty {
        /**
         * The item limit configuration for the category field well of a combo chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartsortconfiguration.html#cfn-quicksight-template-combochartsortconfiguration-categoryitemslimit
         */
        readonly categoryItemsLimit?: cdk.IResolvable | CfnTemplate.ItemsLimitConfigurationProperty;
        /**
         * The sort configuration of the category field well in a combo chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartsortconfiguration.html#cfn-quicksight-template-combochartsortconfiguration-categorysort
         */
        readonly categorySort?: Array<CfnTemplate.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The item limit configuration of the color field well in a combo chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartsortconfiguration.html#cfn-quicksight-template-combochartsortconfiguration-coloritemslimit
         */
        readonly colorItemsLimit?: cdk.IResolvable | CfnTemplate.ItemsLimitConfigurationProperty;
        /**
         * The sort configuration of the color field well in a combo chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartsortconfiguration.html#cfn-quicksight-template-combochartsortconfiguration-colorsort
         */
        readonly colorSort?: Array<CfnTemplate.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * The field wells of the visual.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartfieldwells.html
     */
    interface ComboChartFieldWellsProperty {
        /**
         * The aggregated field wells of a combo chart.
         *
         * Combo charts only have aggregated field wells. Columns in a combo chart are aggregated by category.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartfieldwells.html#cfn-quicksight-template-combochartfieldwells-combochartaggregatedfieldwells
         */
        readonly comboChartAggregatedFieldWells?: CfnTemplate.ComboChartAggregatedFieldWellsProperty | cdk.IResolvable;
    }
    /**
     * The aggregated field wells of a combo chart.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartaggregatedfieldwells.html
     */
    interface ComboChartAggregatedFieldWellsProperty {
        /**
         * The aggregated `BarValues` field well of a combo chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartaggregatedfieldwells.html#cfn-quicksight-template-combochartaggregatedfieldwells-barvalues
         */
        readonly barValues?: Array<cdk.IResolvable | CfnTemplate.MeasureFieldProperty> | cdk.IResolvable;
        /**
         * The aggregated category field wells of a combo chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartaggregatedfieldwells.html#cfn-quicksight-template-combochartaggregatedfieldwells-category
         */
        readonly category?: Array<CfnTemplate.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The aggregated colors field well of a combo chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartaggregatedfieldwells.html#cfn-quicksight-template-combochartaggregatedfieldwells-colors
         */
        readonly colors?: Array<CfnTemplate.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The aggregated `LineValues` field well of a combo chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartaggregatedfieldwells.html#cfn-quicksight-template-combochartaggregatedfieldwells-linevalues
         */
        readonly lineValues?: Array<cdk.IResolvable | CfnTemplate.MeasureFieldProperty> | cdk.IResolvable;
    }
    /**
     * A word cloud.
     *
     * For more information, see [Using word clouds](https://docs.aws.amazon.com/quicksight/latest/user/word-cloud.html) in the *Amazon QuickSight User Guide* .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudvisual.html
     */
    interface WordCloudVisualProperty {
        /**
         * The list of custom actions that are configured for a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudvisual.html#cfn-quicksight-template-wordcloudvisual-actions
         */
        readonly actions?: Array<cdk.IResolvable | CfnTemplate.VisualCustomActionProperty> | cdk.IResolvable;
        /**
         * The configuration settings of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudvisual.html#cfn-quicksight-template-wordcloudvisual-chartconfiguration
         */
        readonly chartConfiguration?: cdk.IResolvable | CfnTemplate.WordCloudChartConfigurationProperty;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudvisual.html#cfn-quicksight-template-wordcloudvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnTemplate.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The subtitle that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudvisual.html#cfn-quicksight-template-wordcloudvisual-subtitle
         */
        readonly subtitle?: cdk.IResolvable | CfnTemplate.VisualSubtitleLabelOptionsProperty;
        /**
         * The title that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudvisual.html#cfn-quicksight-template-wordcloudvisual-title
         */
        readonly title?: cdk.IResolvable | CfnTemplate.VisualTitleLabelOptionsProperty;
        /**
         * The unique identifier of a visual.
         *
         * This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudvisual.html#cfn-quicksight-template-wordcloudvisual-visualid
         */
        readonly visualId: string;
    }
    /**
     * The configuration of a word cloud visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudchartconfiguration.html
     */
    interface WordCloudChartConfigurationProperty {
        /**
         * The label options (label text, label visibility, and sort icon visibility) for the word cloud category.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudchartconfiguration.html#cfn-quicksight-template-wordcloudchartconfiguration-categorylabeloptions
         */
        readonly categoryLabelOptions?: CfnTemplate.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The field wells of the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudchartconfiguration.html#cfn-quicksight-template-wordcloudchartconfiguration-fieldwells
         */
        readonly fieldWells?: cdk.IResolvable | CfnTemplate.WordCloudFieldWellsProperty;
        /**
         * The sort configuration of a word cloud visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudchartconfiguration.html#cfn-quicksight-template-wordcloudchartconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: cdk.IResolvable | CfnTemplate.WordCloudSortConfigurationProperty;
        /**
         * The options for a word cloud visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudchartconfiguration.html#cfn-quicksight-template-wordcloudchartconfiguration-wordcloudoptions
         */
        readonly wordCloudOptions?: cdk.IResolvable | CfnTemplate.WordCloudOptionsProperty;
    }
    /**
     * The sort configuration of a word cloud visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudsortconfiguration.html
     */
    interface WordCloudSortConfigurationProperty {
        /**
         * The limit on the number of groups that are displayed in a word cloud.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudsortconfiguration.html#cfn-quicksight-template-wordcloudsortconfiguration-categoryitemslimit
         */
        readonly categoryItemsLimit?: cdk.IResolvable | CfnTemplate.ItemsLimitConfigurationProperty;
        /**
         * The sort configuration of group by fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudsortconfiguration.html#cfn-quicksight-template-wordcloudsortconfiguration-categorysort
         */
        readonly categorySort?: Array<CfnTemplate.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * The field wells of a word cloud visual.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudfieldwells.html
     */
    interface WordCloudFieldWellsProperty {
        /**
         * The aggregated field wells of a word cloud.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudfieldwells.html#cfn-quicksight-template-wordcloudfieldwells-wordcloudaggregatedfieldwells
         */
        readonly wordCloudAggregatedFieldWells?: cdk.IResolvable | CfnTemplate.WordCloudAggregatedFieldWellsProperty;
    }
    /**
     * The aggregated field wells of a word cloud.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudaggregatedfieldwells.html
     */
    interface WordCloudAggregatedFieldWellsProperty {
        /**
         * The group by field well of a word cloud.
         *
         * Values are grouped by group by fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudaggregatedfieldwells.html#cfn-quicksight-template-wordcloudaggregatedfieldwells-groupby
         */
        readonly groupBy?: Array<CfnTemplate.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The size field well of a word cloud.
         *
         * Values are aggregated based on group by fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudaggregatedfieldwells.html#cfn-quicksight-template-wordcloudaggregatedfieldwells-size
         */
        readonly size?: Array<cdk.IResolvable | CfnTemplate.MeasureFieldProperty> | cdk.IResolvable;
    }
    /**
     * The word cloud options for a word cloud visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudoptions.html
     */
    interface WordCloudOptionsProperty {
        /**
         * The cloud layout options (fluid, normal) of a word cloud.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudoptions.html#cfn-quicksight-template-wordcloudoptions-cloudlayout
         */
        readonly cloudLayout?: string;
        /**
         * The length limit of each word from 1-100.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudoptions.html#cfn-quicksight-template-wordcloudoptions-maximumstringlength
         */
        readonly maximumStringLength?: number;
        /**
         * The word casing options (lower_case, existing_case) for the words in a word cloud.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudoptions.html#cfn-quicksight-template-wordcloudoptions-wordcasing
         */
        readonly wordCasing?: string;
        /**
         * The word orientation options (horizontal, horizontal_and_vertical) for the words in a word cloud.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudoptions.html#cfn-quicksight-template-wordcloudoptions-wordorientation
         */
        readonly wordOrientation?: string;
        /**
         * The word padding options (none, small, medium, large) for the words in a word cloud.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudoptions.html#cfn-quicksight-template-wordcloudoptions-wordpadding
         */
        readonly wordPadding?: string;
        /**
         * The word scaling options (emphasize, normal) for the words in a word cloud.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudoptions.html#cfn-quicksight-template-wordcloudoptions-wordscaling
         */
        readonly wordScaling?: string;
    }
    /**
     * An insight visual.
     *
     * For more information, see [Working with insights](https://docs.aws.amazon.com/quicksight/latest/user/computational-insights.html) in the *Amazon QuickSight User Guide* .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-insightvisual.html
     */
    interface InsightVisualProperty {
        /**
         * The list of custom actions that are configured for a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-insightvisual.html#cfn-quicksight-template-insightvisual-actions
         */
        readonly actions?: Array<cdk.IResolvable | CfnTemplate.VisualCustomActionProperty> | cdk.IResolvable;
        /**
         * The dataset that is used in the insight visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-insightvisual.html#cfn-quicksight-template-insightvisual-datasetidentifier
         */
        readonly dataSetIdentifier: string;
        /**
         * The configuration of an insight visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-insightvisual.html#cfn-quicksight-template-insightvisual-insightconfiguration
         */
        readonly insightConfiguration?: CfnTemplate.InsightConfigurationProperty | cdk.IResolvable;
        /**
         * The subtitle that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-insightvisual.html#cfn-quicksight-template-insightvisual-subtitle
         */
        readonly subtitle?: cdk.IResolvable | CfnTemplate.VisualSubtitleLabelOptionsProperty;
        /**
         * The title that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-insightvisual.html#cfn-quicksight-template-insightvisual-title
         */
        readonly title?: cdk.IResolvable | CfnTemplate.VisualTitleLabelOptionsProperty;
        /**
         * The unique identifier of a visual.
         *
         * This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-insightvisual.html#cfn-quicksight-template-insightvisual-visualid
         */
        readonly visualId: string;
    }
    /**
     * The configuration of an insight visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-insightconfiguration.html
     */
    interface InsightConfigurationProperty {
        /**
         * The computations configurations of the insight visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-insightconfiguration.html#cfn-quicksight-template-insightconfiguration-computations
         */
        readonly computations?: Array<CfnTemplate.ComputationProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The custom narrative of the insight visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-insightconfiguration.html#cfn-quicksight-template-insightconfiguration-customnarrative
         */
        readonly customNarrative?: CfnTemplate.CustomNarrativeOptionsProperty | cdk.IResolvable;
    }
    /**
     * The computation union that is used in an insight visual.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-computation.html
     */
    interface ComputationProperty {
        /**
         * The forecast computation configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-computation.html#cfn-quicksight-template-computation-forecast
         */
        readonly forecast?: CfnTemplate.ForecastComputationProperty | cdk.IResolvable;
        /**
         * The growth rate computation configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-computation.html#cfn-quicksight-template-computation-growthrate
         */
        readonly growthRate?: CfnTemplate.GrowthRateComputationProperty | cdk.IResolvable;
        /**
         * The maximum and minimum computation configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-computation.html#cfn-quicksight-template-computation-maximumminimum
         */
        readonly maximumMinimum?: cdk.IResolvable | CfnTemplate.MaximumMinimumComputationProperty;
        /**
         * The metric comparison computation configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-computation.html#cfn-quicksight-template-computation-metriccomparison
         */
        readonly metricComparison?: cdk.IResolvable | CfnTemplate.MetricComparisonComputationProperty;
        /**
         * The period over period computation configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-computation.html#cfn-quicksight-template-computation-periodoverperiod
         */
        readonly periodOverPeriod?: cdk.IResolvable | CfnTemplate.PeriodOverPeriodComputationProperty;
        /**
         * The period to `DataSetIdentifier` computation configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-computation.html#cfn-quicksight-template-computation-periodtodate
         */
        readonly periodToDate?: cdk.IResolvable | CfnTemplate.PeriodToDateComputationProperty;
        /**
         * The top movers and bottom movers computation configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-computation.html#cfn-quicksight-template-computation-topbottommovers
         */
        readonly topBottomMovers?: cdk.IResolvable | CfnTemplate.TopBottomMoversComputationProperty;
        /**
         * The top ranked and bottom ranked computation configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-computation.html#cfn-quicksight-template-computation-topbottomranked
         */
        readonly topBottomRanked?: cdk.IResolvable | CfnTemplate.TopBottomRankedComputationProperty;
        /**
         * The total aggregation computation configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-computation.html#cfn-quicksight-template-computation-totalaggregation
         */
        readonly totalAggregation?: cdk.IResolvable | CfnTemplate.TotalAggregationComputationProperty;
        /**
         * The unique values computation configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-computation.html#cfn-quicksight-template-computation-uniquevalues
         */
        readonly uniqueValues?: cdk.IResolvable | CfnTemplate.UniqueValuesComputationProperty;
    }
    /**
     * The period to date computation configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-periodtodatecomputation.html
     */
    interface PeriodToDateComputationProperty {
        /**
         * The ID for a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-periodtodatecomputation.html#cfn-quicksight-template-periodtodatecomputation-computationid
         */
        readonly computationId: string;
        /**
         * The name of a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-periodtodatecomputation.html#cfn-quicksight-template-periodtodatecomputation-name
         */
        readonly name?: string;
        /**
         * The time granularity setup of period to date computation. Choose from the following options:.
         *
         * - YEAR: Year to date.
         * - MONTH: Month to date.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-periodtodatecomputation.html#cfn-quicksight-template-periodtodatecomputation-periodtimegranularity
         */
        readonly periodTimeGranularity?: string;
        /**
         * The time field that is used in a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-periodtodatecomputation.html#cfn-quicksight-template-periodtodatecomputation-time
         */
        readonly time?: CfnTemplate.DimensionFieldProperty | cdk.IResolvable;
        /**
         * The value field that is used in a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-periodtodatecomputation.html#cfn-quicksight-template-periodtodatecomputation-value
         */
        readonly value?: cdk.IResolvable | CfnTemplate.MeasureFieldProperty;
    }
    /**
     * The growth rate computation configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-growthratecomputation.html
     */
    interface GrowthRateComputationProperty {
        /**
         * The ID for a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-growthratecomputation.html#cfn-quicksight-template-growthratecomputation-computationid
         */
        readonly computationId: string;
        /**
         * The name of a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-growthratecomputation.html#cfn-quicksight-template-growthratecomputation-name
         */
        readonly name?: string;
        /**
         * The period size setup of a growth rate computation.
         *
         * @default - 0
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-growthratecomputation.html#cfn-quicksight-template-growthratecomputation-periodsize
         */
        readonly periodSize?: number;
        /**
         * The time field that is used in a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-growthratecomputation.html#cfn-quicksight-template-growthratecomputation-time
         */
        readonly time?: CfnTemplate.DimensionFieldProperty | cdk.IResolvable;
        /**
         * The value field that is used in a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-growthratecomputation.html#cfn-quicksight-template-growthratecomputation-value
         */
        readonly value?: cdk.IResolvable | CfnTemplate.MeasureFieldProperty;
    }
    /**
     * The top ranked and bottom ranked computation configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottomrankedcomputation.html
     */
    interface TopBottomRankedComputationProperty {
        /**
         * The category field that is used in a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottomrankedcomputation.html#cfn-quicksight-template-topbottomrankedcomputation-category
         */
        readonly category?: CfnTemplate.DimensionFieldProperty | cdk.IResolvable;
        /**
         * The ID for a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottomrankedcomputation.html#cfn-quicksight-template-topbottomrankedcomputation-computationid
         */
        readonly computationId: string;
        /**
         * The name of a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottomrankedcomputation.html#cfn-quicksight-template-topbottomrankedcomputation-name
         */
        readonly name?: string;
        /**
         * The result size of a top and bottom ranked computation.
         *
         * @default - 0
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottomrankedcomputation.html#cfn-quicksight-template-topbottomrankedcomputation-resultsize
         */
        readonly resultSize?: number;
        /**
         * The computation type. Choose one of the following options:.
         *
         * - TOP: A top ranked computation.
         * - BOTTOM: A bottom ranked computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottomrankedcomputation.html#cfn-quicksight-template-topbottomrankedcomputation-type
         */
        readonly type: string;
        /**
         * The value field that is used in a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottomrankedcomputation.html#cfn-quicksight-template-topbottomrankedcomputation-value
         */
        readonly value?: cdk.IResolvable | CfnTemplate.MeasureFieldProperty;
    }
    /**
     * The total aggregation computation configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-totalaggregationcomputation.html
     */
    interface TotalAggregationComputationProperty {
        /**
         * The ID for a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-totalaggregationcomputation.html#cfn-quicksight-template-totalaggregationcomputation-computationid
         */
        readonly computationId: string;
        /**
         * The name of a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-totalaggregationcomputation.html#cfn-quicksight-template-totalaggregationcomputation-name
         */
        readonly name?: string;
        /**
         * The value field that is used in a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-totalaggregationcomputation.html#cfn-quicksight-template-totalaggregationcomputation-value
         */
        readonly value?: cdk.IResolvable | CfnTemplate.MeasureFieldProperty;
    }
    /**
     * The forecast computation configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastcomputation.html
     */
    interface ForecastComputationProperty {
        /**
         * The ID for a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastcomputation.html#cfn-quicksight-template-forecastcomputation-computationid
         */
        readonly computationId: string;
        /**
         * The custom seasonality value setup of a forecast computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastcomputation.html#cfn-quicksight-template-forecastcomputation-customseasonalityvalue
         */
        readonly customSeasonalityValue?: number;
        /**
         * The lower boundary setup of a forecast computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastcomputation.html#cfn-quicksight-template-forecastcomputation-lowerboundary
         */
        readonly lowerBoundary?: number;
        /**
         * The name of a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastcomputation.html#cfn-quicksight-template-forecastcomputation-name
         */
        readonly name?: string;
        /**
         * The periods backward setup of a forecast computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastcomputation.html#cfn-quicksight-template-forecastcomputation-periodsbackward
         */
        readonly periodsBackward?: number;
        /**
         * The periods forward setup of a forecast computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastcomputation.html#cfn-quicksight-template-forecastcomputation-periodsforward
         */
        readonly periodsForward?: number;
        /**
         * The prediction interval setup of a forecast computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastcomputation.html#cfn-quicksight-template-forecastcomputation-predictioninterval
         */
        readonly predictionInterval?: number;
        /**
         * The seasonality setup of a forecast computation. Choose one of the following options:.
         *
         * - `AUTOMATIC`
         * - `CUSTOM` : Checks the custom seasonality value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastcomputation.html#cfn-quicksight-template-forecastcomputation-seasonality
         */
        readonly seasonality?: string;
        /**
         * The time field that is used in a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastcomputation.html#cfn-quicksight-template-forecastcomputation-time
         */
        readonly time?: CfnTemplate.DimensionFieldProperty | cdk.IResolvable;
        /**
         * The upper boundary setup of a forecast computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastcomputation.html#cfn-quicksight-template-forecastcomputation-upperboundary
         */
        readonly upperBoundary?: number;
        /**
         * The value field that is used in a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastcomputation.html#cfn-quicksight-template-forecastcomputation-value
         */
        readonly value?: cdk.IResolvable | CfnTemplate.MeasureFieldProperty;
    }
    /**
     * The maximum and minimum computation configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-maximumminimumcomputation.html
     */
    interface MaximumMinimumComputationProperty {
        /**
         * The ID for a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-maximumminimumcomputation.html#cfn-quicksight-template-maximumminimumcomputation-computationid
         */
        readonly computationId: string;
        /**
         * The name of a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-maximumminimumcomputation.html#cfn-quicksight-template-maximumminimumcomputation-name
         */
        readonly name?: string;
        /**
         * The time field that is used in a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-maximumminimumcomputation.html#cfn-quicksight-template-maximumminimumcomputation-time
         */
        readonly time?: CfnTemplate.DimensionFieldProperty | cdk.IResolvable;
        /**
         * The type of computation. Choose one of the following options:.
         *
         * - MAXIMUM: A maximum computation.
         * - MINIMUM: A minimum computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-maximumminimumcomputation.html#cfn-quicksight-template-maximumminimumcomputation-type
         */
        readonly type: string;
        /**
         * The value field that is used in a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-maximumminimumcomputation.html#cfn-quicksight-template-maximumminimumcomputation-value
         */
        readonly value?: cdk.IResolvable | CfnTemplate.MeasureFieldProperty;
    }
    /**
     * The period over period computation configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-periodoverperiodcomputation.html
     */
    interface PeriodOverPeriodComputationProperty {
        /**
         * The ID for a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-periodoverperiodcomputation.html#cfn-quicksight-template-periodoverperiodcomputation-computationid
         */
        readonly computationId: string;
        /**
         * The name of a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-periodoverperiodcomputation.html#cfn-quicksight-template-periodoverperiodcomputation-name
         */
        readonly name?: string;
        /**
         * The time field that is used in a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-periodoverperiodcomputation.html#cfn-quicksight-template-periodoverperiodcomputation-time
         */
        readonly time?: CfnTemplate.DimensionFieldProperty | cdk.IResolvable;
        /**
         * The value field that is used in a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-periodoverperiodcomputation.html#cfn-quicksight-template-periodoverperiodcomputation-value
         */
        readonly value?: cdk.IResolvable | CfnTemplate.MeasureFieldProperty;
    }
    /**
     * The metric comparison computation configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-metriccomparisoncomputation.html
     */
    interface MetricComparisonComputationProperty {
        /**
         * The ID for a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-metriccomparisoncomputation.html#cfn-quicksight-template-metriccomparisoncomputation-computationid
         */
        readonly computationId: string;
        /**
         * The field that is used in a metric comparison from value setup.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-metriccomparisoncomputation.html#cfn-quicksight-template-metriccomparisoncomputation-fromvalue
         */
        readonly fromValue?: cdk.IResolvable | CfnTemplate.MeasureFieldProperty;
        /**
         * The name of a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-metriccomparisoncomputation.html#cfn-quicksight-template-metriccomparisoncomputation-name
         */
        readonly name?: string;
        /**
         * The field that is used in a metric comparison to value setup.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-metriccomparisoncomputation.html#cfn-quicksight-template-metriccomparisoncomputation-targetvalue
         */
        readonly targetValue?: cdk.IResolvable | CfnTemplate.MeasureFieldProperty;
        /**
         * The time field that is used in a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-metriccomparisoncomputation.html#cfn-quicksight-template-metriccomparisoncomputation-time
         */
        readonly time?: CfnTemplate.DimensionFieldProperty | cdk.IResolvable;
    }
    /**
     * The top movers and bottom movers computation setup.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottommoverscomputation.html
     */
    interface TopBottomMoversComputationProperty {
        /**
         * The category field that is used in a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottommoverscomputation.html#cfn-quicksight-template-topbottommoverscomputation-category
         */
        readonly category?: CfnTemplate.DimensionFieldProperty | cdk.IResolvable;
        /**
         * The ID for a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottommoverscomputation.html#cfn-quicksight-template-topbottommoverscomputation-computationid
         */
        readonly computationId: string;
        /**
         * The mover size setup of the top and bottom movers computation.
         *
         * @default - 0
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottommoverscomputation.html#cfn-quicksight-template-topbottommoverscomputation-moversize
         */
        readonly moverSize?: number;
        /**
         * The name of a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottommoverscomputation.html#cfn-quicksight-template-topbottommoverscomputation-name
         */
        readonly name?: string;
        /**
         * The sort order setup of the top and bottom movers computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottommoverscomputation.html#cfn-quicksight-template-topbottommoverscomputation-sortorder
         */
        readonly sortOrder?: string;
        /**
         * The time field that is used in a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottommoverscomputation.html#cfn-quicksight-template-topbottommoverscomputation-time
         */
        readonly time?: CfnTemplate.DimensionFieldProperty | cdk.IResolvable;
        /**
         * The computation type. Choose from the following options:.
         *
         * - TOP: Top movers computation.
         * - BOTTOM: Bottom movers computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottommoverscomputation.html#cfn-quicksight-template-topbottommoverscomputation-type
         */
        readonly type: string;
        /**
         * The value field that is used in a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottommoverscomputation.html#cfn-quicksight-template-topbottommoverscomputation-value
         */
        readonly value?: cdk.IResolvable | CfnTemplate.MeasureFieldProperty;
    }
    /**
     * The unique values computation configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-uniquevaluescomputation.html
     */
    interface UniqueValuesComputationProperty {
        /**
         * The category field that is used in a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-uniquevaluescomputation.html#cfn-quicksight-template-uniquevaluescomputation-category
         */
        readonly category?: CfnTemplate.DimensionFieldProperty | cdk.IResolvable;
        /**
         * The ID for a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-uniquevaluescomputation.html#cfn-quicksight-template-uniquevaluescomputation-computationid
         */
        readonly computationId: string;
        /**
         * The name of a computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-uniquevaluescomputation.html#cfn-quicksight-template-uniquevaluescomputation-name
         */
        readonly name?: string;
    }
    /**
     * The custom narrative options.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customnarrativeoptions.html
     */
    interface CustomNarrativeOptionsProperty {
        /**
         * The string input of custom narrative.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customnarrativeoptions.html#cfn-quicksight-template-customnarrativeoptions-narrative
         */
        readonly narrative: string;
    }
    /**
     * A sankey diagram.
     *
     * For more information, see [Using Sankey diagrams](https://docs.aws.amazon.com/quicksight/latest/user/sankey-diagram.html) in the *Amazon QuickSight User Guide* .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramvisual.html
     */
    interface SankeyDiagramVisualProperty {
        /**
         * The list of custom actions that are configured for a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramvisual.html#cfn-quicksight-template-sankeydiagramvisual-actions
         */
        readonly actions?: Array<cdk.IResolvable | CfnTemplate.VisualCustomActionProperty> | cdk.IResolvable;
        /**
         * The configuration of a sankey diagram.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramvisual.html#cfn-quicksight-template-sankeydiagramvisual-chartconfiguration
         */
        readonly chartConfiguration?: cdk.IResolvable | CfnTemplate.SankeyDiagramChartConfigurationProperty;
        /**
         * The subtitle that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramvisual.html#cfn-quicksight-template-sankeydiagramvisual-subtitle
         */
        readonly subtitle?: cdk.IResolvable | CfnTemplate.VisualSubtitleLabelOptionsProperty;
        /**
         * The title that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramvisual.html#cfn-quicksight-template-sankeydiagramvisual-title
         */
        readonly title?: cdk.IResolvable | CfnTemplate.VisualTitleLabelOptionsProperty;
        /**
         * The unique identifier of a visual.
         *
         * This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramvisual.html#cfn-quicksight-template-sankeydiagramvisual-visualid
         */
        readonly visualId: string;
    }
    /**
     * The configuration of a sankey diagram.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramchartconfiguration.html
     */
    interface SankeyDiagramChartConfigurationProperty {
        /**
         * The data label configuration of a sankey diagram.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramchartconfiguration.html#cfn-quicksight-template-sankeydiagramchartconfiguration-datalabels
         */
        readonly dataLabels?: CfnTemplate.DataLabelOptionsProperty | cdk.IResolvable;
        /**
         * The field well configuration of a sankey diagram.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramchartconfiguration.html#cfn-quicksight-template-sankeydiagramchartconfiguration-fieldwells
         */
        readonly fieldWells?: cdk.IResolvable | CfnTemplate.SankeyDiagramFieldWellsProperty;
        /**
         * The sort configuration of a sankey diagram.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramchartconfiguration.html#cfn-quicksight-template-sankeydiagramchartconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: cdk.IResolvable | CfnTemplate.SankeyDiagramSortConfigurationProperty;
    }
    /**
     * The sort configuration of a sankey diagram.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramsortconfiguration.html
     */
    interface SankeyDiagramSortConfigurationProperty {
        /**
         * The limit on the number of destination nodes that are displayed in a sankey diagram.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramsortconfiguration.html#cfn-quicksight-template-sankeydiagramsortconfiguration-destinationitemslimit
         */
        readonly destinationItemsLimit?: cdk.IResolvable | CfnTemplate.ItemsLimitConfigurationProperty;
        /**
         * The limit on the number of source nodes that are displayed in a sankey diagram.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramsortconfiguration.html#cfn-quicksight-template-sankeydiagramsortconfiguration-sourceitemslimit
         */
        readonly sourceItemsLimit?: cdk.IResolvable | CfnTemplate.ItemsLimitConfigurationProperty;
        /**
         * The sort configuration of the weight fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramsortconfiguration.html#cfn-quicksight-template-sankeydiagramsortconfiguration-weightsort
         */
        readonly weightSort?: Array<CfnTemplate.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * The field well configuration of a sankey diagram.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramfieldwells.html
     */
    interface SankeyDiagramFieldWellsProperty {
        /**
         * The field well configuration of a sankey diagram.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramfieldwells.html#cfn-quicksight-template-sankeydiagramfieldwells-sankeydiagramaggregatedfieldwells
         */
        readonly sankeyDiagramAggregatedFieldWells?: cdk.IResolvable | CfnTemplate.SankeyDiagramAggregatedFieldWellsProperty;
    }
    /**
     * The field well configuration of a sankey diagram.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramaggregatedfieldwells.html
     */
    interface SankeyDiagramAggregatedFieldWellsProperty {
        /**
         * The destination field wells of a sankey diagram.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramaggregatedfieldwells.html#cfn-quicksight-template-sankeydiagramaggregatedfieldwells-destination
         */
        readonly destination?: Array<CfnTemplate.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The source field wells of a sankey diagram.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramaggregatedfieldwells.html#cfn-quicksight-template-sankeydiagramaggregatedfieldwells-source
         */
        readonly source?: Array<CfnTemplate.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The weight field wells of a sankey diagram.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramaggregatedfieldwells.html#cfn-quicksight-template-sankeydiagramaggregatedfieldwells-weight
         */
        readonly weight?: Array<cdk.IResolvable | CfnTemplate.MeasureFieldProperty> | cdk.IResolvable;
    }
    /**
     * A gauge chart.
     *
     * For more information, see [Using gauge charts](https://docs.aws.amazon.com/quicksight/latest/user/gauge-chart.html) in the *Amazon QuickSight User Guide* .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartvisual.html
     */
    interface GaugeChartVisualProperty {
        /**
         * The list of custom actions that are configured for a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartvisual.html#cfn-quicksight-template-gaugechartvisual-actions
         */
        readonly actions?: Array<cdk.IResolvable | CfnTemplate.VisualCustomActionProperty> | cdk.IResolvable;
        /**
         * The configuration of a `GaugeChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartvisual.html#cfn-quicksight-template-gaugechartvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnTemplate.GaugeChartConfigurationProperty | cdk.IResolvable;
        /**
         * The conditional formatting of a `GaugeChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartvisual.html#cfn-quicksight-template-gaugechartvisual-conditionalformatting
         */
        readonly conditionalFormatting?: CfnTemplate.GaugeChartConditionalFormattingProperty | cdk.IResolvable;
        /**
         * The subtitle that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartvisual.html#cfn-quicksight-template-gaugechartvisual-subtitle
         */
        readonly subtitle?: cdk.IResolvable | CfnTemplate.VisualSubtitleLabelOptionsProperty;
        /**
         * The title that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartvisual.html#cfn-quicksight-template-gaugechartvisual-title
         */
        readonly title?: cdk.IResolvable | CfnTemplate.VisualTitleLabelOptionsProperty;
        /**
         * The unique identifier of a visual.
         *
         * This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartvisual.html#cfn-quicksight-template-gaugechartvisual-visualid
         */
        readonly visualId: string;
    }
    /**
     * The conditional formatting of a `GaugeChartVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartconditionalformatting.html
     */
    interface GaugeChartConditionalFormattingProperty {
        /**
         * Conditional formatting options of a `GaugeChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartconditionalformatting.html#cfn-quicksight-template-gaugechartconditionalformatting-conditionalformattingoptions
         */
        readonly conditionalFormattingOptions?: Array<CfnTemplate.GaugeChartConditionalFormattingOptionProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * Conditional formatting options of a `GaugeChartVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartconditionalformattingoption.html
     */
    interface GaugeChartConditionalFormattingOptionProperty {
        /**
         * The options that determine the presentation of the arc of a `GaugeChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartconditionalformattingoption.html#cfn-quicksight-template-gaugechartconditionalformattingoption-arc
         */
        readonly arc?: CfnTemplate.GaugeChartArcConditionalFormattingProperty | cdk.IResolvable;
        /**
         * The conditional formatting for the primary value of a `GaugeChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartconditionalformattingoption.html#cfn-quicksight-template-gaugechartconditionalformattingoption-primaryvalue
         */
        readonly primaryValue?: CfnTemplate.GaugeChartPrimaryValueConditionalFormattingProperty | cdk.IResolvable;
    }
    /**
     * The options that determine the presentation of the arc of a `GaugeChartVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartarcconditionalformatting.html
     */
    interface GaugeChartArcConditionalFormattingProperty {
        /**
         * The conditional formatting of the arc foreground color.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartarcconditionalformatting.html#cfn-quicksight-template-gaugechartarcconditionalformatting-foregroundcolor
         */
        readonly foregroundColor?: CfnTemplate.ConditionalFormattingColorProperty | cdk.IResolvable;
    }
    /**
     * The conditional formatting for the primary value of a `GaugeChartVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartprimaryvalueconditionalformatting.html
     */
    interface GaugeChartPrimaryValueConditionalFormattingProperty {
        /**
         * The conditional formatting of the primary value icon.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartprimaryvalueconditionalformatting.html#cfn-quicksight-template-gaugechartprimaryvalueconditionalformatting-icon
         */
        readonly icon?: CfnTemplate.ConditionalFormattingIconProperty | cdk.IResolvable;
        /**
         * The conditional formatting of the primary value text color.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartprimaryvalueconditionalformatting.html#cfn-quicksight-template-gaugechartprimaryvalueconditionalformatting-textcolor
         */
        readonly textColor?: CfnTemplate.ConditionalFormattingColorProperty | cdk.IResolvable;
    }
    /**
     * The configuration of a `GaugeChartVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartconfiguration.html
     */
    interface GaugeChartConfigurationProperty {
        /**
         * The data label configuration of a `GaugeChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartconfiguration.html#cfn-quicksight-template-gaugechartconfiguration-datalabels
         */
        readonly dataLabels?: CfnTemplate.DataLabelOptionsProperty | cdk.IResolvable;
        /**
         * The field well configuration of a `GaugeChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartconfiguration.html#cfn-quicksight-template-gaugechartconfiguration-fieldwells
         */
        readonly fieldWells?: CfnTemplate.GaugeChartFieldWellsProperty | cdk.IResolvable;
        /**
         * The options that determine the presentation of the `GaugeChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartconfiguration.html#cfn-quicksight-template-gaugechartconfiguration-gaugechartoptions
         */
        readonly gaugeChartOptions?: CfnTemplate.GaugeChartOptionsProperty | cdk.IResolvable;
        /**
         * The tooltip configuration of a `GaugeChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartconfiguration.html#cfn-quicksight-template-gaugechartconfiguration-tooltipoptions
         */
        readonly tooltipOptions?: cdk.IResolvable | CfnTemplate.TooltipOptionsProperty;
        /**
         * The visual palette configuration of a `GaugeChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartconfiguration.html#cfn-quicksight-template-gaugechartconfiguration-visualpalette
         */
        readonly visualPalette?: cdk.IResolvable | CfnTemplate.VisualPaletteProperty;
    }
    /**
     * The field well configuration of a `GaugeChartVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartfieldwells.html
     */
    interface GaugeChartFieldWellsProperty {
        /**
         * The target value field wells of a `GaugeChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartfieldwells.html#cfn-quicksight-template-gaugechartfieldwells-targetvalues
         */
        readonly targetValues?: Array<cdk.IResolvable | CfnTemplate.MeasureFieldProperty> | cdk.IResolvable;
        /**
         * The value field wells of a `GaugeChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartfieldwells.html#cfn-quicksight-template-gaugechartfieldwells-values
         */
        readonly values?: Array<cdk.IResolvable | CfnTemplate.MeasureFieldProperty> | cdk.IResolvable;
    }
    /**
     * The options that determine the presentation of the `GaugeChartVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartoptions.html
     */
    interface GaugeChartOptionsProperty {
        /**
         * The arc configuration of a `GaugeChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartoptions.html#cfn-quicksight-template-gaugechartoptions-arc
         */
        readonly arc?: CfnTemplate.ArcConfigurationProperty | cdk.IResolvable;
        /**
         * The arc axis configuration of a `GaugeChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartoptions.html#cfn-quicksight-template-gaugechartoptions-arcaxis
         */
        readonly arcAxis?: CfnTemplate.ArcAxisConfigurationProperty | cdk.IResolvable;
        /**
         * The comparison configuration of a `GaugeChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartoptions.html#cfn-quicksight-template-gaugechartoptions-comparison
         */
        readonly comparison?: CfnTemplate.ComparisonConfigurationProperty | cdk.IResolvable;
        /**
         * The options that determine the primary value display type.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartoptions.html#cfn-quicksight-template-gaugechartoptions-primaryvaluedisplaytype
         */
        readonly primaryValueDisplayType?: string;
        /**
         * The options that determine the primary value font configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartoptions.html#cfn-quicksight-template-gaugechartoptions-primaryvaluefontconfiguration
         */
        readonly primaryValueFontConfiguration?: CfnTemplate.FontConfigurationProperty | cdk.IResolvable;
    }
    /**
     * The arc configuration of a `GaugeChartVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-arcconfiguration.html
     */
    interface ArcConfigurationProperty {
        /**
         * The option that determines the arc angle of a `GaugeChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-arcconfiguration.html#cfn-quicksight-template-arcconfiguration-arcangle
         */
        readonly arcAngle?: number;
        /**
         * The options that determine the arc thickness of a `GaugeChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-arcconfiguration.html#cfn-quicksight-template-arcconfiguration-arcthickness
         */
        readonly arcThickness?: string;
    }
    /**
     * The arc axis configuration of a `GaugeChartVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-arcaxisconfiguration.html
     */
    interface ArcAxisConfigurationProperty {
        /**
         * The arc axis range of a `GaugeChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-arcaxisconfiguration.html#cfn-quicksight-template-arcaxisconfiguration-range
         */
        readonly range?: CfnTemplate.ArcAxisDisplayRangeProperty | cdk.IResolvable;
        /**
         * The reserved range of the arc axis.
         *
         * @default - 0
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-arcaxisconfiguration.html#cfn-quicksight-template-arcaxisconfiguration-reserverange
         */
        readonly reserveRange?: number;
    }
    /**
     * The arc axis range of a `GaugeChartVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-arcaxisdisplayrange.html
     */
    interface ArcAxisDisplayRangeProperty {
        /**
         * The maximum value of the arc axis range.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-arcaxisdisplayrange.html#cfn-quicksight-template-arcaxisdisplayrange-max
         */
        readonly max?: number;
        /**
         * The minimum value of the arc axis range.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-arcaxisdisplayrange.html#cfn-quicksight-template-arcaxisdisplayrange-min
         */
        readonly min?: number;
    }
    /**
     * A line chart.
     *
     * For more information, see [Using line charts](https://docs.aws.amazon.com/quicksight/latest/user/line-charts.html) in the *Amazon QuickSight User Guide* .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartvisual.html
     */
    interface LineChartVisualProperty {
        /**
         * The list of custom actions that are configured for a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartvisual.html#cfn-quicksight-template-linechartvisual-actions
         */
        readonly actions?: Array<cdk.IResolvable | CfnTemplate.VisualCustomActionProperty> | cdk.IResolvable;
        /**
         * The configuration of a line chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartvisual.html#cfn-quicksight-template-linechartvisual-chartconfiguration
         */
        readonly chartConfiguration?: cdk.IResolvable | CfnTemplate.LineChartConfigurationProperty;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartvisual.html#cfn-quicksight-template-linechartvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnTemplate.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The subtitle that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartvisual.html#cfn-quicksight-template-linechartvisual-subtitle
         */
        readonly subtitle?: cdk.IResolvable | CfnTemplate.VisualSubtitleLabelOptionsProperty;
        /**
         * The title that is displayed on the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartvisual.html#cfn-quicksight-template-linechartvisual-title
         */
        readonly title?: cdk.IResolvable | CfnTemplate.VisualTitleLabelOptionsProperty;
        /**
         * The unique identifier of a visual.
         *
         * This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartvisual.html#cfn-quicksight-template-linechartvisual-visualid
         */
        readonly visualId: string;
    }
    /**
     * The configuration of a line chart.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html
     */
    interface LineChartConfigurationProperty {
        /**
         * The default configuration of a line chart's contribution analysis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-contributionanalysisdefaults
         */
        readonly contributionAnalysisDefaults?: Array<CfnTemplate.ContributionAnalysisDefaultProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The data label configuration of a line chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-datalabels
         */
        readonly dataLabels?: CfnTemplate.DataLabelOptionsProperty | cdk.IResolvable;
        /**
         * The options that determine the default presentation of all line series in `LineChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-defaultseriessettings
         */
        readonly defaultSeriesSettings?: cdk.IResolvable | CfnTemplate.LineChartDefaultSeriesSettingsProperty;
        /**
         * The field well configuration of a line chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-fieldwells
         */
        readonly fieldWells?: cdk.IResolvable | CfnTemplate.LineChartFieldWellsProperty;
        /**
         * The forecast configuration of a line chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-forecastconfigurations
         */
        readonly forecastConfigurations?: Array<CfnTemplate.ForecastConfigurationProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The legend configuration of a line chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-legend
         */
        readonly legend?: cdk.IResolvable | CfnTemplate.LegendOptionsProperty;
        /**
         * The series axis configuration of a line chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-primaryyaxisdisplayoptions
         */
        readonly primaryYAxisDisplayOptions?: cdk.IResolvable | CfnTemplate.LineSeriesAxisDisplayOptionsProperty;
        /**
         * The options that determine the presentation of the y-axis label.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-primaryyaxislabeloptions
         */
        readonly primaryYAxisLabelOptions?: CfnTemplate.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The reference lines configuration of a line chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-referencelines
         */
        readonly referenceLines?: Array<cdk.IResolvable | CfnTemplate.ReferenceLineProperty> | cdk.IResolvable;
        /**
         * The series axis configuration of a line chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-secondaryyaxisdisplayoptions
         */
        readonly secondaryYAxisDisplayOptions?: cdk.IResolvable | CfnTemplate.LineSeriesAxisDisplayOptionsProperty;
        /**
         * The options that determine the presentation of the secondary y-axis label.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-secondaryyaxislabeloptions
         */
        readonly secondaryYAxisLabelOptions?: CfnTemplate.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * The series item configuration of a line chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-series
         */
        readonly series?: Array<cdk.IResolvable | CfnTemplate.SeriesItemProperty> | cdk.IResolvable;
        /**
         * The small multiples setup for the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-smallmultiplesoptions
         */
        readonly smallMultiplesOptions?: cdk.IResolvable | CfnTemplate.SmallMultiplesOptionsProperty;
        /**
         * The sort configuration of a line chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: cdk.IResolvable | CfnTemplate.LineChartSortConfigurationProperty;
        /**
         * The tooltip configuration of a line chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-tooltip
         */
        readonly tooltip?: cdk.IResolvable | CfnTemplate.TooltipOptionsProperty;
        /**
         * Determines the type of the line chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-type
         */
        readonly type?: string;
        /**
         * The visual palette configuration of a line chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-visualpalette
         */
        readonly visualPalette?: cdk.IResolvable | CfnTemplate.VisualPaletteProperty;
        /**
         * The options that determine the presentation of the x-axis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-xaxisdisplayoptions
         */
        readonly xAxisDisplayOptions?: CfnTemplate.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * The options that determine the presentation of the x-axis label.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-xaxislabeloptions
         */
        readonly xAxisLabelOptions?: CfnTemplate.ChartAxisLabelOptionsProperty | cdk.IResolvable;
    }
    /**
     * The sort configuration of a line chart.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartsortconfiguration.html
     */
    interface LineChartSortConfigurationProperty {
        /**
         * The limit on the number of categories that are displayed in a line chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartsortconfiguration.html#cfn-quicksight-template-linechartsortconfiguration-categoryitemslimitconfiguration
         */
        readonly categoryItemsLimitConfiguration?: cdk.IResolvable | CfnTemplate.ItemsLimitConfigurationProperty;
        /**
         * The sort configuration of the category fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartsortconfiguration.html#cfn-quicksight-template-linechartsortconfiguration-categorysort
         */
        readonly categorySort?: Array<CfnTemplate.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The limit on the number of lines that are displayed in a line chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartsortconfiguration.html#cfn-quicksight-template-linechartsortconfiguration-coloritemslimitconfiguration
         */
        readonly colorItemsLimitConfiguration?: cdk.IResolvable | CfnTemplate.ItemsLimitConfigurationProperty;
        /**
         * The limit on the number of small multiples panels that are displayed.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartsortconfiguration.html#cfn-quicksight-template-linechartsortconfiguration-smallmultipleslimitconfiguration
         */
        readonly smallMultiplesLimitConfiguration?: cdk.IResolvable | CfnTemplate.ItemsLimitConfigurationProperty;
        /**
         * The sort configuration of the small multiples field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartsortconfiguration.html#cfn-quicksight-template-linechartsortconfiguration-smallmultiplessort
         */
        readonly smallMultiplesSort?: Array<CfnTemplate.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * The series axis configuration of a line chart.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-lineseriesaxisdisplayoptions.html
     */
    interface LineSeriesAxisDisplayOptionsProperty {
        /**
         * The options that determine the presentation of the line series axis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-lineseriesaxisdisplayoptions.html#cfn-quicksight-template-lineseriesaxisdisplayoptions-axisoptions
         */
        readonly axisOptions?: CfnTemplate.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * The configuration options that determine how missing data is treated during the rendering of a line chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-lineseriesaxisdisplayoptions.html#cfn-quicksight-template-lineseriesaxisdisplayoptions-missingdataconfigurations
         */
        readonly missingDataConfigurations?: Array<cdk.IResolvable | CfnTemplate.MissingDataConfigurationProperty> | cdk.IResolvable;
    }
    /**
     * The configuration options that determine how missing data is treated during the rendering of a line chart.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-missingdataconfiguration.html
     */
    interface MissingDataConfigurationProperty {
        /**
         * The treatment option that determines how missing data should be rendered. Choose from the following options:.
         *
         * - `INTERPOLATE` : Interpolate missing values between the prior and the next known value.
         * - `SHOW_AS_ZERO` : Show missing values as the value `0` .
         * - `SHOW_AS_BLANK` : Display a blank space when rendering missing data.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-missingdataconfiguration.html#cfn-quicksight-template-missingdataconfiguration-treatmentoption
         */
        readonly treatmentOption?: string;
    }
    /**
     * The options that determine the default presentation of all line series in `LineChartVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartdefaultseriessettings.html
     */
    interface LineChartDefaultSeriesSettingsProperty {
        /**
         * The axis to which you are binding all line series to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartdefaultseriessettings.html#cfn-quicksight-template-linechartdefaultseriessettings-axisbinding
         */
        readonly axisBinding?: string;
        /**
         * Line styles options for all line series in the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartdefaultseriessettings.html#cfn-quicksight-template-linechartdefaultseriessettings-linestylesettings
         */
        readonly lineStyleSettings?: cdk.IResolvable | CfnTemplate.LineChartLineStyleSettingsProperty;
        /**
         * Marker styles options for all line series in the visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartdefaultseriessettings.html#cfn-quicksight-template-linechartdefaultseriessettings-markerstylesettings
         */
        readonly markerStyleSettings?: cdk.IResolvable | CfnTemplate.LineChartMarkerStyleSettingsProperty;
    }
    /**
     * Line styles options for a line series in `LineChartVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartlinestylesettings.html
     */
    interface LineChartLineStyleSettingsProperty {
        /**
         * Interpolation style for line series.
         *
         * - `LINEAR` : Show as default, linear style.
         * - `SMOOTH` : Show as a smooth curve.
         * - `STEPPED` : Show steps in line.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartlinestylesettings.html#cfn-quicksight-template-linechartlinestylesettings-lineinterpolation
         */
        readonly lineInterpolation?: string;
        /**
         * Line style for line series.
         *
         * - `SOLID` : Show as a solid line.
         * - `DOTTED` : Show as a dotted line.
         * - `DASHED` : Show as a dashed line.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartlinestylesettings.html#cfn-quicksight-template-linechartlinestylesettings-linestyle
         */
        readonly lineStyle?: string;
        /**
         * Configuration option that determines whether to show the line for the series.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartlinestylesettings.html#cfn-quicksight-template-linechartlinestylesettings-linevisibility
         */
        readonly lineVisibility?: string;
        /**
         * Width that determines the line thickness.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartlinestylesettings.html#cfn-quicksight-template-linechartlinestylesettings-linewidth
         */
        readonly lineWidth?: string;
    }
    /**
     * Marker styles options for a line series in `LineChartVisual` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartmarkerstylesettings.html
     */
    interface LineChartMarkerStyleSettingsProperty {
        /**
         * Color of marker in the series.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartmarkerstylesettings.html#cfn-quicksight-template-linechartmarkerstylesettings-markercolor
         */
        readonly markerColor?: string;
        /**
         * Shape option for markers in the series.
         *
         * - `CIRCLE` : Show marker as a circle.
         * - `TRIANGLE` : Show marker as a triangle.
         * - `SQUARE` : Show marker as a square.
         * - `DIAMOND` : Show marker as a diamond.
         * - `ROUNDED_SQUARE` : Show marker as a rounded square.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartmarkerstylesettings.html#cfn-quicksight-template-linechartmarkerstylesettings-markershape
         */
        readonly markerShape?: string;
        /**
         * Size of marker in the series.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartmarkerstylesettings.html#cfn-quicksight-template-linechartmarkerstylesettings-markersize
         */
        readonly markerSize?: string;
        /**
         * Configuration option that determines whether to show the markers in the series.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartmarkerstylesettings.html#cfn-quicksight-template-linechartmarkerstylesettings-markervisibility
         */
        readonly markerVisibility?: string;
    }
    /**
     * The forecast configuration that is used in a line chart's display properties.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastconfiguration.html
     */
    interface ForecastConfigurationProperty {
        /**
         * The forecast properties setup of a forecast in the line chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastconfiguration.html#cfn-quicksight-template-forecastconfiguration-forecastproperties
         */
        readonly forecastProperties?: cdk.IResolvable | CfnTemplate.TimeBasedForecastPropertiesProperty;
        /**
         * The forecast scenario of a forecast in the line chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastconfiguration.html#cfn-quicksight-template-forecastconfiguration-scenario
         */
        readonly scenario?: CfnTemplate.ForecastScenarioProperty | cdk.IResolvable;
    }
    /**
     * The forecast properties setup of a forecast in the line chart.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timebasedforecastproperties.html
     */
    interface TimeBasedForecastPropertiesProperty {
        /**
         * The lower boundary setup of a forecast computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timebasedforecastproperties.html#cfn-quicksight-template-timebasedforecastproperties-lowerboundary
         */
        readonly lowerBoundary?: number;
        /**
         * The periods backward setup of a forecast computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timebasedforecastproperties.html#cfn-quicksight-template-timebasedforecastproperties-periodsbackward
         */
        readonly periodsBackward?: number;
        /**
         * The periods forward setup of a forecast computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timebasedforecastproperties.html#cfn-quicksight-template-timebasedforecastproperties-periodsforward
         */
        readonly periodsForward?: number;
        /**
         * The prediction interval setup of a forecast computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timebasedforecastproperties.html#cfn-quicksight-template-timebasedforecastproperties-predictioninterval
         */
        readonly predictionInterval?: number;
        /**
         * The seasonality setup of a forecast computation. Choose one of the following options:.
         *
         * - `NULL` : The input is set to `NULL` .
         * - `NON_NULL` : The input is set to a custom value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timebasedforecastproperties.html#cfn-quicksight-template-timebasedforecastproperties-seasonality
         */
        readonly seasonality?: number;
        /**
         * The upper boundary setup of a forecast computation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timebasedforecastproperties.html#cfn-quicksight-template-timebasedforecastproperties-upperboundary
         */
        readonly upperBoundary?: number;
    }
    /**
     * The forecast scenario of a forecast in the line chart.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastscenario.html
     */
    interface ForecastScenarioProperty {
        /**
         * The what-if analysis forecast setup with the target date.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastscenario.html#cfn-quicksight-template-forecastscenario-whatifpointscenario
         */
        readonly whatIfPointScenario?: cdk.IResolvable | CfnTemplate.WhatIfPointScenarioProperty;
        /**
         * The what-if analysis forecast setup with the date range.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastscenario.html#cfn-quicksight-template-forecastscenario-whatifrangescenario
         */
        readonly whatIfRangeScenario?: cdk.IResolvable | CfnTemplate.WhatIfRangeScenarioProperty;
    }
    /**
     * Provides the forecast to meet the target for a particular date range.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-whatifrangescenario.html
     */
    interface WhatIfRangeScenarioProperty {
        /**
         * The end date in the date range that you need the forecast results for.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-whatifrangescenario.html#cfn-quicksight-template-whatifrangescenario-enddate
         */
        readonly endDate: string;
        /**
         * The start date in the date range that you need the forecast results for.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-whatifrangescenario.html#cfn-quicksight-template-whatifrangescenario-startdate
         */
        readonly startDate: string;
        /**
         * The target value that you want to meet for the provided date range.
         *
         * @default - 0
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-whatifrangescenario.html#cfn-quicksight-template-whatifrangescenario-value
         */
        readonly value: number;
    }
    /**
     * Provides the forecast to meet the target for a particular date.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-whatifpointscenario.html
     */
    interface WhatIfPointScenarioProperty {
        /**
         * The date that you need the forecast results for.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-whatifpointscenario.html#cfn-quicksight-template-whatifpointscenario-date
         */
        readonly date: string;
        /**
         * The target value that you want to meet for the provided date.
         *
         * @default - 0
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-whatifpointscenario.html#cfn-quicksight-template-whatifpointscenario-value
         */
        readonly value: number;
    }
    /**
     * The series item configuration of a line chart.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-seriesitem.html
     */
    interface SeriesItemProperty {
        /**
         * The data field series item configuration of a line chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-seriesitem.html#cfn-quicksight-template-seriesitem-datafieldseriesitem
         */
        readonly dataFieldSeriesItem?: CfnTemplate.DataFieldSeriesItemProperty | cdk.IResolvable;
        /**
         * The field series item configuration of a line chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-seriesitem.html#cfn-quicksight-template-seriesitem-fieldseriesitem
         */
        readonly fieldSeriesItem?: CfnTemplate.FieldSeriesItemProperty | cdk.IResolvable;
    }
    /**
     * The field series item configuration of a line chart.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldseriesitem.html
     */
    interface FieldSeriesItemProperty {
        /**
         * The axis that you are binding the field to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldseriesitem.html#cfn-quicksight-template-fieldseriesitem-axisbinding
         */
        readonly axisBinding: string;
        /**
         * The field ID of the field for which you are setting the axis binding.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldseriesitem.html#cfn-quicksight-template-fieldseriesitem-fieldid
         */
        readonly fieldId: string;
        /**
         * The options that determine the presentation of line series associated to the field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldseriesitem.html#cfn-quicksight-template-fieldseriesitem-settings
         */
        readonly settings?: cdk.IResolvable | CfnTemplate.LineChartSeriesSettingsProperty;
    }
    /**
     * The options that determine the presentation of a line series in the visual.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartseriessettings.html
     */
    interface LineChartSeriesSettingsProperty {
        /**
         * Line styles options for a line series in `LineChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartseriessettings.html#cfn-quicksight-template-linechartseriessettings-linestylesettings
         */
        readonly lineStyleSettings?: cdk.IResolvable | CfnTemplate.LineChartLineStyleSettingsProperty;
        /**
         * Marker styles options for a line series in `LineChartVisual` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartseriessettings.html#cfn-quicksight-template-linechartseriessettings-markerstylesettings
         */
        readonly markerStyleSettings?: cdk.IResolvable | CfnTemplate.LineChartMarkerStyleSettingsProperty;
    }
    /**
     * The data field series item configuration of a line chart.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datafieldseriesitem.html
     */
    interface DataFieldSeriesItemProperty {
        /**
         * The axis that you are binding the field to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datafieldseriesitem.html#cfn-quicksight-template-datafieldseriesitem-axisbinding
         */
        readonly axisBinding: string;
        /**
         * The field ID of the field that you are setting the axis binding to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datafieldseriesitem.html#cfn-quicksight-template-datafieldseriesitem-fieldid
         */
        readonly fieldId: string;
        /**
         * The field value of the field that you are setting the axis binding to.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datafieldseriesitem.html#cfn-quicksight-template-datafieldseriesitem-fieldvalue
         */
        readonly fieldValue?: string;
        /**
         * The options that determine the presentation of line series associated to the field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datafieldseriesitem.html#cfn-quicksight-template-datafieldseriesitem-settings
         */
        readonly settings?: cdk.IResolvable | CfnTemplate.LineChartSeriesSettingsProperty;
    }
    /**
     * The field well configuration of a line chart.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartfieldwells.html
     */
    interface LineChartFieldWellsProperty {
        /**
         * The field well configuration of a line chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartfieldwells.html#cfn-quicksight-template-linechartfieldwells-linechartaggregatedfieldwells
         */
        readonly lineChartAggregatedFieldWells?: cdk.IResolvable | CfnTemplate.LineChartAggregatedFieldWellsProperty;
    }
    /**
     * The field well configuration of a line chart.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartaggregatedfieldwells.html
     */
    interface LineChartAggregatedFieldWellsProperty {
        /**
         * The category field wells of a line chart.
         *
         * Values are grouped by category fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartaggregatedfieldwells.html#cfn-quicksight-template-linechartaggregatedfieldwells-category
         */
        readonly category?: Array<CfnTemplate.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The color field wells of a line chart.
         *
         * Values are grouped by category fields.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartaggregatedfieldwells.html#cfn-quicksight-template-linechartaggregatedfieldwells-colors
         */
        readonly colors?: Array<CfnTemplate.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The small multiples field well of a line chart.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartaggregatedfieldwells.html#cfn-quicksight-template-linechartaggregatedfieldwells-smallmultiples
         */
        readonly smallMultiples?: Array<CfnTemplate.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The value field wells of a line chart.
         *
         * Values are aggregated based on categories.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartaggregatedfieldwells.html#cfn-quicksight-template-linechartaggregatedfieldwells-values
         */
        readonly values?: Array<cdk.IResolvable | CfnTemplate.MeasureFieldProperty> | cdk.IResolvable;
    }
    /**
     * An empty visual.
     *
     * Empty visuals are used in layouts but have not been configured to show any data. A new visual created in the Amazon QuickSight console is considered an `EmptyVisual` until a visual type is selected.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-emptyvisual.html
     */
    interface EmptyVisualProperty {
        /**
         * The list of custom actions that are configured for a visual.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-emptyvisual.html#cfn-quicksight-template-emptyvisual-actions
         */
        readonly actions?: Array<cdk.IResolvable | CfnTemplate.VisualCustomActionProperty> | cdk.IResolvable;
        /**
         * The data set that is used in the empty visual.
         *
         * Every visual requires a dataset to render.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-emptyvisual.html#cfn-quicksight-template-emptyvisual-datasetidentifier
         */
        readonly dataSetIdentifier: string;
        /**
         * The unique identifier of a visual.
         *
         * This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-emptyvisual.html#cfn-quicksight-template-emptyvisual-visualid
         */
        readonly visualId: string;
    }
    /**
     * The declaration definition of a parameter.
     *
     * For more information, see [Parameters in Amazon QuickSight](https://docs.aws.amazon.com/quicksight/latest/user/parameters-in-quicksight.html) in the *Amazon QuickSight User Guide* .
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdeclaration.html
     */
    interface ParameterDeclarationProperty {
        /**
         * A parameter declaration for the `DateTime` data type.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdeclaration.html#cfn-quicksight-template-parameterdeclaration-datetimeparameterdeclaration
         */
        readonly dateTimeParameterDeclaration?: CfnTemplate.DateTimeParameterDeclarationProperty | cdk.IResolvable;
        /**
         * A parameter declaration for the `Decimal` data type.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdeclaration.html#cfn-quicksight-template-parameterdeclaration-decimalparameterdeclaration
         */
        readonly decimalParameterDeclaration?: CfnTemplate.DecimalParameterDeclarationProperty | cdk.IResolvable;
        /**
         * A parameter declaration for the `Integer` data type.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdeclaration.html#cfn-quicksight-template-parameterdeclaration-integerparameterdeclaration
         */
        readonly integerParameterDeclaration?: CfnTemplate.IntegerParameterDeclarationProperty | cdk.IResolvable;
        /**
         * A parameter declaration for the `String` data type.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdeclaration.html#cfn-quicksight-template-parameterdeclaration-stringparameterdeclaration
         */
        readonly stringParameterDeclaration?: cdk.IResolvable | CfnTemplate.StringParameterDeclarationProperty;
    }
    /**
     * A parameter declaration for the `String` data type.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringparameterdeclaration.html
     */
    interface StringParameterDeclarationProperty {
        /**
         * The default values of a parameter.
         *
         * If the parameter is a single-value parameter, a maximum of one default value can be provided.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringparameterdeclaration.html#cfn-quicksight-template-stringparameterdeclaration-defaultvalues
         */
        readonly defaultValues?: cdk.IResolvable | CfnTemplate.StringDefaultValuesProperty;
        /**
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringparameterdeclaration.html#cfn-quicksight-template-stringparameterdeclaration-mappeddatasetparameters
         */
        readonly mappedDataSetParameters?: Array<cdk.IResolvable | CfnTemplate.MappedDataSetParameterProperty> | cdk.IResolvable;
        /**
         * The name of the parameter that is being declared.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringparameterdeclaration.html#cfn-quicksight-template-stringparameterdeclaration-name
         */
        readonly name: string;
        /**
         * The value type determines whether the parameter is a single-value or multi-value parameter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringparameterdeclaration.html#cfn-quicksight-template-stringparameterdeclaration-parametervaluetype
         */
        readonly parameterValueType: string;
        /**
         * The configuration that defines the default value of a `String` parameter when a value has not been set.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringparameterdeclaration.html#cfn-quicksight-template-stringparameterdeclaration-valuewhenunset
         */
        readonly valueWhenUnset?: cdk.IResolvable | CfnTemplate.StringValueWhenUnsetConfigurationProperty;
    }
    /**
     * A dataset parameter that is mapped to an analysis parameter.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-mappeddatasetparameter.html
     */
    interface MappedDataSetParameterProperty {
        /**
         * A unique name that identifies a dataset within the analysis or dashboard.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-mappeddatasetparameter.html#cfn-quicksight-template-mappeddatasetparameter-datasetidentifier
         */
        readonly dataSetIdentifier: string;
        /**
         * The name of the dataset parameter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-mappeddatasetparameter.html#cfn-quicksight-template-mappeddatasetparameter-datasetparametername
         */
        readonly dataSetParameterName: string;
    }
    /**
     * The default values of the `StringParameterDeclaration` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringdefaultvalues.html
     */
    interface StringDefaultValuesProperty {
        /**
         * The dynamic value of the `StringDefaultValues` .
         *
         * Different defaults displayed according to users, groups, and values mapping.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringdefaultvalues.html#cfn-quicksight-template-stringdefaultvalues-dynamicvalue
         */
        readonly dynamicValue?: CfnTemplate.DynamicDefaultValueProperty | cdk.IResolvable;
        /**
         * The static values of the `DecimalDefaultValues` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringdefaultvalues.html#cfn-quicksight-template-stringdefaultvalues-staticvalues
         */
        readonly staticValues?: Array<string>;
    }
    /**
     * Defines different defaults to the users or groups based on mapping.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-dynamicdefaultvalue.html
     */
    interface DynamicDefaultValueProperty {
        /**
         * The column that contains the default value of each user or group.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-dynamicdefaultvalue.html#cfn-quicksight-template-dynamicdefaultvalue-defaultvaluecolumn
         */
        readonly defaultValueColumn: CfnTemplate.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * The column that contains the group name.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-dynamicdefaultvalue.html#cfn-quicksight-template-dynamicdefaultvalue-groupnamecolumn
         */
        readonly groupNameColumn?: CfnTemplate.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * The column that contains the username.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-dynamicdefaultvalue.html#cfn-quicksight-template-dynamicdefaultvalue-usernamecolumn
         */
        readonly userNameColumn?: CfnTemplate.ColumnIdentifierProperty | cdk.IResolvable;
    }
    /**
     * The configuration that defines the default value of a `String` parameter when a value has not been set.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringvaluewhenunsetconfiguration.html
     */
    interface StringValueWhenUnsetConfigurationProperty {
        /**
         * A custom value that's used when the value of a parameter isn't set.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringvaluewhenunsetconfiguration.html#cfn-quicksight-template-stringvaluewhenunsetconfiguration-customvalue
         */
        readonly customValue?: string;
        /**
         * The built-in options for default values. The value can be one of the following:.
         *
         * - `RECOMMENDED` : The recommended value.
         * - `NULL` : The `NULL` value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringvaluewhenunsetconfiguration.html#cfn-quicksight-template-stringvaluewhenunsetconfiguration-valuewhenunsetoption
         */
        readonly valueWhenUnsetOption?: string;
    }
    /**
     * A parameter declaration for the `DateTime` data type.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimeparameterdeclaration.html
     */
    interface DateTimeParameterDeclarationProperty {
        /**
         * The default values of a parameter.
         *
         * If the parameter is a single-value parameter, a maximum of one default value can be provided.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimeparameterdeclaration.html#cfn-quicksight-template-datetimeparameterdeclaration-defaultvalues
         */
        readonly defaultValues?: CfnTemplate.DateTimeDefaultValuesProperty | cdk.IResolvable;
        /**
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimeparameterdeclaration.html#cfn-quicksight-template-datetimeparameterdeclaration-mappeddatasetparameters
         */
        readonly mappedDataSetParameters?: Array<cdk.IResolvable | CfnTemplate.MappedDataSetParameterProperty> | cdk.IResolvable;
        /**
         * The name of the parameter that is being declared.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimeparameterdeclaration.html#cfn-quicksight-template-datetimeparameterdeclaration-name
         */
        readonly name: string;
        /**
         * The level of time precision that is used to aggregate `DateTime` values.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimeparameterdeclaration.html#cfn-quicksight-template-datetimeparameterdeclaration-timegranularity
         */
        readonly timeGranularity?: string;
        /**
         * The configuration that defines the default value of a `DateTime` parameter when a value has not been set.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimeparameterdeclaration.html#cfn-quicksight-template-datetimeparameterdeclaration-valuewhenunset
         */
        readonly valueWhenUnset?: CfnTemplate.DateTimeValueWhenUnsetConfigurationProperty | cdk.IResolvable;
    }
    /**
     * The default values of the `DateTimeParameterDeclaration` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimedefaultvalues.html
     */
    interface DateTimeDefaultValuesProperty {
        /**
         * The dynamic value of the `DataTimeDefaultValues` .
         *
         * Different defaults are displayed according to users, groups, and values mapping.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimedefaultvalues.html#cfn-quicksight-template-datetimedefaultvalues-dynamicvalue
         */
        readonly dynamicValue?: CfnTemplate.DynamicDefaultValueProperty | cdk.IResolvable;
        /**
         * The rolling date of the `DataTimeDefaultValues` .
         *
         * The date is determined from the dataset based on input expression.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimedefaultvalues.html#cfn-quicksight-template-datetimedefaultvalues-rollingdate
         */
        readonly rollingDate?: cdk.IResolvable | CfnTemplate.RollingDateConfigurationProperty;
        /**
         * The static values of the `DataTimeDefaultValues` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimedefaultvalues.html#cfn-quicksight-template-datetimedefaultvalues-staticvalues
         */
        readonly staticValues?: Array<string>;
    }
    /**
     * The configuration that defines the default value of a `DateTime` parameter when a value has not been set.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimevaluewhenunsetconfiguration.html
     */
    interface DateTimeValueWhenUnsetConfigurationProperty {
        /**
         * A custom value that's used when the value of a parameter isn't set.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimevaluewhenunsetconfiguration.html#cfn-quicksight-template-datetimevaluewhenunsetconfiguration-customvalue
         */
        readonly customValue?: string;
        /**
         * The built-in options for default values. The value can be one of the following:.
         *
         * - `RECOMMENDED` : The recommended value.
         * - `NULL` : The `NULL` value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimevaluewhenunsetconfiguration.html#cfn-quicksight-template-datetimevaluewhenunsetconfiguration-valuewhenunsetoption
         */
        readonly valueWhenUnsetOption?: string;
    }
    /**
     * A parameter declaration for the `Decimal` data type.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-decimalparameterdeclaration.html
     */
    interface DecimalParameterDeclarationProperty {
        /**
         * The default values of a parameter.
         *
         * If the parameter is a single-value parameter, a maximum of one default value can be provided.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-decimalparameterdeclaration.html#cfn-quicksight-template-decimalparameterdeclaration-defaultvalues
         */
        readonly defaultValues?: CfnTemplate.DecimalDefaultValuesProperty | cdk.IResolvable;
        /**
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-decimalparameterdeclaration.html#cfn-quicksight-template-decimalparameterdeclaration-mappeddatasetparameters
         */
        readonly mappedDataSetParameters?: Array<cdk.IResolvable | CfnTemplate.MappedDataSetParameterProperty> | cdk.IResolvable;
        /**
         * The name of the parameter that is being declared.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-decimalparameterdeclaration.html#cfn-quicksight-template-decimalparameterdeclaration-name
         */
        readonly name: string;
        /**
         * The value type determines whether the parameter is a single-value or multi-value parameter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-decimalparameterdeclaration.html#cfn-quicksight-template-decimalparameterdeclaration-parametervaluetype
         */
        readonly parameterValueType: string;
        /**
         * The configuration that defines the default value of a `Decimal` parameter when a value has not been set.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-decimalparameterdeclaration.html#cfn-quicksight-template-decimalparameterdeclaration-valuewhenunset
         */
        readonly valueWhenUnset?: CfnTemplate.DecimalValueWhenUnsetConfigurationProperty | cdk.IResolvable;
    }
    /**
     * The default values of the `DecimalParameterDeclaration` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-decimaldefaultvalues.html
     */
    interface DecimalDefaultValuesProperty {
        /**
         * The dynamic value of the `DecimalDefaultValues` .
         *
         * Different defaults are displayed according to users, groups, and values mapping.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-decimaldefaultvalues.html#cfn-quicksight-template-decimaldefaultvalues-dynamicvalue
         */
        readonly dynamicValue?: CfnTemplate.DynamicDefaultValueProperty | cdk.IResolvable;
        /**
         * The static values of the `DecimalDefaultValues` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-decimaldefaultvalues.html#cfn-quicksight-template-decimaldefaultvalues-staticvalues
         */
        readonly staticValues?: Array<number> | cdk.IResolvable;
    }
    /**
     * The configuration that defines the default value of a `Decimal` parameter when a value has not been set.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-decimalvaluewhenunsetconfiguration.html
     */
    interface DecimalValueWhenUnsetConfigurationProperty {
        /**
         * A custom value that's used when the value of a parameter isn't set.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-decimalvaluewhenunsetconfiguration.html#cfn-quicksight-template-decimalvaluewhenunsetconfiguration-customvalue
         */
        readonly customValue?: number;
        /**
         * The built-in options for default values. The value can be one of the following:.
         *
         * - `RECOMMENDED` : The recommended value.
         * - `NULL` : The `NULL` value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-decimalvaluewhenunsetconfiguration.html#cfn-quicksight-template-decimalvaluewhenunsetconfiguration-valuewhenunsetoption
         */
        readonly valueWhenUnsetOption?: string;
    }
    /**
     * A parameter declaration for the `Integer` data type.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-integerparameterdeclaration.html
     */
    interface IntegerParameterDeclarationProperty {
        /**
         * The default values of a parameter.
         *
         * If the parameter is a single-value parameter, a maximum of one default value can be provided.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-integerparameterdeclaration.html#cfn-quicksight-template-integerparameterdeclaration-defaultvalues
         */
        readonly defaultValues?: CfnTemplate.IntegerDefaultValuesProperty | cdk.IResolvable;
        /**
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-integerparameterdeclaration.html#cfn-quicksight-template-integerparameterdeclaration-mappeddatasetparameters
         */
        readonly mappedDataSetParameters?: Array<cdk.IResolvable | CfnTemplate.MappedDataSetParameterProperty> | cdk.IResolvable;
        /**
         * The name of the parameter that is being declared.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-integerparameterdeclaration.html#cfn-quicksight-template-integerparameterdeclaration-name
         */
        readonly name: string;
        /**
         * The value type determines whether the parameter is a single-value or multi-value parameter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-integerparameterdeclaration.html#cfn-quicksight-template-integerparameterdeclaration-parametervaluetype
         */
        readonly parameterValueType: string;
        /**
         * A parameter declaration for the `Integer` data type.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-integerparameterdeclaration.html#cfn-quicksight-template-integerparameterdeclaration-valuewhenunset
         */
        readonly valueWhenUnset?: CfnTemplate.IntegerValueWhenUnsetConfigurationProperty | cdk.IResolvable;
    }
    /**
     * The default values of the `IntegerParameterDeclaration` .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-integerdefaultvalues.html
     */
    interface IntegerDefaultValuesProperty {
        /**
         * The dynamic value of the `IntegerDefaultValues` .
         *
         * Different defaults are displayed according to users, groups, and values mapping.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-integerdefaultvalues.html#cfn-quicksight-template-integerdefaultvalues-dynamicvalue
         */
        readonly dynamicValue?: CfnTemplate.DynamicDefaultValueProperty | cdk.IResolvable;
        /**
         * The static values of the `IntegerDefaultValues` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-integerdefaultvalues.html#cfn-quicksight-template-integerdefaultvalues-staticvalues
         */
        readonly staticValues?: Array<number> | cdk.IResolvable;
    }
    /**
     * A parameter declaration for the `Integer` data type.
     *
     * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-integervaluewhenunsetconfiguration.html
     */
    interface IntegerValueWhenUnsetConfigurationProperty {
        /**
         * A custom value that's used when the value of a parameter isn't set.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-integervaluewhenunsetconfiguration.html#cfn-quicksight-template-integervaluewhenunsetconfiguration-customvalue
         */
        readonly customValue?: number;
        /**
         * The built-in options for default values. The value can be one of the following:.
         *
         * - `RECOMMENDED` : The recommended value.
         * - `NULL` : The `NULL` value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-integervaluewhenunsetconfiguration.html#cfn-quicksight-template-integervaluewhenunsetconfiguration-valuewhenunsetoption
         */
        readonly valueWhenUnsetOption?: string;
    }
    /**
     * An array of analysis level configurations.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-assetoptions.html
     */
    interface AssetOptionsProperty {
        /**
         * Determines the timezone for the analysis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-assetoptions.html#cfn-quicksight-template-assetoptions-timezone
         */
        readonly timezone?: string;
        /**
         * Determines the week start day for an analysis.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-assetoptions.html#cfn-quicksight-template-assetoptions-weekstart
         */
        readonly weekStart?: string;
    }
    /**
     * Permission for the resource.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-resourcepermission.html
     */
    interface ResourcePermissionProperty {
        /**
         * The IAM action to grant or revoke permissions on.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-resourcepermission.html#cfn-quicksight-template-resourcepermission-actions
         */
        readonly actions: Array<string>;
        /**
         * The Amazon Resource Name (ARN) of the principal. This can be one of the following:.
         *
         * - The ARN of an Amazon QuickSight user or group associated with a data source or dataset. (This is common.)
         * - The ARN of an Amazon QuickSight user, group, or namespace associated with an analysis, dashboard, template, or theme. (This is common.)
         * - The ARN of an AWS account root: This is an IAM ARN rather than a Amazon QuickSight ARN. Use this option only to share resources (templates) across AWS accounts . (This is less common.)
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-resourcepermission.html#cfn-quicksight-template-resourcepermission-principal
         */
        readonly principal: string;
        /**
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-resourcepermission.html#cfn-quicksight-template-resourcepermission-resource
         */
        readonly resource?: string;
    }
    /**
     * The option to relax the validation that is required to create and update analyses, dashboards, and templates with definition objects.
     *
     * When you set this value to `LENIENT` , validation is skipped for specific errors.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-validationstrategy.html
     */
    interface ValidationStrategyProperty {
        /**
         * The mode of validation for the asset to be created or updated.
         *
         * When you set this value to `STRICT` , strict validation for every error is enforced. When you set this value to `LENIENT` , validation is skipped for specific UI errors.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-validationstrategy.html#cfn-quicksight-template-validationstrategy-mode
         */
        readonly mode: string;
    }
    /**
     * A *sheet* , which is an object that contains a set of visuals that are viewed together on one page in Amazon QuickSight.
     *
     * Every analysis and dashboard contains at least one sheet. Each sheet contains at least one visualization widget, for example a chart, pivot table, or narrative insight. Sheets can be associated with other components, such as controls, filters, and so on.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheet.html
     */
    interface SheetProperty {
        /**
         * The name of a sheet.
         *
         * This name is displayed on the sheet's tab in the Amazon QuickSight console.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheet.html#cfn-quicksight-template-sheet-name
         */
        readonly name?: string;
        /**
         * The unique identifier associated with a sheet.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheet.html#cfn-quicksight-template-sheet-sheetid
         */
        readonly sheetId?: string;
    }
    /**
     * List of errors that occurred when the template version creation failed.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateerror.html
     */
    interface TemplateErrorProperty {
        /**
         * Description of the error type.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateerror.html#cfn-quicksight-template-templateerror-message
         */
        readonly message?: string;
        /**
         * Type of error.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateerror.html#cfn-quicksight-template-templateerror-type
         */
        readonly type?: string;
        /**
         * An error path that shows which entities caused the template error.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateerror.html#cfn-quicksight-template-templateerror-violatedentities
         */
        readonly violatedEntities?: Array<CfnTemplate.EntityProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * An object, structure, or sub-structure of an analysis, template, or dashboard.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-entity.html
     */
    interface EntityProperty {
        /**
         * The hierarchical path of the entity within the analysis, template, or dashboard definition tree.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-entity.html#cfn-quicksight-template-entity-path
         */
        readonly path?: string;
    }
    /**
     * A version of a template.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversion.html
     */
    interface TemplateVersionProperty {
        /**
         * The time that this template version was created.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversion.html#cfn-quicksight-template-templateversion-createdtime
         */
        readonly createdTime?: string;
        /**
         * Schema of the dataset identified by the placeholder.
         *
         * Any dashboard created from this template should be bound to new datasets matching the same schema described through this API operation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversion.html#cfn-quicksight-template-templateversion-datasetconfigurations
         */
        readonly dataSetConfigurations?: Array<CfnTemplate.DataSetConfigurationProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The description of the template.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversion.html#cfn-quicksight-template-templateversion-description
         */
        readonly description?: string;
        /**
         * Errors associated with this template version.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversion.html#cfn-quicksight-template-templateversion-errors
         */
        readonly errors?: Array<cdk.IResolvable | CfnTemplate.TemplateErrorProperty> | cdk.IResolvable;
        /**
         * A list of the associated sheets with the unique identifier and name of each sheet.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversion.html#cfn-quicksight-template-templateversion-sheets
         */
        readonly sheets?: Array<cdk.IResolvable | CfnTemplate.SheetProperty> | cdk.IResolvable;
        /**
         * The Amazon Resource Name (ARN) of an analysis or template that was used to create this template.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversion.html#cfn-quicksight-template-templateversion-sourceentityarn
         */
        readonly sourceEntityArn?: string;
        /**
         * The status that is associated with the template.
         *
         * - `CREATION_IN_PROGRESS`
         * - `CREATION_SUCCESSFUL`
         * - `CREATION_FAILED`
         * - `UPDATE_IN_PROGRESS`
         * - `UPDATE_SUCCESSFUL`
         * - `UPDATE_FAILED`
         * - `DELETED`
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversion.html#cfn-quicksight-template-templateversion-status
         */
        readonly status?: string;
        /**
         * The ARN of the theme associated with this version of the template.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversion.html#cfn-quicksight-template-templateversion-themearn
         */
        readonly themeArn?: string;
        /**
         * The version number of the template version.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversion.html#cfn-quicksight-template-templateversion-versionnumber
         */
        readonly versionNumber?: number;
    }
}
/**
 * Properties for defining a `CfnTemplate`
 *
 * @struct
 * @stability external
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html
 */
export interface CfnTemplateProps {
    /**
     * The ID for the AWS account that the group is in.
     *
     * You use the ID for the AWS account that contains your Amazon QuickSight account.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html#cfn-quicksight-template-awsaccountid
     */
    readonly awsAccountId: string;
    /**
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html#cfn-quicksight-template-definition
     */
    readonly definition?: cdk.IResolvable | CfnTemplate.TemplateVersionDefinitionProperty;
    /**
     * A display name for the template.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html#cfn-quicksight-template-name
     */
    readonly name?: string;
    /**
     * A list of resource permissions to be set on the template.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html#cfn-quicksight-template-permissions
     */
    readonly permissions?: Array<cdk.IResolvable | CfnTemplate.ResourcePermissionProperty> | cdk.IResolvable;
    /**
     * The entity that you are using as a source when you create the template.
     *
     * In `SourceEntity` , you specify the type of object you're using as source: `SourceTemplate` for a template or `SourceAnalysis` for an analysis. Both of these require an Amazon Resource Name (ARN). For `SourceTemplate` , specify the ARN of the source template. For `SourceAnalysis` , specify the ARN of the source analysis. The `SourceTemplate` ARN can contain any AWS account and any Amazon QuickSight-supported AWS Region .
     *
     * Use the `DataSetReferences` entity within `SourceTemplate` or `SourceAnalysis` to list the replacement datasets for the placeholders listed in the original. The schema in each dataset must match its placeholder.
     *
     * Either a `SourceEntity` or a `Definition` must be provided in order for the request to be valid.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html#cfn-quicksight-template-sourceentity
     */
    readonly sourceEntity?: cdk.IResolvable | CfnTemplate.TemplateSourceEntityProperty;
    /**
     * Contains a map of the key-value pairs for the resource tag or tags assigned to the resource.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html#cfn-quicksight-template-tags
     */
    readonly tags?: Array<cdk.CfnTag>;
    /**
     * An ID for the template that you want to create.
     *
     * This template is unique per AWS Region ; in each AWS account.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html#cfn-quicksight-template-templateid
     */
    readonly templateId: string;
    /**
     * The option to relax the validation that is required to create and update analyses, dashboards, and templates with definition objects.
     *
     * When you set this value to `LENIENT` , validation is skipped for specific errors.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html#cfn-quicksight-template-validationstrategy
     */
    readonly validationStrategy?: cdk.IResolvable | CfnTemplate.ValidationStrategyProperty;
    /**
     * A description of the current template version being created.
     *
     * This API operation creates the first version of the template. Every time `UpdateTemplate` is called, a new version is created. Each version of the template maintains a description of the version in the `VersionDescription` field.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html#cfn-quicksight-template-versiondescription
     */
    readonly versionDescription?: string;
}
/**
 * Creates a theme.
 *
 * A *theme* is set of configuration options for color and layout. Themes apply to analyses and dashboards. For more information, see [Using Themes in Amazon QuickSight](https://docs.aws.amazon.com/quicksight/latest/user/themes-in-quicksight.html) in the *Amazon QuickSight User Guide* .
 *
 * @cloudformationResource AWS::QuickSight::Theme
 * @stability external
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html
 */
export declare class CfnTheme extends cdk.CfnResource implements cdk.IInspectable, cdk.ITaggable {
    /**
     * The CloudFormation resource type name for this resource class.
     */
    static readonly CFN_RESOURCE_TYPE_NAME: string;
    /**
     * Build a CfnTheme from CloudFormation properties
     *
     * A factory method that creates a new instance of this class from an object
     * containing the CloudFormation properties of this resource.
     * Used in the @aws-cdk/cloudformation-include module.
     *
     * @internal
     */
    static _fromCloudFormation(scope: constructs.Construct, id: string, resourceAttributes: any, options: cfn_parse.FromCloudFormationOptions): CfnTheme;
    /**
     * The Amazon Resource Name (ARN) of the theme.
     *
     * @cloudformationAttribute Arn
     */
    readonly attrArn: string;
    /**
     * The time the theme was created.
     *
     * @cloudformationAttribute CreatedTime
     */
    readonly attrCreatedTime: string;
    /**
     * The time the theme was last updated.
     *
     * @cloudformationAttribute LastUpdatedTime
     */
    readonly attrLastUpdatedTime: string;
    /**
     * Theme type.
     *
     * @cloudformationAttribute Type
     */
    readonly attrType: string;
    /**
     * The version of the theme.
     *
     * @cloudformationAttribute Version
     */
    readonly attrVersion: cdk.IResolvable;
    /**
     * @cloudformationAttribute Version.Arn
     */
    readonly attrVersionArn: string;
    /**
     * @cloudformationAttribute Version.BaseThemeId
     */
    readonly attrVersionBaseThemeId: string;
    /**
     * @cloudformationAttribute Version.Configuration
     */
    readonly attrVersionConfiguration: cdk.IResolvable;
    /**
     * @cloudformationAttribute Version.Configuration.DataColorPalette
     */
    readonly attrVersionConfigurationDataColorPalette: cdk.IResolvable;
    /**
     * @cloudformationAttribute Version.Configuration.Sheet
     */
    readonly attrVersionConfigurationSheet: cdk.IResolvable;
    /**
     * @cloudformationAttribute Version.Configuration.Typography
     */
    readonly attrVersionConfigurationTypography: cdk.IResolvable;
    /**
     * @cloudformationAttribute Version.Configuration.UIColorPalette
     */
    readonly attrVersionConfigurationUiColorPalette: cdk.IResolvable;
    /**
     * @cloudformationAttribute Version.CreatedTime
     */
    readonly attrVersionCreatedTime: string;
    /**
     * @cloudformationAttribute Version.Description
     */
    readonly attrVersionDescription: string;
    /**
     * @cloudformationAttribute Version.Errors
     */
    readonly attrVersionErrors: cdk.IResolvable;
    /**
     * @cloudformationAttribute Version.Status
     */
    readonly attrVersionStatus: string;
    /**
     * @cloudformationAttribute Version.VersionNumber
     */
    readonly attrVersionVersionNumber: cdk.IResolvable;
    /**
     * The ID of the AWS account where you want to store the new theme.
     */
    awsAccountId: string;
    /**
     * The ID of the theme that a custom theme will inherit from.
     */
    baseThemeId: string;
    /**
     * The theme configuration, which contains the theme display properties.
     */
    configuration: cdk.IResolvable | CfnTheme.ThemeConfigurationProperty;
    /**
     * A display name for the theme.
     */
    name: string;
    /**
     * A valid grouping of resource permissions to apply to the new theme.
     */
    permissions?: Array<cdk.IResolvable | CfnTheme.ResourcePermissionProperty> | cdk.IResolvable;
    /**
     * Tag Manager which manages the tags for this resource
     */
    readonly tags: cdk.TagManager;
    /**
     * A map of the key-value pairs for the resource tag or tags that you want to add to the resource.
     */
    tagsRaw?: Array<cdk.CfnTag>;
    /**
     * An ID for the theme that you want to create.
     */
    themeId: string;
    /**
     * A description of the first version of the theme that you're creating.
     */
    versionDescription?: string;
    /**
     * @param scope Scope in which this resource is defined
     * @param id Construct identifier for this resource (unique in its scope)
     * @param props Resource properties
     */
    constructor(scope: constructs.Construct, id: string, props: CfnThemeProps);
    protected get cfnProperties(): Record<string, any>;
    /**
     * Examines the CloudFormation resource and discloses attributes
     *
     * @param inspector tree inspector to collect and process attributes
     */
    inspect(inspector: cdk.TreeInspector): void;
    protected renderProperties(props: Record<string, any>): Record<string, any>;
}
export declare namespace CfnTheme {
    /**
     * The theme configuration.
     *
     * This configuration contains all of the display properties for a theme.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeconfiguration.html
     */
    interface ThemeConfigurationProperty {
        /**
         * Color properties that apply to chart data colors.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeconfiguration.html#cfn-quicksight-theme-themeconfiguration-datacolorpalette
         */
        readonly dataColorPalette?: CfnTheme.DataColorPaletteProperty | cdk.IResolvable;
        /**
         * Display options related to sheets.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeconfiguration.html#cfn-quicksight-theme-themeconfiguration-sheet
         */
        readonly sheet?: cdk.IResolvable | CfnTheme.SheetStyleProperty;
        /**
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeconfiguration.html#cfn-quicksight-theme-themeconfiguration-typography
         */
        readonly typography?: cdk.IResolvable | CfnTheme.TypographyProperty;
        /**
         * Color properties that apply to the UI and to charts, excluding the colors that apply to data.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeconfiguration.html#cfn-quicksight-theme-themeconfiguration-uicolorpalette
         */
        readonly uiColorPalette?: cdk.IResolvable | CfnTheme.UIColorPaletteProperty;
    }
    /**
     * The theme colors that are used for data colors in charts.
     *
     * The colors description is a hexadecimal color code that consists of six alphanumerical characters, prefixed with `#` , for example #37BFF5.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-datacolorpalette.html
     */
    interface DataColorPaletteProperty {
        /**
         * The hexadecimal codes for the colors.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-datacolorpalette.html#cfn-quicksight-theme-datacolorpalette-colors
         */
        readonly colors?: Array<string>;
        /**
         * The hexadecimal code of a color that applies to charts where a lack of data is highlighted.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-datacolorpalette.html#cfn-quicksight-theme-datacolorpalette-emptyfillcolor
         */
        readonly emptyFillColor?: string;
        /**
         * The minimum and maximum hexadecimal codes that describe a color gradient.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-datacolorpalette.html#cfn-quicksight-theme-datacolorpalette-minmaxgradient
         */
        readonly minMaxGradient?: Array<string>;
    }
    /**
     * The theme colors that apply to UI and to charts, excluding data colors.
     *
     * The colors description is a hexadecimal color code that consists of six alphanumerical characters, prefixed with `#` , for example #37BFF5. For more information, see [Using Themes in Amazon QuickSight](https://docs.aws.amazon.com/quicksight/latest/user/themes-in-quicksight.html) in the *Amazon QuickSight User Guide.*
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html
     */
    interface UIColorPaletteProperty {
        /**
         * This color is that applies to selected states and buttons.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-accent
         */
        readonly accent?: string;
        /**
         * The foreground color that applies to any text or other elements that appear over the accent color.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-accentforeground
         */
        readonly accentForeground?: string;
        /**
         * The color that applies to error messages.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-danger
         */
        readonly danger?: string;
        /**
         * The foreground color that applies to any text or other elements that appear over the error color.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-dangerforeground
         */
        readonly dangerForeground?: string;
        /**
         * The color that applies to the names of fields that are identified as dimensions.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-dimension
         */
        readonly dimension?: string;
        /**
         * The foreground color that applies to any text or other elements that appear over the dimension color.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-dimensionforeground
         */
        readonly dimensionForeground?: string;
        /**
         * The color that applies to the names of fields that are identified as measures.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-measure
         */
        readonly measure?: string;
        /**
         * The foreground color that applies to any text or other elements that appear over the measure color.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-measureforeground
         */
        readonly measureForeground?: string;
        /**
         * The background color that applies to visuals and other high emphasis UI.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-primarybackground
         */
        readonly primaryBackground?: string;
        /**
         * The color of text and other foreground elements that appear over the primary background regions, such as grid lines, borders, table banding, icons, and so on.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-primaryforeground
         */
        readonly primaryForeground?: string;
        /**
         * The background color that applies to the sheet background and sheet controls.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-secondarybackground
         */
        readonly secondaryBackground?: string;
        /**
         * The foreground color that applies to any sheet title, sheet control text, or UI that appears over the secondary background.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-secondaryforeground
         */
        readonly secondaryForeground?: string;
        /**
         * The color that applies to success messages, for example the check mark for a successful download.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-success
         */
        readonly success?: string;
        /**
         * The foreground color that applies to any text or other elements that appear over the success color.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-successforeground
         */
        readonly successForeground?: string;
        /**
         * This color that applies to warning and informational messages.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-warning
         */
        readonly warning?: string;
        /**
         * The foreground color that applies to any text or other elements that appear over the warning color.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-warningforeground
         */
        readonly warningForeground?: string;
    }
    /**
     * The theme display options for sheets.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-sheetstyle.html
     */
    interface SheetStyleProperty {
        /**
         * The display options for tiles.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-sheetstyle.html#cfn-quicksight-theme-sheetstyle-tile
         */
        readonly tile?: cdk.IResolvable | CfnTheme.TileStyleProperty;
        /**
         * The layout options for tiles.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-sheetstyle.html#cfn-quicksight-theme-sheetstyle-tilelayout
         */
        readonly tileLayout?: cdk.IResolvable | CfnTheme.TileLayoutStyleProperty;
    }
    /**
     * The display options for the layout of tiles on a sheet.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-tilelayoutstyle.html
     */
    interface TileLayoutStyleProperty {
        /**
         * The gutter settings that apply between tiles.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-tilelayoutstyle.html#cfn-quicksight-theme-tilelayoutstyle-gutter
         */
        readonly gutter?: CfnTheme.GutterStyleProperty | cdk.IResolvable;
        /**
         * The margin settings that apply around the outside edge of sheets.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-tilelayoutstyle.html#cfn-quicksight-theme-tilelayoutstyle-margin
         */
        readonly margin?: cdk.IResolvable | CfnTheme.MarginStyleProperty;
    }
    /**
     * The display options for gutter spacing between tiles on a sheet.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-gutterstyle.html
     */
    interface GutterStyleProperty {
        /**
         * This Boolean value controls whether to display a gutter space between sheet tiles.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-gutterstyle.html#cfn-quicksight-theme-gutterstyle-show
         */
        readonly show?: boolean | cdk.IResolvable;
    }
    /**
     * The display options for margins around the outside edge of sheets.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-marginstyle.html
     */
    interface MarginStyleProperty {
        /**
         * This Boolean value controls whether to display sheet margins.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-marginstyle.html#cfn-quicksight-theme-marginstyle-show
         */
        readonly show?: boolean | cdk.IResolvable;
    }
    /**
     * Display options related to tiles on a sheet.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-tilestyle.html
     */
    interface TileStyleProperty {
        /**
         * The border around a tile.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-tilestyle.html#cfn-quicksight-theme-tilestyle-border
         */
        readonly border?: CfnTheme.BorderStyleProperty | cdk.IResolvable;
    }
    /**
     * The display options for tile borders for visuals.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-borderstyle.html
     */
    interface BorderStyleProperty {
        /**
         * The option to enable display of borders for visuals.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-borderstyle.html#cfn-quicksight-theme-borderstyle-show
         */
        readonly show?: boolean | cdk.IResolvable;
    }
    /**
     * Determines the typography options.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-typography.html
     */
    interface TypographyProperty {
        /**
         * Determines the list of font families.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-typography.html#cfn-quicksight-theme-typography-fontfamilies
         */
        readonly fontFamilies?: Array<CfnTheme.FontProperty | cdk.IResolvable> | cdk.IResolvable;
    }
    /**
     * Determines the font settings.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-font.html
     */
    interface FontProperty {
        /**
         * Determines the font family settings.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-font.html#cfn-quicksight-theme-font-fontfamily
         */
        readonly fontFamily?: string;
    }
    /**
     * Permission for the resource.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-resourcepermission.html
     */
    interface ResourcePermissionProperty {
        /**
         * The IAM action to grant or revoke permissions on.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-resourcepermission.html#cfn-quicksight-theme-resourcepermission-actions
         */
        readonly actions: Array<string>;
        /**
         * The Amazon Resource Name (ARN) of the principal. This can be one of the following:.
         *
         * - The ARN of an Amazon QuickSight user or group associated with a data source or dataset. (This is common.)
         * - The ARN of an Amazon QuickSight user, group, or namespace associated with an analysis, dashboard, template, or theme. (This is common.)
         * - The ARN of an AWS account root: This is an IAM ARN rather than a Amazon QuickSight ARN. Use this option only to share resources (templates) across AWS accounts . (This is less common.)
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-resourcepermission.html#cfn-quicksight-theme-resourcepermission-principal
         */
        readonly principal: string;
        /**
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-resourcepermission.html#cfn-quicksight-theme-resourcepermission-resource
         */
        readonly resource?: string;
    }
    /**
     * Theme error.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeerror.html
     */
    interface ThemeErrorProperty {
        /**
         * The error message.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeerror.html#cfn-quicksight-theme-themeerror-message
         */
        readonly message?: string;
        /**
         * The type of error.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeerror.html#cfn-quicksight-theme-themeerror-type
         */
        readonly type?: string;
    }
    /**
     * A version of a theme.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeversion.html
     */
    interface ThemeVersionProperty {
        /**
         * The Amazon Resource Name (ARN) of the resource.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeversion.html#cfn-quicksight-theme-themeversion-arn
         */
        readonly arn?: string;
        /**
         * The Amazon QuickSight-defined ID of the theme that a custom theme inherits from.
         *
         * All themes initially inherit from a default Amazon QuickSight theme.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeversion.html#cfn-quicksight-theme-themeversion-basethemeid
         */
        readonly baseThemeId?: string;
        /**
         * The theme configuration, which contains all the theme display properties.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeversion.html#cfn-quicksight-theme-themeversion-configuration
         */
        readonly configuration?: cdk.IResolvable | CfnTheme.ThemeConfigurationProperty;
        /**
         * The date and time that this theme version was created.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeversion.html#cfn-quicksight-theme-themeversion-createdtime
         */
        readonly createdTime?: string;
        /**
         * The description of the theme.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeversion.html#cfn-quicksight-theme-themeversion-description
         */
        readonly description?: string;
        /**
         * Errors associated with the theme.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeversion.html#cfn-quicksight-theme-themeversion-errors
         */
        readonly errors?: Array<cdk.IResolvable | CfnTheme.ThemeErrorProperty> | cdk.IResolvable;
        /**
         * The status of the theme version.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeversion.html#cfn-quicksight-theme-themeversion-status
         */
        readonly status?: string;
        /**
         * The version number of the theme.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeversion.html#cfn-quicksight-theme-themeversion-versionnumber
         */
        readonly versionNumber?: number;
    }
}
/**
 * Properties for defining a `CfnTheme`
 *
 * @struct
 * @stability external
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html
 */
export interface CfnThemeProps {
    /**
     * The ID of the AWS account where you want to store the new theme.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html#cfn-quicksight-theme-awsaccountid
     */
    readonly awsAccountId: string;
    /**
     * The ID of the theme that a custom theme will inherit from.
     *
     * All themes inherit from one of the starting themes defined by Amazon QuickSight. For a list of the starting themes, use `ListThemes` or choose *Themes* from within an analysis.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html#cfn-quicksight-theme-basethemeid
     */
    readonly baseThemeId: string;
    /**
     * The theme configuration, which contains the theme display properties.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html#cfn-quicksight-theme-configuration
     */
    readonly configuration: cdk.IResolvable | CfnTheme.ThemeConfigurationProperty;
    /**
     * A display name for the theme.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html#cfn-quicksight-theme-name
     */
    readonly name: string;
    /**
     * A valid grouping of resource permissions to apply to the new theme.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html#cfn-quicksight-theme-permissions
     */
    readonly permissions?: Array<cdk.IResolvable | CfnTheme.ResourcePermissionProperty> | cdk.IResolvable;
    /**
     * A map of the key-value pairs for the resource tag or tags that you want to add to the resource.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html#cfn-quicksight-theme-tags
     */
    readonly tags?: Array<cdk.CfnTag>;
    /**
     * An ID for the theme that you want to create.
     *
     * The theme ID is unique per AWS Region in each AWS account.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html#cfn-quicksight-theme-themeid
     */
    readonly themeId: string;
    /**
     * A description of the first version of the theme that you're creating.
     *
     * Every time `UpdateTheme` is called, a new version is created. Each version of the theme has a description of the version in the `VersionDescription` field.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html#cfn-quicksight-theme-versiondescription
     */
    readonly versionDescription?: string;
}
/**
 * Creates a new Q topic.
 *
 * @cloudformationResource AWS::QuickSight::Topic
 * @stability external
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-topic.html
 */
export declare class CfnTopic extends cdk.CfnResource implements cdk.IInspectable {
    /**
     * The CloudFormation resource type name for this resource class.
     */
    static readonly CFN_RESOURCE_TYPE_NAME: string;
    /**
     * Build a CfnTopic from CloudFormation properties
     *
     * A factory method that creates a new instance of this class from an object
     * containing the CloudFormation properties of this resource.
     * Used in the @aws-cdk/cloudformation-include module.
     *
     * @internal
     */
    static _fromCloudFormation(scope: constructs.Construct, id: string, resourceAttributes: any, options: cfn_parse.FromCloudFormationOptions): CfnTopic;
    /**
     * The Amazon Resource Name (ARN) of the topic.
     *
     * @cloudformationAttribute Arn
     */
    readonly attrArn: string;
    /**
     * The ID of the AWS account that you want to create a topic in.
     */
    awsAccountId?: string;
    /**
     * The data sets that the topic is associated with.
     */
    dataSets?: Array<CfnTopic.DatasetMetadataProperty | cdk.IResolvable> | cdk.IResolvable;
    /**
     * The description of the topic.
     */
    description?: string;
    /**
     * The name of the topic.
     */
    name?: string;
    /**
     * The ID for the topic.
     */
    topicId?: string;
    /**
     * The user experience version of a topic.
     */
    userExperienceVersion?: string;
    /**
     * @param scope Scope in which this resource is defined
     * @param id Construct identifier for this resource (unique in its scope)
     * @param props Resource properties
     */
    constructor(scope: constructs.Construct, id: string, props?: CfnTopicProps);
    protected get cfnProperties(): Record<string, any>;
    /**
     * Examines the CloudFormation resource and discloses attributes
     *
     * @param inspector tree inspector to collect and process attributes
     */
    inspect(inspector: cdk.TreeInspector): void;
    protected renderProperties(props: Record<string, any>): Record<string, any>;
}
export declare namespace CfnTopic {
    /**
     * A structure that represents a dataset.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-datasetmetadata.html
     */
    interface DatasetMetadataProperty {
        /**
         * The list of calculated field definitions.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-datasetmetadata.html#cfn-quicksight-topic-datasetmetadata-calculatedfields
         */
        readonly calculatedFields?: Array<cdk.IResolvable | CfnTopic.TopicCalculatedFieldProperty> | cdk.IResolvable;
        /**
         * The list of column definitions.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-datasetmetadata.html#cfn-quicksight-topic-datasetmetadata-columns
         */
        readonly columns?: Array<cdk.IResolvable | CfnTopic.TopicColumnProperty> | cdk.IResolvable;
        /**
         * The definition of a data aggregation.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-datasetmetadata.html#cfn-quicksight-topic-datasetmetadata-dataaggregation
         */
        readonly dataAggregation?: CfnTopic.DataAggregationProperty | cdk.IResolvable;
        /**
         * The Amazon Resource Name (ARN) of the dataset.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-datasetmetadata.html#cfn-quicksight-topic-datasetmetadata-datasetarn
         */
        readonly datasetArn: string;
        /**
         * The description of the dataset.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-datasetmetadata.html#cfn-quicksight-topic-datasetmetadata-datasetdescription
         */
        readonly datasetDescription?: string;
        /**
         * The name of the dataset.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-datasetmetadata.html#cfn-quicksight-topic-datasetmetadata-datasetname
         */
        readonly datasetName?: string;
        /**
         * The list of filter definitions.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-datasetmetadata.html#cfn-quicksight-topic-datasetmetadata-filters
         */
        readonly filters?: Array<cdk.IResolvable | CfnTopic.TopicFilterProperty> | cdk.IResolvable;
        /**
         * The list of named entities definitions.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-datasetmetadata.html#cfn-quicksight-topic-datasetmetadata-namedentities
         */
        readonly namedEntities?: Array<cdk.IResolvable | CfnTopic.TopicNamedEntityProperty> | cdk.IResolvable;
    }
    /**
     * A structure that represents a filter used to select items for a topic.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicfilter.html
     */
    interface TopicFilterProperty {
        /**
         * The category filter that is associated with this filter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicfilter.html#cfn-quicksight-topic-topicfilter-categoryfilter
         */
        readonly categoryFilter?: cdk.IResolvable | CfnTopic.TopicCategoryFilterProperty;
        /**
         * The date range filter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicfilter.html#cfn-quicksight-topic-topicfilter-daterangefilter
         */
        readonly dateRangeFilter?: cdk.IResolvable | CfnTopic.TopicDateRangeFilterProperty;
        /**
         * The class of the filter.
         *
         * Valid values for this structure are `ENFORCED_VALUE_FILTER` , `CONDITIONAL_VALUE_FILTER` , and `NAMED_VALUE_FILTER` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicfilter.html#cfn-quicksight-topic-topicfilter-filterclass
         */
        readonly filterClass?: string;
        /**
         * A description of the filter used to select items for a topic.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicfilter.html#cfn-quicksight-topic-topicfilter-filterdescription
         */
        readonly filterDescription?: string;
        /**
         * The name of the filter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicfilter.html#cfn-quicksight-topic-topicfilter-filtername
         */
        readonly filterName: string;
        /**
         * The other names or aliases for the filter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicfilter.html#cfn-quicksight-topic-topicfilter-filtersynonyms
         */
        readonly filterSynonyms?: Array<string>;
        /**
         * The type of the filter.
         *
         * Valid values for this structure are `CATEGORY_FILTER` , `NUMERIC_EQUALITY_FILTER` , `NUMERIC_RANGE_FILTER` , `DATE_RANGE_FILTER` , and `RELATIVE_DATE_FILTER` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicfilter.html#cfn-quicksight-topic-topicfilter-filtertype
         */
        readonly filterType?: string;
        /**
         * The numeric equality filter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicfilter.html#cfn-quicksight-topic-topicfilter-numericequalityfilter
         */
        readonly numericEqualityFilter?: cdk.IResolvable | CfnTopic.TopicNumericEqualityFilterProperty;
        /**
         * The numeric range filter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicfilter.html#cfn-quicksight-topic-topicfilter-numericrangefilter
         */
        readonly numericRangeFilter?: cdk.IResolvable | CfnTopic.TopicNumericRangeFilterProperty;
        /**
         * The name of the field that the filter operates on.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicfilter.html#cfn-quicksight-topic-topicfilter-operandfieldname
         */
        readonly operandFieldName: string;
        /**
         * The relative date filter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicfilter.html#cfn-quicksight-topic-topicfilter-relativedatefilter
         */
        readonly relativeDateFilter?: cdk.IResolvable | CfnTopic.TopicRelativeDateFilterProperty;
    }
    /**
     * A structure that represents a relative date filter.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicrelativedatefilter.html
     */
    interface TopicRelativeDateFilterProperty {
        /**
         * The constant used in a relative date filter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicrelativedatefilter.html#cfn-quicksight-topic-topicrelativedatefilter-constant
         */
        readonly constant?: cdk.IResolvable | CfnTopic.TopicSingularFilterConstantProperty;
        /**
         * The function to be used in a relative date filter to determine the range of dates to include in the results.
         *
         * Valid values for this structure are `BEFORE` , `AFTER` , and `BETWEEN` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicrelativedatefilter.html#cfn-quicksight-topic-topicrelativedatefilter-relativedatefilterfunction
         */
        readonly relativeDateFilterFunction?: string;
        /**
         * The level of time precision that is used to aggregate `DateTime` values.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicrelativedatefilter.html#cfn-quicksight-topic-topicrelativedatefilter-timegranularity
         */
        readonly timeGranularity?: string;
    }
    /**
     * A structure that represents a singular filter constant, used in filters to specify a single value to match against.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicsingularfilterconstant.html
     */
    interface TopicSingularFilterConstantProperty {
        /**
         * The type of the singular filter constant.
         *
         * Valid values for this structure are `SINGULAR` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicsingularfilterconstant.html#cfn-quicksight-topic-topicsingularfilterconstant-constanttype
         */
        readonly constantType?: string;
        /**
         * The value of the singular filter constant.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicsingularfilterconstant.html#cfn-quicksight-topic-topicsingularfilterconstant-singularconstant
         */
        readonly singularConstant?: string;
    }
    /**
     * A filter that filters topics based on the value of a numeric field.
     *
     * The filter includes only topics whose numeric field value matches the specified value.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicnumericequalityfilter.html
     */
    interface TopicNumericEqualityFilterProperty {
        /**
         * An aggregation function that specifies how to calculate the value of a numeric field for a topic.
         *
         * Valid values for this structure are `NO_AGGREGATION` , `SUM` , `AVERAGE` , `COUNT` , `DISTINCT_COUNT` , `MAX` , `MEDIAN` , `MIN` , `STDEV` , `STDEVP` , `VAR` , and `VARP` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicnumericequalityfilter.html#cfn-quicksight-topic-topicnumericequalityfilter-aggregation
         */
        readonly aggregation?: string;
        /**
         * The constant used in a numeric equality filter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicnumericequalityfilter.html#cfn-quicksight-topic-topicnumericequalityfilter-constant
         */
        readonly constant?: cdk.IResolvable | CfnTopic.TopicSingularFilterConstantProperty;
    }
    /**
     * A filter that filters topics based on the value of a numeric field.
     *
     * The filter includes only topics whose numeric field value falls within the specified range.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicnumericrangefilter.html
     */
    interface TopicNumericRangeFilterProperty {
        /**
         * An aggregation function that specifies how to calculate the value of a numeric field for a topic, Valid values for this structure are `NO_AGGREGATION` , `SUM` , `AVERAGE` , `COUNT` , `DISTINCT_COUNT` , `MAX` , `MEDIAN` , `MIN` , `STDEV` , `STDEVP` , `VAR` , and `VARP` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicnumericrangefilter.html#cfn-quicksight-topic-topicnumericrangefilter-aggregation
         */
        readonly aggregation?: string;
        /**
         * The constant used in a numeric range filter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicnumericrangefilter.html#cfn-quicksight-topic-topicnumericrangefilter-constant
         */
        readonly constant?: cdk.IResolvable | CfnTopic.TopicRangeFilterConstantProperty;
        /**
         * A Boolean value that indicates whether the endpoints of the numeric range are included in the filter.
         *
         * If set to true, topics whose numeric field value is equal to the endpoint values will be included in the filter. If set to false, topics whose numeric field value is equal to the endpoint values will be excluded from the filter.
         *
         * @default - false
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicnumericrangefilter.html#cfn-quicksight-topic-topicnumericrangefilter-inclusive
         */
        readonly inclusive?: boolean | cdk.IResolvable;
    }
    /**
     * A constant value that is used in a range filter to specify the endpoints of the range.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicrangefilterconstant.html
     */
    interface TopicRangeFilterConstantProperty {
        /**
         * The data type of the constant value that is used in a range filter.
         *
         * Valid values for this structure are `RANGE` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicrangefilterconstant.html#cfn-quicksight-topic-topicrangefilterconstant-constanttype
         */
        readonly constantType?: string;
        /**
         * The value of the constant that is used to specify the endpoints of a range filter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicrangefilterconstant.html#cfn-quicksight-topic-topicrangefilterconstant-rangeconstant
         */
        readonly rangeConstant?: cdk.IResolvable | CfnTopic.RangeConstantProperty;
    }
    /**
     * The value of the constant that is used to specify the endpoints of a range filter.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-rangeconstant.html
     */
    interface RangeConstantProperty {
        /**
         * The maximum value for a range constant.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-rangeconstant.html#cfn-quicksight-topic-rangeconstant-maximum
         */
        readonly maximum?: string;
        /**
         * The minimum value for a range constant.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-rangeconstant.html#cfn-quicksight-topic-rangeconstant-minimum
         */
        readonly minimum?: string;
    }
    /**
     * A filter used to restrict data based on a range of dates or times.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicdaterangefilter.html
     */
    interface TopicDateRangeFilterProperty {
        /**
         * The constant used in a date range filter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicdaterangefilter.html#cfn-quicksight-topic-topicdaterangefilter-constant
         */
        readonly constant?: cdk.IResolvable | CfnTopic.TopicRangeFilterConstantProperty;
        /**
         * A Boolean value that indicates whether the date range filter should include the boundary values.
         *
         * If set to true, the filter includes the start and end dates. If set to false, the filter excludes them.
         *
         * @default - false
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicdaterangefilter.html#cfn-quicksight-topic-topicdaterangefilter-inclusive
         */
        readonly inclusive?: boolean | cdk.IResolvable;
    }
    /**
     * A structure that represents a category filter.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccategoryfilter.html
     */
    interface TopicCategoryFilterProperty {
        /**
         * The category filter function.
         *
         * Valid values for this structure are `EXACT` and `CONTAINS` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccategoryfilter.html#cfn-quicksight-topic-topiccategoryfilter-categoryfilterfunction
         */
        readonly categoryFilterFunction?: string;
        /**
         * The category filter type.
         *
         * This element is used to specify whether a filter is a simple category filter or an inverse category filter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccategoryfilter.html#cfn-quicksight-topic-topiccategoryfilter-categoryfiltertype
         */
        readonly categoryFilterType?: string;
        /**
         * The constant used in a category filter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccategoryfilter.html#cfn-quicksight-topic-topiccategoryfilter-constant
         */
        readonly constant?: cdk.IResolvable | CfnTopic.TopicCategoryFilterConstantProperty;
        /**
         * A Boolean value that indicates if the filter is inverse.
         *
         * @default - false
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccategoryfilter.html#cfn-quicksight-topic-topiccategoryfilter-inverse
         */
        readonly inverse?: boolean | cdk.IResolvable;
    }
    /**
     * A constant used in a category filter.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccategoryfilterconstant.html
     */
    interface TopicCategoryFilterConstantProperty {
        /**
         * A collective constant used in a category filter.
         *
         * This element is used to specify a list of values for the constant.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccategoryfilterconstant.html#cfn-quicksight-topic-topiccategoryfilterconstant-collectiveconstant
         */
        readonly collectiveConstant?: CfnTopic.CollectiveConstantProperty | cdk.IResolvable;
        /**
         * The type of category filter constant.
         *
         * This element is used to specify whether a constant is a singular or collective. Valid values are `SINGULAR` and `COLLECTIVE` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccategoryfilterconstant.html#cfn-quicksight-topic-topiccategoryfilterconstant-constanttype
         */
        readonly constantType?: string;
        /**
         * A singular constant used in a category filter.
         *
         * This element is used to specify a single value for the constant.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccategoryfilterconstant.html#cfn-quicksight-topic-topiccategoryfilterconstant-singularconstant
         */
        readonly singularConstant?: string;
    }
    /**
     * A structure that represents a collective constant.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-collectiveconstant.html
     */
    interface CollectiveConstantProperty {
        /**
         * A list of values for the collective constant.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-collectiveconstant.html#cfn-quicksight-topic-collectiveconstant-valuelist
         */
        readonly valueList?: Array<string>;
    }
    /**
     * A structure that represents a named entity.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicnamedentity.html
     */
    interface TopicNamedEntityProperty {
        /**
         * The definition of a named entity.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicnamedentity.html#cfn-quicksight-topic-topicnamedentity-definition
         */
        readonly definition?: Array<cdk.IResolvable | CfnTopic.NamedEntityDefinitionProperty> | cdk.IResolvable;
        /**
         * The description of the named entity.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicnamedentity.html#cfn-quicksight-topic-topicnamedentity-entitydescription
         */
        readonly entityDescription?: string;
        /**
         * The name of the named entity.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicnamedentity.html#cfn-quicksight-topic-topicnamedentity-entityname
         */
        readonly entityName: string;
        /**
         * The other names or aliases for the named entity.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicnamedentity.html#cfn-quicksight-topic-topicnamedentity-entitysynonyms
         */
        readonly entitySynonyms?: Array<string>;
        /**
         * The type of named entity that a topic represents.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicnamedentity.html#cfn-quicksight-topic-topicnamedentity-semanticentitytype
         */
        readonly semanticEntityType?: cdk.IResolvable | CfnTopic.SemanticEntityTypeProperty;
    }
    /**
     * A structure that represents a semantic entity type.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-semanticentitytype.html
     */
    interface SemanticEntityTypeProperty {
        /**
         * The semantic entity sub type name.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-semanticentitytype.html#cfn-quicksight-topic-semanticentitytype-subtypename
         */
        readonly subTypeName?: string;
        /**
         * The semantic entity type name.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-semanticentitytype.html#cfn-quicksight-topic-semanticentitytype-typename
         */
        readonly typeName?: string;
        /**
         * The semantic entity type parameters.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-semanticentitytype.html#cfn-quicksight-topic-semanticentitytype-typeparameters
         */
        readonly typeParameters?: cdk.IResolvable | Record<string, string>;
    }
    /**
     * A structure that represents a named entity.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-namedentitydefinition.html
     */
    interface NamedEntityDefinitionProperty {
        /**
         * The name of the entity.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-namedentitydefinition.html#cfn-quicksight-topic-namedentitydefinition-fieldname
         */
        readonly fieldName?: string;
        /**
         * The definition of a metric.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-namedentitydefinition.html#cfn-quicksight-topic-namedentitydefinition-metric
         */
        readonly metric?: cdk.IResolvable | CfnTopic.NamedEntityDefinitionMetricProperty;
        /**
         * The property name to be used for the named entity.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-namedentitydefinition.html#cfn-quicksight-topic-namedentitydefinition-propertyname
         */
        readonly propertyName?: string;
        /**
         * The property role.
         *
         * Valid values for this structure are `PRIMARY` and `ID` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-namedentitydefinition.html#cfn-quicksight-topic-namedentitydefinition-propertyrole
         */
        readonly propertyRole?: string;
        /**
         * The property usage.
         *
         * Valid values for this structure are `INHERIT` , `DIMENSION` , and `MEASURE` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-namedentitydefinition.html#cfn-quicksight-topic-namedentitydefinition-propertyusage
         */
        readonly propertyUsage?: string;
    }
    /**
     * A structure that represents a metric.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-namedentitydefinitionmetric.html
     */
    interface NamedEntityDefinitionMetricProperty {
        /**
         * The aggregation of a named entity.
         *
         * Valid values for this structure are `SUM` , `MIN` , `MAX` , `COUNT` , `AVERAGE` , `DISTINCT_COUNT` , `STDEV` , `STDEVP` , `VAR` , `VARP` , `PERCENTILE` , `MEDIAN` , and `CUSTOM` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-namedentitydefinitionmetric.html#cfn-quicksight-topic-namedentitydefinitionmetric-aggregation
         */
        readonly aggregation?: string;
        /**
         * The additional parameters for an aggregation function.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-namedentitydefinitionmetric.html#cfn-quicksight-topic-namedentitydefinitionmetric-aggregationfunctionparameters
         */
        readonly aggregationFunctionParameters?: cdk.IResolvable | Record<string, string>;
    }
    /**
     * A structure that represents a calculated field.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccalculatedfield.html
     */
    interface TopicCalculatedFieldProperty {
        /**
         * The default aggregation.
         *
         * Valid values for this structure are `SUM` , `MAX` , `MIN` , `COUNT` , `DISTINCT_COUNT` , and `AVERAGE` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccalculatedfield.html#cfn-quicksight-topic-topiccalculatedfield-aggregation
         */
        readonly aggregation?: string;
        /**
         * The list of aggregation types that are allowed for the calculated field.
         *
         * Valid values for this structure are `COUNT` , `DISTINCT_COUNT` , `MIN` , `MAX` , `MEDIAN` , `SUM` , `AVERAGE` , `STDEV` , `STDEVP` , `VAR` , `VARP` , and `PERCENTILE` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccalculatedfield.html#cfn-quicksight-topic-topiccalculatedfield-allowedaggregations
         */
        readonly allowedAggregations?: Array<string>;
        /**
         * The calculated field description.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccalculatedfield.html#cfn-quicksight-topic-topiccalculatedfield-calculatedfielddescription
         */
        readonly calculatedFieldDescription?: string;
        /**
         * The calculated field name.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccalculatedfield.html#cfn-quicksight-topic-topiccalculatedfield-calculatedfieldname
         */
        readonly calculatedFieldName: string;
        /**
         * The other names or aliases for the calculated field.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccalculatedfield.html#cfn-quicksight-topic-topiccalculatedfield-calculatedfieldsynonyms
         */
        readonly calculatedFieldSynonyms?: Array<string>;
        /**
         * The other names or aliases for the calculated field cell value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccalculatedfield.html#cfn-quicksight-topic-topiccalculatedfield-cellvaluesynonyms
         */
        readonly cellValueSynonyms?: Array<CfnTopic.CellValueSynonymProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The column data role for a calculated field.
         *
         * Valid values for this structure are `DIMENSION` and `MEASURE` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccalculatedfield.html#cfn-quicksight-topic-topiccalculatedfield-columndatarole
         */
        readonly columnDataRole?: string;
        /**
         * The order in which data is displayed for the calculated field when it's used in a comparative context.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccalculatedfield.html#cfn-quicksight-topic-topiccalculatedfield-comparativeorder
         */
        readonly comparativeOrder?: CfnTopic.ComparativeOrderProperty | cdk.IResolvable;
        /**
         * The default formatting definition.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccalculatedfield.html#cfn-quicksight-topic-topiccalculatedfield-defaultformatting
         */
        readonly defaultFormatting?: CfnTopic.DefaultFormattingProperty | cdk.IResolvable;
        /**
         * The calculated field expression.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccalculatedfield.html#cfn-quicksight-topic-topiccalculatedfield-expression
         */
        readonly expression: string;
        /**
         * A boolean value that indicates if a calculated field is included in the topic.
         *
         * @default - false
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccalculatedfield.html#cfn-quicksight-topic-topiccalculatedfield-isincludedintopic
         */
        readonly isIncludedInTopic?: boolean | cdk.IResolvable;
        /**
         * A Boolean value that indicates whether to never aggregate calculated field in filters.
         *
         * @default - false
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccalculatedfield.html#cfn-quicksight-topic-topiccalculatedfield-neveraggregateinfilter
         */
        readonly neverAggregateInFilter?: boolean | cdk.IResolvable;
        /**
         * The non additive for the table style target.
         *
         * @default - false
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccalculatedfield.html#cfn-quicksight-topic-topiccalculatedfield-nonadditive
         */
        readonly nonAdditive?: boolean | cdk.IResolvable;
        /**
         * The list of aggregation types that are not allowed for the calculated field.
         *
         * Valid values for this structure are `COUNT` , `DISTINCT_COUNT` , `MIN` , `MAX` , `MEDIAN` , `SUM` , `AVERAGE` , `STDEV` , `STDEVP` , `VAR` , `VARP` , and `PERCENTILE` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccalculatedfield.html#cfn-quicksight-topic-topiccalculatedfield-notallowedaggregations
         */
        readonly notAllowedAggregations?: Array<string>;
        /**
         * The semantic type.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccalculatedfield.html#cfn-quicksight-topic-topiccalculatedfield-semantictype
         */
        readonly semanticType?: cdk.IResolvable | CfnTopic.SemanticTypeProperty;
        /**
         * The level of time precision that is used to aggregate `DateTime` values.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccalculatedfield.html#cfn-quicksight-topic-topiccalculatedfield-timegranularity
         */
        readonly timeGranularity?: string;
    }
    /**
     * A structure that represents a semantic type.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-semantictype.html
     */
    interface SemanticTypeProperty {
        /**
         * The semantic type falsey cell value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-semantictype.html#cfn-quicksight-topic-semantictype-falseycellvalue
         */
        readonly falseyCellValue?: string;
        /**
         * The other names or aliases for the false cell value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-semantictype.html#cfn-quicksight-topic-semantictype-falseycellvaluesynonyms
         */
        readonly falseyCellValueSynonyms?: Array<string>;
        /**
         * The semantic type sub type name.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-semantictype.html#cfn-quicksight-topic-semantictype-subtypename
         */
        readonly subTypeName?: string;
        /**
         * The semantic type truthy cell value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-semantictype.html#cfn-quicksight-topic-semantictype-truthycellvalue
         */
        readonly truthyCellValue?: string;
        /**
         * The other names or aliases for the true cell value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-semantictype.html#cfn-quicksight-topic-semantictype-truthycellvaluesynonyms
         */
        readonly truthyCellValueSynonyms?: Array<string>;
        /**
         * The semantic type name.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-semantictype.html#cfn-quicksight-topic-semantictype-typename
         */
        readonly typeName?: string;
        /**
         * The semantic type parameters.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-semantictype.html#cfn-quicksight-topic-semantictype-typeparameters
         */
        readonly typeParameters?: cdk.IResolvable | Record<string, string>;
    }
    /**
     * A structure that represents a default formatting definition.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-defaultformatting.html
     */
    interface DefaultFormattingProperty {
        /**
         * The display format.
         *
         * Valid values for this structure are `AUTO` , `PERCENT` , `CURRENCY` , `NUMBER` , `DATE` , and `STRING` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-defaultformatting.html#cfn-quicksight-topic-defaultformatting-displayformat
         */
        readonly displayFormat?: string;
        /**
         * The additional options for display formatting.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-defaultformatting.html#cfn-quicksight-topic-defaultformatting-displayformatoptions
         */
        readonly displayFormatOptions?: CfnTopic.DisplayFormatOptionsProperty | cdk.IResolvable;
    }
    /**
     * A structure that represents additional options for display formatting.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-displayformatoptions.html
     */
    interface DisplayFormatOptionsProperty {
        /**
         * Determines the blank cell format.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-displayformatoptions.html#cfn-quicksight-topic-displayformatoptions-blankcellformat
         */
        readonly blankCellFormat?: string;
        /**
         * The currency symbol, such as `USD` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-displayformatoptions.html#cfn-quicksight-topic-displayformatoptions-currencysymbol
         */
        readonly currencySymbol?: string;
        /**
         * Determines the `DateTime` format.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-displayformatoptions.html#cfn-quicksight-topic-displayformatoptions-dateformat
         */
        readonly dateFormat?: string;
        /**
         * Determines the decimal separator.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-displayformatoptions.html#cfn-quicksight-topic-displayformatoptions-decimalseparator
         */
        readonly decimalSeparator?: string;
        /**
         * Determines the number of fraction digits.
         *
         * @default - 0
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-displayformatoptions.html#cfn-quicksight-topic-displayformatoptions-fractiondigits
         */
        readonly fractionDigits?: number;
        /**
         * Determines the grouping separator.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-displayformatoptions.html#cfn-quicksight-topic-displayformatoptions-groupingseparator
         */
        readonly groupingSeparator?: string;
        /**
         * The negative format.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-displayformatoptions.html#cfn-quicksight-topic-displayformatoptions-negativeformat
         */
        readonly negativeFormat?: cdk.IResolvable | CfnTopic.NegativeFormatProperty;
        /**
         * The prefix value for a display format.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-displayformatoptions.html#cfn-quicksight-topic-displayformatoptions-prefix
         */
        readonly prefix?: string;
        /**
         * The suffix value for a display format.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-displayformatoptions.html#cfn-quicksight-topic-displayformatoptions-suffix
         */
        readonly suffix?: string;
        /**
         * The unit scaler.
         *
         * Valid values for this structure are: `NONE` , `AUTO` , `THOUSANDS` , `MILLIONS` , `BILLIONS` , and `TRILLIONS` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-displayformatoptions.html#cfn-quicksight-topic-displayformatoptions-unitscaler
         */
        readonly unitScaler?: string;
        /**
         * A Boolean value that indicates whether to use blank cell format.
         *
         * @default - false
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-displayformatoptions.html#cfn-quicksight-topic-displayformatoptions-useblankcellformat
         */
        readonly useBlankCellFormat?: boolean | cdk.IResolvable;
        /**
         * A Boolean value that indicates whether to use grouping.
         *
         * @default - false
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-displayformatoptions.html#cfn-quicksight-topic-displayformatoptions-usegrouping
         */
        readonly useGrouping?: boolean | cdk.IResolvable;
    }
    /**
     * A structure that represents a negative format.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-negativeformat.html
     */
    interface NegativeFormatProperty {
        /**
         * The prefix for a negative format.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-negativeformat.html#cfn-quicksight-topic-negativeformat-prefix
         */
        readonly prefix?: string;
        /**
         * The suffix for a negative format.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-negativeformat.html#cfn-quicksight-topic-negativeformat-suffix
         */
        readonly suffix?: string;
    }
    /**
     * The order in which data is displayed for the column when it's used in a comparative context.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-comparativeorder.html
     */
    interface ComparativeOrderProperty {
        /**
         * The list of columns to be used in the ordering.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-comparativeorder.html#cfn-quicksight-topic-comparativeorder-specifedorder
         */
        readonly specifedOrder?: Array<string>;
        /**
         * The treat of undefined specified values.
         *
         * Valid values for this structure are `LEAST` and `MOST` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-comparativeorder.html#cfn-quicksight-topic-comparativeorder-treatundefinedspecifiedvalues
         */
        readonly treatUndefinedSpecifiedValues?: string;
        /**
         * The ordering type for a column.
         *
         * Valid values for this structure are `GREATER_IS_BETTER` , `LESSER_IS_BETTER` and `SPECIFIED` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-comparativeorder.html#cfn-quicksight-topic-comparativeorder-useordering
         */
        readonly useOrdering?: string;
    }
    /**
     * A structure that represents the cell value synonym.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-cellvaluesynonym.html
     */
    interface CellValueSynonymProperty {
        /**
         * The cell value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-cellvaluesynonym.html#cfn-quicksight-topic-cellvaluesynonym-cellvalue
         */
        readonly cellValue?: string;
        /**
         * Other names or aliases for the cell value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-cellvaluesynonym.html#cfn-quicksight-topic-cellvaluesynonym-synonyms
         */
        readonly synonyms?: Array<string>;
    }
    /**
     * Represents a column in a dataset.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccolumn.html
     */
    interface TopicColumnProperty {
        /**
         * The type of aggregation that is performed on the column data when it's queried.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccolumn.html#cfn-quicksight-topic-topiccolumn-aggregation
         */
        readonly aggregation?: string;
        /**
         * The list of aggregation types that are allowed for the column.
         *
         * Valid values for this structure are `COUNT` , `DISTINCT_COUNT` , `MIN` , `MAX` , `MEDIAN` , `SUM` , `AVERAGE` , `STDEV` , `STDEVP` , `VAR` , `VARP` , and `PERCENTILE` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccolumn.html#cfn-quicksight-topic-topiccolumn-allowedaggregations
         */
        readonly allowedAggregations?: Array<string>;
        /**
         * The other names or aliases for the column cell value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccolumn.html#cfn-quicksight-topic-topiccolumn-cellvaluesynonyms
         */
        readonly cellValueSynonyms?: Array<CfnTopic.CellValueSynonymProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The role of the column in the data.
         *
         * Valid values are `DIMENSION` and `MEASURE` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccolumn.html#cfn-quicksight-topic-topiccolumn-columndatarole
         */
        readonly columnDataRole?: string;
        /**
         * A description of the column and its contents.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccolumn.html#cfn-quicksight-topic-topiccolumn-columndescription
         */
        readonly columnDescription?: string;
        /**
         * A user-friendly name for the column.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccolumn.html#cfn-quicksight-topic-topiccolumn-columnfriendlyname
         */
        readonly columnFriendlyName?: string;
        /**
         * The name of the column.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccolumn.html#cfn-quicksight-topic-topiccolumn-columnname
         */
        readonly columnName: string;
        /**
         * The other names or aliases for the column.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccolumn.html#cfn-quicksight-topic-topiccolumn-columnsynonyms
         */
        readonly columnSynonyms?: Array<string>;
        /**
         * The order in which data is displayed for the column when it's used in a comparative context.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccolumn.html#cfn-quicksight-topic-topiccolumn-comparativeorder
         */
        readonly comparativeOrder?: CfnTopic.ComparativeOrderProperty | cdk.IResolvable;
        /**
         * The default formatting used for values in the column.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccolumn.html#cfn-quicksight-topic-topiccolumn-defaultformatting
         */
        readonly defaultFormatting?: CfnTopic.DefaultFormattingProperty | cdk.IResolvable;
        /**
         * A Boolean value that indicates whether the column is included in the query results.
         *
         * @default - false
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccolumn.html#cfn-quicksight-topic-topiccolumn-isincludedintopic
         */
        readonly isIncludedInTopic?: boolean | cdk.IResolvable;
        /**
         * A Boolean value that indicates whether to aggregate the column data when it's used in a filter context.
         *
         * @default - false
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccolumn.html#cfn-quicksight-topic-topiccolumn-neveraggregateinfilter
         */
        readonly neverAggregateInFilter?: boolean | cdk.IResolvable;
        /**
         * The non additive value for the column.
         *
         * @default - false
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccolumn.html#cfn-quicksight-topic-topiccolumn-nonadditive
         */
        readonly nonAdditive?: boolean | cdk.IResolvable;
        /**
         * The list of aggregation types that are not allowed for the column.
         *
         * Valid values for this structure are `COUNT` , `DISTINCT_COUNT` , `MIN` , `MAX` , `MEDIAN` , `SUM` , `AVERAGE` , `STDEV` , `STDEVP` , `VAR` , `VARP` , and `PERCENTILE` .
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccolumn.html#cfn-quicksight-topic-topiccolumn-notallowedaggregations
         */
        readonly notAllowedAggregations?: Array<string>;
        /**
         * The semantic type of data contained in the column.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccolumn.html#cfn-quicksight-topic-topiccolumn-semantictype
         */
        readonly semanticType?: cdk.IResolvable | CfnTopic.SemanticTypeProperty;
        /**
         * The level of time precision that is used to aggregate `DateTime` values.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccolumn.html#cfn-quicksight-topic-topiccolumn-timegranularity
         */
        readonly timeGranularity?: string;
    }
    /**
     * The definition of a data aggregation.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-dataaggregation.html
     */
    interface DataAggregationProperty {
        /**
         * The level of time precision that is used to aggregate `DateTime` values.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-dataaggregation.html#cfn-quicksight-topic-dataaggregation-datasetrowdategranularity
         */
        readonly datasetRowDateGranularity?: string;
        /**
         * The column name for the default date.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-dataaggregation.html#cfn-quicksight-topic-dataaggregation-defaultdatecolumnname
         */
        readonly defaultDateColumnName?: string;
    }
}
/**
 * Properties for defining a `CfnTopic`
 *
 * @struct
 * @stability external
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-topic.html
 */
export interface CfnTopicProps {
    /**
     * The ID of the AWS account that you want to create a topic in.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-topic.html#cfn-quicksight-topic-awsaccountid
     */
    readonly awsAccountId?: string;
    /**
     * The data sets that the topic is associated with.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-topic.html#cfn-quicksight-topic-datasets
     */
    readonly dataSets?: Array<CfnTopic.DatasetMetadataProperty | cdk.IResolvable> | cdk.IResolvable;
    /**
     * The description of the topic.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-topic.html#cfn-quicksight-topic-description
     */
    readonly description?: string;
    /**
     * The name of the topic.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-topic.html#cfn-quicksight-topic-name
     */
    readonly name?: string;
    /**
     * The ID for the topic.
     *
     * This ID is unique per AWS Region for each AWS account.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-topic.html#cfn-quicksight-topic-topicid
     */
    readonly topicId?: string;
    /**
     * The user experience version of a topic.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-topic.html#cfn-quicksight-topic-userexperienceversion
     */
    readonly userExperienceVersion?: string;
}
/**
 * Creates a new VPC connection.
 *
 * @cloudformationResource AWS::QuickSight::VPCConnection
 * @stability external
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-vpcconnection.html
 */
export declare class CfnVPCConnection extends cdk.CfnResource implements cdk.IInspectable, cdk.ITaggable {
    /**
     * The CloudFormation resource type name for this resource class.
     */
    static readonly CFN_RESOURCE_TYPE_NAME: string;
    /**
     * Build a CfnVPCConnection from CloudFormation properties
     *
     * A factory method that creates a new instance of this class from an object
     * containing the CloudFormation properties of this resource.
     * Used in the @aws-cdk/cloudformation-include module.
     *
     * @internal
     */
    static _fromCloudFormation(scope: constructs.Construct, id: string, resourceAttributes: any, options: cfn_parse.FromCloudFormationOptions): CfnVPCConnection;
    /**
     * The Amazon Resource Name (ARN) of the VPC connection.
     *
     * @cloudformationAttribute Arn
     */
    readonly attrArn: string;
    /**
     * The time that the VPC connection was created.
     *
     * @cloudformationAttribute CreatedTime
     */
    readonly attrCreatedTime: string;
    /**
     * The time that the VPC connection was last updated.
     *
     * @cloudformationAttribute LastUpdatedTime
     */
    readonly attrLastUpdatedTime: string;
    /**
     * A list of network interfaces.
     *
     * @cloudformationAttribute NetworkInterfaces
     */
    readonly attrNetworkInterfaces: cdk.IResolvable;
    /**
     * The HTTP status of the request.
     *
     * @cloudformationAttribute Status
     */
    readonly attrStatus: string;
    /**
     * The Amazon EC2 VPC ID associated with the VPC connection.
     *
     * @cloudformationAttribute VPCId
     */
    readonly attrVpcId: string;
    /**
     * The availability status of the VPC connection.
     */
    availabilityStatus?: string;
    /**
     * The AWS account ID of the account where you want to create a new VPC connection.
     */
    awsAccountId?: string;
    /**
     * A list of IP addresses of DNS resolver endpoints for the VPC connection.
     */
    dnsResolvers?: Array<string>;
    /**
     * The display name for the VPC connection.
     */
    name?: string;
    /**
     * The ARN of the IAM role associated with the VPC connection.
     */
    roleArn?: string;
    /**
     * The Amazon EC2 security group IDs associated with the VPC connection.
     */
    securityGroupIds?: Array<string>;
    /**
     * A list of subnet IDs for the VPC connection.
     */
    subnetIds?: Array<string>;
    /**
     * Tag Manager which manages the tags for this resource
     */
    readonly tags: cdk.TagManager;
    /**
     * A map of the key-value pairs for the resource tag or tags assigned to the VPC connection.
     */
    tagsRaw?: Array<cdk.CfnTag>;
    /**
     * The ID of the VPC connection that you're creating.
     */
    vpcConnectionId?: string;
    /**
     * @param scope Scope in which this resource is defined
     * @param id Construct identifier for this resource (unique in its scope)
     * @param props Resource properties
     */
    constructor(scope: constructs.Construct, id: string, props?: CfnVPCConnectionProps);
    protected get cfnProperties(): Record<string, any>;
    /**
     * Examines the CloudFormation resource and discloses attributes
     *
     * @param inspector tree inspector to collect and process attributes
     */
    inspect(inspector: cdk.TreeInspector): void;
    protected renderProperties(props: Record<string, any>): Record<string, any>;
}
export declare namespace CfnVPCConnection {
    /**
     * The structure that contains information about a network interface.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-vpcconnection-networkinterface.html
     */
    interface NetworkInterfaceProperty {
        /**
         * The availability zone that the network interface resides in.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-vpcconnection-networkinterface.html#cfn-quicksight-vpcconnection-networkinterface-availabilityzone
         */
        readonly availabilityZone?: string;
        /**
         * An error message.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-vpcconnection-networkinterface.html#cfn-quicksight-vpcconnection-networkinterface-errormessage
         */
        readonly errorMessage?: string;
        /**
         * The network interface ID.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-vpcconnection-networkinterface.html#cfn-quicksight-vpcconnection-networkinterface-networkinterfaceid
         */
        readonly networkInterfaceId?: string;
        /**
         * The status of the network interface.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-vpcconnection-networkinterface.html#cfn-quicksight-vpcconnection-networkinterface-status
         */
        readonly status?: string;
        /**
         * The subnet ID associated with the network interface.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-vpcconnection-networkinterface.html#cfn-quicksight-vpcconnection-networkinterface-subnetid
         */
        readonly subnetId?: string;
    }
}
/**
 * Properties for defining a `CfnVPCConnection`
 *
 * @struct
 * @stability external
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-vpcconnection.html
 */
export interface CfnVPCConnectionProps {
    /**
     * The availability status of the VPC connection.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-vpcconnection.html#cfn-quicksight-vpcconnection-availabilitystatus
     */
    readonly availabilityStatus?: string;
    /**
     * The AWS account ID of the account where you want to create a new VPC connection.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-vpcconnection.html#cfn-quicksight-vpcconnection-awsaccountid
     */
    readonly awsAccountId?: string;
    /**
     * A list of IP addresses of DNS resolver endpoints for the VPC connection.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-vpcconnection.html#cfn-quicksight-vpcconnection-dnsresolvers
     */
    readonly dnsResolvers?: Array<string>;
    /**
     * The display name for the VPC connection.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-vpcconnection.html#cfn-quicksight-vpcconnection-name
     */
    readonly name?: string;
    /**
     * The ARN of the IAM role associated with the VPC connection.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-vpcconnection.html#cfn-quicksight-vpcconnection-rolearn
     */
    readonly roleArn?: string;
    /**
     * The Amazon EC2 security group IDs associated with the VPC connection.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-vpcconnection.html#cfn-quicksight-vpcconnection-securitygroupids
     */
    readonly securityGroupIds?: Array<string>;
    /**
     * A list of subnet IDs for the VPC connection.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-vpcconnection.html#cfn-quicksight-vpcconnection-subnetids
     */
    readonly subnetIds?: Array<string>;
    /**
     * A map of the key-value pairs for the resource tag or tags assigned to the VPC connection.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-vpcconnection.html#cfn-quicksight-vpcconnection-tags
     */
    readonly tags?: Array<cdk.CfnTag>;
    /**
     * The ID of the VPC connection that you're creating.
     *
     * This ID is a unique identifier for each AWS Region in an AWS account.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-vpcconnection.html#cfn-quicksight-vpcconnection-vpcconnectionid
     */
    readonly vpcConnectionId?: string;
}
